from __future__ import annotations

from typing import *


Unknown = Any

_T = TypeVar("_T")

Queryable = Union[bool, _T]
Multiuse = Union[_T, List[_T]]
Range = Union[Tuple[_T], Tuple[_T, _T]]
NullableRange = Range[Optional[_T]]

def aaf2fcp(*, deleteFile: bool = ..., dstPath: str = ..., getFileName: int = ..., progress: int = ..., srcFile: str = ..., terminate: int = ..., waitCompletion: int = ...) -> str:
    """This command is used to convert an aff file to a Final Cut Pro (fcp) xml file
    The conversion process can take several seconds to complete and the command is meant
    to be run asynchronouslyutility, aaf, fcp
    Args:
        deleteFile (bool?): Delete temporary file. Can only be used with the terminate option  
                Properties: create
        dstPath (str?): Specifiy a destination path  
                Properties: create
        getFileName (int?): Query output file name  
                Properties: create
        progress (int?): Request progress report  
                Properties: create
        srcFile (str?): Specifiy a source file  
                Properties: create
        terminate (int?): Complete the task  
                Properties: create
        waitCompletion (int?): Wait for the conversion process to complete  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def about(*, apiVersion: bool = ..., application: bool = ..., arm64: bool = ..., batch: bool = ..., buildDirectory: bool = ..., buildVariant: bool = ..., codeset: bool = ..., compositingManager: bool = ..., connected: bool = ..., creativeVersion: bool = ..., ctime: bool = ..., currentDate: bool = ..., currentTime: bool = ..., customVersion: bool = ..., customVersionClient: bool = ..., customVersionMajor: bool = ..., customVersionMinor: bool = ..., customVersionString: bool = ..., cutIdentifier: bool = ..., date: bool = ..., environmentFile: bool = ..., evalVersion: bool = ..., file: bool = ..., fontInfo: bool = ..., helpDataDirectory: bool = ..., installedVersion: bool = ..., ioVersion: bool = ..., irix: bool = ..., is64: bool = ..., languageResources: bool = ..., linux: bool = ..., linux64: bool = ..., liveUpdate: bool = ..., localizedResourceLocation: bool = ..., ltVersion: bool = ..., macOS: bool = ..., macOSASi: bool = ..., macOSppc: bool = ..., macOSx86: bool = ..., majorVersion: bool = ..., minorVersion: bool = ..., ntOS: bool = ..., operatingSystem: bool = ..., operatingSystemVersion: bool = ..., patchVersion: bool = ..., preferences: bool = ..., product: bool = ..., qtVersion: bool = ..., tablet: bool = ..., tabletMode: bool = ..., uiLanguage: bool = ..., uiLanguageForStartup: bool = ..., uiLanguageIsLocalized: bool = ..., uiLocaleLanguage: bool = ..., version: bool = ..., win64: bool = ..., windowManager: bool = ..., windows: bool = ...) -> str:
    """This command displays version information about the application if it is
    executed without flags.  If one of the above flags is specified
    then the specified version information is returned.
    Args:
        apiVersion (bool?): Returns the api version.  
                Properties: create
        application (bool?): Returns the application name string.  
                Properties: create
        arm64 (bool?): Returns true if the CPU is arm64 based.  
                Properties: create
        batch (bool?): Returns true if application is in batch mode.  
                Properties: create
        buildDirectory (bool?): Returns the build directory string.  
                Properties: create
        buildVariant (bool?): Returns the build variant string.  
                Properties: create
        codeset (bool?): Returns a string identifying the codeset (codepage) of the  
                locale that Maya is running in.  
                Example return values include "UTF-8", "ISO-8859. 1", "1252".  
                Note that the codeset values and naming conventions  
                are highly platform dependent.  They may differ in format  
                even if they have the same meaning (e.g. "utf8" vs. "UTF-8").  
                Properties: create
        compositingManager (bool?): On Linux, returns true if there is a compositing manager running; on  
                all other platforms, it always returns true.  
                Properties: create
        connected (bool?): Return whether the user is connected or not to the Internet.  
                Properties: create
        creativeVersion (bool?): Returns true if this is the Maya Creative version of the application.  
                Properties: create
        ctime (bool?): Returns the current time in the format Wed Jan 02 02. 03. 55 1980  
                Properties: create
        currentDate (bool?): Returns the current date in the format yyyy/mm/dd, e.g. 2003/05/04.  
                Properties: create
        currentTime (bool?): Returns the current time in the format hh:mm:ss, e.g. 14. 27. 53.  
                Properties: create
        customVersion (bool?): Returns true if this is a custom version of Maya.  
                Properties: create
        customVersionClient (bool?): Returns the custom client version string for Maya  
                or an empty string if this is not a custom version.  
                Properties: create
        customVersionMajor (bool?): Returns the custom major version of Maya  
                or 0 if this is not a custom version.  
                Properties: create
        customVersionMinor (bool?): Returns the custom minor version of Maya  
                or 0 if this is not a custom version.  
                Properties: create
        customVersionString (bool?): Returns the custom version string for Maya  
                or an empty string if this is not a custom version.  
                Properties: create
        cutIdentifier (bool?): Returns the cut string.  
                Properties: create
        date (bool?): Returns the build date string.  
                Properties: create
        environmentFile (bool?): Returns the location of the application defaults file.  
                Properties: create
        evalVersion (bool?): This flag is now deprecated. Always returns false, as the eval version is no longer supported.  
                Properties: create
        file (bool?): Returns the file version string.  
                Properties: create
        fontInfo (bool?): Returns a string of the specifications of the  
                fonts requested, and the specifications of the  
                fonts that are actually being used.  
                Properties: create
        helpDataDirectory (bool?): Returns the help data directory.  
                Properties: create
        installedVersion (bool?): Returns the product version string.  
                Properties: create
        ioVersion (bool?): Returns true if this is the Maya IO version of the application.  
                Properties: create
        irix (bool?): Returns true if the operating system is Irix.  
                Always false with support for Irix removed.  
                Properties: create
        is64 (bool?): Returns true if the application is 64 bit.  
                Properties: create
        languageResources (bool?): Returns a string array of the currently installed language resources.  
                Each string entry consists of three elements delimited with a colon (':').  
                The first token is the locale code (ISO 639. 1 language code followed by ISO 3166. 1 country code).  The second token is the language name in English.  
                This third token is the alpha-3 code (ISO 639. 2).  For example English is  
                represented as "en_US:English:enu".  
                Properties: create
        linux (bool?): Returns true if the operating system is Linux.  
                Properties: create
        linux64 (bool?): Returns true if the operating system is Linux 64 bit.  
                Properties: create
        liveUpdate (bool?): This flag is deprecated(2019) and may be removed in future releases of Maya.  
                Returns Autodesk formatted product information.  
                Properties: create
        localizedResourceLocation (bool?): Returns the path to the top level of the localized resource  
                directory, if we are running in an alternate language.  
                Returns an empty string if we are running in the default  
                language.  
                Properties: create
        ltVersion (bool?): Deprecated.  
                Returns true if this is the Maya LT version of the application.  
                Properties: create
        macOS (bool?): Returns true if the operating system is Macintosh.  
                Properties: create
        macOSASi (bool?): Returns true if the operating system is an Apple Silicon Mac.  
                Properties: create
        macOSppc (bool?): Returns true if the operating system is a PowerPC Macintosh.  
                Properties: create
        macOSx86 (bool?): Returns true if the operating system is an Intel Macintosh.  
                Properties: create
        majorVersion (bool?): Returns the major version of Maya.  
                Properties: create
        minorVersion (bool?): Returns the minor version of Maya.  
                Properties: create
        ntOS (bool?): Returns true if the operating system is Windows.  
                Properties: create
        operatingSystem (bool?): Returns the operating system type. Valid return types are  
                "nt", "win64", "mac", "linux" and "linux64"  
                Properties: create
        operatingSystemVersion (bool?): Returns the operating system version.  
                on Linux this returns the equivalent of uname -srvm  
                Properties: create
        patchVersion (bool?): Returns the patch version of Maya.  
                Properties: create
        preferences (bool?): Returns the location of the preferences directory.  
                Properties: create
        product (bool?): Returns the license product name.  
                Properties: create
        qtVersion (bool?): Returns Qt version string.  
                Properties: create
        tablet (bool?): Windows only.  Returns true if the PC is a Tablet PC.  
                Properties: create
        tabletMode (bool?): Windows 8 (and above) only.  If your device is a Tablet PC, then the convertible  
                mode the device is currently running in.  Returns  either: tablet or laptop (keyboard attached).  
                See the tablet flag.  
                Properties: create
        uiLanguage (bool?): Returns the language that Maya's running in.  Example return  
                values include "en_US" for English and "ja_JP" for Japanese.  
                Properties: create
        uiLanguageForStartup (bool?): Returns the language that is used for Maya's next start up.  
                This is read from config file and is rewritten after setting  
                ui language in preference.  
                Properties: create
        uiLanguageIsLocalized (bool?): Returns true if we are running in an alternate  
                language, not the default (English).  
                Properties: create
        uiLocaleLanguage (bool?): Returns the language locale of the OS. English is default.  
                Properties: create
        version (bool?): Returns the version string.  
                Properties: create
        win64 (bool?): Returns true if the operating system is Windows x64 based.  
                Properties: create
        windowManager (bool?): Returns the name of the Window Manager that is  
                assumed to be running.  
                Properties: create
        windows (bool?): Returns true if the operating system is Windows based.  
                Properties: create

    Returns:
        str: The application's version information.

    Example:
    """

def addAttr(*args: str, edit: bool = ..., query: bool = ..., attributeType: Queryable[str] = ..., binaryTag: Queryable[str] = ..., cachedInternally: bool = ..., category: Queryable[Multiuse[str]] = ..., dataType: Queryable[Multiuse[str]] = ..., defaultValue: Queryable[float] = ..., disconnectBehaviour: Queryable[int] = ..., enumName: Queryable[str] = ..., exists: bool = ..., fromPlugin: bool = ..., hasMaxValue: bool = ..., hasMinValue: bool = ..., hasSoftMaxValue: bool = ..., hasSoftMinValue: bool = ..., hidden: bool = ..., indexMatters: bool = ..., internalSet: bool = ..., keyable: bool = ..., longName: Queryable[str] = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., multi: bool = ..., niceName: Queryable[str] = ..., numberOfChildren: Queryable[int] = ..., parent: Queryable[str] = ..., proxy: Queryable[str] = ..., readable: bool = ..., shortName: Queryable[str] = ..., softMaxValue: Queryable[float] = ..., softMinValue: Queryable[float] = ..., storable: bool = ..., usedAsColor: bool = ..., usedAsFilename: bool = ..., usedAsProxy: bool = ..., worldSpace: bool = ..., writable: bool = ...) -> Union[bool, str, Multiuse[str], float, int]:
    """This command is used to add a dynamic attribute to a node or nodes.
    Either the longName or the shortName or both must be specified.
    If neither a dataType nor an attributeType is specified, a double
    attribute will be added.  The dataType flag can be specified more than
    once indicating that any of the supplied types will be accepted (logical-or).To add a non-double attribute the following criteria
    can be used to determine whether the dataType or the attributeType
    flag is appropriate.  Some types, such ascan use either.
    In these cases theflag should be used when you only wish to
    access the data as an atomic entity (eg. you never want to access the
    three individual values that make up a).  In general it
    is best to use thein these cases for maximum flexibility.
    In most cases theversion will not display in the attribute
    editor as it is an atomic type and you are not allowed to change
    individual parts of it.All attributes flagged as "(compound)" below or the compound attribute itself
    are not actually added to the node until all of the children are defined
    (using the "-p" flag to set their parent to the compound being created).  See
    the EXAMPLES section for more details.attribute, dependency, graph, add, dynamic, create
    Args:
        attributeType (Queryable[str]?): Specifies the attribute type, see above table for more details.  
                Note that the attribute types "float", "matrix" and "string"  
                are also MEL keywords and must be enclosed in quotes.  
                Properties: create, query
        binaryTag (Queryable[str]?): This flag is obsolete and does not do anything any more  
                Properties: create, query
        cachedInternally (bool?): Whether or not attribute data is cached internally in the node.  
                This flag defaults to true for writable attributes and false  
                for non-writable attributes. A warning will be issued if  
                users attempt to force a writable attribute to be uncached as  
                this will make it impossible to set keyframes.  
                Properties: create, query
        category (Queryable[Multiuse[str]]?): An attribute category is a string associated with the attribute to identify it.  
                (e.g. the name of a plugin that created the attribute, version information, etc.)  
                Any attribute can be associated with an arbitrary number of categories however  
                categories can not be removed once associated.  
                Properties: create, query, edit, multiuse
        dataType (Queryable[Multiuse[str]]?): Specifies the data type.  See "setAttr" for  
                more information on data type names.  
                Properties: create, query, multiuse
        defaultValue (Queryable[float]?): Specifies the default value for the attribute  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        disconnectBehaviour (Queryable[int]?): defines the Disconnect Behaviour 2 Nothing, 1 Reset, 0 Delete  
                Properties: create, query
        enumName (Queryable[str]?): Flag used to specify the ui names corresponding to the enum values. The specified string should contain a colon-separated list of the names, with optional values. If values are not specified, they will treated as sequential integers starting with 0. For example: -enumName "A:B:C" would produce options: A,B,C with values of 0,1,2; -enumName "zero:one:two:thousand=1000" would produce four options with values 0,1,2,1000; and -enumName "solo=1. triplet=3. quintet=5" would produce three options with values 1,3,5.  (Note that there is a current limitation of the Channel Box that will sometimes incorrectly display an enumerated attribute's pull-down menu.  Extra menu items can appear that represent the numbers inbetween non-sequential option values.  To avoid this limitation, specify sequential values for the options of any enumerated attributes that will appear in the Channel Box.  For example: "solo=1. triplet=2. quintet=3".)  
                Properties: create, query, edit
        exists (bool?): Returns true if the attribute queried is a user-added, dynamic attribute; false if not.  
                Properties: create, query
        fromPlugin (bool?): Was the attribute originally created by a plugin? Normally set  
                automatically when the API call is made - only added here to support  
                storing it in a file independently from the creating plugin.  
                Properties: create, query
        hasMaxValue (bool?): Flag indicating whether an attribute has a maximum value.  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        hasMinValue (bool?): Flag indicating whether an attribute has a minimum value.  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        hasSoftMaxValue (bool?): Flag indicating whether a numeric attribute has a soft maximum.  
                Properties: create, query
        hasSoftMinValue (bool?): Flag indicating whether a numeric attribute has a soft minimum.  
                Properties: create, query
        hidden (bool?): Will this attribute be hidden from the UI?  
                Properties: create, query
        indexMatters (bool?): Sets whether an index must be used when connecting  
                to this multi-attribute. Setting indexMatters to false forces the  
                attribute to non-readable.  
                Properties: create, query
        internalSet (bool?): Whether or not the internal cached value is set when  
                this attribute value is changed.  This is an internal flag  
                used for updating UI elements.  
                Properties: create, query
        keyable (bool?): Is the attribute keyable by default?  
                Properties: create, query
        longName (Queryable[str]?): Sets the long name of the attribute.  
                Properties: create, query
        maxValue (Queryable[float]?): Specifies the maximum value for the attribute  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        minValue (Queryable[float]?): Specifies the minimum value for the attribute  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        multi (bool?): Makes the new attribute a multi-attribute.  
                Properties: create, query
        niceName (Queryable[str]?): Sets the nice name of the attribute for display in the UI.  Setting the  
                attribute's nice name to a non-empty string overrides the default  
                behaviour of looking up the nice name from Maya's  
                string catalog.   (Use the MEL commands  
                "attributeNiceName" and "attributeQuery -niceName" to lookup an attribute's  
                nice name in the catalog.)  
                Properties: create, query, edit
        numberOfChildren (Queryable[int]?): How many children will the new attribute have?  
                Properties: create, query
        parent (Queryable[str]?): Attribute that is to be the new attribute's parent.  
                Properties: create, query
        proxy (Queryable[str]?): Proxy another node's attribute. Proxied plug will be connected as source. The UsedAsProxy flag is automatically set in this case.  
                Properties: create, query
        readable (bool?): Can outgoing connections be made from this attribute?  
                Properties: create, query
        shortName (Queryable[str]?): Sets the short name of the attribute.  
                Properties: create, query
        softMaxValue (Queryable[float]?): Soft maximum, valid for numeric attributes only.  Specifies the  
                upper default limit used in sliders for this attribute.  
                Properties: create, query, edit
        softMinValue (Queryable[float]?): Soft minimum, valid for numeric attributes only.  Specifies the  
                lower default limit used in sliders for this attribute.  
                Properties: create, query, edit
        storable (bool?): Can the attribute be stored out to a file?  
                Properties: create, query
        usedAsColor (bool?): Is the attribute to be used as a color definition?  
                Must have 3 DOUBLE or 3 FLOAT children to use this  
                flag.  The attribute type "-at" should be "double3"  
                or "float3" as appropriate.  It can also be used to  
                less effect with data types "-dt" as "double3" or  
                "float3" as well but some parts of the code do not  
                support this alternative.  The special attribute  
                types/data "spectrum" and "reflectance" also support  
                the color flag and on them it is set by default.  
                Properties: create, query
        usedAsFilename (bool?): Is the attribute to be treated as a filename definition?  
                This flag is only supported on attributes with data type "-dt" of "string".  
                Properties: create, query
        usedAsProxy (bool?): Set if the specified attribute should be treated as a proxy to another attributes.  
                Properties: create, query
        worldSpace (bool?): Sets whether this attribute should be treated as worldspace.  
                Being worldspace indicates the attribute is dependent on the worldSpace  
                transformation of this node, and will be marked dirty by any attribute  
                changes in the hierarchy that affects the worldSpace transformation. The  
                attribute needs to be an array since during instancing there are  
                multiple worldSpace paths to the node and Maya requires one array element  
                per path for worldSpace attributes. Remarks:  
                1. Can only be used on array attributes.  
                2. This property is ignored on non-dag nodes.  
                3. The attribute should be affected by another attribute or have a connection.  
                   Otherwise, the attribute will not get computed and will not get dirty again.  
                Properties: create, query
        writable (bool?): Can incoming connections be made to this attribute?  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def addDynamic(*args: str) -> str:
    """Makes the "object" specified as second argument the source of an
    existing field or emitter specified as the first argument. In
    practical terms, what this means is that a field will emanate its
    force from its owner object, and an emitter will emit from its owner
    object.addDynamic makes the specified field or emitter a child of
    the owner's transform (adding it to the model if it was not already
    there), and makes the necessary attribute connections.If either of the arguments is omitted, addDynamic searches the
    selection list for objects to use instead. If more than one possible
    owner or field/emitter is selected, addDynamic will do
    nothing.If the specified field/emitter already has a source, addDynamic will
    remove the current source and replace it with the newly specified
    source.If a subset of the owner object's cvs/particles/vertices is selected,
    addDynamic will add the field/emitter to that subset only.
    Returns:
        str: The name of the source object and the field or emitter which was
            attached to it.

    Example:
    """

def addDynamicAttribute() -> None: ...
def addExtension(*, edit: bool = ..., query: bool = ..., nodeType: Queryable[str] = ..., attributeType: Queryable[str] = ..., binaryTag: Queryable[str] = ..., cachedInternally: bool = ..., category: Queryable[Multiuse[str]] = ..., dataType: Queryable[Multiuse[str]] = ..., defaultValue: Queryable[float] = ..., disconnectBehaviour: Queryable[int] = ..., enumName: Queryable[str] = ..., exists: bool = ..., fromPlugin: bool = ..., hasMaxValue: bool = ..., hasMinValue: bool = ..., hasSoftMaxValue: bool = ..., hasSoftMinValue: bool = ..., hidden: bool = ..., indexMatters: bool = ..., internalSet: bool = ..., keyable: bool = ..., longName: Queryable[str] = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., multi: bool = ..., niceName: Queryable[str] = ..., numberOfChildren: Queryable[int] = ..., parent: Queryable[str] = ..., proxy: Queryable[str] = ..., readable: bool = ..., shortName: Queryable[str] = ..., softMaxValue: Queryable[float] = ..., softMinValue: Queryable[float] = ..., storable: bool = ..., usedAsColor: bool = ..., usedAsFilename: bool = ..., usedAsProxy: bool = ..., worldSpace: bool = ..., writable: bool = ...) -> Union[bool, str, Multiuse[str], float, int]:
    """This command is used to add an extension attribute to a node type.
    Either the longName or the shortName or both must be specified.
    If neither a dataType nor an attributeType is specified, a double
    attribute will be added.  The dataType flag can be specified more than
    once indicating that any of the supplied types will be accepted (logical-or).To add a non-double attribute the following criteria
    can be used to determine whether the dataType or the attributeType
    flag is appropriate.  Some types, such ascan use either.
    In these cases theflag should be used when you only wish to
    access the data as an atomic entity (eg. you never want to access the
    three individual values that make up a).  In general it
    is best to use thein these cases for maximum flexibility.
    In most cases theversion will not display in the attribute
    editor as it is an atomic type and you are not allowed to change
    individual parts of it.All attributes flagged as "(compound)" below or the compound attribute itself
    are not actually added to the node until all of the children are defined
    (using the "-p" flag to set their parent to the compound being created).  See
    the EXAMPLES section for more details.attribute, dependency, graph, add, dynamic, create
    Args:
        nodeType (Queryable[str]?): Specifies the type of node to which the attribute will be added.  
                See the nodeType command for the names of different node types.  
                Properties: create, query, edit
        attributeType (Queryable[str]?): Specifies the attribute type, see above table for more details.  
                Note that the attribute types "float", "matrix" and "string"  
                are also MEL keywords and must be enclosed in quotes.  
                Properties: create, query
        binaryTag (Queryable[str]?): This flag is obsolete and does not do anything any more  
                Properties: create, query
        cachedInternally (bool?): Whether or not attribute data is cached internally in the node.  
                This flag defaults to true for writable attributes and false  
                for non-writable attributes. A warning will be issued if  
                users attempt to force a writable attribute to be uncached as  
                this will make it impossible to set keyframes.  
                Properties: create, query
        category (Queryable[Multiuse[str]]?): An attribute category is a string associated with the attribute to identify it.  
                (e.g. the name of a plugin that created the attribute, version information, etc.)  
                Any attribute can be associated with an arbitrary number of categories however  
                categories can not be removed once associated.  
                Properties: create, query, edit, multiuse
        dataType (Queryable[Multiuse[str]]?): Specifies the data type.  See "setAttr" for  
                more information on data type names.  
                Properties: create, query, multiuse
        defaultValue (Queryable[float]?): Specifies the default value for the attribute  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        disconnectBehaviour (Queryable[int]?): defines the Disconnect Behaviour 2 Nothing, 1 Reset, 0 Delete  
                Properties: create, query
        enumName (Queryable[str]?): Flag used to specify the ui names corresponding to the enum values. The specified string should contain a colon-separated list of the names, with optional values. If values are not specified, they will treated as sequential integers starting with 0. For example: -enumName "A:B:C" would produce options: A,B,C with values of 0,1,2; -enumName "zero:one:two:thousand=1000" would produce four options with values 0,1,2,1000; and -enumName "solo=1. triplet=3. quintet=5" would produce three options with values 1,3,5.  (Note that there is a current limitation of the Channel Box that will sometimes incorrectly display an enumerated attribute's pull-down menu.  Extra menu items can appear that represent the numbers inbetween non-sequential option values.  To avoid this limitation, specify sequential values for the options of any enumerated attributes that will appear in the Channel Box.  For example: "solo=1. triplet=2. quintet=3".)  
                Properties: create, query, edit
        exists (bool?): Returns true if the attribute queried is a user-added, dynamic attribute; false if not.  
                Properties: create, query
        fromPlugin (bool?): Was the attribute originally created by a plugin? Normally set  
                automatically when the API call is made - only added here to support  
                storing it in a file independently from the creating plugin.  
                Properties: create, query
        hasMaxValue (bool?): Flag indicating whether an attribute has a maximum value.  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        hasMinValue (bool?): Flag indicating whether an attribute has a minimum value.  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        hasSoftMaxValue (bool?): Flag indicating whether a numeric attribute has a soft maximum.  
                Properties: create, query
        hasSoftMinValue (bool?): Flag indicating whether a numeric attribute has a soft minimum.  
                Properties: create, query
        hidden (bool?): Will this attribute be hidden from the UI?  
                Properties: create, query
        indexMatters (bool?): Sets whether an index must be used when connecting  
                to this multi-attribute. Setting indexMatters to false forces the  
                attribute to non-readable.  
                Properties: create, query
        internalSet (bool?): Whether or not the internal cached value is set when  
                this attribute value is changed.  This is an internal flag  
                used for updating UI elements.  
                Properties: create, query
        keyable (bool?): Is the attribute keyable by default?  
                Properties: create, query
        longName (Queryable[str]?): Sets the long name of the attribute.  
                Properties: create, query
        maxValue (Queryable[float]?): Specifies the maximum value for the attribute  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        minValue (Queryable[float]?): Specifies the minimum value for the attribute  
                (can only be used for numeric attributes).  
                Properties: create, query, edit
        multi (bool?): Makes the new attribute a multi-attribute.  
                Properties: create, query
        niceName (Queryable[str]?): Sets the nice name of the attribute for display in the UI.  Setting the  
                attribute's nice name to a non-empty string overrides the default  
                behaviour of looking up the nice name from Maya's  
                string catalog.   (Use the MEL commands  
                "attributeNiceName" and "attributeQuery -niceName" to lookup an attribute's  
                nice name in the catalog.)  
                Properties: create, query, edit
        numberOfChildren (Queryable[int]?): How many children will the new attribute have?  
                Properties: create, query
        parent (Queryable[str]?): Attribute that is to be the new attribute's parent.  
                Properties: create, query
        proxy (Queryable[str]?): Proxy another node's attribute. Proxied plug will be connected as source. The UsedAsProxy flag is automatically set in this case.  
                Properties: create, query
        readable (bool?): Can outgoing connections be made from this attribute?  
                Properties: create, query
        shortName (Queryable[str]?): Sets the short name of the attribute.  
                Properties: create, query
        softMaxValue (Queryable[float]?): Soft maximum, valid for numeric attributes only.  Specifies the  
                upper default limit used in sliders for this attribute.  
                Properties: create, query, edit
        softMinValue (Queryable[float]?): Soft minimum, valid for numeric attributes only.  Specifies the  
                lower default limit used in sliders for this attribute.  
                Properties: create, query, edit
        storable (bool?): Can the attribute be stored out to a file?  
                Properties: create, query
        usedAsColor (bool?): Is the attribute to be used as a color definition?  
                Must have 3 DOUBLE or 3 FLOAT children to use this  
                flag.  The attribute type "-at" should be "double3"  
                or "float3" as appropriate.  It can also be used to  
                less effect with data types "-dt" as "double3" or  
                "float3" as well but some parts of the code do not  
                support this alternative.  The special attribute  
                types/data "spectrum" and "reflectance" also support  
                the color flag and on them it is set by default.  
                Properties: create, query
        usedAsFilename (bool?): Is the attribute to be treated as a filename definition?  
                This flag is only supported on attributes with data type "-dt" of "string".  
                Properties: create, query
        usedAsProxy (bool?): Set if the specified attribute should be treated as a proxy to another attributes.  
                Properties: create, query
        worldSpace (bool?): Sets whether this attribute should be treated as worldspace.  
                Being worldspace indicates the attribute is dependent on the worldSpace  
                transformation of this node, and will be marked dirty by any attribute  
                changes in the hierarchy that affects the worldSpace transformation. The  
                attribute needs to be an array since during instancing there are  
                multiple worldSpace paths to the node and Maya requires one array element  
                per path for worldSpace attributes. Remarks:  
                1. Can only be used on array attributes.  
                2. This property is ignored on non-dag nodes.  
                3. The attribute should be affected by another attribute or have a connection.  
                   Otherwise, the attribute will not get computed and will not get dirty again.  
                Properties: create, query
        writable (bool?): Can incoming connections be made to this attribute?  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def addMetadata(*args: str, query: bool = ..., channelName: Queryable[str] = ..., channelType: Queryable[str] = ..., indexType: Queryable[str] = ..., scene: bool = ..., streamName: Queryable[str] = ..., structure: Queryable[str] = ...) -> Union[List[str], str, bool]:
    """Defines the attachment of a metadata structure to one or more selected
    objects. This creates a placeholder with an empty metadata Stream for
    later population through thecommand. It's similar
    in concept to thecommand for nodes - a data description
    is added but no data is actually set.When assigning a metadata structure you must specify these flags
    -is the metadata channel type (e.g. "vertex"),is the name of the metadata stream to be created,
    andis the name of the structure type defining the
    contents of the metadata. Theflag is optional.
    If it is not present then the index will be presumed to be a standard
    numerical value.You can query metadata information at a variety of levels. See the
    table below for a full list of the queryable arguments. In each case
    the specification of any of the non-queried arguments filters the list
    of metadata to be examined during the query. For all queries a single
    object must be selected for querying.For example querying theflag with no other
    arguments will return the list of all Channel types on the selected
    object that contain any metadata. Querying theflag
    with theflag specified will return only those
    channel types containing metadata streams that use that particular
    type of index.Flag Combinations:metadata, component, stream, channel, association
    Args:
        channelName (Queryable[str]?): Name of the Channel type to which the structure is to be added (e.g. "vertex").  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        channelType (Queryable[str]?): Obsolete - use the 'channelName' flag instead.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        indexType (Queryable[str]?): Name of the index type the new Channel should be using. If not specified this defaults  
                to a simple numeric index. Of the native types only a mesh "vertexFace" channel is  
                different, using a "pair" index type.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        scene (bool?): Use this flag when you want to add metadata to the scene as a whole rather than to  
                any individual nodes. If you use this flag and have nodes selected the nodes will  
                be ignored and a warning will be displayed.  
                Properties: create, query
        streamName (Queryable[str]?): Name of the empty stream being created. In query mode not specifying a value will  
                return a list of streams on the named channel type.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        structure (Queryable[str]?): Name of the structure which defines the metadata to be attached to the object.  
                In query mode this will return the name of the structure attached at a given  
                stream.  
                			In query mode, this flag can accept a value.  
                Properties: create, query

    Returns:
        List[str]: List of nodes to which a new Stream was successfully added (create mode)
        List[str]: List of channel types containing metadata on an object when querying the channelName flag
        List[str]: List of stream names on an object when querying the streamName flag
        List[str]: List of structures used by an object's metadata Streams when querying the structure flag
        List[str]: List of index types used by an object when querying the indexType flag

    Example:
    """

def addPP(*args: str, attribute: str = ...) -> List[str]:
    """Adds per-point (per-cv, per-vertex, or per-particle) attribute
    capability for an attribute of an emitter or field.  The -atr flag
    identifies the attribute.  If no attribute is named, addPP returns a
    warning and does nothing.The command adds any other necessary attributes wherever they are
    needed, and makes all necessary connections.  If any of the attributes
    already exist, the command simply connects to them.  The command also
    toggles any relevant attributes in the emitter or field to indicate
    that per-point capability is being used.The command adds a separate per-point attribute to the owning object
    for each emitter/field.  For example, for emission rate, there is a
    separate ratePP for each emitter.  These attributes are named
    according to the convention <emitter/field name><attr
    name>PP.  For example, if a particle shape owned an emitter
    "smoke", that shape would get attribute "smokeRatePP."The name of the object must be the emitter or field for which
    per-point capability is to be added (or the name of its parent
    transform).  The addPP command adds the per-point capability for that
    emitter or field but not for any others owned by the same object.  If
    per-point capability is not supported for a named object, the command
    will trigger a warning, but will continue executing for any other
    objects which were valid.If no objects are named, addPP uses any objects in the current
    selection list for which the specified attribute is applicable.  (For
    example, it would add per-point rate for all selected emitters.)If addPP detects that the owner object has left-over attributes from a
    deleted emitter, it will remove those attributes before adding the new
    ones.  Thus, you can delete the emitter, make a new one, and run addPP
    again, and addPP will clean up after the deleted emitter.  This is
    most commonly used if you have a geometry emitter and then decide to
    change the geometry.  Likewise, if addPP detects that some cvs or
    vertices have been added to the geometry, then it will expand the
    corresponding multi-attributes as necessary.  However, if it detects
    that some cvs/vertices have been removed, it will not remove any
    entries from the multi.  See the user manual for more discussion.
    Args:
        attribute (str?): Name of attribute to which you wish to add PP capability.  
                Currently the only attribute supported is rate (for emitters).  
                Properties: create

    Returns:
        List[str]: Returns names of emitters/fields for which the per-point
            capability was added for the specified attribute.

    Example:
    """

def adpAnalyticsDialog(*, activeNotification: bool = ..., desktopAnalytics: bool = ...) -> None: ...
def adpWaypoint(*, name: str = ..., property: Multiuse[str] = ...) -> None: ...
def adskAsset(arg0: str = ..., /, *, query: bool = ..., assetID: str = ..., library: str = ..., resolved: bool = ...) -> None: ...
def adskAssetLibrary(*args: str, unloadAll: bool = ..., unload: bool = ...) -> None: ...
def adskAssetList(*, infoType: str = ...) -> None: ...
def adskAssetListUI(*, query: bool = ..., commandSuffix: str = ..., materialLoaded: bool = ..., uiCommand: str = ...) -> None: ...
def affectedNet(*args: str, edit: bool = ..., query: bool = ..., type: str = ...) -> bool:
    """This command gets the list of attributes on a node or node type and
    creates nodes of type TdnAffect, one for each attribute, that are
    connected iff the source node's attribute affects the destination node's
    attribute.
    Args:
        type (str?): Get information from the given node type instead of one node  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def affects(arg0: str = ..., /, *args: str, by: bool = ..., type: str = ...) -> str:
    """This command returns the list of attributes on a node or node type which
    affect the named attribute.attribute, node, class, dg
    Args:
        by (bool?): Show attributes that are affected by the given one rather than the  
                ones that affect it.  
                Properties: create
        type (str?): static node type from which to get 'affects' information  
                Properties: create

    Returns:
        str: List of affected/affecting attributes

    Example:
    """

def agFormatIn(*, file: str = ..., name: str = ...) -> None: ...
def agFormatOut(*args: str, file: str = ...) -> None: ...
def aimConstraint(*args: str, edit: bool = ..., query: bool = ..., aimVector: Queryable[Tuple[float, float, float]] = ..., layer: str = ..., maintainOffset: bool = ..., name: Queryable[str] = ..., offset: Queryable[Tuple[float, float, float]] = ..., remove: bool = ..., skip: Multiuse[str] = ..., targetList: bool = ..., upVector: Queryable[Tuple[float, float, float]] = ..., weight: Queryable[float] = ..., weightAliasList: bool = ..., worldUpObject: Queryable[str] = ..., worldUpType: Queryable[str] = ..., worldUpVector: Queryable[Tuple[float, float, float]] = ...) -> Union[List[str], Tuple[float, float, float], str, bool, float]:
    """Constrain an object's orientation to point at a target object or
    at the average position of a number of targets.An aimConstraint takes as input one or more "target" DAG transform
    nodes at which to aim the single "constraint object" DAG transform
    node.  The aimConstraint orients the constrained object such that
    the aimVector (in the object's local coordinate system) points to
    the in weighted average of the world space position target
    objects.  The upVector (again the the object's local coordinate
    system) is aligned in world space with the worldUpVector.
    Args:
        aimVector (Queryable[Tuple[float, float, float]]?): Set the aim vector.  This is the vector in local  
                coordinates that points at the target.  If not given at creation  
                time, the default value of (1.0, 0.0, 0.0) is used.  
                Properties: create, query, edit
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        maintainOffset (bool?): The offset necessary to preserve the constrained  
                object's initial rotation will be calculated and used as the  
                offset.  
                Properties: create
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        offset (Queryable[Tuple[float, float, float]]?): Sets or queries the value of the offset. Default is 0,0,0.  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        skip (Multiuse[str]?): Specify the axis to be skipped. Valid values are "x", "y", "z" and  
                "none". During creation, "none" is the default.  
                Properties: create, edit, multiuse
        targetList (bool?): Return the list of target objects.  
                Properties: query
        upVector (Queryable[Tuple[float, float, float]]?): Set local up vector.  This is the vector in local  
                coordinates that aligns with the world up vector.  If not given  
                at creation time, the default value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query
        worldUpObject (Queryable[str]?): Set the DAG object use for worldUpType "object" and  
                "objectrotation". See worldUpType for greater detail.  
                The default value is no up object, which is interpreted  
                as world space.  
                Properties: create, query, edit
        worldUpType (Queryable[str]?): Set the type of the world up vector computation.  
                The worldUpType can have one of 5 values: "scene",  
                "object", "objectrotation", "vector", or "none".  
                If the value is "scene", the upVector is  
                aligned with the up axis of the scene and  
                worldUpVector and worldUpObject are ignored.  
                If the value is "object", the upVector is  
                aimed as closely as possible to the  
                origin of the space of the worldUpObject and  
                the worldUpVector is ignored.  
                If the value is "objectrotation" then the  
                worldUpVector is interpreted as being in  
                the coordinate space of the worldUpObject, transformed into  
                world space and the upVector is aligned as  
                closely as possible to the result.  
                If the value is "vector", the upVector  
                is aligned with worldUpVector as closely as  
                possible and worldUpMatrix is ignored.  
                Finally, if the value is "none" no twist calculation  
                is performed by the constraint, with the resulting "upVector"  
                orientation based previous orientation of the  
                constrained object, and the "great circle" rotation needed  
                to align the aim vector with its constraint.  
                The default worldUpType is "vector".  
                Properties: create, query, edit
        worldUpVector (Queryable[Tuple[float, float, float]]?): Set world up vector.  This is the vector in world  
                coordinates that up vector should align with.  
                See -wut/worldUpType (below)for greater detail.  
                If not given at creation time, the default  
                value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit

    Returns:
        List[str]: name of the created constraint node

    Example:
    """

def air(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., enableSpread: bool = ..., fanSetup: bool = ..., inheritRotation: bool = ..., inheritVelocity: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., speed: Queryable[float] = ..., spread: Queryable[float] = ..., torusSectionRadius: Queryable[float] = ..., velocityComponentOnly: bool = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ..., wakeSetup: bool = ..., windSetup: bool = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    The air field simulates the effects of moving air. The affected objects
    will be accelerated or decelerated so that their velocities match that
    of the air.With the '-vco true' flag thrown, only accelerations are applied.
    By parenting an air field to a moving part of an object (ie. a foot of a
    character) and using '-i 1 -m 0 -s .5 -vco true' flags, one can simulate
    the movement of air around the
    foot as it moves, since the TOTAL velocity vector of the field would be
    only based on the
    movement of the foot. This can be done while the character walks through
    leaves or dust on the ground.For each listed object, the command creates a new field.
    The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created,  this command returns the field names. If
    a field was queried, the results of the query are returned. If a field
    was edited, the field name is returned.If the -pos flag is specified, a field is created at the position specified.
    If not, if object names are provided or the active selection list is
    non-empty, the command creates a field for every object in the list and
    calls addDynamic to add it to the object; otherwise the command defaults
    to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        directionX (Queryable[float]?):   
                Properties: query, edit
        directionY (Queryable[float]?):   
                Properties: query, edit
        directionZ (Queryable[float]?): Direction that the air will try to match the affected  
                particles' velocity to. NOTE: This is not the velocity; this is only  
                the direction. Use the -s flag to set the speed.  
                Properties: query, edit
        enableSpread (bool?): This tells the system whether or not to use the spread  
                angle given by '-sp'. If this is 'false' then all connected objectswithin the maximum distance will  
                be affected. Also, if this is set to 'false', all affected objects are forced to match their velocities  
                along the direction vector. If this is set to 'true' and spread is used, then the direction of the force  
                is along the direction from the field to the object.  
                Properties: query, edit
        fanSetup (bool?): Similar to 'windSetup' except that the effects of a fan or  
                a person blowing air are approximated. The user can pass the same  
                flags on the command line to adjust them from the defaults. These are  
                the values that get set to approximate a 'fan':  
                inheritVelocity 1.0  
                inheritRotation true  
                componentOnly false  
                enableSpread true  
                spread .5 (45 degrees from center )  
                Properties: edit
        inheritRotation (bool?): If this is set to 'true', then the direction vector  
                described with -dx, -dy, and -dz will be considered local to the owning object. Therefore, if the  
                owning object's transform undergoes any rotation (by itself or one of its parents), the direction  
                vector of the air field will undergo that same rotation.  
                Properties: query, edit
        inheritVelocity (Queryable[float]?): Amount (from 0 to 1) of the field-owner's velocity added to the  
                vector determined by the direction and speed flags. The combination  
                of these two vectors makes  
                up the TOTAL velocity vector for the air field. This allows the air  
                to be determined directly by the motion of the owning object.  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        speed (Queryable[float]?): How fast the affected objects' speed reaches the speed (based on the -mag, -dx, -dy, -dz flags) of the air field.  
                This value gets clamped internally to be between 0.0 and 1.0.  A value of 0.0 will make the air field have no effect.  
                A value of 1.0 will try to match the air field's speed much quicker, but not necessarily immediately.  
                Properties: query, edit
        spread (Queryable[float]?): This represents the angle from the direction vector within which  
                objects will be affected. The values are in the range of 0 to 1.  
                A value of 0 will result in an effect only  
                exactly in front of the air field along the direction vector. A  
                value of 1 will result in any object in front of the owning object, 90  
                degrees in all direction from the direction vector.  
                Properties: query, edit
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        velocityComponentOnly (bool?): If this is 'false', the air will accelerate or decelerate  
                the affected objects so that their velocities will eventually match  
                the TOTAL velocity vector of the air field. If this is 'true',  
                only ACCELERTION is applied to the affected objects so that their  
                velocity component along the TOTAL velocity vector matches or is  
                greater in magnitude than the TOTAL velocity vector. This will not  
                slow objects down to match velocities, only speed them up  
                to match components. This is most useful when using the -iv flag  
                with a value >0.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit
        wakeSetup (bool?): Like the 'windSetup' and 'fanSetup', 'wakeSetup'  
                sets certain values in the field to approximate the movement of air  
                near a moving object, such as  a character's foot or hand.  
                The values that are set are:  
                inheritVelocity 1.0  
                inheritRotation false  
                componentOnly true  
                enableSpread false  
                speed 0.0  
                Properties: edit
        windSetup (bool?): This will set some of the values above in a way that  
                approximates the effects of a basic wind. This allows the user to then change certain values as  
                he/she wishes on the same command line. First the preset values get set, and then any other flags  
                that were passed get taken into account. These are the values that get set to approximate 'wind':  
                inheritVelocity 0.0  
                inheritRotation true  
                componentOnly false  
                enableSpread false  
                Properties: edit

    Returns:
        str: Command result

    Example:
    """

def aliasAttr(*args: str, edit: bool = ..., query: bool = ..., remove: bool = ...) -> List[str]:
    """Allows aliases (alternate names) to be defined for any attribute of
    a specified node. When an attribute is aliased, the alias will be
    used by the system to display information about the attribute.
    The user may, however, freely use either the alias or the original
    name of the attribute. Only a single alias can be specified for an
    attribute so setting an alias on an already-aliased attribute destroys
    the old alias.dg, dependency, graph, alias, attribute, name
    Args:
        remove (bool?): Specifies that aliases listed should be removed (otherwise new aliases  
                are added).  
                Properties: create

    Returns:
        List[str]: in query mode.

    Example:
    """

def align(*args: str, alignToLead: bool = ..., coordinateSystem: str = ..., xAxis: str = ..., yAxis: str = ..., zAxis: str = ...) -> bool:
    """Align or spread objects along X Y and Z axis.objects, move, align
    Args:
        alignToLead (bool?): When set, the min, center or max values are computed from the  
                lead object. Otherwise, the values are averaged for all objects.  
                Default is false  
                Properties: create
        coordinateSystem (str?): Defines the X, Y, and Z coordinates. Default is the world coordinates  
                Properties: create
        xAxis (str?): Any of none, min, mid, max, dist, stack.  
                This defines the kind of alignment to perfom, default is none.  
                Properties: create
        yAxis (str?): Any of none, min, mid, max, dist, stack.  
                This defines the kind of alignment to perfom, default is none.  
                Properties: create
        zAxis (str?): Any of none, min, mid, max, dist, stack.  
                This defines the kind of alignment to perfom, default is none.  
                Properties: create

    Returns:
        bool: true/false

    Example:
    """

def alignCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: bool = ..., anchorFirstObject: bool = ..., distribute: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., showAlignTouch: bool = ...) -> Union[str, bool]:
    """The alignCtx command creates a tool for aligning and
    distributing objects.
    Args:
        align (bool?): Align objects  
                Properties: create, query, edit
        anchorFirstObject (bool?): Anchor first or last selected object. Default false.  
                Only applicable when aligning objects.  
                Properties: create, query, edit
        distribute (bool?): Distribute objects  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        showAlignTouch (bool?): Show or hide align touching handles. Default true.  
                Only applicable when aligning objects.  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def alignCurve(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., curvatureContinuity: bool = ..., curvatureScale1: Queryable[float] = ..., curvatureScale2: Queryable[float] = ..., joinParameter: Queryable[float] = ..., nodeState: Queryable[int] = ..., positionalContinuity: bool = ..., positionalContinuityType: Queryable[int] = ..., reverse1: bool = ..., reverse2: bool = ..., tangentContinuity: bool = ..., tangentContinuityType: Queryable[int] = ..., tangentScale1: Queryable[float] = ..., tangentScale2: Queryable[float] = ..., attach: bool = ..., constructionHistory: bool = ..., keepMultipleKnots: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, float, int]:
    """The curve align command is used to align curves in maya. The main
    alignment options are positional, tangent and curvature continuity.
    Curvature continuity implies tangent continuity.Positional continuity means the curves (move) or the ends of the
    curves (modify) are changed.Tangent continuity means one of the curves is modified to be tangent
    at the points where they meet.Curvature continuity means one of the curves is modified to be
    curvature continuous as well as tangent.The default behaviour, when no curves or flags are passed, is to only
    do positional and tangent continuity on the active list with the end
    of the first curve and the start of the other curve used for alignment.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        curvatureContinuity (bool?): Curvature continuity is on if true and off otherwise.  
                Default: false  
                Properties: create, query, edit
        curvatureScale1 (Queryable[float]?): Curvature scale applied to curvature of first curve for curvature continuity.  
                Default: 0.0  
                Properties: create, query, edit
        curvatureScale2 (Queryable[float]?): Curvature scale applied to curvature of second curve for curvature continuity.  
                Default: 0.0  
                Properties: create, query, edit
        joinParameter (Queryable[float]?): Parameter on reference curve where modified curve is to be aligned to.  
                Default: 123456.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        positionalContinuity (bool?): Positional continuity is on if true and off otherwise.  
                Default: true  
                Properties: create, query, edit
        positionalContinuityType (Queryable[int]?): Positional continuity type legal values:  
                1. move first curve,  
                2. move second curve,  
                3. move both curves,  
                4. modify first curve,  
                5. modify second curve,  
                6. modify both curves  
                Default: 1  
                Properties: create, query, edit
        reverse1 (bool?): If true, reverse the first input curve before doing align. Otherwise, do nothing to the first input curve before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        reverse2 (bool?): If true, reverse the second input curve before doing align. Otherwise, do nothing to the second input curve before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        tangentContinuity (bool?): Tangent continuity is on if true and off otherwise.  
                Default: true  
                Properties: create, query, edit
        tangentContinuityType (Queryable[int]?): Tangent continuity type legal values:  
                1. do tangent continuity on first curve,  
                2. do tangent continuity on second curve  
                Default: 1  
                Properties: create, query, edit
        tangentScale1 (Queryable[float]?): Tangent scale applied to tangent of first curve for tangent continuity.  
                Default: 1.0  
                Properties: create, query, edit
        tangentScale2 (Queryable[float]?): Tangent scale applied to tangent of second curve for tangent continuity.  
                Default: 1.0  
                Properties: create, query, edit
        attach (bool?): True if the curve is to be attached  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        keepMultipleKnots (bool?): True if multiple knots should be left as-is.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def alignSurface(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., curvatureContinuity: bool = ..., curvatureScale1: Queryable[float] = ..., curvatureScale2: Queryable[float] = ..., directionU: bool = ..., joinParameter: Queryable[float] = ..., nodeState: Queryable[int] = ..., positionalContinuity: bool = ..., positionalContinuityType: Queryable[int] = ..., reverse1: bool = ..., reverse2: bool = ..., swap1: bool = ..., swap2: bool = ..., tangentContinuity: bool = ..., tangentContinuityType: Queryable[int] = ..., tangentScale1: Queryable[float] = ..., tangentScale2: Queryable[float] = ..., twist: bool = ..., attach: bool = ..., constructionHistory: bool = ..., keepMultipleKnots: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, float, int]:
    """The surface align command is used to align surfaces in maya. The main
    alignment options are positional, tangent and curvature continuity.
    Curvature continuity implies tangent continuity.NOTE: this tool is based on Studio's align tool.Positional continuity means the surfaces (move) or the ends of the
    surfaces (modify) are changed.Tangent continuity means one of the surfaces is modified to be tangent
    at the points where they meet.Curvature continuity means one of the surfaces is modified to be
    curvature continuous as well as tangent.The default behaviour, when no surfaces or flags are passed, is to only
    do positional and tangent continuity on the active list with the end
    of the first surface and the start of the other surface used for
    alignment.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        curvatureContinuity (bool?): Curvature continuity is on if true and off otherwise.  
                Default: false  
                Properties: create, query, edit
        curvatureScale1 (Queryable[float]?): Curvature scale applied to curvature of first surface for curvature continuity.  
                Default: 0.0  
                Properties: create, query, edit
        curvatureScale2 (Queryable[float]?): Curvature scale applied to curvature of second surface for curvature continuity.  
                Default: 0.0  
                Properties: create, query, edit
        directionU (bool?): If true use U direction of surface and V direction otherwise.  
                Default: true  
                Properties: create, query, edit
        joinParameter (Queryable[float]?): Parameter on reference surface where modified surface is to be aligned to.  
                Default: 123456.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        positionalContinuity (bool?): Positional continuity is on if true and off otherwise.  
                Default: true  
                Properties: create, query, edit
        positionalContinuityType (Queryable[int]?): Positional continuity type legal values:  
                1. move first surface,  
                2. move second surface,  
                3. move both surfaces,  
                4. modify first surface,  
                5. modify second surface,  
                6. modify both surfaces  
                Default: 1  
                Properties: create, query, edit
        reverse1 (bool?): If true, reverse the direction (specified by directionU) of the first input surface before doing align. Otherwise, do nothing to the first input surface before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        reverse2 (bool?): If true, reverse the direction (specified by directionU) of the second input surface before doing align. Otherwise, do nothing to the second input surface before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        swap1 (bool?): If true, swap the UV directions of the first input surface before doing align. Otherwise, do nothing to the first input surface before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        swap2 (bool?): If true, swap the UV directions of the second input surface before doing align. Otherwise, do nothing to the second input surface before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        tangentContinuity (bool?): Tangent continuity is on if true and off otherwise.  
                Default: true  
                Properties: create, query, edit
        tangentContinuityType (Queryable[int]?): Tangent continuity type legal values:  
                1. do tangent continuity on first surface,  
                2. do tangent continuity on second surface  
                Default: 1  
                Properties: create, query, edit
        tangentScale1 (Queryable[float]?): Tangent scale applied to tangent of first surface for tangent continuity.  
                Default: 1.0  
                Properties: create, query, edit
        tangentScale2 (Queryable[float]?): Tangent scale applied to tangent of second surface for tangent continuity.  
                Default: 1.0  
                Properties: create, query, edit
        twist (bool?): If true, reverse the second surface in the opposite direction (specified by directionU) before doing align. This will avoid twists in the aligned surfaces. Otherwise, do nothing to the second input surface before aligning. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        attach (bool?): Should surfaces be attached after alignment?  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        keepMultipleKnots (bool?): Should multiple knots be kept?  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def allNodeTypes(*, includeAbstract: bool = ...) -> List[str]:
    """This command returns a list containing the type names of every kind of
    creatable node registered with the system. Note that some node types are
    abstract and cannot be created. These will not show up on this list.
    (e.g. transform and polyShape both inherit from dagObject, but dagObject
     cannot be created directly so it will not appear on this list.)debug, node, type, graph
    Args:
        includeAbstract (bool?): Show every node type, even the abstract ones which cannot be created  
                via the 'createNode' command. These will have the suffix "(abstract)" appended  
                to them in the list.  
                Properties: create

    Returns:
        List[str]: List of node types

    Example:
    """

def ambientLight(*args: str, edit: bool = ..., query: bool = ..., ambientShade: Queryable[float] = ..., discRadius: Queryable[float] = ..., exclusive: bool = ..., intensity: Queryable[float] = ..., name: Queryable[str] = ..., position: Queryable[Tuple[float, float, float]] = ..., rgb: Queryable[Tuple[float, float, float]] = ..., rotation: Queryable[Tuple[float, float, float]] = ..., shadowColor: Queryable[Tuple[float, float, float]] = ..., shadowDither: Queryable[float] = ..., shadowSamples: Queryable[int] = ..., softShadow: bool = ..., useRayTraceShadows: bool = ...) -> Union[List[float], str, float, bool, Tuple[float, float, float], int]:
    """TlightCmd is the base class for other light commands.
    The ambientLight command is used to edit the parameters of
    existing ambientLights, or to create new ones. The default
    behaviour is to create a new ambientlight.This is the commmand that instantiates an ambientLight
    or edits the parameters of an existing one.
    TambientLightCmd inherits from TlightCmd which defines
    common flags like intensity, colour etc.
    See TlightCmd for a global picture of the light commands.
    Note that the flag fAmbientLightUsed indicates whether
    the command uses any ambient specific flags.
    That is, if a command doesn't use flags
    defined here, the boolean fAmbientLightUsed is set to
    false and thus the undo/redo information is not saved
    at this level.TambientLightCmd behaves like any other command, it
    has flags, saves undo information etc. the only slightly
    different behaviour is that it calls up to TlightCmd to
    complete the functionality of the command.
    Example	parseArgs:  TambientLightCmd defines
    ambientLight specific parameters like -ambientShade
    however, several other parameters are available in
    TlightCmd such as -intensity etc.  So when parsing
    the arguments, a call is made to TlightCmd::parseArgs
    to parse common parameters (like Intensity).
    Args:
        ambientShade (Queryable[float]?): ambientShade  
                Properties: create, query, edit
        discRadius (Queryable[float]?): radius of the disc around the light  
                Properties: create, query, edit
        exclusive (bool?): True if the light is exclusively assigned  
                Properties: create, query
        intensity (Queryable[float]?): Intensity of the light  
                Properties: create, query
        name (Queryable[str]?): Name of the light  
                Properties: create, query
        position (Queryable[Tuple[float, float, float]]?): Position of the light  
                Properties: create, query
        rgb (Queryable[Tuple[float, float, float]]?): RGB colour of the light  
                Properties: create, query
        rotation (Queryable[Tuple[float, float, float]]?): Rotation of the light for orientation, where applicable  
                Properties: create, query
        shadowColor (Queryable[Tuple[float, float, float]]?): Color of the light's shadow  
                Properties: create, query
        shadowDither (Queryable[float]?): dither the shadow  
                Properties: create, query, edit
        shadowSamples (Queryable[int]?): number of shadow samples.  
                Properties: create, query, edit
        softShadow (bool?): soft shadow  
                Properties: create, query, edit
        useRayTraceShadows (bool?): True if ray trace shadows are to be used  
                Properties: create, query

    Returns:
        List[float]: when querying the rgb or shadowColor flags
            double when querying the intensity flag
            boolean when querying the useRayTraceShadows or exclusive flags
            linear[] when querying the position flag
            angle[] when querying the rotation flag
            string when querying the name flag
        str: Light shape name

    Example:
    """

def angleBetween(*, caching: bool = ..., constructionHistory: bool = ..., euler: bool = ..., nodeState: int = ..., vector1: Tuple[float, float, float] = ..., vector1X: float = ..., vector1Y: float = ..., vector1Z: float = ..., vector2: Tuple[float, float, float] = ..., vector2X: float = ..., vector2Y: float = ..., vector2Z: float = ...) -> Union[List[float], str]:
    """Returns the axis and angle required to rotate one vector onto another.
    If the construction history () flag is ON, then the name of
    the new dependency node is returned.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        euler (bool?): return the rotation as 3 Euler angles instead of axis + angle  
                Properties: create
        nodeState (int?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create
        vector1 (Tuple[float, float, float]?): vector from which to compute the rotation  
                Properties: create
        vector1X (float?): X coordinate of the vector from which to compute the rotation  
                Properties: create
        vector1Y (float?): Y coordinate of the vector from which to compute the rotation  
                Properties: create
        vector1Z (float?): Z coordinate of the vector from which to compute the rotation  
                Properties: create
        vector2 (Tuple[float, float, float]?): vector to which to compute the rotation  
                Properties: create
        vector2X (float?): X coordinate of the vector to which to compute the rotation  
                Properties: create
        vector2Y (float?): Y coordinate of the vector to which to compute the rotation  
                Properties: create
        vector2Z (float?): Z coordinate of the vector to which to compute the rotation  
                Properties: create

    Returns:
        List[float]: 3 Euler angles or axis and angle
        str: When constructionHistory flag is used.

    Example:
    """

def animCurveEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., areCurvesSelected: bool = ..., autoFit: Queryable[str] = ..., autoFitTime: Queryable[str] = ..., classicMode: bool = ..., clipTime: Queryable[str] = ..., constrainDrag: Queryable[int] = ..., control: bool = ..., curvesShown: bool = ..., curvesShownForceUpdate: bool = ..., defineTemplate: str = ..., denormalizeCurvesCommand: str = ..., displayActiveKeyTangents: str = ..., displayActiveKeys: str = ..., displayInfinities: str = ..., displayKeys: str = ..., displayNormalized: bool = ..., displayTangents: str = ..., displayValues: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightAffectedCurves: bool = ..., highlightConnection: Queryable[str] = ..., keyMinScale: Queryable[float] = ..., keyScale: Queryable[float] = ..., keyingTime: Queryable[str] = ..., lockMainConnection: bool = ..., lockPlayRangeShades: Queryable[str] = ..., lookAt: str = ..., mainListConnection: Queryable[str] = ..., menu: Callable[..., Any] = ..., normalizeCurvesCommand: str = ..., outliner: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., preSelectionHighlight: bool = ..., renormalizeCurves: bool = ..., resultSamples: Queryable[int] = ..., resultScreenSamples: Queryable[int] = ..., resultUpdate: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., showActiveCurveNames: bool = ..., showBufferCurves: Queryable[str] = ..., showCurveNames: bool = ..., showPlayRangeShades: Queryable[str] = ..., showResults: Queryable[str] = ..., showUpstreamCurves: bool = ..., simpleKeyView: bool = ..., smoothness: Queryable[str] = ..., snapTime: Queryable[str] = ..., snapValue: Queryable[str] = ..., stackedCurves: bool = ..., stackedCurvesMax: Queryable[float] = ..., stackedCurvesMin: Queryable[float] = ..., stackedCurvesSpace: Queryable[float] = ..., stateString: bool = ..., timelinePositionTop: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., valueLinesToggle: str = ...) -> Union[str, bool, int, float]:
    """Edit a characteristic of a graph editor
    Args:
        areCurvesSelected (bool?): Returns a boolean to know if at least one curve is selected in the graph editor.  
                Properties: query
        autoFit (Queryable[str]?): on | off | tgl  
                Auto fit-to-view.  
                Properties: query, edit
        autoFitTime (Queryable[str]?): on | off | tgl  
                Auto fit-to-view along the time axis, as well.  
                Properties: query, edit
        classicMode (bool?): When on, the graph editor is displayed in "Classic Mode", otherwise "Suites Mode" is used.  
                Properties: query, edit
        clipTime (Queryable[str]?): Valid values: "on" "off"  
                Display the clips with their offset and scale  
                applied to the anim curves in the clip.  
                Properties: query, edit
        constrainDrag (Queryable[int]?): Constrains all Graph Editor animation curve drag operations  
                to either the X-axis, the Y-axis, or to neither of those axes.  
                Values to supply are: 0 for not constraining any axis,  
                1 for constraing the X-axis, or 2 for constraining the Y-axis.  
                When used in queries, this flag returns the latter values and  
                these values have the same interpretation as above.  
                Note: when the shift key is pressed before dragging the animation  
                curve, the first mouse movement will instead determine (and override)  
                any prior set constrained axis.  
                Properties: create, query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        curvesShown (bool?): Returns a string array containing the names of the animCurve nodes  
                currently displayed in the graph editor.  
                Properties: query
        curvesShownForceUpdate (bool?): Returns a string array containing the names of the animCurve nodes  
                currently displayed in the graph editor. Unlike the curvesShown flag,  
                this will force an update of the graph editor for the case where  
                the mainListConnection has been modified since the last refresh.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        denormalizeCurvesCommand (str?): Sets the script that is run to denormalize curves in the graph editor.  
                This is intended for internal use only.  
                Properties: create, edit
        displayActiveKeyTangents (str?): on | off | tgl  
                Display active key tangents in the editor.  
                Properties: edit
        displayActiveKeys (str?): on | off | tgl  
                Display active keys in the editor.  
                Properties: edit
        displayInfinities (str?): on | off | tgl  
                Display infinities in the editor.  
                Properties: edit
        displayKeys (str?): on | off | tgl  
                Display keyframes in the editor.  
                Properties: edit
        displayNormalized (bool?): When on, display all curves normalized to the range -1 to +1.  
                Properties: query, edit
        displayTangents (str?): on | off | tgl  
                Display tangents in the editor.  
                Properties: edit
        displayValues (str?): on | off | tgl  
                Display active keys and tangents values in the editor.  
                Properties: edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightAffectedCurves (bool?): When on, highlights the curve segment affected by the selected key/tangent  
                Properties: query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        keyMinScale (Queryable[float]?): The minimum key selection size in the graph editor.  
                A value of 0.0 means there is no minimum size.  
                A value of 1.0 means the minimum size is the size of a key with keyScale set to 1.0  
                Properties: query, edit
        keyScale (Queryable[float]?): Scales the key size in the graph editor  
                Properties: query, edit
        keyingTime (Queryable[str]?): The current time in the given curve to be keyed in the graph editor.  
                Properties: query
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lockPlayRangeShades (Queryable[str]?): Valid values: "on" "off" "tgl"  
                Lock Play Range Shades.  
                Properties: query, edit
        lookAt (str?): all | selected | currentTime  
                FitView helpers.  
                Properties: edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        menu (Callable[..., Any]?): Specify a script to be run when the editor  
                is created.  The function will be passed one string  
                argument which is the new editor's name.  
                Properties: create
        normalizeCurvesCommand (str?): Sets the script that is run to normalize curves in the graph editor.  
                This is intended for internal use only.  
                Properties: create, edit
        outliner (Queryable[str]?): The name of the outliner that is associated with the graph editor.  
                Properties: query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        preSelectionHighlight (bool?): When on, the curve/key/tangent under the mouse pointer is highlighted  
                to ease selection.  
                Properties: query, edit
        renormalizeCurves (bool?): This flag causes the curve normalization factors to be recalculated.  
                Properties: edit
        resultSamples (Queryable[int]?): Specify the sampling for result curves  
                Note: the smaller this number is, the longer it will  
                take to update the display.  
                Properties: query, edit
        resultScreenSamples (Queryable[int]?): Specify the screen base result sampling for result curves.  
                If 0, then results are sampled in time.  
                Properties: query, edit
        resultUpdate (Queryable[str]?): Valid values: "interactive" "delayed"  
                Controls how changes to animCurves are reflected in the  
                result curves (if results are being shown).  If resultUpdate  
                is "interactive", then as interactive changes are being made  
                to the animCurve, the result curves will be updated.  If  
                modelUpdate is delayed (which is the default setting), then  
                result curves are updated once the final change to an  
                animCurve has been made.  
                Properties: query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        showActiveCurveNames (bool?): Display the active curve(s)'s name.  
                Properties: query, edit
        showBufferCurves (Queryable[str]?): Valid values: "on" "off" "tgl"  
                Display buffer curves.  
                Properties: query, edit
        showCurveNames (bool?): Display the curves's name.  
                Properties: query, edit
        showPlayRangeShades (Queryable[str]?): Valid values: "on" "off" "tgl"  
                Display Play Range Shades.  
                Properties: query, edit
        showResults (Queryable[str]?): Valid values: "on" "off" "tgl"  
                Display result curves from expression or other non-keyed  
                action.  
                Properties: query, edit
        showUpstreamCurves (bool?): If true, the dependency graph is searched upstream for all curves  
                that drive the selected plugs (showing multiple curves for example  
                in a typical driven key setup, where first the driven key curve is  
                encountered, followed by the actual animation curve that drives the  
                source object). If false, only the first curves encountered  
                will be shown. Note that, even if false, multiple curves can be shown  
                if e.g. a blendWeighted node is being used to combine multiple curves.  
                Properties: query, edit
        simpleKeyView (bool?): on | off  
                Display simpler and smaller key.  
                Properties: query, edit
        smoothness (Queryable[str]?): Valid values: "coarse" "rough" "medium" "fine"  
                Specify the display smoothness of animation curves.  
                Properties: query, edit
        snapTime (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in time.  
                Properties: query, edit
        snapValue (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in values.  
                Properties: query, edit
        stackedCurves (bool?): Switches the display mode between normal (all curves sharing one set of axes)  
                to stacked (each curve on its own value axis, stacked vertically).  
                Properties: query, edit
        stackedCurvesMax (Queryable[float]?): Sets the maximum value on the per-curve value axis when in stacked mode.  
                Properties: query, edit
        stackedCurvesMin (Queryable[float]?): Sets the minimum value on the per-curve value axis when in stacked mode.  
                Properties: query, edit
        stackedCurvesSpace (Queryable[float]?): Sets the spacing between curves when in stacked mode.  
                Properties: query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        timelinePositionTop (bool?): on | off | tgl  
                Display timeline either at the top or bottom.  
                Properties: query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        valueLinesToggle (str?): on | off | tgl  
                Display the value lines for high/low/zero of selected curves in the editor  
                Properties: edit

    Returns:
        str: Editor name

    Example:
    """

def animDisplay(*, edit: bool = ..., query: bool = ..., modelUpdate: Queryable[str] = ..., refAnimCurvesEditable: bool = ..., timeCode: Queryable[str] = ..., timeCodeOffset: Queryable[str] = ...) -> Union[bool, str]:
    """This command changes certain display options used by
    animation windows.
    Args:
        modelUpdate (Queryable[str]?): Controls how changes to animCurves are propagated through the  
                dependency graph. Valid modes are "none", "interactive" or  
                "delayed". If modelUpdate is "none" then changing an  
                animCurve will not cause the model to be updated (change currentTime  
                in order to update the model).  If modelUpdate is "interactive" (which  
                is the default setting), then as interactive changes are being made  
                to the animCurve, the model will be updated.  If modelUpdate is  
                delayed, then the model is updated once the final change to an  
                animCurve has been made.  With modelUpdate set to  
                either "interactive" or "delayed", changes  
                to animCurves made via commands will also cause the  
                model to be updated.  
                Properties: create, query, edit
        refAnimCurvesEditable (bool?): Specify if animation curves from referenced files are  
                editable.  
                Properties: create, query, edit
        timeCode (Queryable[str]?): Controls how time value are display. Valid values are "frame", "timecode", "fulltimecode".  
                If the value is "frame" maya will display time in frame everywhere.  
                If the value is "timecode" maya will display time in timecode in time  
                slider, graph editor and dope sheet.  
                If the value is "fulltimecode" maya will display time in timecode everywhere.  
                Properties: create, query, edit
        timeCodeOffset (Queryable[str]?): This flag has now been deprecated.  It still exists to not break  
                legacy scripts, but it will now do nothing.  See the new timeCode  
                command to set and query timeCodes.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def animLayer(arg0: str = ..., arg1: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., addRelatedKG: bool = ..., addSelectedObjects: bool = ..., affectedLayers: bool = ..., animCurves: bool = ..., attribute: Queryable[Multiuse[str]] = ..., baseAnimCurves: bool = ..., bestAnimLayer: bool = ..., bestLayer: bool = ..., blendNodes: bool = ..., children: Queryable[str] = ..., collapse: bool = ..., copy: str = ..., copyAnimation: str = ..., copyNoAnimation: str = ..., excludeBoolean: bool = ..., excludeDynamic: bool = ..., excludeEnum: bool = ..., excludeProxy: bool = ..., excludeRotate: bool = ..., excludeScale: bool = ..., excludeTranslate: bool = ..., excludeVisibility: bool = ..., exists: bool = ..., extractAnimation: str = ..., findCurveForPlug: str = ..., forceUIRebuild: bool = ..., forceUIRefresh: bool = ..., layeredPlug: str = ..., lock: bool = ..., maxLayers: bool = ..., moveLayerAfter: str = ..., moveLayerBefore: str = ..., mute: bool = ..., override: bool = ..., parent: Queryable[str] = ..., passthrough: bool = ..., preferred: bool = ..., removeAllAttributes: bool = ..., removeAttribute: Multiuse[str] = ..., removeSelectedObjects: bool = ..., root: Queryable[str] = ..., selected: bool = ..., solo: bool = ..., weight: Queryable[float] = ..., writeBlendnodeDestinations: bool = ...) -> Union[str, bool, Multiuse[str], float]:
    """This command creates and edits animation layers.layer, animation, additive, override
    Args:
        addRelatedKG (bool?): When adding or removing selected object(s) from the layer, adds associated keying group(s)  
                to the object(s).  
                Properties: create, query, edit
        addSelectedObjects (bool?): Adds selected object(s) to the layer.  
                Properties: create, query, edit
        affectedLayers (bool?): Return the layers that the currently selected object(s) are members of  
                Properties: query
        animCurves (bool?): In query mode returns the anim curves associated with this layer  
                Properties: create, query, edit
        attribute (Queryable[Multiuse[str]]?): Adds a specific attribute on a object to the layer.  
                Properties: create, query, edit, multiuse
        baseAnimCurves (bool?): In query mode returns the base layer anim curves associated with this layer, if any.  
                Properties: create, query, edit
        bestAnimLayer (bool?): In query mode returns the best anim layers for keying for the selected  
                objects. If used in conjunction with -at, will return the best anim layers  
                for keying for the specific plugs (attributes) specified.  
                Properties: create, query, edit
        bestLayer (bool?): Return the layer that will be keyed for specified attribute.  
                Properties: query
        blendNodes (bool?): In query mode returns the blend nodes associated with this layer  
                Properties: create, query, edit
        children (Queryable[str]?): Get the list of children layers. Return value is a string array.  
                Properties: query
        collapse (bool?): Determine if a layer is collapse in the layer editor.  
                Properties: create, query, edit
        copy (str?): Copy from the layer.  
                Properties: edit
        copyAnimation (str?): Copy animation from specified layer to destination layer, only animation that are on attribute layered by both layer that are concerned.  
                Properties: create, edit
        copyNoAnimation (str?): Copy from layer without the animation curves.  
                Properties: edit
        excludeBoolean (bool?): When adding or removing selected object(s) from the layer, excludes any boolean attributes.  
                Properties: create, query, edit
        excludeDynamic (bool?): When adding or removing selected object(s) from the layer, excludes any dynamic attributes.  
                Properties: create, query, edit
        excludeEnum (bool?): When adding or removing selected object(s) from the layer, excludes any enum attributes.  
                Properties: create, query, edit
        excludeProxy (bool?): When adding or removing selected object(s) from the layer, excludes any proxy attributes.  
                Properties: create, query, edit
        excludeRotate (bool?): When adding or removing selected object(s) from the layer, excludes the rotate attribute.  
                Properties: create, query, edit
        excludeScale (bool?): When adding or removing selected object(s) from the layer, excludes the scale attribute.  
                Properties: create, query, edit
        excludeTranslate (bool?): When adding or removing selected object(s) from the layer, excludes the translate attribute.  
                Properties: create, query, edit
        excludeVisibility (bool?): When adding or removing selected object(s) from the layer, excludes the visibility attribute.  
                Properties: create, query, edit
        exists (bool?): Determine if a layer exists.  
                Properties: query
        extractAnimation (str?): Transfer animation from specified layer to destination layer, only animation that are on attribute layered by both layer that are concerned.  
                Properties: create, edit
        findCurveForPlug (str?): Finds the parameter curve containing the animation data for the specified plug on the given layer.  
                			In query mode, this flag needs a value.  
                Properties: query, edit
        forceUIRebuild (bool?): Rebuilds the animation layers user interface.  
                Properties: create
        forceUIRefresh (bool?): Refreshes the animation layers user interface.  
                Properties: create
        layeredPlug (str?): Returns the plug on the blend node corresponding to the specified layer  
                			In query mode, this flag needs a value.  
                Properties: query
        lock (bool?): Set the lock state of the specified layer. A locked layer cannot receive key. Default is false.  
                Properties: create, query, edit
        maxLayers (bool?): Returns the maximum number of anim layers supported by this product.  
                Properties: query
        moveLayerAfter (str?): Move layer after the specified layer  
                Properties: edit
        moveLayerBefore (str?): Move layer before the specified layer  
                Properties: edit
        mute (bool?): Set the mute state of the specified layer. Default is false.  
                Properties: create, query, edit
        override (bool?): Set the overide state of the specified layer. Default is false.  
                Properties: create, query, edit
        parent (Queryable[str]?): Set the parent of the specified layer. Default is the animation layer root.  
                Properties: create, query, edit
        passthrough (bool?): Set the passthrough state of the specified layer. Default is true.  
                Properties: create, query, edit
        preferred (bool?): Determine if a layer is a preferred layer, the best layer algorithm will try to set keyframe in preferred layer first.  
                Properties: create, query, edit
        removeAllAttributes (bool?): Remove all objects from the layer.  
                Properties: edit
        removeAttribute (Multiuse[str]?): Remove object from the layer.  
                Properties: edit, multiuse
        removeSelectedObjects (bool?): Removes selected object(s) from the layer.  
                Properties: edit
        root (Queryable[str]?): Return the base layer if it exist  
                Properties: query
        selected (bool?): Determine if a layer is selected, a selected layer will be show in the timecontrol, graph editor.  
                Properties: create, query, edit
        solo (bool?): Set the solo state of the specified layer. Default is false.  
                Properties: create, query, edit
        weight (Queryable[float]?): Set the weight of the specified layer between 0.0 and 1.0. Default is 1.  
                Properties: create, query, edit
        writeBlendnodeDestinations (bool?): In edit mode writes the destination plugs of the blend nodes that belong to the layer  
                into the blend node. This is used for layer import/export purposes and is not for  
                general use.  
                Properties: edit

    Returns:
        str: Return values currently not documented.

    Example:
    """

def animView(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., endTime: int = ..., maxValue: float = ..., minValue: float = ..., nextView: bool = ..., previousView: bool = ..., startTime: int = ...) -> bool:
    """This command allows you to specify the current view range within
    an animation editor.
    Args:
        endTime (int?): End time to display within the editor
        maxValue (float?): Upper value to display within the editor
        minValue (float?): Lower value to display within the editor
        nextView (bool?): Switches to the next view.  
                Properties: edit
        previousView (bool?): Switches to the previous view.  
                Properties: edit
        startTime (int?): Start time to display within the editor

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def annotate(*args: str, point: Tuple[float, float, float] = ..., text: str = ...) -> str:
    """This command is used to create an annotation to be attached to the
    specified objects at the specified point.
    Args:
        point (Tuple[float, float, float]?): Specifies the point about which the annotation text is to be  
                centered.  
                Properties: create
        text (str?): Specifies the annotation text.  
                Properties: create

    Returns:
        str: Annotation added

    Example:
    """

def appHome(*, edit: bool = ..., query: bool = ..., iconVisible: bool = ..., instrument: str = ..., setTab: str = ..., toggleVisibility: bool = ..., updateRecentFiles: bool = ..., visible: bool = ...) -> bool:
    """Used for displaying and hiding application home.
    Args:
        iconVisible (bool?): Query or set application home icon visibility preference.  
              
                Note: Icon visibility cannot be modified if the MAYA_NO_HOME_ICON  
                environment variable is defined.  
                Properties: create, query, edit
        instrument (str?): Instrument the app home command with the given string.  
                Properties: create
        setTab (str?): Navigate app home to the specified tab.  
              
                Available tabs are:  
                Recent  
                GettingStarted  
                Learning  
                WhatsNew  
                Community  
                Properties: create, edit
        toggleVisibility (bool?): Toggle application home widget visibility.  
                Properties: create, edit
        updateRecentFiles (bool?): Update the recent file list data.  
                Properties: create, edit
        visible (bool?): Query or set application home widget visibility.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def appendListItem() -> None: ...
def applyAttrPattern(*args: str, nodeType: str = ..., patternName: str = ...) -> int:
    """Take the attribute structure described by a pre-defined pattern and apply it either to a
    node (as dynamic attributes) or a node type (as extension attributes). The same pattern
    can be applied more than once to different nodes or node types as the operation duplicates
    the attribute structure described by the pattern.  See the 'createAttrPatterns' command
    for a description of how to create a pattern.attribute, pattern
    Args:
        nodeType (str?): Name of the node type to which the attribute pattern is to be applied. This flag  
                will cause a new extension attribute tree to be created, making the new attributes  
                available on all nodes of the given type. If it is not specified then either a node  
                name must be specified or a node must be selected for application of dynamic  
                attributes.  
                Properties: create
        patternName (str?): The name of the pattern to apply. The pattern with this name must have been previously created using the createAttrPatterns command.  
                Properties: create

    Returns:
        int: Number of nodes or node types to which the attribute were added

    Example:
    """

def applyMetadata(arg0: str = ..., /, *, format: str = ..., scene: bool = ..., value: str = ...) -> bool:
    """Define the values of a particular set of metadata on selected objects.
    This command is used in preservation of metadata through Maya file formats
    (.ma/.mb). If any metadata already exists it will be kept and merged with
    the new metadata, overwriting duplicate entries. (i.e. if this command
    specifies data at index N and you already have a value at index N then
    the one this command specifies will be the new value and the old one
    will cease to exist.)Unlike thecommand it is not necessary to first use
    thecommand or API equivalent to attach a metadata
    stream to the object, this command will do both assignment of structure
    and of metadata values. You do have to use thecommand or API equivalent to create the structure being assigned first
    though.The formatted input will be in a form expected by the data
    associations serializer (see adsk::Data::AssociationsSerializer for
    more information). The specific serialization type will be the default
    'raw' if theflag is not used.For example the "raw" format input string
    "channel face\\n[STREAMDATA]\\nendChannels\\nendAssociations"
    with no flags is equivalent to the input "[STREAMDATA]\\nendChannels" with
    theflag set to 'face'metadata, component, stream, channel, association
    Args:
        format (str?): Name of the data association format type to use in the value flag parsing.  
                Default value is "raw".  
                Properties: create
        scene (bool?): Use this flag when you want to apply metadata to the scene as a whole  
                rather than to any individual nodes. If you use this flag and have  
                nodes selected the nodes will be ignored and a warning will be displayed.  
                Scene metadata is incompatible with referenced scenes. Node associated  
                metadata from referenced files will still be readable from master scenes  
                but scene specific metadata of referenced files will not be accessible  
                from a any master scene. This will ensure that referenced files metadata  
                will not end up corrupting the master file scene-metadata.  
                Properties: create
        value (str?): String containing all of the metadata to be assigned to the selected  
                object.  
                Properties: create

    Returns:
        bool: True if the application succeeded

    Example:
    """

def applyTake(*args: Any, channel: Multiuse[str] = ..., device: Multiuse[str] = ..., filter: Multiuse[str] = ..., preview: bool = ..., recurseChannel: bool = ..., reset: bool = ..., specifyChannel: bool = ..., startTime: int = ...) -> bool:
    """This command takes data in a device (refered to as a take) and converts
    it into a form that may be played back and reviewed. The take can either
    be imported through the readTake action, or recorded by the recordDevice
    action. The take is either converted into animation curves or if the
    -preview flag is used, into blendDevice nodes.The command looks for animation curves attached to the target attributes
    of a device attachment. If animation curves exist, the take is
    pasted over the existing curves. If the curves do not exist, new
    animation curves are created.If devices are not specified, all of the devices with take data and that
    are enabled for applyTake, will have their data applied.See also: recordDevice, enableDevice, readTake, writeTake
    Args:
        channel (Multiuse[str]?): This flag overrides the set channel enable value.  
                If a channel is specified, it will be enabled.   
                C: The default is all applyTake enabled channels for the device(s).  
                Properties: create, multiuse
        device (Multiuse[str]?): Specifies which device contains the take.   
                C: The default is all applyTake enabled devices.  
                Properties: create, multiuse
        filter (Multiuse[str]?): This flag specifies the filters to use during the  
                applyTake. If this flag is used multiple times, the ordering  
                of the filters is from left to right.   
                C: The default is no filters.  
                Properties: create, multiuse
        preview (bool?): Applies the take to blendDevice nodes attached to the target  
                attributes connected to the device attachments. Animation curves  
                attached to the attributes will not be altered, but for the time  
                that preview data is defined, the preview data will be the data  
                used during playback.   
                C: The default is to not preview.  
                Properties: create
        recurseChannel (bool?): When this flag is used, the children of the channel(s)  
                specified by -c/channel are also applied.  
                C: The default is all of the enabled channels.  
                Properties: create
        reset (bool?): Resets the blendDevice nodes affected by -preview. The preview data  
                is removed and if animation curves exist, they are used during  
                playback.  
                Properties: create
        specifyChannel (bool?): This flag is used with -c/channel flag. When used, applyTake  
                will only work on the channels listed with the -c/channel flag.   
                C: The default is all of the enabled channels.  
                Properties: create
        startTime (int?): The default start time for a take is determined at record time.  
                The startTime option sets the starting time of the take in the  
                current animation units.   
                C: The default is the first time stamp of the take. If a time  
                stamp does not exist for the take, 0 is used.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def arcLenDimContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Command used to register the arcLenDimCtx tool.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: : name of the context created

    Example:
    """

def arcLengthDimension(*args: str) -> str:
    """This command is used to create an arcLength dimension to display the
    arcLength of a curve/surface at a specified point on the curve/surface.
    Returns:
        str: Name of the arcLengthDimension node created

    Example:
    """

def arclen(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., nodeState: Queryable[int] = ...) -> Union[float, str, bool, int]:
    """This command returns the arclength of a curve if the history
    flag is not set (the default).  If the history flag is set, a node
    is created that can produce the arclength, and is connected and
    its name returned.  Having the construction history option on
    makes this command useful for expressions.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        float: Length in non history mode.
        str: Node name, in history mode.

    Example:
    """

def arrayMapper(*, destAttr: str = ..., inputU: str = ..., inputV: str = ..., mapTo: str = ..., target: Multiuse[str] = ..., type: str = ...) -> List[str]:
    """Create an arrayMapper node and connect it to a target object.
    If the -type flag is used, then this command also creates an external
    node used for computing the output values. If the input attribute
    does not already exist, it will be created. The output attribute
    must exists. If    a flag is omitted, the selection list will be used
    to supply the needed objects. If none are found, that action is omitted.
    Args:
        destAttr (str?): Specifies the attribute which will be the downstream  
                connection for the output data from the mapper node. The  
                attribute type will be used to determine which output attribute  
                to use: float array gets outValuePP, vector array gets outColorPP.  
                If the flag is omitted, no output connection is made.  
                Properties: create
        inputU (str?): Specifies the upstream attribute to connect to the mapper's  
                uCoordPP attribute. If the flag is omitted, no input connection  
                is made.  
                Properties: create
        inputV (str?): Specifies the upstream attribute to connect to the mapper's  
                vCoordPP attribute. If the flag is omitted, no input connection  
                is made.  
                Properties: create
        mapTo (str?): Specifies an existing node to be used to compute the output values.  
                This node must be of the appropriate type. Currently, only ramp nodes  
                may be used.  
                Properties: create
        target (Multiuse[str]?): Specifies the target object to be connected to.  
                Properties: create, multiuse
        type (str?): Specifies the node type to create which will be used to compute  
                the output values. Currently, only ramp is valid. If the flag is  
                omitted, no connection is made and the external node is not created.  
                Properties: create

    Returns:
        List[str]: Names of created arrayMapper nodes.

    Example:
    """

def art3dPaintCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., afterStrokeCmd: Queryable[str] = ..., alphablendmode: Queryable[str] = ..., assigntxt: bool = ..., attrnames: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushdepth: Queryable[float] = ..., brushfeedback: bool = ..., brushtype: Queryable[str] = ..., clear: bool = ..., commonattr: Queryable[str] = ..., dragSlider: str = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., extendFillColor: bool = ..., fileformat: Queryable[str] = ..., filetxtaspectratio: Queryable[float] = ..., filetxtsizex: Queryable[int] = ..., filetxtsizey: Queryable[int] = ..., floodOpacity: Queryable[float] = ..., floodall: bool = ..., floodselect: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., keepaspectratio: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., name: str = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., painttxtattr: Queryable[str] = ..., painttxtattrname: Queryable[str] = ..., pfxScale: Queryable[float] = ..., pfxWidth: Queryable[float] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., pressureMapping1: Queryable[int] = ..., pressureMapping2: Queryable[int] = ..., pressureMapping3: Queryable[int] = ..., pressureMax1: Queryable[float] = ..., pressureMax2: Queryable[float] = ..., pressureMax3: Queryable[float] = ..., pressureMin1: Queryable[float] = ..., pressureMin2: Queryable[float] = ..., pressureMin3: Queryable[float] = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., reloadtexfile: bool = ..., resizeratio: Queryable[float] = ..., resizetxt: bool = ..., rgbcolor: Queryable[Tuple[float, float, float]] = ..., rgbflood: Queryable[Tuple[float, float, float]] = ..., saveTextureOnStroke: bool = ..., saveonstroke: bool = ..., savetexture: bool = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., shadernames: Queryable[str] = ..., shapeattr: bool = ..., shapenames: Queryable[str] = ..., showactive: bool = ..., soloAsDiffuse: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., textureFilenames: bool = ..., updateEraseTex: bool = ..., usepressure: bool = ..., worldRadius: Queryable[float] = ...) -> Union[bool, str, float, int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float], Tuple[float, float, float]]:
    """This is a tool context command for 3d Paint tool.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphablendmode (Queryable[str]?): Specifies the blend mode used while painting  
                RGB channel. Currently, we support the following blend modes:  
                "Default" "Lighten" "Darken" "Difference" "Exclusion"  
                "Hard Light" "Soft Light" "Multiply" "Screen" "Overlay" "Constant"  
                Default is "Default".  
                Properties: create, query, edit
        assigntxt (bool?): Sends a request to the tool to allocate and assign  
                file textures to the specified attibute on the selected  
                shaders.  
                Properties: edit
        attrnames (Queryable[str]?): Name of attributes  
                Properties: create, query, edit
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushdepth (Queryable[float]?): Depth of the brush  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushtype (Queryable[str]?): Name of the brush type  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        commonattr (Queryable[str]?): Returns a string with the names of all common to  
                all the shaders paintable attributes and supported by the  
                Paint Texture Tool.  
                Properties: query
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        extendFillColor (bool?): States if the painted textures will be automatically  
                postprocessed on each stroke to fill in the background color.  
                Default is true.  
                Properties: create, query, edit
        fileformat (Queryable[str]?): Name of the file format  
                Properties: create, query, edit
        filetxtaspectratio (Queryable[float]?): Specifies the aspect ration of the texture  
                width and height.  
                Default is 1.  
                Properties: create, query, edit
        filetxtsizex (Queryable[int]?): Specifies the width of the texture.  
                Default is 256.  
                Properties: create, query, edit
        filetxtsizey (Queryable[int]?): Specifies the height of the texture.  
                Default is 256.  
                Properties: create, query, edit
        floodOpacity (Queryable[float]?): Value of the flood opacity  
                Properties: create, query, edit
        floodall (bool?): Turn on to flood everything  
                Properties: create, query, edit
        floodselect (bool?): Should the selected area be flooded?  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        keepaspectratio (bool?): States if the aspect ratio of the file texture  
                sizes should remain constant.  
                Default is true.  
                boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        painttxtattr (Queryable[str]?): Specifies the attribute on the shader which  
                the user wants to paint. Currently, we support the following  
                attributes: "Color", "Transparency", "Ambient", "Incandescence",  
                "BumpMap", "Diffuse", "Translucence" "Eccentricity"  
                "SpecularColor", "Reflectivity", "ReflectedColor", and  
                user-defined float, float3, double, and double3 attributes.  
                Default is "Color".  
                Properties: create, query, edit
        painttxtattrname (Queryable[str]?): Returns a string with the names of all paintable  
                attributes supported by the Paint Texture Tool.  
                Properties: query, edit
        pfxScale (Queryable[float]?): Specifies the scale for Paint Effect brushes.  
                Properties: query, edit
        pfxWidth (Queryable[float]?): Specifies the width for Paint Effect brushes.  
                Properties: query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        pressureMapping1 (Queryable[int]?): First pressure mapping value  
                Properties: create, query, edit
        pressureMapping2 (Queryable[int]?): Second pressure mapping value  
                Properties: create, query, edit
        pressureMapping3 (Queryable[int]?): Third pressure mapping value  
                Properties: create, query, edit
        pressureMax1 (Queryable[float]?): First pressure maximum value  
                Properties: create, query, edit
        pressureMax2 (Queryable[float]?): Second pressure maximum value  
                Properties: create, query, edit
        pressureMax3 (Queryable[float]?): Third pressure maximum value  
                Properties: create, query, edit
        pressureMin1 (Queryable[float]?): First pressure minimum value  
                Properties: create, query, edit
        pressureMin2 (Queryable[float]?): Second pressure minimum value  
                Properties: create, query, edit
        pressureMin3 (Queryable[float]?): Third pressure minimum value  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        reloadtexfile (bool?): Sends a request to the tool to reload the texture  
                from the disc.  
                Properties: edit
        resizeratio (Queryable[float]?): Specifies the scale by which to resize the  
                current textures.  
                Properties: query, edit
        resizetxt (bool?): Sends a request to the tool to resize all the  
                currently in use textures.  
                Properties: edit
        rgbcolor (Queryable[Tuple[float, float, float]]?): Colour value  
                Properties: create, query, edit
        rgbflood (Queryable[Tuple[float, float, float]]?): Color of the flood  
                Properties: create, query, edit
        saveTextureOnStroke (bool?): States if the original texture will be automatically saved  
                on each stroke.  
                Default is false.  
                Properties: create, query, edit
        saveonstroke (bool?): States if the temporary texture will be automatically saved  
                on each stroke.  
                Default is false.  
                Properties: create, query, edit
        savetexture (bool?): Sends a request to the tool to save the texture  
                to the disc.  
                Properties: edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        shadernames (Queryable[str]?): Returns a string with the names of all shaders assigned  
                to selected surfaces.  
                Properties: query
        shapeattr (bool?): States if the attribute to paint is an attribute of the shape and not the shader.  
                Default is false.  
                Properties: query, edit
        shapenames (Queryable[str]?): Returns a string with the names of all surfaces  
                which are being painted on.  
                Properties: query
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        soloAsDiffuse (bool?): States if the currently paintable texture will be rendered as  
                as diffuse texture in the viewport.  
                Default is false.  
                Properties: query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        textureFilenames (bool?): Returns a string array with the names of all the painted  
                file textures.  
                Properties: query
        updateEraseTex (bool?): Should the erase texture update?  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artAttr(*args: str) -> None: ...
def artAttrCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., activeListChangedProc: Queryable[str] = ..., afterStrokeCmd: Queryable[str] = ..., alphaclamp: Queryable[str] = ..., alphaclamplower: Queryable[float] = ..., alphaclampupper: Queryable[float] = ..., attrSelected: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clamp: Queryable[str] = ..., clamplower: Queryable[float] = ..., clampupper: Queryable[float] = ..., clear: bool = ..., colorAlphaValue: Queryable[float] = ..., colorRGBAValue: Queryable[Tuple[float, float, float, float]] = ..., colorRGBValue: Queryable[Tuple[float, float, float]] = ..., colorRamp: Queryable[str] = ..., colorfeedback: bool = ..., colorfeedbackOverride: bool = ..., colorrangelower: Queryable[float] = ..., colorrangeupper: Queryable[float] = ..., dataTypeIndex: Queryable[int] = ..., disablelighting: bool = ..., dragSlider: str = ..., duringStrokeCmd: Queryable[str] = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., filterNodes: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., interactiveUpdate: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., maxvalue: Queryable[float] = ..., minvalue: Queryable[float] = ..., name: str = ..., numericColorRamp: Queryable[str] = ..., numericDisplayColor: Queryable[Tuple[float, float, float]] = ..., numericDisplayPrecision: Queryable[int] = ..., numericMaxColor: Queryable[Tuple[float, float, float]] = ..., numericMinColor: Queryable[Tuple[float, float, float]] = ..., objattrArray: Queryable[str] = ..., objattrArrayNoMenu: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintNodeArray: Queryable[str] = ..., paintattrselected: str = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., selectedattroper: Queryable[str] = ..., showactive: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toolOffProc: Queryable[str] = ..., toolOnProc: Queryable[str] = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ..., useNumericColorRamp: bool = ..., useNumericDisplay: bool = ..., usepressure: bool = ..., value: Queryable[float] = ..., whichTool: Queryable[str] = ..., worldRadius: Queryable[float] = ...) -> Union[str, bool, float, Tuple[float, float, float, float], Tuple[float, float, float], int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This is a context command to set the flags on the artAttrContext,
    which is the base context for attribute painting operations. All
    commands require the name of the context as the last argument as
    this provides the name of the context to create, edit or query.This is a context command to set the flags on the
    Attribute Paint Tool context.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        activeListChangedProc (Queryable[str]?): Accepts a string that contains a MEL command that is  
                invoked whenever the active list changes. There may be some  
                situations where the UI, for example, needs to be updated,  
                when objects are selected/deselected in the scene. In query  
                mode, the name of the currently registered MEL command is  
                returned and this will be an empty string if none is defined.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphaclamp (Queryable[str]?): Specifies if the weight value should be alpha clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        alphaclamplower (Queryable[float]?): Specifies the lower bound for the alpha values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        alphaclampupper (Queryable[float]?): Specifies the upper bound for the alpha values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        attrSelected (Queryable[str]?): Returns a name of the currently selected attribute.  
                Q: When queried, it returns a string.  
                Properties: query
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clamp (Queryable[str]?): Specifies if the weight value should be clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamplower (Queryable[float]?): Specifies the lower bound for the values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clampupper (Queryable[float]?): Specifies the upper bound for the values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        colorAlphaValue (Queryable[float]?): The Alpha value of the color.  
                Properties: create, query, edit
        colorRGBAValue (Queryable[Tuple[float, float, float, float]]?): The RGBA value of the color.  
                Properties: create, query, edit
        colorRGBValue (Queryable[Tuple[float, float, float]]?): The RGB value of the color.  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: create, query, edit
        colorfeedback (bool?): Sets on/off the color feedback display.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorfeedbackOverride (bool?): Sets on/off the color feedback override.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorrangelower (Queryable[float]?): Specifies the value that maps to black when  
                color feedback mode is on.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorrangeupper (Queryable[float]?): Specifies the value that maps to the maximum  
                color when color feedback mode is on.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        dataTypeIndex (Queryable[int]?): When the selected paintable attribute is a vectorArray,  
                it specifies which field to paint on.  
                Properties: query, edit
        disablelighting (bool?): If color feedback is on, this flag determines whether  
                lighting is disabled or not for the surfaces that are  
                affected.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        duringStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                during the stroke, each time the mouse is dragged.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        filterNodes (bool?): Sets the node filter.  
                Properties: edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        interactiveUpdate (bool?): Specifies how often to transfer the painted values  
                into the attribute.  
                TRUE: transfer them "continuously" (many times per stroke)  
                FALSE: transfer them only at the end of a stroke (on mouse  
                button release).  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        maxvalue (Queryable[float]?): Specifies the maximum value for each attribute.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        minvalue (Queryable[float]?): Specifies the minimum value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numericColorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors for the  
                numeric display.  
                Properties: create, query, edit
        numericDisplayColor (Queryable[Tuple[float, float, float]]?): Defines a color to be used when displaying numeric values.  
                Properties: create, query, edit
        numericDisplayPrecision (Queryable[int]?): Specifies how many decimal points of precision should be used for the  
                numeric display.  
                Properties: create, query, edit
        numericMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        numericMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        objattrArray (Queryable[str]?): An array of all paintable attributes. Each element of  
                the array is a string with the following information:  
                NodeType.NodeName.AttributeName.MenuType  
                *MenuType: type (level) of the item in the Menu (UI).  
                Q: When queried, it returns a string.  
                Properties: query
        objattrArrayNoMenu (Queryable[str]?): Returns an array of all paintable attributes in their original order.  
                Each element of the array is a string with the following information:  
                NodeType.NodeName.AttributeName  
                Properties: query
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintNodeArray (Queryable[str]?): An array of paintable nodes.  
                Q: When queried, it returns a string.  
                Properties: query
        paintattrselected (str?): An array of selected paintable attributes.  
                Each element of the array is a string with the  
                following information:  
                NodeType.NodeName.AttributeName.  
                Properties: edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectedattroper (Queryable[str]?): Sets the edit weight operation. Four edit weights  
                operations are provided : "absolute" - the value of the weight  
                is replaced by the current one, "additive" - the value of the  
                weight is added to the current one, "scale" - the value of the  
                weight is multiplied by the current one, "smooth" - the value  
                of the weight is divided by the current one.  
                C: Default is "absolute".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toolOffProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned off.  
                For example, cloth invokes "clothPaintToolOff" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is deactivated.  
                It is typical that if you implement a toolOffProc you will  
                want to implement a toolOnProc as well (see the -toolOnProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolOnProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned on.  
                For example, cloth invokes "clothPaintToolOn" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is activated.  
                It is typical that if you implement a toolOnProc you will  
                want to implement a toolOffProc as well (see the -toolOffProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors.  If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: create, query, edit
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: create, query, edit
        useNumericColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors on the numeric display. If this is turned off, the set single  
                numeric color will be used.  
                Properties: create, query, edit
        useNumericDisplay (bool?): Specifies whether numerical weight values should be displayed next to  
                their associated control points.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        value (Queryable[float]?): Specifies the value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        whichTool (Queryable[str]?): The string defines the name of the tool to be  
                used for the Artisan context. An example is "artClothPaint".  
                In query mode, the tool name for the given context is returned.  
                Note: due to the way MEL works, always specify the -query flag  
                last when specifying a flag that takes arguments.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        str: The name of the context created.

    Example:
    """

def artAttrPaintVertexCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., activeListChangedProc: Queryable[str] = ..., afterStrokeCmd: Queryable[str] = ..., alphaclamp: Queryable[str] = ..., alphaclamplower: Queryable[float] = ..., alphaclampupper: Queryable[float] = ..., attrSelected: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clamp: Queryable[str] = ..., clamplower: Queryable[float] = ..., clampupper: Queryable[float] = ..., clear: bool = ..., colorAlphaValue: Queryable[float] = ..., colorRGBAValue: Queryable[Tuple[float, float, float, float]] = ..., colorRGBValue: Queryable[Tuple[float, float, float]] = ..., colorRamp: Queryable[str] = ..., colorfeedback: bool = ..., colorfeedbackOverride: bool = ..., colorrangelower: Queryable[float] = ..., colorrangeupper: Queryable[float] = ..., dataTypeIndex: Queryable[int] = ..., disablelighting: bool = ..., dragSlider: str = ..., duringStrokeCmd: Queryable[str] = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., filterNodes: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., interactiveUpdate: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., maxvalue: Queryable[float] = ..., minvalue: Queryable[float] = ..., name: str = ..., numericColorRamp: Queryable[str] = ..., numericDisplayColor: Queryable[Tuple[float, float, float]] = ..., numericDisplayPrecision: Queryable[int] = ..., numericMaxColor: Queryable[Tuple[float, float, float]] = ..., numericMinColor: Queryable[Tuple[float, float, float]] = ..., objattrArray: Queryable[str] = ..., objattrArrayNoMenu: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintChannel: Queryable[str] = ..., paintComponent: Queryable[int] = ..., paintNodeArray: Queryable[str] = ..., paintNumChannels: Queryable[int] = ..., paintRGBA: bool = ..., paintVertexFace: bool = ..., paintattrselected: str = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., selectedattroper: Queryable[str] = ..., showactive: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toolOffProc: Queryable[str] = ..., toolOnProc: Queryable[str] = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ..., useNumericColorRamp: bool = ..., useNumericDisplay: bool = ..., usepressure: bool = ..., value: Queryable[float] = ..., vertexColorRange: bool = ..., vertexColorRangeLower: Queryable[float] = ..., vertexColorRangeUpper: Queryable[float] = ..., whichTool: Queryable[str] = ..., worldRadius: Queryable[float] = ...) -> Union[bool, str, float, Tuple[float, float, float, float], Tuple[float, float, float], int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This is a context command to set the flags on the artAttrContext,
    which is the base context for attribute painting operations. All
    commands require the name of the context as the last argument as
    this provides the name of the context to create, edit or query.This is a context command to set the flags on the
    Paint color on vertex Tool context.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        activeListChangedProc (Queryable[str]?): Accepts a string that contains a MEL command that is  
                invoked whenever the active list changes. There may be some  
                situations where the UI, for example, needs to be updated,  
                when objects are selected/deselected in the scene. In query  
                mode, the name of the currently registered MEL command is  
                returned and this will be an empty string if none is defined.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphaclamp (Queryable[str]?): Specifies if the weight value should be alpha clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        alphaclamplower (Queryable[float]?): Specifies the lower bound for the alpha values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        alphaclampupper (Queryable[float]?): Specifies the upper bound for the alpha values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        attrSelected (Queryable[str]?): Returns a name of the currently selected attribute.  
                Q: When queried, it returns a string.  
                Properties: query
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clamp (Queryable[str]?): Specifies if the weight value should be clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamplower (Queryable[float]?): Specifies the lower bound for the values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clampupper (Queryable[float]?): Specifies the upper bound for the values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        colorAlphaValue (Queryable[float]?): The Alpha value of the color.  
                Properties: create, query, edit
        colorRGBAValue (Queryable[Tuple[float, float, float, float]]?): The RGBA value of the color.  
                Properties: create, query, edit
        colorRGBValue (Queryable[Tuple[float, float, float]]?): The RGB value of the color.  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: create, query, edit
        colorfeedback (bool?): Sets on/off the color feedback display.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorfeedbackOverride (bool?): Sets on/off the color feedback override.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorrangelower (Queryable[float]?): Specifies the value that maps to black when  
                color feedback mode is on.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorrangeupper (Queryable[float]?): Specifies the value that maps to the maximum  
                color when color feedback mode is on.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        dataTypeIndex (Queryable[int]?): When the selected paintable attribute is a vectorArray,  
                it specifies which field to paint on.  
                Properties: query, edit
        disablelighting (bool?): If color feedback is on, this flag determines whether  
                lighting is disabled or not for the surfaces that are  
                affected.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        duringStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                during the stroke, each time the mouse is dragged.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        filterNodes (bool?): Sets the node filter.  
                Properties: edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        interactiveUpdate (bool?): Specifies how often to transfer the painted values  
                into the attribute.  
                TRUE: transfer them "continuously" (many times per stroke)  
                FALSE: transfer them only at the end of a stroke (on mouse  
                button release).  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        maxvalue (Queryable[float]?): Specifies the maximum value for each attribute.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        minvalue (Queryable[float]?): Specifies the minimum value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numericColorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors for the  
                numeric display.  
                Properties: create, query, edit
        numericDisplayColor (Queryable[Tuple[float, float, float]]?): Defines a color to be used when displaying numeric values.  
                Properties: create, query, edit
        numericDisplayPrecision (Queryable[int]?): Specifies how many decimal points of precision should be used for the  
                numeric display.  
                Properties: create, query, edit
        numericMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        numericMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        objattrArray (Queryable[str]?): An array of all paintable attributes. Each element of  
                the array is a string with the following information:  
                NodeType.NodeName.AttributeName.MenuType  
                *MenuType: type (level) of the item in the Menu (UI).  
                Q: When queried, it returns a string.  
                Properties: query
        objattrArrayNoMenu (Queryable[str]?): Returns an array of all paintable attributes in their original order.  
                Each element of the array is a string with the following information:  
                NodeType.NodeName.AttributeName  
                Properties: query
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintChannel (Queryable[str]?): Channel to paint - RGB, RGBA, R, G, B, A  
                Properties: create, query, edit
        paintComponent (Queryable[int]?): Specifies whether face or vertex or vertex face is being painted.  
                1. Vertex  
                2. VertexFace  
                3. Face  
                C: Default is Vertex.  Q: When queried, it returns a int.  
                Properties: create, query, edit
        paintNodeArray (Queryable[str]?): An array of paintable nodes.  
                Q: When queried, it returns a string.  
                Properties: query
        paintNumChannels (Queryable[int]?): Number of channels to paint - 1 (alpha), 3 (RGB), or 4 (RGBA)  
                Properties: create, query, edit
        paintRGBA (bool?): Specifies whether RGB or RGBA channels are being painted.  
                TRUE: RGBA channels.  
                FALSE: RGB channels. Alpha channel remains unaffected.  
                C: Default is FALSE (Painting RGB channels).  
                Q: When queried, it returns a int.  
                Properties: create, query, edit
        paintVertexFace (bool?): Specifies whether vertex face is being painted.  
                TRUE: Vertex face being painted. (Allows each face connected to the vertex  
                to be painted)  
                FALSE: Vertex being painted.(affects all connected faces)  
                C: Default is FALSE.  Q: When queried, it returns a int.  
                Properties: create, query, edit
        paintattrselected (str?): An array of selected paintable attributes.  
                Each element of the array is a string with the  
                following information:  
                NodeType.NodeName.AttributeName.  
                Properties: edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectedattroper (Queryable[str]?): Sets the edit weight operation. Four edit weights  
                operations are provided : "absolute" - the value of the weight  
                is replaced by the current one, "additive" - the value of the  
                weight is added to the current one, "scale" - the value of the  
                weight is multiplied by the current one, "smooth" - the value  
                of the weight is divided by the current one.  
                C: Default is "absolute".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toolOffProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned off.  
                For example, cloth invokes "clothPaintToolOff" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is deactivated.  
                It is typical that if you implement a toolOffProc you will  
                want to implement a toolOnProc as well (see the -toolOnProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolOnProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned on.  
                For example, cloth invokes "clothPaintToolOn" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is activated.  
                It is typical that if you implement a toolOnProc you will  
                want to implement a toolOffProc as well (see the -toolOffProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors.  If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: create, query, edit
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: create, query, edit
        useNumericColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors on the numeric display. If this is turned off, the set single  
                numeric color will be used.  
                Properties: create, query, edit
        useNumericDisplay (bool?): Specifies whether numerical weight values should be displayed next to  
                their associated control points.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        value (Queryable[float]?): Specifies the value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        vertexColorRange (bool?): Specifies whether the vertex color range should be applied  
                to the currently selected object.  
                C: Default is false  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        vertexColorRangeLower (Queryable[float]?): Specifies the min value of the vertex color range.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        vertexColorRangeUpper (Queryable[float]?): Specifies the max value of the vertex color range.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        whichTool (Queryable[str]?): The string defines the name of the tool to be  
                used for the Artisan context. An example is "artClothPaint".  
                In query mode, the tool name for the given context is returned.  
                Note: due to the way MEL works, always specify the -query flag  
                last when specifying a flag that takes arguments.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artAttrSkinPaintCmd(*args: Any, **kwargs: Any) -> None: ...
def artAttrSkinPaintCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., activeListChangedProc: Queryable[str] = ..., afterStrokeCmd: Queryable[str] = ..., alphaclamp: Queryable[str] = ..., alphaclamplower: Queryable[float] = ..., alphaclampupper: Queryable[float] = ..., attrSelected: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clamp: Queryable[str] = ..., clamplower: Queryable[float] = ..., clampupper: Queryable[float] = ..., clear: bool = ..., colorAlphaValue: Queryable[float] = ..., colorRGBAValue: Queryable[Tuple[float, float, float, float]] = ..., colorRGBValue: Queryable[Tuple[float, float, float]] = ..., colorRamp: Queryable[str] = ..., colorfeedback: bool = ..., colorfeedbackOverride: bool = ..., colorrangelower: Queryable[float] = ..., colorrangeupper: Queryable[float] = ..., dataTypeIndex: Queryable[int] = ..., disablelighting: bool = ..., dragSlider: str = ..., duringStrokeCmd: Queryable[str] = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., filterNodes: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., influence: Queryable[str] = ..., interactiveUpdate: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., maxvalue: Queryable[float] = ..., minvalue: Queryable[float] = ..., name: str = ..., numericColorRamp: Queryable[str] = ..., numericDisplayColor: Queryable[Tuple[float, float, float]] = ..., numericDisplayPrecision: Queryable[int] = ..., numericMaxColor: Queryable[Tuple[float, float, float]] = ..., numericMinColor: Queryable[Tuple[float, float, float]] = ..., objattrArray: Queryable[str] = ..., objattrArrayNoMenu: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintNodeArray: Queryable[str] = ..., paintSelectMode: Queryable[int] = ..., paintattrselected: str = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., selectedattroper: Queryable[str] = ..., showactive: bool = ..., skinPaintMode: Queryable[int] = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toolOffProc: Queryable[str] = ..., toolOnProc: Queryable[str] = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ..., useNumericColorRamp: bool = ..., useNumericDisplay: bool = ..., usepressure: bool = ..., value: Queryable[float] = ..., whichTool: Queryable[str] = ..., worldRadius: Queryable[float] = ..., xrayJoints: bool = ...) -> Union[bool, str, float, Tuple[float, float, float, float], Tuple[float, float, float], int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This is a context command to set the flags on the artAttrContext,
    which is the base context for attribute painting operations. All
    commands require the name of the context as the last argument as
    this provides the name of the context to create, edit or query.This is a context command to set the flags on the
    Paint skin weights tool context.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        activeListChangedProc (Queryable[str]?): Accepts a string that contains a MEL command that is  
                invoked whenever the active list changes. There may be some  
                situations where the UI, for example, needs to be updated,  
                when objects are selected/deselected in the scene. In query  
                mode, the name of the currently registered MEL command is  
                returned and this will be an empty string if none is defined.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphaclamp (Queryable[str]?): Specifies if the weight value should be alpha clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        alphaclamplower (Queryable[float]?): Specifies the lower bound for the alpha values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        alphaclampupper (Queryable[float]?): Specifies the upper bound for the alpha values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        attrSelected (Queryable[str]?): Returns a name of the currently selected attribute.  
                Q: When queried, it returns a string.  
                Properties: query
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clamp (Queryable[str]?): Specifies if the weight value should be clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamplower (Queryable[float]?): Specifies the lower bound for the values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clampupper (Queryable[float]?): Specifies the upper bound for the values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        colorAlphaValue (Queryable[float]?): The Alpha value of the color.  
                Properties: create, query, edit
        colorRGBAValue (Queryable[Tuple[float, float, float, float]]?): The RGBA value of the color.  
                Properties: create, query, edit
        colorRGBValue (Queryable[Tuple[float, float, float]]?): The RGB value of the color.  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: create, query, edit
        colorfeedback (bool?): Sets on/off the color feedback display.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorfeedbackOverride (bool?): Sets on/off the color feedback override.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorrangelower (Queryable[float]?): Specifies the value that maps to black when  
                color feedback mode is on.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorrangeupper (Queryable[float]?): Specifies the value that maps to the maximum  
                color when color feedback mode is on.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        dataTypeIndex (Queryable[int]?): When the selected paintable attribute is a vectorArray,  
                it specifies which field to paint on.  
                Properties: query, edit
        disablelighting (bool?): If color feedback is on, this flag determines whether  
                lighting is disabled or not for the surfaces that are  
                affected.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        duringStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                during the stroke, each time the mouse is dragged.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        filterNodes (bool?): Sets the node filter.  
                Properties: edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        influence (Queryable[str]?): Specifies which joint has been selected by the user for painting.  
                Q: When queried, it returns a string.  
                Properties: query, edit
        interactiveUpdate (bool?): Specifies how often to transfer the painted values  
                into the attribute.  
                TRUE: transfer them "continuously" (many times per stroke)  
                FALSE: transfer them only at the end of a stroke (on mouse  
                button release).  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        maxvalue (Queryable[float]?): Specifies the maximum value for each attribute.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        minvalue (Queryable[float]?): Specifies the minimum value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numericColorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors for the  
                numeric display.  
                Properties: create, query, edit
        numericDisplayColor (Queryable[Tuple[float, float, float]]?): Defines a color to be used when displaying numeric values.  
                Properties: create, query, edit
        numericDisplayPrecision (Queryable[int]?): Specifies how many decimal points of precision should be used for the  
                numeric display.  
                Properties: create, query, edit
        numericMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        numericMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        objattrArray (Queryable[str]?): An array of all paintable attributes. Each element of  
                the array is a string with the following information:  
                NodeType.NodeName.AttributeName.MenuType  
                *MenuType: type (level) of the item in the Menu (UI).  
                Q: When queried, it returns a string.  
                Properties: query
        objattrArrayNoMenu (Queryable[str]?): Returns an array of all paintable attributes in their original order.  
                Each element of the array is a string with the following information:  
                NodeType.NodeName.AttributeName  
                Properties: query
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintNodeArray (Queryable[str]?): An array of paintable nodes.  
                Q: When queried, it returns a string.  
                Properties: query
        paintSelectMode (Queryable[int]?): Specifies whether the paint select tool: adds to selection (1)  
                removes from selection (2), toggles selection (3)  
                Q: When queried, it returns an int as defined above.  
                Properties: query, edit
        paintattrselected (str?): An array of selected paintable attributes.  
                Each element of the array is a string with the  
                following information:  
                NodeType.NodeName.AttributeName.  
                Properties: edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectedattroper (Queryable[str]?): Sets the edit weight operation. Four edit weights  
                operations are provided : "absolute" - the value of the weight  
                is replaced by the current one, "additive" - the value of the  
                weight is added to the current one, "scale" - the value of the  
                weight is multiplied by the current one, "smooth" - the value  
                of the weight is divided by the current one.  
                C: Default is "absolute".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        skinPaintMode (Queryable[int]?): Specifies whether the skin paint tool is in paint skin weights mode (1)  
                Marquee select mode (0), or paint select mode (2)  
                Q: When queried, it returns an int as defined above.  
                Properties: query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toolOffProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned off.  
                For example, cloth invokes "clothPaintToolOff" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is deactivated.  
                It is typical that if you implement a toolOffProc you will  
                want to implement a toolOnProc as well (see the -toolOnProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolOnProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned on.  
                For example, cloth invokes "clothPaintToolOn" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is activated.  
                It is typical that if you implement a toolOnProc you will  
                want to implement a toolOffProc as well (see the -toolOffProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors.  If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: create, query, edit
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: create, query, edit
        useNumericColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors on the numeric display. If this is turned off, the set single  
                numeric color will be used.  
                Properties: create, query, edit
        useNumericDisplay (bool?): Specifies whether numerical weight values should be displayed next to  
                their associated control points.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        value (Queryable[float]?): Specifies the value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        whichTool (Queryable[str]?): The string defines the name of the tool to be  
                used for the Artisan context. An example is "artClothPaint".  
                In query mode, the tool name for the given context is returned.  
                Note: due to the way MEL works, always specify the -query flag  
                last when specifying a flag that takes arguments.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit
        xrayJoints (bool?): Specifies whether joints should be displayed in xray mode while painting  
                Q: When queried, it returns a boolean.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artAttrTool(*args: Any, query: bool = ..., add: str = ..., exists: Queryable[str] = ..., remove: str = ...) -> Union[bool, str]:
    """The artAttrTool command manages the list of tool types which are
            used for attribute painting. This command supports querying the
            list contents as well as adding new tools to the list. Note that
            there is a set of built-in tools. The list of built-ins can
            be queried by starting Maya and doing an "artAttrTool -q".The tools which are managed by this command are all intended for
            attribute painting via Artisan: when you create a new context via
            artAttrCtx you specify the tool name via artAttrCtx'sflag. Typically the user may wish to simply use one of the built-in
            tools. However, if you need to have custom Properties and Values sheets
            asscociated with your tool, you will need to define a custom tool
            via. For an example of a custom
            attribute painting tool, see the devkit example customtoolPaint.mel.artisan, attribute, paint, context
    Args:
        add (str?): Adds the named tool to the internal list of tools.  
                Properties: create
        exists (Queryable[str]?): Checks if the named tool exists, returning true if found, and false otherwise.  
                Properties: create, query
        remove (str?): Removes the named tool from the internal list of tools.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artBaseCtx(*args: Any, **kwargs: Any) -> None: ...
def artBuildPaintMenu(*args: str) -> bool:
    """??polygons
    Returns:
        bool:

    Example:
    """

def artFluidAttr(*args: Any, **kwargs: Any) -> None: ...
def artFluidAttrCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., activeListChangedProc: Queryable[str] = ..., afterStrokeCmd: Queryable[str] = ..., alphaclamp: Queryable[str] = ..., alphaclamplower: Queryable[float] = ..., alphaclampupper: Queryable[float] = ..., attrSelected: Queryable[str] = ..., autoSave: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clamp: Queryable[str] = ..., clamplower: Queryable[float] = ..., clampupper: Queryable[float] = ..., clear: bool = ..., colorAlphaValue: Queryable[float] = ..., colorRGBAValue: Queryable[Tuple[float, float, float, float]] = ..., colorRGBValue: Queryable[Tuple[float, float, float]] = ..., colorRamp: Queryable[str] = ..., colorfeedback: bool = ..., colorfeedbackOverride: bool = ..., colorrangelower: Queryable[float] = ..., colorrangeupper: Queryable[float] = ..., currentPaintableFluid: Queryable[str] = ..., dataTypeIndex: Queryable[int] = ..., delaySelectionChanged: bool = ..., disablelighting: bool = ..., displayAsRender: bool = ..., displayVelocity: bool = ..., doAutoSave: bool = ..., dragSlider: str = ..., duringStrokeCmd: Queryable[str] = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., filterNodes: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., interactiveUpdate: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., maxvalue: Queryable[float] = ..., minvalue: Queryable[float] = ..., name: str = ..., numericColorRamp: Queryable[str] = ..., numericDisplayColor: Queryable[Tuple[float, float, float]] = ..., numericDisplayPrecision: Queryable[int] = ..., numericMaxColor: Queryable[Tuple[float, float, float]] = ..., numericMinColor: Queryable[Tuple[float, float, float]] = ..., objattrArray: Queryable[str] = ..., objattrArrayNoMenu: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintNodeArray: Queryable[str] = ..., paintattrselected: str = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., property: Queryable[str] = ..., radius: Queryable[float] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., rgbValue: Queryable[Tuple[float, float, float]] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., selectedattroper: Queryable[str] = ..., showactive: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toolOffProc: Queryable[str] = ..., toolOnProc: Queryable[str] = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ..., useNumericColorRamp: bool = ..., useNumericDisplay: bool = ..., useStrokeDirection: bool = ..., usepressure: bool = ..., value: Queryable[float] = ..., velocity: Queryable[Tuple[float, float, float]] = ..., whichTool: Queryable[str] = ..., worldRadius: Queryable[float] = ...) -> Union[bool, str, float, Tuple[float, float, float, float], Tuple[float, float, float], int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This is a context command to set the flags on the artAttrContext,
    which is the base context for attribute painting operations. All
    commands require the name of the context as the last argument as
    this provides the name of the context to create, edit or query.This command is used to paint properties
    (such as density) of selected fluid volumes.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        activeListChangedProc (Queryable[str]?): Accepts a string that contains a MEL command that is  
                invoked whenever the active list changes. There may be some  
                situations where the UI, for example, needs to be updated,  
                when objects are selected/deselected in the scene. In query  
                mode, the name of the currently registered MEL command is  
                returned and this will be an empty string if none is defined.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphaclamp (Queryable[str]?): Specifies if the weight value should be alpha clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        alphaclamplower (Queryable[float]?): Specifies the lower bound for the alpha values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        alphaclampupper (Queryable[float]?): Specifies the upper bound for the alpha values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        attrSelected (Queryable[str]?): Returns a name of the currently selected attribute.  
                Q: When queried, it returns a string.  
                Properties: query
        autoSave (Queryable[str]?): A MEL command to save the fluid state.  Called  
                before an event which could overwrite unsaved values of  
                painted fluid properties.  Such events include: changing  
                current time, changing the current paintable property, and  
                exiting the paint tool.  (To turn auto-save off, pass in  
                an empty-valued string argument: e.g., "".)  
                Properties: create, query, edit
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clamp (Queryable[str]?): Specifies if the weight value should be clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamplower (Queryable[float]?): Specifies the lower bound for the values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clampupper (Queryable[float]?): Specifies the upper bound for the values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        colorAlphaValue (Queryable[float]?): The Alpha value of the color.  
                Properties: create, query, edit
        colorRGBAValue (Queryable[Tuple[float, float, float, float]]?): The RGBA value of the color.  
                Properties: create, query, edit
        colorRGBValue (Queryable[Tuple[float, float, float]]?): The RGB value of the color.  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: create, query, edit
        colorfeedback (bool?): Sets on/off the color feedback display.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorfeedbackOverride (bool?): Sets on/off the color feedback override.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorrangelower (Queryable[float]?): Specifies the value that maps to black when  
                color feedback mode is on.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorrangeupper (Queryable[float]?): Specifies the value that maps to the maximum  
                color when color feedback mode is on.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        currentPaintableFluid (Queryable[str]?): Query the name of the fluid on which this context is  
                currently painting.  Returns string.  
                Properties: query
        dataTypeIndex (Queryable[int]?): When the selected paintable attribute is a vectorArray,  
                it specifies which field to paint on.  
                Properties: query, edit
        delaySelectionChanged (bool?): Internal use only.  Under normal conditions,  
                the tool responds to changes to the selection list so it  
                can update its list of paintable geometry.  When  
                -dsl true is used, the tool will not update its paintable  
                list until a corresponding -dsl false is called.  
                Properties: create, query, edit
        disablelighting (bool?): If color feedback is on, this flag determines whether  
                lighting is disabled or not for the surfaces that are  
                affected.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        displayAsRender (bool?): When true, sets the "Shaded Display" attribute  
                of the fluid to "AsRender": all fluid properties displayed  
                as hardware rendered.  When false, displays only the  
                currently selected paintable attribute of the fluid.  
                Properties: create, query, edit
        displayVelocity (bool?): Turns on/off velocity display, independently of the  
                above "dar/displayAsRender" setting.  Use this flag  
                to enable velocity display while only displaying density, for  
                example.  
                Properties: create, query, edit
        doAutoSave (bool?): Execute the -autoSave command if there are  
                unsaved painted fluid properties.  
                Properties: edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        duringStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                during the stroke, each time the mouse is dragged.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        filterNodes (bool?): Sets the node filter.  
                Properties: edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        interactiveUpdate (bool?): Specifies how often to transfer the painted values  
                into the attribute.  
                TRUE: transfer them "continuously" (many times per stroke)  
                FALSE: transfer them only at the end of a stroke (on mouse  
                button release).  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        maxvalue (Queryable[float]?): Specifies the maximum value for each attribute.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        minvalue (Queryable[float]?): Specifies the minimum value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numericColorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors for the  
                numeric display.  
                Properties: create, query, edit
        numericDisplayColor (Queryable[Tuple[float, float, float]]?): Defines a color to be used when displaying numeric values.  
                Properties: create, query, edit
        numericDisplayPrecision (Queryable[int]?): Specifies how many decimal points of precision should be used for the  
                numeric display.  
                Properties: create, query, edit
        numericMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        numericMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        objattrArray (Queryable[str]?): An array of all paintable attributes. Each element of  
                the array is a string with the following information:  
                NodeType.NodeName.AttributeName.MenuType  
                *MenuType: type (level) of the item in the Menu (UI).  
                Q: When queried, it returns a string.  
                Properties: query
        objattrArrayNoMenu (Queryable[str]?): Returns an array of all paintable attributes in their original order.  
                Each element of the array is a string with the following information:  
                NodeType.NodeName.AttributeName  
                Properties: query
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintNodeArray (Queryable[str]?): An array of paintable nodes.  
                Q: When queried, it returns a string.  
                Properties: query
        paintattrselected (str?): An array of selected paintable attributes.  
                Each element of the array is a string with the  
                following information:  
                NodeType.NodeName.AttributeName.  
                Properties: edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        property (Queryable[str]?): Specifies a property to paint on the fluid.  
                Valid values are "color", "density", "densityAndColor,"  
                "densityAndFuel," "temperature," "fuel", "velocity".  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        rgbValue (Queryable[Tuple[float, float, float]]?): Specifies the values of the red, green, and  
                blue components of the color to  
                use when painting the property "color."  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectedattroper (Queryable[str]?): Sets the edit weight operation. Four edit weights  
                operations are provided : "absolute" - the value of the weight  
                is replaced by the current one, "additive" - the value of the  
                weight is added to the current one, "scale" - the value of the  
                weight is multiplied by the current one, "smooth" - the value  
                of the weight is divided by the current one.  
                C: Default is "absolute".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toolOffProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned off.  
                For example, cloth invokes "clothPaintToolOff" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is deactivated.  
                It is typical that if you implement a toolOffProc you will  
                want to implement a toolOnProc as well (see the -toolOnProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolOnProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned on.  
                For example, cloth invokes "clothPaintToolOn" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is activated.  
                It is typical that if you implement a toolOnProc you will  
                want to implement a toolOffProc as well (see the -toolOffProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors.  If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: create, query, edit
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: create, query, edit
        useNumericColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors on the numeric display. If this is turned off, the set single  
                numeric color will be used.  
                Properties: create, query, edit
        useNumericDisplay (bool?): Specifies whether numerical weight values should be displayed next to  
                their associated control points.  
                Properties: create, query, edit
        useStrokeDirection (bool?): Applicable only during "velocity"  
                painting.  Specifies whether the value of the  
                painted velocity should come from the direction  
                of the brush stroke, overriding the value specified  
                by the -v/-velocity flag.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        value (Queryable[float]?): Specifies the value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        velocity (Queryable[Tuple[float, float, float]]?): Specifies the values of the x, y, and z  
                components of the velocity to use when painting the property  
                "velocity".  
                Properties: create, query, edit
        whichTool (Queryable[str]?): The string defines the name of the tool to be  
                used for the Artisan context. An example is "artClothPaint".  
                In query mode, the tool name for the given context is returned.  
                Note: due to the way MEL works, always specify the -query flag  
                last when specifying a flag that takes arguments.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artPuttyCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., activeListChangedProc: Queryable[str] = ..., afterStrokeCmd: Queryable[str] = ..., alphaclamp: Queryable[str] = ..., alphaclamplower: Queryable[float] = ..., alphaclampupper: Queryable[float] = ..., attrSelected: Queryable[str] = ..., autosmooth: bool = ..., beforeStrokeCmd: Queryable[str] = ..., brushStrength: Queryable[float] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clamp: Queryable[str] = ..., clamplower: Queryable[float] = ..., clampupper: Queryable[float] = ..., clear: bool = ..., collapsecvtol: Queryable[float] = ..., colorAlphaValue: Queryable[float] = ..., colorRGBAValue: Queryable[Tuple[float, float, float, float]] = ..., colorRGBValue: Queryable[Tuple[float, float, float]] = ..., colorRamp: Queryable[str] = ..., colorfeedback: bool = ..., colorfeedbackOverride: bool = ..., colorrangelower: Queryable[float] = ..., colorrangeupper: Queryable[float] = ..., dataTypeIndex: Queryable[int] = ..., disablelighting: bool = ..., dispdecr: bool = ..., dispincr: bool = ..., dragSlider: str = ..., duringStrokeCmd: Queryable[str] = ..., dynclonemode: bool = ..., erasesrfupd: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., filterNodes: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., interactiveUpdate: bool = ..., invertrefvector: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., maxdisp: Queryable[float] = ..., maxvalue: Queryable[float] = ..., minvalue: Queryable[float] = ..., mouldtypehead: Queryable[str] = ..., mouldtypemouse: Queryable[str] = ..., mouldtypetail: Queryable[str] = ..., name: str = ..., numericColorRamp: Queryable[str] = ..., numericDisplayColor: Queryable[Tuple[float, float, float]] = ..., numericDisplayPrecision: Queryable[int] = ..., numericMaxColor: Queryable[Tuple[float, float, float]] = ..., numericMinColor: Queryable[Tuple[float, float, float]] = ..., objattrArray: Queryable[str] = ..., objattrArrayNoMenu: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintNodeArray: Queryable[str] = ..., paintattrselected: str = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., polecv: bool = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., refsurface: bool = ..., refvector: Queryable[str] = ..., refvectoru: Queryable[float] = ..., refvectorv: Queryable[float] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., selectedattroper: Queryable[str] = ..., showactive: bool = ..., smoothiters: Queryable[int] = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., stitchcorner: bool = ..., stitchedgeflood: bool = ..., stitchtype: Queryable[str] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toolOffProc: Queryable[str] = ..., toolOnProc: Queryable[str] = ..., updateerasesrf: bool = ..., updaterefsrf: bool = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ..., useNumericColorRamp: bool = ..., useNumericDisplay: bool = ..., usepressure: bool = ..., value: Queryable[float] = ..., whichTool: Queryable[str] = ..., worldRadius: Queryable[float] = ...) -> Union[bool, str, float, Tuple[float, float, float, float], Tuple[float, float, float], int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This is a context command to set the flags on the artAttrContext,
    which is the base context for attribute painting operations. All
    commands require the name of the context as the last argument as
    this provides the name of the context to create, edit or query.This command is used to modify NURBS surfaces using a brush based
    interface (Maya Artisan). This is accomplished by moving the control
    vertices (CVs) under the brush in the specified direction.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        activeListChangedProc (Queryable[str]?): Accepts a string that contains a MEL command that is  
                invoked whenever the active list changes. There may be some  
                situations where the UI, for example, needs to be updated,  
                when objects are selected/deselected in the scene. In query  
                mode, the name of the currently registered MEL command is  
                returned and this will be an empty string if none is defined.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphaclamp (Queryable[str]?): Specifies if the weight value should be alpha clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        alphaclamplower (Queryable[float]?): Specifies the lower bound for the alpha values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        alphaclampupper (Queryable[float]?): Specifies the upper bound for the alpha values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        attrSelected (Queryable[str]?): Returns a name of the currently selected attribute.  
                Q: When queried, it returns a string.  
                Properties: query
        autosmooth (bool?): Sets up the auto smoothing option. When the brush  
                is in the smooth mode, adjusting the strength will adjust how  
                fast the surfaces is smoothed out.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushStrength (Queryable[float]?): Sets the strength of the brush. Brush strength is supported  
                by the pinch and slide brushes. In pinch mode, adjusting the strength  
                will adjust how quickly the surface converges on the brush  
                center. In slide mode, the strength scales the motion of the brush.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clamp (Queryable[str]?): Specifies if the weight value should be clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamplower (Queryable[float]?): Specifies the lower bound for the values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clampupper (Queryable[float]?): Specifies the upper bound for the values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        collapsecvtol (Queryable[float]?): Specifies the tolerance for the collapse cv detection.  
                C: Default is 0.005 cm.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorAlphaValue (Queryable[float]?): The Alpha value of the color.  
                Properties: create, query, edit
        colorRGBAValue (Queryable[Tuple[float, float, float, float]]?): The RGBA value of the color.  
                Properties: create, query, edit
        colorRGBValue (Queryable[Tuple[float, float, float]]?): The RGB value of the color.  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: create, query, edit
        colorfeedback (bool?): Sets on/off the color feedback display.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorfeedbackOverride (bool?): Sets on/off the color feedback override.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorrangelower (Queryable[float]?): Specifies the value that maps to black when  
                color feedback mode is on.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorrangeupper (Queryable[float]?): Specifies the value that maps to the maximum  
                color when color feedback mode is on.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        dataTypeIndex (Queryable[int]?): When the selected paintable attribute is a vectorArray,  
                it specifies which field to paint on.  
                Properties: query, edit
        disablelighting (bool?): If color feedback is on, this flag determines whether  
                lighting is disabled or not for the surfaces that are  
                affected.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        dispdecr (bool?): Decreases a maximum displacement by 10%.  
                Properties: create, edit
        dispincr (bool?): Increases a maximum displacement by 10%.  
                Properties: create, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        duringStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                during the stroke, each time the mouse is dragged.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        erasesrfupd (bool?): Toggles the update for the erase surface  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        filterNodes (bool?): Sets the node filter.  
                Properties: edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        interactiveUpdate (bool?): Specifies how often to transfer the painted values  
                into the attribute.  
                TRUE: transfer them "continuously" (many times per stroke)  
                FALSE: transfer them only at the end of a stroke (on mouse  
                button release).  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        invertrefvector (bool?): Sets the invert of the reference vector option when  
                the reflection is ON. If it is true, the reference vector  
                for the reflected stroke is negated with respect to the original  
                one.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        maxdisp (Queryable[float]?): Defines a maximum displacement  
                ( maxDisp in [0.0..5.0] ).  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        maxvalue (Queryable[float]?): Specifies the maximum value for each attribute.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        minvalue (Queryable[float]?): Specifies the minimum value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        mouldtypehead (Queryable[str]?): Type of type mould to use  
                Properties: create, query, edit
        mouldtypemouse (Queryable[str]?): Specifies the putty operations/mode ("push" - pushes CVs  
                along the given direction (see refvector flag), "pull" - pulls  
                CVs along the specified direction, "smooth" - smooths the sculpt,  
                "erase" - erases the paint).  
                C: Default is "push".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        mouldtypetail (Queryable[str]?): Type of eraser mould to use  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numericColorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors for the  
                numeric display.  
                Properties: create, query, edit
        numericDisplayColor (Queryable[Tuple[float, float, float]]?): Defines a color to be used when displaying numeric values.  
                Properties: create, query, edit
        numericDisplayPrecision (Queryable[int]?): Specifies how many decimal points of precision should be used for the  
                numeric display.  
                Properties: create, query, edit
        numericMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        numericMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        objattrArray (Queryable[str]?): An array of all paintable attributes. Each element of  
                the array is a string with the following information:  
                NodeType.NodeName.AttributeName.MenuType  
                *MenuType: type (level) of the item in the Menu (UI).  
                Q: When queried, it returns a string.  
                Properties: query
        objattrArrayNoMenu (Queryable[str]?): Returns an array of all paintable attributes in their original order.  
                Each element of the array is a string with the following information:  
                NodeType.NodeName.AttributeName  
                Properties: query
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintNodeArray (Queryable[str]?): An array of paintable nodes.  
                Q: When queried, it returns a string.  
                Properties: query
        paintattrselected (str?): An array of selected paintable attributes.  
                Each element of the array is a string with the  
                following information:  
                NodeType.NodeName.AttributeName.  
                Properties: edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        polecv (bool?): Pull all the pole CVs to the same position.  
                Properties: create, query, edit
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        refsurface (bool?): Sets on/off the update of the reference surface.  
                If it is true the reference surface is automatically updated  
                on the per stroke bases. If it is false, the user has to update  
                the reference surface explicitly by pressing the update button  
                (see updaterefsrf).  
                C: Default is TRUE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        refvector (Queryable[str]?): Specifies the direction of the push/pull operation  
                ("normal" - sculpt along normals, "firstnormal" - sculpt along  
                the first normal of the stroke, "view" - sculpt along the view  
                direction, "xaxis", "yaxis", "zaxis" - sculpt along a given  
                axis directions, "uisoparm", "visoparm" - sculpt along U or V  
                isoparametric lines), "uvvector" - sculpt along an arbitrary  
                vector in UV space.  
                C: Default is "normal".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        refvectoru (Queryable[float]?): Specifies the U component of the UV vector to be used  
                when -refVector is set to "uvvector".  
                Properties: create, query, edit
        refvectorv (Queryable[float]?): Specifies the V component of the UV vector to be used  
                when -refVector is set to "uvvector".  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectedattroper (Queryable[str]?): Sets the edit weight operation. Four edit weights  
                operations are provided : "absolute" - the value of the weight  
                is replaced by the current one, "additive" - the value of the  
                weight is added to the current one, "scale" - the value of the  
                weight is multiplied by the current one, "smooth" - the value  
                of the weight is divided by the current one.  
                C: Default is "absolute".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        smoothiters (Queryable[int]?): Sets the quality of the smoothing operation (number of  
                iterations).  
                C: Default is 3.  Q: When queried, it returns an int.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        stitchcorner (bool?): Sets on/off the stitching corner mode  
                C: Default is "off".  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stitchedgeflood (bool?): Triggers postprocessing stitching edge procedure.  
                Properties: edit
        stitchtype (Queryable[str]?): Sets on/off the stitching mode ( "off" - stitching  
                is turned off, "position" - position stitching is done without  
                taking care about the tangent continuity C0, "tan" - C1  
                continuity is preserved).  
                C: Default is "position".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toolOffProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned off.  
                For example, cloth invokes "clothPaintToolOff" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is deactivated.  
                It is typical that if you implement a toolOffProc you will  
                want to implement a toolOnProc as well (see the -toolOnProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolOnProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned on.  
                For example, cloth invokes "clothPaintToolOn" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is activated.  
                It is typical that if you implement a toolOnProc you will  
                want to implement a toolOffProc as well (see the -toolOffProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        updateerasesrf (bool?): Updates the erase surface.  
                Properties: create, edit
        updaterefsrf (bool?): Updates the reference surface.  
                Properties: create, edit
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors.  If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: create, query, edit
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: create, query, edit
        useNumericColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors on the numeric display. If this is turned off, the set single  
                numeric color will be used.  
                Properties: create, query, edit
        useNumericDisplay (bool?): Specifies whether numerical weight values should be displayed next to  
                their associated control points.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        value (Queryable[float]?): Specifies the value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        whichTool (Queryable[str]?): The string defines the name of the tool to be  
                used for the Artisan context. An example is "artClothPaint".  
                In query mode, the tool name for the given context is returned.  
                Note: due to the way MEL works, always specify the -query flag  
                last when specifying a flag that takes arguments.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artSelect(*args: str) -> None: ...
def artSelectCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., addselection: bool = ..., afterStrokeCmd: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clear: bool = ..., dragSlider: str = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., importthreshold: Queryable[float] = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., name: str = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., screenRadius: Queryable[float] = ..., selectall: bool = ..., selectclonesource: bool = ..., selectop: Queryable[str] = ..., showactive: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toggleall: bool = ..., unselectall: bool = ..., usepressure: bool = ..., worldRadius: Queryable[float] = ...) -> Union[bool, str, float, int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This command is used to select/deselect/toggle components on
    selected surfaces using a brush interface (Maya Artisan). Since,
    it selects components of the surface, it only works in the
    component mode.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        addselection (bool?): If true, each new stroke adds cvs to the active  
                list. If false, each stroke replaces the previous selection.  
                C: Default is true. Q: When queried, it returns a boole  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        importthreshold (Queryable[float]?): Specifies the threshold for the import of  
                the attribute maps.  
                C: Default is 0.5.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectall (bool?): Selects all vertices/egdes/faces/uvs.  
                Properties: create, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectop (Queryable[str]?): Specifies the selection operation  
                ("select", "unselect", "toggle").  
                C: Default is "select". Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toggleall (bool?): Toggle all vertices/egdes/faces/uvs.  
                Properties: create, edit
        unselectall (bool?): Unselects all vertices/egdes/faces/uvs.  
                Properties: create, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artSetPaint(*args: str) -> None: ...
def artSetPaintCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., afterStrokeCmd: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., clear: bool = ..., dragSlider: str = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., name: str = ..., objectsetnames: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., setcolorfeedback: bool = ..., setdisplaycvs: bool = ..., setopertype: Queryable[str] = ..., settomodify: Queryable[str] = ..., showactive: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., usepressure: bool = ..., worldRadius: Queryable[float] = ...) -> Union[bool, str, float, int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This tool allows the user to modify the set membership
    (add, transfer, remove cvs) on nurbs surfaces using Maya
    Artisan's interface.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        objectsetnames (Queryable[str]?): Default name of object sets  
                Properties: create, query, edit
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        setcolorfeedback (bool?): Specifies if the color feedback is on or off.  
                C: Default is ON.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        setdisplaycvs (bool?): Specifies if the active cvs are displayed.  
                C: Default is ON. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        setopertype (Queryable[str]?): Specifies the setEdit operation  
                ("add", "transfer", "remove").  
                C: Default is "add". Q: When queried, it returns a string.  
                Properties: create, query, edit
        settomodify (Queryable[str]?): Specifies the name of the set to modify.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def artUserPaintCtx(*args: Any, edit: bool = ..., query: bool = ..., accopacity: bool = ..., activeListChangedProc: Queryable[str] = ..., afterStrokeCmd: Queryable[str] = ..., alphaclamp: Queryable[str] = ..., alphaclamplower: Queryable[float] = ..., alphaclampupper: Queryable[float] = ..., attrSelected: Queryable[str] = ..., beforeStrokeCmd: Queryable[str] = ..., brushalignment: bool = ..., brushfeedback: bool = ..., chunkCommand: Queryable[str] = ..., clamp: Queryable[str] = ..., clamplower: Queryable[float] = ..., clampupper: Queryable[float] = ..., clear: bool = ..., colorAlphaValue: Queryable[float] = ..., colorRGBAValue: Queryable[Tuple[float, float, float, float]] = ..., colorRGBValue: Queryable[Tuple[float, float, float]] = ..., colorRamp: Queryable[str] = ..., colorfeedback: bool = ..., colorfeedbackOverride: bool = ..., colorrangelower: Queryable[float] = ..., colorrangeupper: Queryable[float] = ..., dataTypeIndex: Queryable[int] = ..., disablelighting: bool = ..., dragSlider: str = ..., duringStrokeCmd: Queryable[str] = ..., dynclonemode: bool = ..., exists: bool = ..., expandfilename: bool = ..., exportaspectratio: Queryable[float] = ..., exportfilemode: Queryable[str] = ..., exportfilesave: str = ..., exportfilesizex: Queryable[int] = ..., exportfilesizey: Queryable[int] = ..., exportfiletype: Queryable[str] = ..., filterNodes: bool = ..., finalizeCmd: Queryable[str] = ..., fullpaths: bool = ..., getArrayAttrCommand: Queryable[str] = ..., getSurfaceCommand: Queryable[str] = ..., getValueCommand: Queryable[str] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., importfileload: str = ..., importfilemode: Queryable[str] = ..., importreassign: bool = ..., initializeCmd: Queryable[str] = ..., interactiveUpdate: bool = ..., lastRecorderCmd: Queryable[str] = ..., lastStampName: Queryable[str] = ..., lowerradius: Queryable[float] = ..., makeStroke: Queryable[Multiuse[int]] = ..., mappressure: Queryable[str] = ..., maxvalue: Queryable[float] = ..., minvalue: Queryable[float] = ..., name: str = ..., numericColorRamp: Queryable[str] = ..., numericDisplayColor: Queryable[Tuple[float, float, float]] = ..., numericDisplayPrecision: Queryable[int] = ..., numericMaxColor: Queryable[Tuple[float, float, float]] = ..., numericMinColor: Queryable[Tuple[float, float, float]] = ..., objattrArray: Queryable[str] = ..., objattrArrayNoMenu: Queryable[str] = ..., opacity: Queryable[float] = ..., outline: bool = ..., outwhilepaint: bool = ..., paintNodeArray: Queryable[str] = ..., paintattrselected: str = ..., paintmode: Queryable[str] = ..., paintoperationtype: Queryable[str] = ..., pickColor: bool = ..., pickValue: bool = ..., playbackCursor: Queryable[Multiuse[Tuple[float, float]]] = ..., playbackPressure: Queryable[Multiuse[float]] = ..., preserveclonesource: bool = ..., profileShapeFile: Queryable[str] = ..., projective: bool = ..., radius: Queryable[float] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., record: bool = ..., reflection: bool = ..., reflectionaboutorigin: bool = ..., reflectionaxis: Queryable[str] = ..., screenRadius: Queryable[float] = ..., selectclonesource: bool = ..., selectedattroper: Queryable[str] = ..., setArrayValueCommand: Queryable[str] = ..., setValueCommand: Queryable[str] = ..., showactive: bool = ..., stampDepth: Queryable[float] = ..., stampProfile: Queryable[str] = ..., stampSpacing: Queryable[float] = ..., strokesmooth: Queryable[str] = ..., surfaceConformedBrushVertices: bool = ..., tablet: bool = ..., tangentOutline: bool = ..., toolCleanupCmd: Queryable[str] = ..., toolOffProc: Queryable[str] = ..., toolOnProc: Queryable[str] = ..., toolSetupCmd: Queryable[str] = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ..., useNumericColorRamp: bool = ..., useNumericDisplay: bool = ..., usepressure: bool = ..., value: Queryable[float] = ..., whichTool: Queryable[str] = ..., worldRadius: Queryable[float] = ...) -> Union[str, bool, float, Tuple[float, float, float, float], Tuple[float, float, float], int, Multiuse[int], Multiuse[Tuple[float, float]], Multiuse[float]]:
    """This is a context command to set the flags on the artAttrContext,
    which is the base context for attribute painting operations. All
    commands require the name of the context as the last argument as
    this provides the name of the context to create, edit or query.This command executes a scriptable paint (Maya Artisan). It
    allows the user to apply Mel commands/scripts to modify cvs'
    attributes for all cvs under the paint brush.
    Args:
        accopacity (bool?): Sets opacity accumulation on/off.  
                C: Default is false (Except for sculpt tool for which it is true by default).  
                Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        activeListChangedProc (Queryable[str]?): Accepts a string that contains a MEL command that is  
                invoked whenever the active list changes. There may be some  
                situations where the UI, for example, needs to be updated,  
                when objects are selected/deselected in the scene. In query  
                mode, the name of the currently registered MEL command is  
                returned and this will be an empty string if none is defined.  
                Properties: create, query, edit
        afterStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately after the end of a stroke.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        alphaclamp (Queryable[str]?): Specifies if the weight value should be alpha clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        alphaclamplower (Queryable[float]?): Specifies the lower bound for the alpha values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        alphaclampupper (Queryable[float]?): Specifies the upper bound for the alpha values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        attrSelected (Queryable[str]?): Returns a name of the currently selected attribute.  
                Q: When queried, it returns a string.  
                Properties: query
        beforeStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                immediately before the start of a stroke.  
                C: Default is no command. Q: When queried, it returns the  
                current command  
                Properties: create, query, edit
        brushalignment (bool?): Specifies the path brush alignemnt. If true,  
                the brush will align to stroke path, otherwise it will  
                align to up vector.  
                C: Default is true. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        brushfeedback (bool?): Specifies if the brush additional feedback should  
                be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        chunkCommand (Queryable[str]?): Specifies th name of the Mel script/procedure that is  
                called once for every selected surface when a chunk is  
                received on that surface.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamp (Queryable[str]?): Specifies if the weight value should be clamped to  
                the lower and upper bounds. There are four options here:  
                "none" - no clamping is performed, "lower" - clamps only to  
                the lower bound, "upper" - clamps only to the upper bounds,  
                "both" - clamps to the lower and upper bounds.  
                C: Default is "none".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        clamplower (Queryable[float]?): Specifies the lower bound for the values.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clampupper (Queryable[float]?): Specifies the upper bound for the values.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        clear (bool?): Floods all cvs/vertices to the current value.  
                Properties: create, edit
        colorAlphaValue (Queryable[float]?): The Alpha value of the color.  
                Properties: create, query, edit
        colorRGBAValue (Queryable[Tuple[float, float, float, float]]?): The RGBA value of the color.  
                Properties: create, query, edit
        colorRGBValue (Queryable[Tuple[float, float, float]]?): The RGB value of the color.  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: create, query, edit
        colorfeedback (bool?): Sets on/off the color feedback display.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorfeedbackOverride (bool?): Sets on/off the color feedback override.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        colorrangelower (Queryable[float]?): Specifies the value that maps to black when  
                color feedback mode is on.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        colorrangeupper (Queryable[float]?): Specifies the value that maps to the maximum  
                color when color feedback mode is on.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        dataTypeIndex (Queryable[int]?): When the selected paintable attribute is a vectorArray,  
                it specifies which field to paint on.  
                Properties: query, edit
        disablelighting (bool?): If color feedback is on, this flag determines whether  
                lighting is disabled or not for the surfaces that are  
                affected.  
                C: Default is FALSE.  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        dragSlider (str?): Sets the current brush drag state for resizing or  
                offsetting the brush (like the 'b' and 'm' default hotkeys).  
                The string argument is one of: "radius", "lowradius",  
                "opacity", "value", "depth", "displacement", "uvvector"  
                or "none".  
                C: Default is "none".  
                Properties: create, edit
        duringStrokeCmd (Queryable[str]?): The passed string is executed as a MEL command  
                during the stroke, each time the mouse is dragged.  
                C: Default is no command. Q: When queried, it returns  
                the current command  
                Properties: create, query, edit
        dynclonemode (bool?): Enable or disable dynamic clone mode.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        expandfilename (bool?): If true, it will expand the name of the export file  
                and concatenate it with the surface name. Otherwise it  
                will take the name as it is.  
                C: Default is true.  
                Properties: create, edit
        exportaspectratio (Queryable[float]?): Value of aspect ratio for export  
                Properties: create, query, edit
        exportfilemode (Queryable[str]?): Specifies the export channel.The valid  
                entries here are: "alpha", "luminance", "rgb", "rgba".  
                C: Default is "luminance/rgb".  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        exportfilesave (str?): Exports the attribute map and saves to a specified file.  
                Properties: edit
        exportfilesizex (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfilesizey (Queryable[int]?): Specifies the width of the attribute map to export.  
                C: Default width is 256. Q: When queried, it returns an integer.  
                Properties: create, query, edit
        exportfiletype (Queryable[str]?): Specifies the image file format. It can be one of  
                the following: "iff", "tiff", "jpeg", "alias", "rgb", "fit"  
                "postScriptEPS", "softimage", "wavefrontRLA", "wavefrontEXP".  
                C: default is tiff. Q: When queried, it returns a string.  
                Properties: create, query, edit
        filterNodes (bool?): Sets the node filter.  
                Properties: edit
        finalizeCmd (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called at the end of each stroke.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        fullpaths (bool?): Specifies whether full path names should  
                be used when surface names are passed to scripts. If  
                false, just the surface name is passed.  
                C: Default is false  Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        getArrayAttrCommand (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called once for every surface that is selected for painting.  
                This procedure returns a string, which is interpreted  
                as a list of names referring to double array attributes on some  
                dependency node.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        getSurfaceCommand (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called once for every dependency node on the selection list,  
                whenever Artisan processes the selection list.  
                It returns the name of the surface to paint on.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        getValueCommand (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called every time a value on the surface is needed  
                by the scriptable paint tool.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        importfileload (str?): Load the attribute map a specified file.  
                Properties: edit
        importfilemode (Queryable[str]?): Specifies the channel to import. The valid  
                entries here are: "alpha", "luminance", "red", "green",  
                "blue", and "rgb"  
                C: Default is "alpha". Q: When queried, it returns a string.  
                Properties: create, query, edit
        importreassign (bool?): Specifies if the multiply atrribute maps are to be  
                reassigned while importing. Only maps previously exported from  
                within Artisan can be reassigned.  
                C: Default is FALSE. Q: When queried, it returns a  boolean.  
                Properties: create, query, edit
        initializeCmd (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called in the beginning of each stroke.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        interactiveUpdate (bool?): Specifies how often to transfer the painted values  
                into the attribute.  
                TRUE: transfer them "continuously" (many times per stroke)  
                FALSE: transfer them only at the end of a stroke (on mouse  
                button release).  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        lastRecorderCmd (Queryable[str]?): Value of last recorded command.  
                Properties: create, query, edit
        lastStampName (Queryable[str]?): Value of the last stamp name.  
                Properties: create, query, edit
        lowerradius (Queryable[float]?): Sets the lower size of the brush (only apply on tablet).  
                Properties: create, query, edit
        makeStroke (Queryable[Multiuse[int]]?): Stroke point values.  
                Properties: create, query, edit, multiuse
        mappressure (Queryable[str]?): Sets the tablet pressure mapping when the table  
                is used. There are three options:  
                "Opacity" - the pressure is mapped to the opacity,  
                "Radius" - the is mapped to modify the radius of the brush,  
                "Both" - the pressure modifies both the opacity and the radius.  
                C: Default is "Opacity". Q: When queried, it returns a string.  
                Properties: create, query, edit
        maxvalue (Queryable[float]?): Specifies the maximum value for each attribute.  
                C: Default is 1.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        minvalue (Queryable[float]?): Specifies the minimum value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numericColorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors for the  
                numeric display.  
                Properties: create, query, edit
        numericDisplayColor (Queryable[Tuple[float, float, float]]?): Defines a color to be used when displaying numeric values.  
                Properties: create, query, edit
        numericDisplayPrecision (Queryable[int]?): Specifies how many decimal points of precision should be used for the  
                numeric display.  
                Properties: create, query, edit
        numericMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        numericMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        objattrArray (Queryable[str]?): An array of all paintable attributes. Each element of  
                the array is a string with the following information:  
                NodeType.NodeName.AttributeName.MenuType  
                *MenuType: type (level) of the item in the Menu (UI).  
                Q: When queried, it returns a string.  
                Properties: query
        objattrArrayNoMenu (Queryable[str]?): Returns an array of all paintable attributes in their original order.  
                Each element of the array is a string with the following information:  
                NodeType.NodeName.AttributeName  
                Properties: query
        opacity (Queryable[float]?): Sets the brush opacity.  
                C: Default is 1.0. Q: When queried, it returns a float.  
                Properties: create, query, edit
        outline (bool?): Specifies if the brush should be drawn.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        outwhilepaint (bool?): Specifies if the brush outline should be drawn  
                while painting.  
                C: Default is FALSE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        paintNodeArray (Queryable[str]?): An array of paintable nodes.  
                Q: When queried, it returns a string.  
                Properties: query
        paintattrselected (str?): An array of selected paintable attributes.  
                Each element of the array is a string with the  
                following information:  
                NodeType.NodeName.AttributeName.  
                Properties: edit
        paintmode (Queryable[str]?): Specifies the paint mode. There are two  
                possibilities: "screen" and "tangent".  
                C: Default is "screen". Q: When queried, it returns a string.  
                Properties: create, query, edit
        paintoperationtype (Queryable[str]?): Specifies the operation type used by the  
                Paint Tool.  Currently, we support the following  
                paint modes: "Paint", "Smear", "Blur", "Erase"  
                and "Clone".  
                Default is "Paint".  
                Properties: create, query, edit
        pickColor (bool?): Set pick color mode on or off  
                Properties: create, query, edit
        pickValue (bool?): Toggle for picking  
                Properties: create, query, edit
        playbackCursor (Queryable[Multiuse[Tuple[float, float]]]?): Values for the playback cursor.  
                Properties: create, query, edit, multiuse
        playbackPressure (Queryable[Multiuse[float]]?): Valus for the playback pressure.  
                Properties: create, query, edit, multiuse
        preserveclonesource (bool?): Whether or not to preserve a clone source.  
                Properties: create, query, edit
        profileShapeFile (Queryable[str]?): Passes a name of the image file for the stamp shape  
                profile.  
                Properties: query, edit
        projective (bool?): Specifies the projective paint mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        radius (Queryable[float]?): Sets the size of the brush.  
                C: Default is 1.0 cm. Q: When queried, it returns a float.  
                Properties: create, query, edit
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: create, query, edit
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: create, query, edit
        record (bool?): Toggle on for recording.  
                Properties: create, query, edit
        reflection (bool?): Specifies the reflection mode.  
                C: Default is 'false'. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        reflectionaboutorigin (bool?): Toggle on to reflect about the origin  
                Properties: create, query, edit
        reflectionaxis (Queryable[str]?): Specifies the reflection axis. There are three  
                possibilities: "x", "y" and "z".  
                C: Default is "x". Q: When queried, it returns a string.  
                Properties: create, query, edit
        screenRadius (Queryable[float]?): Brush radius on the screen  
                Properties: create, query, edit
        selectclonesource (bool?): Toggle on to select the clone source  
                Properties: create, query, edit
        selectedattroper (Queryable[str]?): Sets the edit weight operation. Four edit weights  
                operations are provided : "absolute" - the value of the weight  
                is replaced by the current one, "additive" - the value of the  
                weight is added to the current one, "scale" - the value of the  
                weight is multiplied by the current one, "smooth" - the value  
                of the weight is divided by the current one.  
                C: Default is "absolute".  Q: When queried, it returns a string.  
                Properties: create, query, edit
        setArrayValueCommand (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called for each paint stamp. A stamp may affect  
                one or more values on the surface. This call rolls up  
                all the calls that would be made to setValueCommand  
                for the stamp into one call with array arguments.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        setValueCommand (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called every time a value on the surface is changed.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        showactive (bool?): Sets on/off the display of the surface isoparms.  
                C: Default is TRUE. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        stampDepth (Queryable[float]?): Depth of the stamps  
                Properties: create, query, edit
        stampProfile (Queryable[str]?): Sets the brush profile of the current stamp.  
                Currently, the following profiles are supported:  
                "gaussian", "poly", "solid" and "square".  
                C: Default is gaussian. Q: When queried, it returns a string.  
                Properties: create, query, edit
        stampSpacing (Queryable[float]?): Specifies the stamp spacing. Default is 1.0.  
                Properties: create, query, edit
        strokesmooth (Queryable[str]?): Stroke smoothing type name  
                Properties: create, query, edit
        surfaceConformedBrushVertices (bool?): Enables/disables the the display of the effective brush area  
                as affected vertices.  
                Properties: create, query, edit
        tablet (bool?): Returns true if the tablet device is present, false if it is absent  
                Properties: query
        tangentOutline (bool?): Enables/disables the display of the brush circle tangent to  
                the surface.  
                Properties: create, query, edit
        toolCleanupCmd (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called when this tool is exited.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        toolOffProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned off.  
                For example, cloth invokes "clothPaintToolOff" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is deactivated.  
                It is typical that if you implement a toolOffProc you will  
                want to implement a toolOnProc as well (see the -toolOnProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolOnProc (Queryable[str]?): Accepts a strings describing the name of a MEL  
                procedure that is invoked whenever the tool is turned on.  
                For example, cloth invokes "clothPaintToolOn" when the cloth  
                paint tool is turned on. Define this callback if your tool  
                requires special functionality when your tool is activated.  
                It is typical that if you implement a toolOnProc you will  
                want to implement a toolOffProc as well (see the -toolOffProc  
                flag. In query mode, the name of the currently registered MEL  
                command is returned and this will be an empty string if none  
                is defined.  
                Properties: create, query, edit
        toolSetupCmd (Queryable[str]?): Specifies the name of the Mel script/procedure  
                that is called once for every selected surface when an  
                initial click is received on that surface.  
                Q: When queried, it returns a string.  
                Properties: create, query, edit
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors.  If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: create, query, edit
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: create, query, edit
        useNumericColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors on the numeric display. If this is turned off, the set single  
                numeric color will be used.  
                Properties: create, query, edit
        useNumericDisplay (bool?): Specifies whether numerical weight values should be displayed next to  
                their associated control points.  
                Properties: create, query, edit
        usepressure (bool?): Sets the tablet pressure on/off.  
                C: Default is false. Q: When queried, it returns a boolean.  
                Properties: create, query, edit
        value (Queryable[float]?): Specifies the value for each attribute.  
                C: Default is 0.0.  Q: When queried, it returns a float.  
                Properties: create, query, edit
        whichTool (Queryable[str]?): The string defines the name of the tool to be  
                used for the Artisan context. An example is "artClothPaint".  
                In query mode, the tool name for the given context is returned.  
                Note: due to the way MEL works, always specify the -query flag  
                last when specifying a flag that takes arguments.  
                Properties: create, query, edit
        worldRadius (Queryable[float]?): Radius in worldspace  
                Properties: create, query, edit

    Returns:
        str: The name of the context created.

    Example:
    """

def arubaNurbsToPoly(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., localSpace: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., worldSpace: bool = ...) -> Union[List[str], bool, int]:
    """This command tesselates a NURBS surface and produces a polygonal surface.
    The name of the new polygonal surface is returned.
    If construction history is ON, then the name of the new dependency
    node is returned as well.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        localSpace (bool?): Tesselate in local space  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        worldSpace (bool?): Tesselate in world space  
                Properties: create

    Returns:
        List[str]: The polygon and optionally the dependency node name

    Example:
    """

def assembly(*args: str, edit: bool = ..., query: bool = ..., active: Queryable[str] = ..., activeLabel: Queryable[str] = ..., canCreate: Queryable[str] = ..., createOptionBoxProc: Queryable[Callable[..., Any]] = ..., createRepresentation: str = ..., defaultType: Queryable[str] = ..., deleteRepresentation: str = ..., deregister: str = ..., input: str = ..., isAType: Queryable[str] = ..., isTrackingMemberEdits: Queryable[str] = ..., label: Queryable[str] = ..., listRepTypes: bool = ..., listRepTypesProc: Queryable[Callable[..., Any]] = ..., listRepresentations: bool = ..., listTypes: bool = ..., name: str = ..., newRepLabel: str = ..., postCreateUIProc: Queryable[Callable[..., Any]] = ..., proc: Callable[..., Any] = ..., renameRepresentation: str = ..., repLabel: str = ..., repName: str = ..., repNamespace: Queryable[str] = ..., repPostCreateUIProc: str = ..., repPreCreateUIProc: str = ..., repType: str = ..., repTypeLabel: str = ..., repTypeLabelProc: Queryable[Callable[..., Any]] = ..., type: str = ...) -> Union[bool, str, Callable[..., Any]]:
    """Command to register assemblies for the scene assembly
    framework, to create them, and to edit and query them.
    Assembly nodes are DAG nodes, and are therefore shown in the various
    DAG editors (Outliner, Hypergraph, Node Editor). At assembly creation time,
    the node name defaults to the node type name.
    The assembly command can create any node that is derived from the assembly
    node base class.  It also acts as a registry of these types, so that various
    scripting callbacks can be defined and registered with the assembly
    command.  These callbacks are invoked by Maya during operations on
    assembly nodes, and can be used to customize behavior.When defining a new type of assembly derived from the assembly node
    base class, a number of procedures can be defined through the assembly
    command to properly integrate the new assembly node type into Maya.
    Most of these procedures are used to integrate the assembly type with the
    Maya user interface, and are not required for non-interactive
    scripting use.  For more information, see the MPxAssembly class
    description in the Maya API documentation.
    Some of the important procedures that can be registered through the assembly
    command are the following:representation, assembly
    Args:
        active (Queryable[str]?): Set the active representation by name, or query the name of the active representation.  
                Edit mode can be applied to more than one assembly.  
                Query mode will return a single string when only a single assembly is specified,  
                and will return an array of strings when multiple assemblies are specified.  
                Using an empty string as name means to inactivate the currently active representation.  
                Properties: query, edit
        activeLabel (Queryable[str]?): Set the active representation by label, or query the label of the active representation.  
                Edit mode can be applied to more than one assembly.  
                Query mode will return a single string when only a single assembly is specified,  
                and will return an array of strings when multiple assemblies are specified.  
                Properties: query, edit
        canCreate (Queryable[str]?): Query the representation types the specific assembly can create.  
                Properties: query
        createOptionBoxProc (Queryable[Callable[..., Any]]?): Set or query the option box menu procedure for a specific assembly type.  
                The assembly type will be the default type, unless  
                the -type flag is used to specify an explicit assembly type.  
                Properties: query, edit
        createRepresentation (str?): Create and add a specific type of representation for an assembly.  
                If the representation type needs additional parameters, they  
                must be specified using the "input" flag. For example, the Maya  
                scene assembly reference implementation Cache and Scene  
                representations need an input file.  
                Properties: edit
        defaultType (Queryable[str]?): Set or query the default type of assembly.  When the assembly  
                command is used to perform an operation on an assembly type rather  
                than on an assembly object, it will be performed on the default  
                type, unless the -type flag is used to specify an explicit assembly type.  
                Properties: query, edit
        deleteRepresentation (str?): Delete a specific representation from an assembly.  
                Properties: edit
        deregister (str?): Deregister a registered assembly type.  
                If the deregistered type is the default type,  
                the default type will be set to the empty string.  
                Properties: edit
        input (str?): Specify the additional parameters of representation creation procedure  
                when creating a representation.  
                This flag must be used with createRepresentation flag.  
                Properties: edit
        isAType (Queryable[str]?): Query whether the given object is of an assembly type.  
                Properties: query
        isTrackingMemberEdits (Queryable[str]?): Query whether the given object is tracking member edits.  
                Properties: query
        label (Queryable[str]?): Set or query the label for an assembly type. Assembly type is specified  
                with flag "type". If no type specified, the default type is used.  
                Properties: query, edit
        listRepTypes (bool?): Query the supported representation types for a given assembly type.  The  
                assembly type will be the default type, unless the -type flag is used to  
                specify an explicit assembly type.  
                Properties: query
        listRepTypesProc (Queryable[Callable[..., Any]]?): Set or query the procedure that provides the representation type list which  
                an assembly type supports.  This procedure takes no argument, and  
                returns a string array of representation types that represents the full set  
                of representation types this assembly type can create.  The assembly type  
                for which this procedure applies will be the default type, unless the type  
                flag is used to specify an explicit assembly type.  
                Properties: query, edit
        listRepresentations (bool?): Query the created representations list for a specific assembly.  The -repType  
                flag can be used to filter the list and return representations for a  
                single representation type.  If the -repType flag is not used, all created  
                representations will be returned.  
                Properties: query
        listTypes (bool?): Query the supported assembly types.  
                Properties: query
        name (str?): Specify the name of the assembly when creating it.  
                Properties: create
        newRepLabel (str?): Specify the representation label to set on representation label edit.  
                Properties: edit
        postCreateUIProc (Queryable[Callable[..., Any]]?): Set or query the UI post-creation procedure for a given assembly type.  
                This procedure will be invoked by Maya immediately after an assembly of the  
                specified type is created from the UI, but not through scripting.  It can be  
                used to invoke a dialog, to obtain and set initial parameters on a  
                newly-created assembly.  The assembly type will be the default type, unless  
                the -type flag is used to specify an explicit assembly type.  
                Properties: query, edit
        proc (Callable[..., Any]?): Specify the procedure when setting the representation UI post- or  
                pre-creation procedure, for a given assembly type.  The assembly  
                type will be the default type, unless the -type flag is used to specify  
                an explicit assembly type.  
                Properties: edit
        renameRepresentation (str?): Renames the representation that is the argument to this flag.  The  
                repName flag must be used to provide the new name.  
                Properties: edit
        repLabel (str?): Query or edit the label of the representation that is the argument to this  
                flag, for a given assembly.  In both query and edit modes, the -repLabel flag  
                specifies the name of the representation.  In edit mode, the -newRepLabel flag  
                must be used to specify the new representation label.  
                			In query mode, this flag needs a value.  
                Properties: query, edit
        repName (str?): Specify the representation name to set on representation creation or rename.  
                This flag is optional with the createRepresentation flag: if omitted, the  
                assembly will name the representation.  It is mandatory with the  
                renameRepresentation flag.  
                Properties: edit
        repNamespace (Queryable[str]?): Query the representation namespace of this assembly node.  
                The value returned is used by Maya for creating the namespace where nodes created  
                by the activation of a representation will be added. If a name clash occurs when the  
                namespace is added to its parent namespace, Maya will update repNamespace with the new  
                name.  
                Two namespaces are involved when dealing with an assembly node: the namespace of the  
                assembly node itself (which this flag does not affect or query), and the namespace  
                of its representations. The representation namespace is a child of its assembly node's  
                namespace. The assembly node's namespace is set by its containing assembly, if it  
                is nested, or by the top-level file. Either the assembly node's namespace, or the  
                representation namespace, or both, can be the empty string.  
                It should be noted that if the assembly node is nested, the assembly  
                node's namespace will be (by virtue of its nesting) the  
                representation namespace of its containing assembly.  
                Properties: query
        repPostCreateUIProc (str?): Set or query the UI post-creation procedure for a specific representation type,  
                and for a specific assembly type.  This procedure takes two arguments, the  
                first the DAG path to the assembly, and the second the name of the  
                representation.  It returns no value.  It will be invoked by Maya  
                immediately after a representation of the specified type is created  
                from the UI, but not through scripting.  It can be used to invoke a  
                dialog, to obtain and set initial parameters on a newly-created  
                representation.  The representation type is the argument of this flag.  
                The -proc flag must be used to specify the procedure name.  The  
                assembly type will be the default type, unless the -type flag is used  
                to specify an explicit assembly type.  
                			In query mode, this flag needs a value.  
                Properties: query, edit
        repPreCreateUIProc (str?): Set or query the UI pre-creation procedure for a specific representation type,  
                and for a specific assembly type.  This procedure takes no argument, and  
                returns a string that is passed as an argument to the -input flag  
                when Maya invokes the assembly command with the -createRepresentation flag.  
                The representation pre-creation procedure is invoked by Maya  
                immediately before creating a representation of the specified type from the  
                UI, but not through scripting.  It can be used to invoke a dialog, to obtain  
                the creation argument for a new representation.  The representation type is  
                the argument of this flag.  The -proc flag must be used to specify the  
                procedure name.  The assembly type will be the default type, unless the  
                -type flag is used to specify an explicit assembly type.  
                			In query mode, this flag needs a value.  
                Properties: query, edit
        repType (str?): Specify a representation type to use as a filter for the -listRepresentations  
                query.  The representation type is the argument to this flag.  
                			In query mode, this flag needs a value.  
                Properties: query
        repTypeLabel (str?): Query the label of the specific representation type.  
                			In query mode, this flag needs a value.  
                Properties: query
        repTypeLabelProc (Queryable[Callable[..., Any]]?): Set or query the procedure that provides the representation type label,  
                for a given assembly type.  The procedure takes the representation type as  
                its sole argument, and returns a localized representation type label.  
                The assembly type for which this procedure applies will be the  
                default type, unless the -type flag is used to specify an explicit  
                assembly type.  
                Properties: query, edit
        type (str?): Set or query properties for the specified registered assembly type.  
                			In query mode, this flag needs a value.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def assignCommand(arg0: int = ..., /, *, edit: bool = ..., query: bool = ..., addDivider: str = ..., altModifier: bool = ..., annotation: Queryable[str] = ..., command: Queryable[Callable[..., Any]] = ..., commandModifier: bool = ..., ctrlModifier: bool = ..., data1: Queryable[str] = ..., data2: Queryable[str] = ..., data3: Queryable[str] = ..., delete: int = ..., dividerString: Queryable[str] = ..., enableCommandRepeat: bool = ..., factorySettings: bool = ..., index: int = ..., keyArray: bool = ..., keyString: Queryable[str] = ..., keyUp: bool = ..., name: bool = ..., numDividersPreceding: Queryable[int] = ..., numElements: bool = ..., optionModifier: bool = ..., sortByKey: bool = ..., sourceUserCommands: bool = ...) -> Union[bool, str, Callable[..., Any], int]:
    """This command allows the user to assign hotkeys and manipulate the internal
    array of named command objects. Each object in the array has an 1-based
    index which is used for referencing. Under expected usage you should
    not need to use this command directly as the Hotkey Editor may be used
    to assign hotkeys.This command is obsolete for setting new hotkeys, instead please use the "hotkey" command.
    Args:
        addDivider (str?): Appends an "annotated divider" item to the end of the list of  
                commands.  
                Properties: edit
        altModifier (bool?): This flag specifies if an alt modifier is used for the key.  
                Properties: edit
        annotation (Queryable[str]?): The string is the english name describing the command.  
                Properties: query, edit
        command (Queryable[Callable[..., Any]]?): This is the command that is executed when this object is  
                mapped to a key or menuItem.  
                Properties: query, edit
        commandModifier (bool?): This flag specifies if a command modifier is used for the key.  
                This is only available on systems which support a separate command key.  
                Properties: edit
        ctrlModifier (bool?): This flag specifies if a ctrl modifier is used for the key.  
                Properties: edit
        data1 (Queryable[str]?): Optional, user-defined data strings may be attached to  
                the nameCommand objects.  
                Properties: query, edit
        data2 (Queryable[str]?): Optional, user-defined data strings may be attached to  
                the nameCommand objects.  
                Properties: query, edit
        data3 (Queryable[str]?): Optional, user-defined data strings may be attached to  
                the nameCommand objects.  
                Properties: query, edit
        delete (int?): This tells the Manager to delete the object at position index.  
                Properties: edit
        dividerString (Queryable[str]?): If the passed index corresponds to a "divider" item, then the  
                divider's annotation is returned.  Otherwise, a null string is  
                returned.  
                Properties: query
        enableCommandRepeat (bool?): This flag specifies whether command repeat is enabled.  
                Properties: edit
        factorySettings (bool?): This flag sets the manager back to factory settings.  
                Properties: edit
        index (int?): The index of the object to operate on. The index value  
                ranges from 1 to the number of name command objects.  
                Properties: edit
        keyArray (bool?): This flag returns all of the hotkeys on the command.  
                Properties: query
        keyString (Queryable[str]?): This specifies a key to assign a command to in edit mode.  
                In query mode this flag returns the key string, modifiers and  
                indicates if the command is mapped to keyUp or keyDown.  
                Properties: query, edit
        keyUp (bool?): This flag specifies if the command is executed on keyUp  
                or keyDown.  
                Properties: edit
        name (bool?): The name of the command object.  
                Properties: query
        numDividersPreceding (Queryable[int]?): If the index of a namedCommand object C is passed in,  
                then this flag returns the number of "divider" items preceding  
                C when the namedCommands are sorted by category.  
                Properties: query
        numElements (bool?): This command returns the number of namedCommands in the system.  
                This flag doesn't require the index to be specified.  
                Properties: query
        optionModifier (bool?): This flag specifies if an option modifier is used for the key.  
                Properties: edit
        sortByKey (bool?): This key tells the manager to sort by key or by order of  
                creation.  
                Properties: query, edit
        sourceUserCommands (bool?): This command sources the user named command file.  
                Properties: edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def assignInputDevice(*args: Any, query: bool = ..., clutch: str = ..., continuous: bool = ..., device: str = ..., immediate: bool = ..., multiple: bool = ...) -> str:
    """This command associates a command string (i.e. a mel script)
    with the input device.  When the device moves or a button on
    the device is pressed, the command string is executed as if
    you typed it into the window.  If the command string contains
    the names of buttons or axes of the device, the current value
    of these buttons/axes are substituted in.  Buttons are reported
    as booleans and axes as doubles.This command is most useful for associating buttons on a device
    with commands.  For using a device to capture continous movements
    it is much more efficient to attach the device directly into
    the dependency graph.
    Args:
        clutch (str?): specify a clutch button.  This button must be down  
                for the command string to be executed.  
                If no clutch is specified the command string is  
                executed everytime the device state changes  
                Properties: create
        continuous (bool?): if this flag is set the command string is continously  
                (once for everytime the device changes state).  By  
                default if a clutch button is specified the command  
                string is only executed once when the button is  
                pressed.  
                Properties: create
        device (str?): specify which device to assign the command string.  
                Properties: create
        immediate (bool?): Immediately executes the command, without using the queue.  
                Properties: create
        multiple (bool?): if this flag is set the other command strings  
                associated with this device are not deleted.  
                By default, when a new command string is attached  
                to the device, all other command strings are deleted.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def assignViewportFactories(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., materialFactory: Queryable[str] = ..., nodeType: Queryable[str] = ..., textureFactory: Queryable[str] = ...) -> Union[bool, str]:
    """Sets viewport factories for displays as materials or textures.assignViewportFactories, registration
    Args:
        materialFactory (Queryable[str]?): Set or query the materialFactory for the node type.  
                Properties: create, query, edit
        nodeType (Queryable[str]?): The node type.  
                Properties: create, query, edit
        textureFactory (Queryable[str]?): Set or query the textureFactory for the node type.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def attachCache() -> None: ...
def attachCurve(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., blendBias: Queryable[float] = ..., blendKnotInsertion: bool = ..., caching: bool = ..., keepMultipleKnots: bool = ..., method: Queryable[int] = ..., nodeState: Queryable[int] = ..., parameter: Queryable[float] = ..., reverse1: bool = ..., reverse2: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], float, bool, int]:
    """This attach command is used to attach curves. Once the curves are
    attached, there will be multiple knots at the joined point(s). These
    can be kept or removed if the user wishes.If there are two curves, the end of the first curve is attached to the
    start of the second curve. If there are more than two curves, closest
    endpoints are joined.Note: if the command is done with Keep Original off, the first curve
    is replaced by the attached curve. All other curves will remain, the
    command does not delete them.
    Args:
        blendBias (Queryable[float]?): Skew the result toward the first or the second curve depending  
                on the blend factory being smaller or larger than 0.5.  
                Default: 0.5  
                Properties: create, query, edit
        blendKnotInsertion (bool?): If set to true, insert a knot in one of the original curves  
                (relative position given by the parameter attribute below)  
                in order to produce a slightly different effect.  
                Default: false  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        keepMultipleKnots (bool?): If true, keep multiple knots at the join parameter.  
                Otherwise remove them.  
                Default: true  
                Properties: create, query, edit
        method (Queryable[int]?): Attach method (connect-0, blend-1)  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[float]?): The parameter value for the positioning of the newly inserted knot.  
                Default: 0.1  
                Properties: create, query, edit
        reverse1 (bool?): If true, reverse the first input curve before doing attach.  
                Otherwise, do nothing to the first input curve before attaching.  
                NOTE: setting this attribute to random values will cause  
                unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        reverse2 (bool?): If true, reverse the second input curve before doing attach.  
                Otherwise, do nothing to the second input curve before  
                attaching. NOTE: setting this attribute to random values will  
                cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def attachDeviceAttr(*args: Any, query: bool = ..., attribute: Multiuse[str] = ..., axis: str = ..., camera: bool = ..., cameraRotate: bool = ..., cameraTranslate: bool = ..., clutch: str = ..., device: str = ..., selection: bool = ...) -> bool:
    """This command associates a device/axis pair with a node/attribute pair.
    When the device axis moves, the value of the attribute is set to the
    value of the axis. This value can be scaled and offset using
    the setAttrScale command.
    Args:
        attribute (Multiuse[str]?): specify the attribute to attach to  
                Properties: create, multiuse
        axis (str?): specify the axis to attach from.  
                Properties: create
        camera (bool?): This flag attaches the device/axis to the current camera.  
                The mapping between device axes and camera controls is  
                uses a heuristic based on the device descripton.  
                The interaction is a copy of the mouse camera navigation  
                controls.  
                Properties: create
        cameraRotate (bool?): This flag attaches the device/axis to the current cameras  
                rotation controls.  
                Properties: create
        cameraTranslate (bool?): This flag attaches the device/axis to the current cameras  
                translate controls.  
                Properties: create
        clutch (str?): specify a clutch button.  This button must be down  
                for the command string to be executed.  
                If no clutch is specified the command string is  
                executed everytime the device state changes  
                Properties: create
        device (str?): specify which device to assign the command string.  
                Properties: create
        selection (bool?): This flag attaches to the nodes in the selection list.  
                This is different from the default arguments of the command  
                since changing the selection will change the attachments.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def attachFluidCache() -> None: ...
def attachGeometryCache() -> None: ...
def attachNclothCache() -> None: ...
def attachSurface(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., blendBias: Queryable[float] = ..., blendKnotInsertion: bool = ..., caching: bool = ..., directionU: bool = ..., keepMultipleKnots: bool = ..., method: Queryable[int] = ..., nodeState: Queryable[int] = ..., parameter: Queryable[float] = ..., reverse1: bool = ..., reverse2: bool = ..., swap1: bool = ..., swap2: bool = ..., twist: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], float, bool, int]:
    """This attach command is used to attach surfaces. Once the surfaces are
    attached, there will be multiple knots at the joined point(s). These
    can be kept or removed if the user wishes.The end of the first surface is attached to the start of the second
    surface in the specified direction.Note: if the command is done with Keep Original off there will be an
    extra surface in the model (the second surface). The command does not
    delete it. The first surface is replaced by the attached surface.
    Args:
        blendBias (Queryable[float]?): Skew the result toward the first or the second curve depending on the blend factory being smaller or larger than 0.5.  
                Default: 0.5  
                Properties: create, query, edit
        blendKnotInsertion (bool?): If set to true, insert a knot in one of the original curves (relative position given by the parameter attribute below) in order to produce a slightly different effect.  
                Default: false  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        directionU (bool?): If true attach in U direction of surface and V direction otherwise.  
                Default: true  
                Properties: create, query, edit
        keepMultipleKnots (bool?): If true, keep multiple knots at the join parameter. Otherwise remove them.  
                Default: true  
                Properties: create, query, edit
        method (Queryable[int]?): Attach method (connect-0, blend-1)  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[float]?): The parameter value for the positioning of the newly inserted knot.  
                Default: 0.1  
                Properties: create, query, edit
        reverse1 (bool?): If true, reverse the direction (specified by directionU) of the first input surface before doing attach. Otherwise, do nothing to the first input surface before attaching. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        reverse2 (bool?): If true, reverse the direction (specified by directionU) of the second input surface before doing attach. Otherwise, do nothing to the second input surface before attaching. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        swap1 (bool?): If true, swap the UV directions of the first input surface before doing attach. Otherwise, do nothing to the first input surface before attaching. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        swap2 (bool?): If true, swap the UV directions of the second input surface before doing attach. Otherwise, do nothing to the second input surface before attaching. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        twist (bool?): If true, reverse the second surface in the opposite direction (specified by directionU) before doing attach. This will avoid twists in the attached surfaces. Otherwise, do nothing to the second input surface before attaching. NOTE: setting this attribute to random values will cause unpredictable results and is not supported.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def attrColorSliderGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., alphaValue: Queryable[float] = ..., annotation: Queryable[str] = ..., attrNavDecision: Queryable[Tuple[str, str]] = ..., attribute: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hsvValue: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rgbValue: Queryable[Tuple[float, float, float]] = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., showButton: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, float, Tuple[str, str], Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.Create a color slider group consisting of a label, a color canvas,
    a slider and a button.  Clicking on the canvas will bring up the
    color editor.  If the button is visible, it will allow you to map
    a texture to the attribute.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        alphaValue (Queryable[float]?): Alpha (transparency) of the color. Will show the alpha UI.  
                Alpha will be set only if RGB or HSV is also set at the same time.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attrNavDecision (Queryable[Tuple[str, str]]?): The first argument is the name of an attribute.  
                The button will be attached to the attribute so the button  
                can be kept in synch with the attribute.  The second  
                argument is the navigatorDecisionString that can guide the  
                behaviour that the navigator implements.  
                Properties: create, query, edit
        attribute (Queryable[str]?): The name of a unique attribute of type 3double.  This newly  
                created field will be attached to the attribute, so that  
                modifications to one will change the other.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hsvValue (Queryable[Tuple[float, float, float]]?): Specifies the color in hsv style.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): By default, the label of this field will be the name of the  
                attribute.  This flag can be used to override that name with  
                whatever the user wants.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rgbValue (Queryable[Tuple[float, float, float]]?): Specifies the color in rgb style.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        showButton (bool?): Control the display of the texture link button.  
                True by default (show it).  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: (the name of the created group)

    Example:
    """

def attrCompatibility(arg0: str = ..., arg1: str = ..., /, *, addAttr: bool = ..., clear: bool = ..., dumpTable: bool = ..., enable: bool = ..., nodeRename: str = ..., pluginNode: str = ..., renameAttr: str = ..., removeAttr: bool = ..., type: str = ..., version: str = ...) -> None: ...
def attrControlGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., attribute: Queryable[str] = ..., changeCommand: Queryable[Callable[..., Any]] = ..., enable: bool = ..., exists: bool = ..., handlesAttribute: str = ..., hideMapButton: bool = ..., label: Queryable[str] = ..., preventOverride: bool = ...) -> Union[str, Callable[..., Any], bool]:
    """This command creates a control of the type most appropriate for the specified
    attribute, and associates the control with the attribute. Any change to the
    control will cause a change in the attribute value, and any change to the
    attribute value will be reflected in the control. Not all attribute types are
    supported.attribute, control
    Args:
        annotation (Queryable[str]?): Sets or queries the annotation value of the control group.  
                Properties: create, query, edit
        attribute (Queryable[str]?): Sets or queries the attribute the control represents. The name of the attribute  
                must be fully specified, including the name of the node. Some types of  
                attributes are not supported, but most commonly used attribute types are.  
                Properties: create, query, edit
        changeCommand (Queryable[Callable[..., Any]]?): Sets or queries the change command of the control group. The change  
                command will be executed when the control is used to change the value  
                of the attribute.  
                Properties: create, query, edit
        enable (bool?): Sets or queries the enable state of the control group. The control is dimmed if  
                the enable state is set to false.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create, query, edit
        handlesAttribute (str?): Returns true or false as to whether this command can create a control for the  
                specified attribute.  
                			In query mode, this flag needs a value.  
                Properties: query, edit
        hideMapButton (bool?): Force the map button to remain hidden for this control.  
                Properties: create, query, edit
        label (Queryable[str]?): Sets or queries the label of the control group.  
                Properties: create, query, edit
        preventOverride (bool?): Sets or queries the prevent adjustment state of the control group. If true,  
                the RMB menu for the control will not allow adjustments to be made.  
                Properties: create, query, edit

    Returns:
        str: The control name.

    Example:
    """

def attrEnumOptionMenu(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., attribute: str = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enumeratedItem: Multiuse[Tuple[int, str]] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates an enumerated attribute control. It is
    usually an option menu.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attribute (str?): Attribute that the menu controls.  
                Properties: create, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): The command string is executed when the value of the  
                option menu changes.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enumeratedItem (Multiuse[Tuple[int, str]]?): Enumerated item and the corresponding string.  If this flag is  
                not supplied when the control is created, then the command will  
                try to read the values from the attribute.  
                Properties: create, multiuse
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the control.

    Example:
    """

def attrEnumOptionMenuGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., attribute: str = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enumeratedItem: Multiuse[Tuple[int, str]] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label and option
    menu button associated with an attribute of a node. The attribute
    should be an integer, and this control allows a UI association of
    strings to the integers of the attribute. When a new menu item is
    choosen the corresponding integer will be assigned to the
    attribute.This control will automatically read the enumeration values from
    the attribute if none are provided.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attribute (str?): The name of an attribute.  The button will be attached  
                to the attribute so the button can be kept in synch  
                with the attribute.  
                Properties: create, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enumeratedItem (Multiuse[Tuple[int, str]]?): Enumerated item and the corresponding string. If this flag is  
                not supplied when the control is created, then the command will  
                try to read the values from the attribute.  
                Properties: create, multiuse
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Text for the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the control on creation.

    Example:
    """

def attrFieldGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., attribute: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraButton: bool = ..., extraButtonCommand: Callable[..., Any] = ..., extraButtonIcon: Queryable[str] = ..., extraLabel: Queryable[str] = ..., forceAddMapButton: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., hideMapButton: bool = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfFields: int = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: int = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text, plus two to
    four float fields.  These fields will be attached to the
    specified vector attribute, so that changes in either will be reflected
    in the other.The fields created here are expression fields -- while normally operating
    as a float field, the user can type in any expression starting with
    the character "-".The field also has an automatic menu brought up by the right mouse
    button.  The contents of this menu change depending on the state of
    the attribute being watched by the field.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attribute (Queryable[str]?): The name of a unique attribute of type vector.  This newly  
                created field will be attached to the attribute, so that modifications  
                to one will change the other.  A "vector" attribute is any  
                compound attribute whose children consist of two to four double-valued  
                attributes.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): The command string is executed when the value of any of the  
                floatFields change.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraButton (bool?): Add an extra icon button to the end of this control (before extra label).  
                Properties: create
        extraButtonCommand (Callable[..., Any]?): The command string is executed when the extra button is clicked.  
                Properties: create, edit
        extraButtonIcon (Queryable[str]?): The icon file name of the extra button.  
                Properties: create, query, edit
        extraLabel (Queryable[str]?): set an optional string that will be positioned to the right of all the fields.  
                Properties: create, query, edit
        forceAddMapButton (bool?): Force adding a map button to this control. If this option is true,  
                option hideMapButton is suppressed.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        hideMapButton (bool?): Force the map button to remain hidden for this control.  
                Properties: create
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): By default, the label of this field will be the name of the  
                attribute.  This flag can be used to override that name with  
                whatever the user wants.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Sets the maximum value for all fields.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Sets the minimum value for all fields.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfFields (int?): sets the number of fields.  Only allowed values are 2 to 4.  If not  
                specified, defaults to 3.  NOTE: if the -at flag is used when this  
                widget is created, the number of children in the attribute will determine  
                the number of fields.  Also note:  after creation, the number of fields cannot  
                be changed with the -e flag.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (int?): Sets the precision for all fields  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Sets the increment for all fields  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the control.

    Example:
    """

def attrFieldSliderGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., attribute: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraButton: bool = ..., extraButtonCommand: Callable[..., Any] = ..., extraButtonIcon: Queryable[str] = ..., fieldMaxValue: Queryable[float] = ..., fieldMinValue: Queryable[float] = ..., fieldStep: Queryable[float] = ..., forceAddMapButton: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., hideMapButton: bool = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: int = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., sliderMaxValue: Queryable[float] = ..., sliderMinValue: Queryable[float] = ..., sliderStep: Queryable[float] = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., vertical: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, float, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text, float
    field and float slider (for values with a min or max specified)
    The group
    also supports the notion of a larger secondary range of possible
    field values.If an attribute is specified for this object, then it will use any
    min and max values defined in the attribute.  The user-specified
    values can reduce the min and max, but cannot expand them.The field created here
    is an expression field -- while normally operating
    as a float field, the user can type in any expression starting with
    the character "=".  This will expand the field to occupy the space
    previously taken by the slider.The field also has
    an automatic menu brought up by the right mouse button.
    The contents of this menu change depending on the state of
    the attribute being watched by the field.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attribute (Queryable[str]?): The name of a unique attribute of type double or int.  
                This newly created field will be attached to the attribute, so  
                that modifications to one will change the other.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): The command string is executed when the value of the slider  
                or floatField changes.  It will be executed only once after a  
                drag of the slider.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraButton (bool?): Add an extra icon button to the end of this control.  
                Properties: create
        extraButtonCommand (Callable[..., Any]?): The command string is executed when the extra button is clicked.  
                Properties: create, edit
        extraButtonIcon (Queryable[str]?): The icon file name of the extra button.  
                Properties: create, query, edit
        fieldMaxValue (Queryable[float]?): Set the maximum value for the field.  This flag allows you  
                to specify a maximum bound for the field higher than that  
                of the slider.   (See note above  
                about max and min values.)  
                Properties: create, query, edit
        fieldMinValue (Queryable[float]?): Set the minimum value for the field.  This flag allows you  
                to specify a minimum bound for the field lower than that of  
                the slider.  (See note above  
                about max and min values.)  
                Properties: create, query, edit
        fieldStep (Queryable[float]?): Sets the increment for the float field.  
                Properties: create, query, edit
        forceAddMapButton (bool?): Force adding a map button to this control. If this option is true,  
                option hideMapButton is suppressed.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        hideMapButton (bool?): Force the map button to remain hidden for this control.  
                Properties: create
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): By default, the label of this field will be the name of the  
                attribute.  This flag can be used to override that name with  
                whatever string you want.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Sets the maximum value for both the slider and the field.  
                (See note above about min and max values)  
                Properties: create, query, edit
        minValue (Queryable[float]?): Sets the minimum value for both the slider and the field.  
                (by default max and min are set according to what is in the  
                attribute, if anything.  If no max and min are specified,  
                or if only one of the two are specified, then no slider  
                is created.)  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (int?): Sets the number of digits to the right of the decimal.  
                (If attached to an int attribute, this is automatically  
                set to 0 and cannot be overridden.)  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        sliderMaxValue (Queryable[float]?): Set the maximum value for the slider.  The slider  
                max will be clipped to the field max.  
                Properties: create, query, edit
        sliderMinValue (Queryable[float]?): Set the minimum value for the slider.  The slider min  
                will be clipped to the field min.  
                Properties: create, query, edit
        sliderStep (Queryable[float]?): On Linux the slider step value represents the  
                amount the value will increase or decrease when  
                you click either side of the slider.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Sets the increment for both the slider and float field.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        vertical (bool?): Whether the orientation of the controls in this group  
                are horizontal (default) or vertical.  
                Properties: create, query
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def attrNavigationControlGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., attrNavDecision: Queryable[Tuple[str, str]] = ..., attribute: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., connectAttrToDropped: Queryable[Callable[..., Any]] = ..., connectNodeToDropped: Queryable[Callable[..., Any]] = ..., connectToExisting: Queryable[Callable[..., Any]] = ..., createNew: Queryable[Callable[..., Any]] = ..., defaultTraversal: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., delete: Queryable[str] = ..., disconnect: Queryable[Callable[..., Any]] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraButton: bool = ..., extraButtonCommand: Callable[..., Any] = ..., extraButtonIcon: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., ignore: Queryable[Callable[..., Any]] = ..., ignoreNotSupported: bool = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., noIgnorableMenu: bool = ..., noKeyableMenu: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., relatedNodes: Queryable[Callable[..., Any]] = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., unignore: Queryable[Callable[..., Any]] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[str, str], Tuple[float, float, float], Callable[..., Any], bool, int]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged label
    navigation button.The group is used to help the user manage connections to
    a particular attribute.When creating the control you have the opportunity to attach
    scripts to the control that are executed on various
    UI events.  You can define what happens when the navigation
    button is pressed, and when a node is dragged and dropped
    onto this attribute.The navigation button can traverse to the connected node
    or can bring up UI to create new connections to the attribute.
    The button also can show you state information: if there
    already exists a connection/if the connection is ignored.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attrNavDecision (Queryable[Tuple[str, str]]?): The first argument is the name of an attribute.  
                The button will be attached to the attribute so the button  
                can be kept in synch with the attribute.  The second  
                argument is the navigatorDecisionString that can guide the  
                behaviour that the navigator implements.  
                Properties: create, query, edit
        attribute (Queryable[str]?): The name of an attribute. The button will be attached  
                to the attribute so the button can be kept in synch  
                with the attribute.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        connectAttrToDropped (Queryable[Callable[..., Any]]?): The script to execute when a node is dragged and dropped  
                onto an attribute (multilister dnd attribute editor).  
                Your script should take in two arguments: the source node  
                and destination attribute respectively.  
                Properties: create, query, edit
        connectNodeToDropped (Queryable[Callable[..., Any]]?): The script to execute when a node is dragged and dropped  
                onto a node (the multilister issues this).  Your script  
                should take in two arguments: the source node and  
                destination node respectively.  
                Properties: create, query, edit
        connectToExisting (Queryable[Callable[..., Any]]?): The script to execute when a connection should be  
                made to an existing node.  
                Properties: create, query, edit
        createNew (Queryable[Callable[..., Any]]?): The script to execute when a new "connection" is  
                requested.  
                Properties: create, query, edit
        defaultTraversal (Queryable[Callable[..., Any]]?): The script to execute to find out the name of the default  
                traversal node.  The script you attach should be able to  
                take in one argument (the attribute) and return the name  
                of the node that is the default traversal node.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        delete (Queryable[str]?): The script to execute when the connection (and the node  
                connected to) should be deleted.  
                Properties: create, query, edit
        disconnect (Queryable[Callable[..., Any]]?): The script to execute when a "disconnection" is  
                requested.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraButton (bool?): Add an extra icon button to the last of this control.  
                Properties: create
        extraButtonCommand (Callable[..., Any]?): The command string is executed when the extra button is clicked.  
                Properties: create, edit
        extraButtonIcon (Queryable[str]?): The icon file name of the extra button.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        ignore (Queryable[Callable[..., Any]]?): The script to execute when the connection should be  
                ignored.  
                Properties: create, query, edit
        ignoreNotSupported (bool?): Obsolete flag; has no effect.
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Text for the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        noIgnorableMenu (bool?): Not show ignorable related popup menu when right click the label.  
                Properties: create, edit
        noKeyableMenu (bool?): Not show keyable related popup menu when right click the label.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        relatedNodes (Queryable[Callable[..., Any]]?): The script to execute to find out what the related  
                nodes are.  The script you attach should be able to  
                take in one argument (the attribute) and return a list  
                of strings that are the name of the nodes that are  
                related.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        unignore (Queryable[Callable[..., Any]]?): The script to execute when the connection should be  
                unignored.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def attributeInfo(*args: str, allAttributes: bool = ..., bool: bool = ..., enumerated: bool = ..., hidden: bool = ..., inherited: bool = ..., internal: bool = ..., leaf: bool = ..., logicalAnd: bool = ..., multi: bool = ..., short: bool = ..., userInterface: bool = ..., writable: bool = ..., type: str = ...) -> List[str]:
    """This command lists all of the attributes that are marked with certain
    flags.  Combinations of flags may be specified and all will be considered.
    (The method of combination depends on the state of the "logicalAnd/and" flag.)
    When the "allAttributes/all" flag is specified, attributes of all
    types will be listed.attribute
    Args:
        allAttributes (bool?): Show all attributes associated with the node regardless of type.  
                Use of this flag overrides any other attribute type flags and logical operation  
                that may be specified on the command.  
                Properties: create
        bool (bool?): Show the attributes that are of type boolean.  
                Use the 'on' state to get only boolean attributes; the 'off' state  
                to ignore boolean attributes.  
                Properties: create
        enumerated (bool?): Show the attributes that are of type enumerated.  
                Use the 'on' state to get only enumerated attributes; the 'off' state  
                to ignore enumerated attributes.  
                Properties: create
        hidden (bool?): Show the attributes that are marked as hidden.  
                Use the 'on' state to get hidden attributes; the 'off' state  
                to get non-hidden attributes.  
                Properties: create
        inherited (bool?): Filter the attributes based on whether they belong to the node type directly  
                or have been inherited from a root type (e.g. meshShape/direct or  
                dagObject/inherited).  
                Use the 'on' state to get only inherited attributes, the 'off' state  
                to get only directly owned attributes, and leave the flag unspecified to  
                get both.  
                Properties: create
        internal (bool?): Show the attributes that are marked as internal to the node.  
                Use the 'on' state to get internal attributes; the 'off' state  
                to get non-internal attributes.  
                Properties: create
        leaf (bool?): Show the attributes that are complex leaves (ie. that have parent attributes  
                and have no children themselves).  
                Use the 'on' state to get leaf attributes; the 'off' state  
                to get non-leaf attributes.  
                Properties: create
        logicalAnd (bool?): The default is to take the logical 'or' of the above conditions.  
                Specifying this flag switches to the logical 'and' instead.  
                Properties: create
        multi (bool?): Show the attributes that are multis.  
                Use the 'on' state to get multi attributes; the 'off' state  
                to get non-multi attributes.  
                Properties: create
        short (bool?): Show the short attribute names instead of the long names.  
                Properties: create
        userInterface (bool?): Show the UI-friendly attribute names instead of the Maya ASCII names.  
                Takes precedence over the -s/-short flag if both are specified.  
                Properties: create
        writable (bool?): Show the attributes that are writable (ie. can have input connections).  
                Use the 'on' state to get writable attributes; the 'off' state  
                to get non-writable attributes.  
                Properties: create
        type (str?): static node type from which to get 'affects' information  
                Properties: create

    Returns:
        List[str]: List of attributes matching criteria

    Example:
    """

def attributeMenu(*args: Any, beginMenu: bool = ..., editor: str = ..., finishMenu: bool = ..., inputs: bool = ..., plug: str = ..., regPulldownMenuCommand: str = ..., unregPulldownMenuCommand: int = ...) -> str:
    """Action to generate popup connection menus for Hypershade. This command is
    used internally by the Hypershade panel.render, hypergraph, shader, hypershade
    Args:
        beginMenu (bool?): If true the menu will be used to start a connection edit so it will list all  
                available attributes for either inputs or outputs.  If false the menu will  
                be used to complete a connection so it will list only the attributes  
                compatible with the attribute at the other end of the connection.  A  
                plug must be supplied in this case.  
                Properties: create
        editor (str?): Name of the Hypergraph, Hypershade or Visor editor for which this menu  
                is being built.  This argument is no longer mandatory. If it is omitted,  
                the inputs flag and the node must be used to specify the search targets.  
                This allows attributeMenu to be used in the absence of a hypershade editor.  
                Properties: create
        finishMenu (bool?): finishes the menu  
                Properties: create
        inputs (bool?): If true only attributes which can be used as inputs will be listed.  If  
                false only attributes which can be used as outputs will be listed  
                Properties: create
        plug (str?): If inputs is false then we are completing a connection and the name  
                of the plug at the other end of the connection must be supplied.  
                Properties: create
        regPulldownMenuCommand (str?): This flag will register a callback that allows the user to define their own popup menu  
                for a specific node type for use in the Hypershade and Hypergraph editor.  
                The command signature should look like this:  
              
                global proc int proc_name>(string $editorName, string $nodeName, string $plug, string $mode, string $menuType)  
              
                The method should return 0 if it does not recognize the node type  
                and the default attributeMenu popup menu will be displayed.  
                If the callback returns one then the menu is considered built and no other menuItems will be  
                added to the popup. The return value from this flag will be the ID to use for the -unregPulldownMenuCommand flag.  
                Properties: create
        unregPulldownMenuCommand (int?): This flag will unregister a callback procedure that was registered with the -regPulldownMenuCommand flag.  
                The argument should be the integer identifier returned from the -regPulldownMenuCommand flag.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def attributeName(arg0: str = ..., /, *, leaf: bool = ..., long: bool = ..., nice: bool = ..., short: bool = ...) -> str:
    """This command takes one "node.attribute"-style specifier on the command line
    and returns either the attribute's long, short, or nice name.  (The "nice" name,
    or UI name, is the name used to display the attribute in Maya's interface, and
    may be localized when running Maya in a language other than English.)
    If more than one "node.attribute" specifier is given on the command line,
    only the first valid specifier is processed.query, attribute, nice, name
    Args:
        leaf (bool?): When false, shows parent multi attributes (like  
                "controlPoints[2].xValue").  When true, shows only the  
                leaf-level attribute name (like "xValue").  Default is true.  
                Note that for incomplete attribute strings, like a missing  
                multi-parent index ("controlPoints.xValue") or an  
                incorrectly named compound (cntrlPnts[2].xValue), this  
                flag defaults to true and provides a result as long as the  
                named leaf-level attribute is defined for the node.  
                Properties: create
        long (bool?): Returns names in "long name" format like "translateX"  
                Properties: create
        nice (bool?): Returns names in "nice name" format like "Translate X"  
                Properties: create
        short (bool?): Returns names in "short name" format like "tx"  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def attributeQuery(arg0: str = ..., /, *, affectsAppearance: bool = ..., affectsWorldspace: bool = ..., attributeType: bool = ..., cachedInternally: bool = ..., categories: bool = ..., channelBox: bool = ..., connectable: bool = ..., enum: bool = ..., exists: bool = ..., hidden: bool = ..., indeterminant: bool = ..., indexMatters: bool = ..., internal: bool = ..., internalGet: bool = ..., internalSet: bool = ..., keyable: bool = ..., listChildren: bool = ..., listDefault: bool = ..., listEnum: bool = ..., listParent: bool = ..., listSiblings: bool = ..., localizedListEnum: bool = ..., longName: bool = ..., maxExists: bool = ..., maximum: bool = ..., message: bool = ..., minExists: bool = ..., minimum: bool = ..., multi: bool = ..., niceName: bool = ..., node: str = ..., numberOfChildren: bool = ..., range: bool = ..., rangeExists: bool = ..., readable: bool = ..., renderSource: bool = ..., shortName: bool = ..., softMax: bool = ..., softMaxExists: bool = ..., softMin: bool = ..., softMinExists: bool = ..., softRange: bool = ..., softRangeExists: bool = ..., storable: bool = ..., type: str = ..., typeExact: str = ..., usedAsColor: bool = ..., usedAsFilename: bool = ..., usesMultiBuilder: bool = ..., worldspace: bool = ..., writable: bool = ...) -> Union[List[float], bool]:
    """attributeQuery returns information about the configuration of an attribute.
    It handles both boolean flags, returning true or false, as well as other return values.
    Specifying more than one boolean flag will return the logical "and"
    of all the specified boolean flags.  You may not specify any two flags when both do not
    provide a boolean return type.  (eg. "-internal -hidden" is okay but "-range -hidden" or
    "-range -softRange" is not.)dg, dependency, graph, attribute, query
    Args:
        affectsAppearance (bool?): Return true if the attribute affects the appearance of the node  
                Properties: create
        affectsWorldspace (bool?): Return the status of the attribute flag marking attributes affecting worldspace  
                Properties: create
        attributeType (bool?): Return the name of the attribute type (will be the same type names as described in the addAttr and addExtension commands).  
                Properties: create
        cachedInternally (bool?): Return whether the attribute is cached within the node as well as in the datablock  
                Properties: create
        categories (bool?): Return the categories to which the attribute belongs or an empty list if it does not belong to any.  
                Properties: create
        channelBox (bool?): Return whether the attribute should show up in the channelBox or not  
                Properties: create
        connectable (bool?): Return the connectable status of the attribute  
                Properties: create
        enum (bool?): Return true if the attribute is a enum attribute  
                Properties: create
        exists (bool?): Return true if the attribute exists  
                Properties: create
        hidden (bool?): Return the hidden status of the attribute  
                Properties: create
        indeterminant (bool?): Return true if this attribute might be used in evaluation but it's not known for sure until evaluation time  
                Properties: create
        indexMatters (bool?): Return the indexMatters status of the attribute  
                Properties: create
        internal (bool?): Return true if the attribute is either internalSet or internalGet  
                Properties: create
        internalGet (bool?): Return true if the attribute come from getCachedValue  
                Properties: create
        internalSet (bool?): Return true if the attribute must be set through setCachedValue  
                Properties: create
        keyable (bool?): Return the keyable status of the attribute  
                Properties: create
        listChildren (bool?): Return the list of children attributes of the given attribute.  
                Properties: create
        listDefault (bool?): Return the default values of numeric and compound numeric attributes.  
                Properties: create
        listEnum (bool?): Return the list of enum strings for the given attribute.  
                Properties: create
        listParent (bool?): Return the parent of the given attribute.  
                Properties: create
        listSiblings (bool?): Return the list of sibling attributes of the given attribute.  
                Properties: create
        localizedListEnum (bool?): Return the list of localized enum strings for the given attribute.  
                Properties: create
        longName (bool?): Return the long name of the attribute.  
                Properties: create
        maxExists (bool?): Return true if the attribute has a hard maximum. A min does not have to be present.  
                Properties: create
        maximum (bool?): Return the hard maximum of the attribute's value  
                Properties: create
        message (bool?): Return true if the attribute is a message attribute  
                Properties: create
        minExists (bool?): Return true if the attribute has a hard minimum. A max does not have to be present.  
                Properties: create
        minimum (bool?): Return the hard minimum of the attribute's value  
                Properties: create
        multi (bool?): Return true if the attribute is a multi-attribute  
                Properties: create
        niceName (bool?): Return the nice name (or "UI name") of the attribute.  
                Properties: create
        node (str?): Use all attributes from node named NAME  
                Properties: create
        numberOfChildren (bool?): Return the number of children the attribute has  
                Properties: create
        range (bool?): Return the hard range of the attribute's value  
                Properties: create
        rangeExists (bool?): Return true if the attribute has a hard range. Both min and max must be present.  
                Properties: create
        readable (bool?): Return the readable status of the attribute  
                Properties: create
        renderSource (bool?): Return whether this attribute is marked as a render source or not  
                Properties: create
        shortName (bool?): Return the short name of the attribute.  
                Properties: create
        softMax (bool?): Return the soft max (slider range) of the attribute's value  
                Properties: create
        softMaxExists (bool?): Return true if the attribute has a soft maximum. A min does not have to be present.  
                Properties: create
        softMin (bool?): Return the soft min (slider range) of the attribute's value  
                Properties: create
        softMinExists (bool?): Return true if the attribute has a soft minimum. A max does not have to be present.  
                Properties: create
        softRange (bool?): Return the soft range (slider range) of the attribute's value  
                Properties: create
        softRangeExists (bool?): Return true if the attribute has a soft range. Both min and max must be present.  
                Properties: create
        storable (bool?): Return true if the attribute is storable  
                Properties: create
        type (str?): Use static attributes from nodes of type TYPE.  Includes attributes inherited from parent class nodes.  
                Properties: create
        typeExact (str?): Use static attributes only from nodes of type TYPE.  Does not included inherited attributes.  
                Properties: create
        usedAsColor (bool?): Return true if the attribute should bring up a color picker  
                Properties: create
        usedAsFilename (bool?): Return true if the attribute should bring up a file browser  
                Properties: create
        usesMultiBuilder (bool?): Return true if the attribute is a multi-attribute and it uses the multi-builder to handle its data  
                Properties: create
        worldspace (bool?): Return the status of the attribute flag marking worldspace attribute  
                Properties: create
        writable (bool?): Return the writable status of the attribute  
                Properties: create

    Returns:
        List[float]: when querying ranges or default values
        bool: when querying attribute flags

    Example:
    """

def audioTrack(*args: str, edit: bool = ..., query: bool = ..., insertTrack: int = ..., lock: bool = ..., mute: bool = ..., numTracks: Queryable[int] = ..., removeEmptyTracks: bool = ..., removeTrack: int = ..., solo: bool = ..., swapTracks: Tuple[int, int] = ..., title: Queryable[str] = ..., track: int = ...) -> Union[bool, int, str]:
    """This command is used for inserting and removing tracks related to the audio clips displayed in the sequencer. It can also be used to modify the track state, for example, to lock or mute a track.shot, audio, sequencer, track
    Args:
        insertTrack (int?): This flag is used to insert a new empty track at the track index specified. Indices are 1. based.  
                Properties: create
        lock (bool?): This flag specifies whether all audio clips on the same track as the specified audio node are to be locked at their current location and track.  
                Properties: create, query, edit
        mute (bool?): This flag specifies whether all audio clips on the same track as the specified audio node are to be muted or not.  
                Properties: create, query, edit
        numTracks (Queryable[int]?): To query the number of audio tracks  
                Properties: query
        removeEmptyTracks (bool?): This flag is used to remove all tracks that have no clips.  
                Properties: create
        removeTrack (int?): This flag is used to remove the track with the specified index.  The  
                track must have no clips on it before it can be removed.  
                Properties: create
        solo (bool?): This flag specifies whether all audio clips on the same track as the specified audio node are to be soloed or not.  
                Properties: create, query, edit
        swapTracks (Tuple[int, int]?): This flag is used to swap the contents of two specified tracks. Indices are 1. based.  
                Properties: create
        title (Queryable[str]?): This flag specifies the title for the track.  
                Properties: create, query, edit
        track (int?): Specify the track on which to operate by using the track's trackNumber.  
                			In query mode, this flag needs a value.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def autoKeyframe(*, edit: bool = ..., query: bool = ..., addAttr: str = ..., characterOption: Queryable[str] = ..., listAttr: bool = ..., noReset: bool = ..., state: bool = ...) -> Union[int, str, bool]:
    """With no flags, this command will set keyframes on all
    attributes that have been modified since an "autoKeyframe -state on"
    command was issued.  To stop keeping track of modified attributes,
    use "autoKeyframe -state off"autoKeyframe does not create new animation curves.  An attribute
    must have already been keyframed (with the setKeyframe command)
    for autoKeyframe to  add new keyframes for modified attributes.You can also query the current state of autoKeyframing
    with "autoKeyframe -query -state".
    Args:
        addAttr (str?): Add to the list of plugs (node.attribute) that autoKeyframe is currently  
                considering for auto keying.  This list is transient and short-lived, and  
                is reset as soon as autoKeyframe sets the keyframe or decides that no  
                keyframe is to be set, on completion of the next set attribute.  
                Properties: edit
        characterOption (Queryable[str]?): Valid options are: "standard", "all". Dictates whether  
                when auto-keying characters the auto-key works as usual or whether  
                it keys all of the character attributes. Default is "standard".  
                Properties: create, query, edit
        listAttr (bool?): Returns the list of plugs (node.attribute) that autoKeyframe is currently  
                considering for auto keying.  This list is transient and short-lived, and  
                is reset as soon as autoKeyframe sets the keyframe or decides that no  
                keyframe is to be set, on completion of the next set attribute.  
                Properties: query
        noReset (bool?): Must be used in conjunction with the state/st flag.  
                When noReset/nr is specified, the list of plugs to be autokeyed  
                is not cleared when the state changes  
                Properties: create, edit
        state (bool?): turns on/off remembering of modified attributes  
                Properties: create, query, edit

    Returns:
        int: Number of keyframes set.

    Example:
    """

def autoPlace(*, useMouse: bool = ...) -> List[float]:
    """This command takes a point in the centre of the current
    modeling pane and projects it onto the live surface.
    This produces a point in 3 space which is returned.
    If theflag is set the current mouse position
    is used rather than the centre of the modeling pane.
    Args:
        useMouse (bool?): Use the current mouse position rather than the centre of the  
                active view.  
                Properties: create

    Returns:
        List[float]: Placement location in 3D space

    Example:
    """

def autoSave(*, query: bool = ..., destination: Queryable[int] = ..., destinationFolder: bool = ..., enable: bool = ..., folder: Queryable[str] = ..., interval: Queryable[float] = ..., limitBackups: bool = ..., maxBackups: Queryable[int] = ..., perform: bool = ..., prompt: bool = ...) -> Union[bool, int, str, float]:
    """Provides an interface to the auto-save mechanism.
    Args:
        destination (Queryable[int]?): Sets the option for where auto-save files go.  
                0. auto-saves go into the workspace autosave folder  
                1. auto-saves go into the named folder (set with the -folder flag)  
                2. auto-saves go into a folder set by an environment variable (MAYA_AUTOSAVE_FOLDER)  
                Properties: create, query
        destinationFolder (bool?): Queries the actual destination folder for auto-saves, based on the current  
                setting of the -destination flag, workspace rules and environment variables.  
                Resolves environment variables etc. and makes any relative path  
                absolute (resolved relative to the workspace root).  
                The returned string will end with a trailing separator ('/').  
                Properties: query
        enable (bool?): Enables or disables auto-saves.  
                Properties: create, query
        folder (Queryable[str]?): Sets the folder for auto-saves used if the destination option is 1.  
                Properties: create, query
        interval (Queryable[float]?): Sets the interval between auto-saves (in seconds).  
                The default interval is 600 seconds (10 minutes).  
                Properties: create, query
        limitBackups (bool?): Sets whether the number of auto-save files is limited.  
                Properties: create, query
        maxBackups (Queryable[int]?): Sets the maximum number of auto-save files, if limiting is in effect.  
                Properties: create, query
        perform (bool?): Invokes the auto-save process.  
                Properties: create
        prompt (bool?): Sets whether the auto-save prompts the user before auto-saving.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def backgroundEvaluationManager(*args: str, query: bool = ..., interrupt: bool = ..., mode: Queryable[str] = ..., pause: bool = ..., resume: bool = ...) -> Union[bool, str]:
    """Allows user to pause and restart background evaluations.async, background, time, evaluation, manager, DG, runtime
    Args:
        interrupt (bool?): Enable or disable fast interrupt of background execution during interactive workflow.  
                Properties: create, query
        mode (Queryable[str]?): Changes the current evaluation mode in the evaluation manager. Supported values are  
                "serial" and "parallel".  
                Properties: create, query
        pause (bool?): Pause background evaluation. Will block till background evaluation is fully stopped.  
                Can be queried to get the current state.  
                Properties: create, query
        resume (bool?): Resume background evaluation. Will start suspended evaluations unless someones else requested it.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def bakeClip(*args: str, blend: Tuple[int, int] = ..., clipIndex: Multiuse[int] = ..., keepOriginals: bool = ..., name: str = ...) -> str:
    """This command is used to bake clips and blends into a single clip.character, clip, blend, animation, bake
    Args:
        blend (Tuple[int, int]?): Specify the indices of the clips being blended.  
                Properties: create
        clipIndex (Multiuse[int]?): Specify the index of the clip to bake.  
                Properties: create, multiuse
        keepOriginals (bool?): Keep original clips in the trax editor and place the merged clip into the visor. The default is to schedule the merged clip, and to keep the original clips in the visor.  
                Properties: create
        name (str?): Specify the name of the new clip to create.  
                Properties: create

    Returns:
        str: clip name

    Example:
    """

def bakeDeformer(*, colorizeSkeleton: bool = ..., customRangeOfMotion: NullableRange[float] = ..., dstMeshName: str = ..., dstSkeletonName: str = ..., hierarchy: bool = ..., influences: List[str] = ..., maxInfluences: int = ..., pruneWeights: float = ..., smoothWeights: int = ..., srcMeshName: str = ..., srcSkeletonName: str = ...) -> str:
    """Given a rigged character, whose mesh shape is determined by a set of deformers, bakeDeformer calculates linear blend skin weights most closely approximating observed deformations. To do this, a test set of examples is generated by moving the rig through a range of motion. Results mesh and pose pairs are then used to solve a constrained optimization, solving for skinning weights. bakeDeformer automatically binds and applies resulting weights to the destination geometry. If the source and destination mesh/skeleton are identical, the command will replace the original deformations with a skinCluster and computed weights. See the below examples for sample usage.bake, skinning, deformer
    Args:
        colorizeSkeleton (bool?): The new skin cluster created will have its skeleton colorized. Must be used with the -srcSkeletonName and -dstSkeletonName flags.  
                Properties: create
        customRangeOfMotion (NullableRange[float]?): When this flag is specified with the frames for the range of motion to be used, the tool will step through  
                each frame as a separate pose. Otherwise the tool will use the existing range of motion in the tool  
                that rotates each influence 45 degrees.  
              
                    Usage examples:  
                  
                 -rom "10. 20" means all frames in the range from 10 to 20, inclusive, in the current time unit.   
                 Omitting one end of a range means using either end of the animation range (or both), as in the following examples:   
                 -rom "10. " means all frames from time 10 (in the current time unit) onwards to the maximum time in the animation range (on the timeline).   
                 -rom ":10" means all frames from the minimum time on the animation range (on the timeline) up to (and including) time 10 (in the current time unit).   
                 -rom ":" is a short form to specify all frames, from minimum to maximum time on the current animation range.   
              
              
                When using this flag, some of the joints in the specified range of motion may not have changed sufficiently.  
                To improve bakeDeformer results or avoid algorithm errors, the command will return a list of influences that do not move enough in the specified range of motion.  
                To detect these joints, the local transformation of each joint is compared between subsequent frames.  
                We consider that a joint has sufficiently changed if any of the below criteria are met:  
                  
                There is a rotation of at least 5 degrees, as determined by the shortest rotation between transforms.  
                There is a translation of 1% or greater of the size of the largest bounding box containing all joints for each frame.  
                There is a scaling change of at least 1%. This percentage represents the smallest scaling value over the largest scaling value (in absolute value).  
              
              
                    If a joint has not met any of the criteria, it will be added to the warning of joints that have not moved enough.  
                  
              
              
                The custom range of motion should be considered experimental.  
                Properties: create
        dstMeshName (str?): The destination mesh name.  
                Properties: create
        dstSkeletonName (str?): The destination skeleton name.  
                Properties: create
        hierarchy (bool?): All children of the passed joints that are used in the influences flag are used.  
                Properties: create
        influences (List[str]?): A list of joints that are used as the influences to determine new weights.  
                Properties: create
        maxInfluences (int?): The maximum number of influences per vertex.  
                Properties: create
        pruneWeights (float?): On the newly created skin cluster, set any weight below the given the value to zero (post-processing).  
                This will call the skinPercent command as follows: "skinPercent -pruneWeights [value] [skinClusterName] [dstMeshName]"  
                where [value] is the value passed into this flag, [skinClusterName] is the name of the new skinCluster node created  
                after running this tool, and [dstMeshName] is the mesh provided in the -dstMeshName flag.  
                Properties: create
        smoothWeights (int?): The number of smoothing iterations for smoothing weights (post-processing). This also renormalizes the remaining the weights.  
                Properties: create
        srcMeshName (str?): The source mesh name.  
                Properties: create
        srcSkeletonName (str?): The source skeleton name.  
                Properties: create

    Returns:
        str: BakeDeformer name

    Example:
    """

def bakePartialHistory(*args: str, edit: bool = ..., query: bool = ..., allShapes: bool = ..., postSmooth: bool = ..., preCache: bool = ..., preDeformers: bool = ..., prePostDeformers: bool = ...) -> Union[str, bool]:
    """This command is used to bake sections of the construction history of a shape node
    when possible. A typical usage would be on a shape that has both modelling operations
    and deformers in its history. Using this command with the -prePostDeformers flag will
    bake the modeling portions of the graph, so that only the deformers remain.Note that not all modeling operations can be baked such that they create exactly the
    same effect after baking. For example, imagine the history contains a skinning operation
    followed by a smooth. Before baking, the smooth operation is performed each time
    the skin deforms, so it will smooth differently depending on the output of the skin.
    When the smooth operation is baked into the skinning, the skin will be reweighted
    based on the smooth points to attempt to approximate the original behavior. However,
    the skin node does not perform the smooth operation, it merely performs skinning with
    the newly calculated weights and the result will not be identical to before the bake.In general, modeling operations that occur before deformers can be baked precisely.
    Those which occur after can only be approximated. The -pre and -post flags allow you
    to control whether only the operations before or after the deformers are baked.When the command is used on an object with no deformers, the entire history
    will be deleted.deformers, history, bake
    Args:
        allShapes (bool?): Specifies that the bake operation should be performed on all shapes in the entire scene. By default, only selected objects are baked.  
                If this option is specified and there are no shapes in the scene, then this command will do nothing and end successfully.  
                Properties: create, query
        postSmooth (bool?): Specifies whether or not a smoothing operation should be done on skin vertices. This  
                smoothing is only done on vertices that are found to deviate largely from other  
                vertex values.  The default is false.  
                Properties: create, query
        preCache (bool?): Specifies baking of any history operations that occur before the caching operation, including deformers. In query mode, returns a list of the nodes that will be baked.  
                Properties: create, query
        preDeformers (bool?): Specifies baking of any modeling operations in the history that occur before the deformers. In query mode, returns a list of the nodes that will be baked.  
                Properties: create, query
        prePostDeformers (bool?): Specifies baking of all modeling operations in the history whether they are before or after the deformers in the history. If neither the -prePostDeformers nor the -preDeformers flag is specified, prePostDeformers will be used as the default. In query mode, returns a list of the nodes that will be baked.  
                Properties: create, query

    Returns:
        str: name of shapes that were baked

    Example:
    """

def bakeResults(*args: str, edit: bool = ..., query: bool = ..., animation: str = ..., attribute: Multiuse[str] = ..., bakeOnOverrideLayer: bool = ..., controlPoints: bool = ..., destinationLayer: str = ..., disableImplicitControl: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., minimizeRotation: bool = ..., oversamplingRate: int = ..., preserveOutsideKeys: bool = ..., removeBakedAnimFromLayer: bool = ..., removeBakedAttributeFromLayer: bool = ..., resolveWithoutLayer: Multiuse[str] = ..., sampleBy: int = ..., shape: bool = ..., simulation: bool = ..., smart: Union[Tuple[()], Tuple[bool, float]] = ..., sparseAnimCurveBake: bool = ..., time: Multiuse[NullableRange[float]] = ...) -> int:
    """This command allows the user to replace a chain of dependency nodes
    which define the value for an attribute with a single animation curve.
    Command allows the user to specify the range and frequency of sampling.This command operates on a keyset. A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices. Times and indices should
    be specified as a range, as shown below.
    Args:
        animation (str?): Where this command should get the animation to act  
                on. Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects." See  
                command description for details.  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        bakeOnOverrideLayer (bool?): If true, all layered and baked attribute will be added as a top override layer.  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        destinationLayer (str?): This flag can be used to specify an existing layer where the baked results  
                should be stored. Use this flag with caution. If the destination layer already has animation on it  
                that contributes to the final result, it will be replaced by the output of the bake. As a result,  
                it is possible that the combined animation visible in the scene is different before / after the baking  
                process.  
                Properties: create
        disableImplicitControl (bool?): Whether to disable implicit control after the anim curves  
                are obtained as the result of this command. An implicit control  
                to an attribute is some function that affects the attribute  
                without using an explicit dependency graph connection. The  
                control of IK, via ik handles, is an example.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve. Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true. This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound. Note: when used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace." This  
                flag has no effect on the curve pasted from the clipboard.  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        minimizeRotation (bool?): Specify whether to minimize the local Euler component from key to key during baking of rotation channels.  
                Properties: create
        oversamplingRate (int?): Amount of samples per sampleBy period. Default is 1.  
                Properties: create
        preserveOutsideKeys (bool?): Whether to preserve keys that are outside the bake range  
                when there are directly connected animation curves or a pairBlend node  
                which has an animation curve as its direct input. The default  
                (false) is to remove frames outside the bake range. If the channel  
                that you are baking is not controlled by a single animation curve,  
                then a new animation curve will be created with keys only in the  
                bake range. In the case of pairBlend-driven channels, setting pok to  
                true will retain both the pairBlend and its input animCurve. The  
                blended values will be baked onto the animCurve and the weight of the  
                pairBlend weight will be keyed to the animCurve during the baked  
                range.  
                Properties: create
        removeBakedAnimFromLayer (bool?): If true, all baked animation will be removed from the layer.  
                Otherwise all layer associated with the baked animation will be muted.  
                Properties: create
        removeBakedAttributeFromLayer (bool?): If true, all baked attribute will be removed from the layer.  
                Otherwise all layer associated with the baked attribute will be muted.  
                Properties: create
        resolveWithoutLayer (Multiuse[str]?): This flag can be used to specify a list of layers to be merged together during the bake process. This  
                is a multi-use flag. Its name refers to the fact that when solving for the value to key, it determines  
                the proper value to key on the destination layer to achieve the same result as the merged layers.  
                Properties: create, multiuse
        sampleBy (int?): Amount to sample by. Default is 1.0 in current timeUnit.  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        simulation (bool?): Using this flag instructs the command to preform a simulation instead  
                of just evaluating each attribute separately over the range of time.  
                The simulation flag is required to bake animation that depends on  
                the whole scene being evaluated at each time step such as dynamics. The  
                default is false.  
                Properties: create
        smart (Union[Tuple[()], Tuple[bool, float]]?): Specify whether to enable smart bake and the optional smart bake tolerance.  
                Properties: create
        sparseAnimCurveBake (bool?): When this is true and anim curves are being baked, do not insert  
                any keys into areas of the curve where animation is defined. And, use  
                as few keys as possible to bake the pre and post infinity behavior.  
                When this is false, one key will be inserted at each time step. The  
                default is false.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse

    Returns:
        int: - The number of channels baked

    Example:
    """

def bakeSimulation(*args: str, edit: bool = ..., query: bool = ..., animation: str = ..., attribute: Multiuse[str] = ..., bakeOnOverrideLayer: bool = ..., controlPoints: bool = ..., destinationLayer: str = ..., disableImplicitControl: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., minimizeRotation: bool = ..., preserveOutsideKeys: bool = ..., removeBakedAnimFromLayer: bool = ..., removeBakedAttributeFromLayer: bool = ..., resolveWithoutLayer: Multiuse[str] = ..., sampleBy: int = ..., shape: bool = ..., simulation: bool = ..., smart: Union[Tuple[()], Tuple[bool, float]] = ..., sparseAnimCurveBake: bool = ..., time: Multiuse[NullableRange[float]] = ...) -> bool:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).The bakeSimulation command is obsolete.  Instead, "bakeResults
    -simulation true" should be used.  The bakeSimulation command has
    retained for backwards compatibility.This command allows the user to replace a chain of dependency
    nodes, or implicit relationship, such as those between joints
    and IK handles, which define the value of an attribute, with a
    single animation curve. Command allows the user to specify the
    range and frequency of sampling. Unlike the bakeResults
    command, this command will actually set the time of the
    current scene to all the times, in sequence, inside the given time
    interval before it sets the time back to when it is started.
    As a result, it may modify the scene.
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        bakeOnOverrideLayer (bool?): If true, all layered and baked attributes will be added as a top override layer.  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        destinationLayer (str?): This flag can be used to specify an existing layer where the baked results  
                should be stored.  
                Properties: create
        disableImplicitControl (bool?): Whether to disable implicit control after the anim curves  
                are obtained as the result of this command. An implicit control  
                to an attribute is some function that affects the attribute  
                without using an explicit dependency graph connection. The  
                control of IK, via ik handles, is an example.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        minimizeRotation (bool?): Specify whether to minimize the local euler component from key to key during baking of rotation channels.  
                Properties: create
        preserveOutsideKeys (bool?): Whether to preserve keys that are outside the bake range  
                when there are directly connected animation curves.  The default  
                (false) is to remove frames outside the bake range.  If the channel  
                that you are baking is not controlled by a single animation curve,  
                then a new animation curve will be created with keys only in the  
                bake range.  
                Properties: create
        removeBakedAnimFromLayer (bool?): If true, all baked animation will be removed from the layer.  
                Properties: create
        removeBakedAttributeFromLayer (bool?): If true, all baked attributes will be removed from the layer.  
                Properties: create
        resolveWithoutLayer (Multiuse[str]?): This flag can be used to specify a list of layers to be merged together during the bake process. This  
                is a multi-use flag. Its name refers to the fact that when solving for the value to key, it determines  
                the proper value to key on the destination layer to achieve the same result as the merged layers.  
                Properties: create, multiuse
        sampleBy (int?): Amount to sample by. Default is 1.0 in current timeUnit  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        simulation (bool?): Using this flag instructs the command to preform a simulation instead  
                of just evaluating each attribute separately over the range of time.  
                The simulation flag is required to bake animation that that depends on  
                the whole scene being evaluated at each time step such as dynamics. The  
                default is true.  
                Properties: create
        smart (Union[Tuple[()], Tuple[bool, float]]?): Specify whether to enable smart bake and the optional smart bake tolerance.  
                Properties: create
        sparseAnimCurveBake (bool?): When baking anim curves, do not insert any keys into areas  
                of the curve where animation is defined.  And, use as few keys  
                as possible to bake the pre and post infinity behaviors.  When  
                this is false, one key will be inserted at each time step.  The  
                default is false.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def baseTemplate(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., fileName: Queryable[str] = ..., force: bool = ..., load: bool = ..., matchFile: str = ..., silent: bool = ..., unload: bool = ..., viewList: Queryable[str] = ...) -> Union[bool, str]:
    """This is the class for the commands that edit and/or query templates.base, template
    Args:
        exists (bool?): Returns true or false depending upon whether the specified template exists.  
                When used with the matchFile argument, the query will return true if the  
                template exists and the filename it was loaded from matches the filename  
                given.  
                Properties: query
        fileName (Queryable[str]?): Specifies the filename associated with the template.  This argument can be  
                used in conjunction with load, save or query modes. If no filename is  
                associated with a template, a default file name based on the template  
                name will be used.  It is recommended but not required that the  
                filename and template name correspond.  
                Properties: create, query
        force (bool?): This flag is used with some actions to allow them to proceed with an  
                overwrite or destructive operation.  
                When used with load, it will allow an existing template to be reloaded  
                from a file.  When used in create mode, it will allow an existing template  
                to be recreated (for example when using fromContainer argument to  
                regenerate a template).  
                Properties: create
        load (bool?): Load an existing template from a file.  
                If a filename is specified for the template, the entire file  
                (and all templates in it) will be loaded.  
                If no file is specified, a default filename will be assumed,  
                based on the template name.
        matchFile (str?): Used in query mode in conjunction with other flags this flag specifies  
                an optional file name that is to be matched as part of the query operation.  
                			In query mode, this flag needs a value.  
                Properties: query
        silent (bool?): Silent mode will suppress any error or warning messages that would normally be  
                reported from the command execution.  The return values are unaffected.  
                Properties: create, query, edit
        unload (bool?): Unload the specified template.  This action will not delete the  
                associated template file if one exists, it merely removes the template  
                definition from the current session.  
                Properties: create
        viewList (Queryable[str]?): Used in query mode, returns a list of all views defined on the template.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def baseView(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., itemInfo: str = ..., itemList: bool = ..., viewDescription: bool = ..., viewLabel: bool = ..., viewList: bool = ..., viewName: Queryable[str] = ...) -> Union[bool, str]:
    """A view defines the layout information for the attributes of a
    particular node type or container.  Views can be selected from a set of
    built-in views or may be defined on an associated container template.
    This command queries the view-related information for a container node or
    for a given template.  The information returned from this command will be
    based on the view-related settings in force on the container node at the time
    of the query (i.e. the container's view mode, template name, view name
    attributes), when applicable.base, view
    Args:
        itemInfo (str?): Used in query mode in conjunction with the itemList flag.  
                The command will return a list of information for each item in the view, the  
                information fields returned for each item are determined by this argument value.  
                The information fields will be listed in the string array returned.  
                The order in which the keyword is specified will determine the order in which  
                the data will be returned by the command.  
                One or more of the following keywords, separated by colons ':' are used to  
                specify the argument value.  
              
                itemIndex  : sequential item number (0. based)  
                itemName   : item name (string)  
                itemLabel  : item display label (string)  
                itemDescription : item description field (string)  
                itemLevel  : item hierarchy level (0. n)  
                itemIsGroup : (boolean 0 or 1) indicates whether or not this item is a group  
                itemIsAttribute : (boolean 0 or 1) indicates whether or not this item is an attribute  
                itemNumChildren: number of immediate children (groups or attributes) of this item  
                itemAttrType : item attribute type (string)  
                itemCallback : item callback field (string)  
              
                In query mode, this flag needs a value.  
                Properties: query
        itemList (bool?): Used in query mode, the command will return a list of information for each item in  
                the view.  The viewName flag is used to select the view to query.  
                The information returned about each item is determined by the itemInfo argument value.  
                For efficiency, it is best to query all necessary item information at one time  
                (to avoid recomputing the view information on each call).  
                Properties: query
        viewDescription (bool?): Used in query mode, returns the description field associated with the  
                selected view.  
                If no description was defined for this view, the value will be empty.  
                Properties: query
        viewLabel (bool?): Used in query mode, returns the display label associated with the view.  
                An appropriate label suitable for the user interface will be  
                returned based on the selected view.  Use of the view label  
                is usually more suitable than the view name for display purposes.  
                Properties: query
        viewList (bool?): Used in query mode, command will return a list of all views defined for the  
                given target (container or template).  
                Properties: query
        viewName (Queryable[str]?): Used in query mode, specifies the name of the queried view when used in  
                conjunction with a template target. When used in conjunction with a container  
                target, it requires no string argument, and returns the name of the currently  
                active view associated with the container; this value may be empty if the  
                current view is not a valid template view or is generated by one of the  
                built-in views modes. For this reason, the view label is generally more  
                suitable for display purposes.  
                			In query mode, this flag can accept a value.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def batchRender(arg0: str = ..., arg1: str = ..., arg2: str = ..., arg3: str = ..., arg4: str = ..., /, *, filename: str = ..., melCommand: str = ..., numProcs: int = ..., preRenderCommand: str = ..., remoteRenderMachine: str = ..., renderCommandOptions: str = ..., showImage: bool = ..., status: str = ..., useRemoteRender: bool = ..., useStandalone: bool = ..., verbosity: int = ...) -> bool:
    """The batchRender command is used to spawn off a separate
    rendering session of the current maya file. If no
    mayaFile is specified, it'll ask you whether you want the
    current job killed.The batchRender will spawn a separate maya process in which
    commands will be communicated to it through a commandPort. If Maya
    is unable to find an available port an error will be
    produced. Maya will attempt to use ports 7835 through 7844.
    Args:
        filename (str?): Filename to be rendered; if empty, a temporary filename will be created.  
                Properties: create
        melCommand (str?): Mel command to execute to run a renderer other than the software renderer.  
                Properties: create
        numProcs (int?): Number of processors to use (0 means use all available processors).  
                Properties: create
        preRenderCommand (str?): Command to be run prior to invoking a batch render.  
                Properties: create
        remoteRenderMachine (str?): Name of remote render machine. Not available on Windows.  
                Properties: create
        renderCommandOptions (str?): Arguments to the render command for batch rendering.  
                Properties: create
        showImage (bool?): Show progress of the current rendering job.  
                Properties: create
        status (str?): Status string for displaying the batch render status.  
                Properties: create
        useRemoteRender (bool?): If remote rendering is desired. Not available on Windows.  
                Properties: create
        useStandalone (bool?): Batch rendering is to be done by exporting the scene and rendering with a standalone renderer.  
                Properties: create
        verbosity (int?): Defines the verbosity level to report the batch rendering  
                status:  
                1. display only one start message, then one message when all  
                frames are rendered.  
                2. display only start and end frame messages.  
                3. display all messages (default).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def bevel(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., bevelShapeType: Queryable[int] = ..., caching: bool = ..., cornerType: Queryable[int] = ..., depth: Queryable[float] = ..., extrudeDepth: Queryable[float] = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ..., width: Queryable[float] = ..., constructionHistory: bool = ..., joinSurfaces: bool = ..., name: str = ..., numberOfSides: Queryable[int] = ..., object: bool = ..., polygon: int = ..., range: bool = ...) -> Union[List[str], int, bool, float]:
    """The bevel command creates a new bevel surface for the specified curve.
    The curve can be any nurbs curves.
    Args:
        bevelShapeType (Queryable[int]?): Shape type: 1. straight cut, 2. curve out, 3. curve in  
                Default: 1  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        cornerType (Queryable[int]?): Corner type: 1. linear, 2. circular  
                Default: 2  
                Properties: create, query, edit
        depth (Queryable[float]?): The depth for bevel  
                Default: 0.5  
                Properties: create, query, edit
        extrudeDepth (Queryable[float]?): The extrude depth for bevel  
                Default: 1.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance for bevel offsets  
                Default: 0.01  
                Properties: create, query, edit
        width (Queryable[float]?): The width for bevel  
                Default: 0.5  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        joinSurfaces (bool?): Attach bevelled surfaces into one surface for each  
                input curve.  
                Default:true  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        numberOfSides (Queryable[int]?): How to apply the bevel.  
              
                1. no bevels  
                2. bevel at start only  
                3. bevel at end only  
                4. bevel at start and end  
              
                Default: 4  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def bevelPlus(*args: str, edit: bool = ..., query: bool = ..., bevelInside: bool = ..., capSides: Queryable[int] = ..., constructionHistory: bool = ..., innerStyle: Queryable[int] = ..., joinSurfaces: bool = ..., name: str = ..., normalsOutwards: bool = ..., numberOfSides: Queryable[int] = ..., outerStyle: Queryable[int] = ..., polygon: int = ..., range: bool = ...) -> Union[List[str], bool, int]:
    """The bevelPlus command creates a new bevel surface for the specified
    curves using a given style curve. The first curve should be the
    "outside" curve, and the (optional) rest of them should be inside of
    the first one. For predictable results, the curves should be planar
    and all in the same plane.
    Args:
        bevelInside (bool?): If true, ensure surface always remains within the original profile curve  
                Default: false  
                Properties: create, query, edit
        capSides (Queryable[int]?): How to cap the bevel.  
              
                1. no caps  
                2. cap at start only  
                3. cap at end only  
                4. cap at start and end  
              
                Default:4  
                Properties: create, query
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        innerStyle (Queryable[int]?): Similar to outerStyle, this style is applied to all  
                but the first (outer) curve specified.  
                Properties: create, query, edit
        joinSurfaces (bool?): Attach bevelled surfaces into one surface for each  
                input curve.  
                Default:true  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        normalsOutwards (bool?): If enabled, the normals point outwards on the  
                resulting NURBS or poly surface.  
                Properties: create, query, edit
        numberOfSides (Queryable[int]?): How to apply the bevel.  
              
                1. no bevels  
                2. bevel at start only  
                3. bevel at end only  
                4. bevel at start and end  
              
                Default: 4  
                Properties: create, query, edit
        outerStyle (Queryable[int]?): Choose a style to use for the bevel of the first (outer)  
                curve.  There are 15 predefined styles (values 0 to 14 can be used  
                to select them). For those experienced with MEL, you can, after  
                the fact, specify a custom curve and use it for the style curve.  
                See the documentation for styleCurve node to see what requirements  
                a style curve must satisfy.  
                Properties: create, query, edit
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name(s) and node name

    Example:
    """

def bezierAnchorPreset(*, preset: int = ...) -> int:
    """This command provides a queryable interface for Bezier curve shapes.
    Args:
        preset (int?): Selects a preset to apply to selected Bezier anchors. Valid arguments are:  
              
                0. Bezier  
                1. Bezier Corner  
                2. Corner  
                Properties: create

    Returns:
        int: (number of modified anchors)

    Example:
    """

def bezierAnchorState(*, even: bool = ..., smooth: bool = ...) -> int:
    """The bezierAnchorState command provides an easy interface to modify anchor states:- Smooth/Broken anchor tangents
    - Even/Uneven weighted anchor tangents
    Args:
        even (bool?): Sets selected anchors (or attached tangent handles) to even weighting when true, uneven otherwise.  
                Properties: create
        smooth (bool?): Sets selected anchors (or attached tangent handles) to smooth when true, broken otherwise.  
                Properties: create

    Returns:
        int: (number of modified anchors)

    Example:
    """

def bezierCurveToNurbs() -> List[str]:
    """The bezierCurveToNurbs command attempts to convert an existing NURBS curve
    to a Bezier curve.
    Returns:
        List[str]: (object name and node name)

    Example:
    """

def bezierInfo(*, anchorFromCV: int = ..., cvFromAnchor: int = ..., isAnchorSelected: bool = ..., isTangentSelected: bool = ..., onlyAnchorsSelected: bool = ..., onlyTangentsSelected: bool = ...) -> int:
    """This command provides a queryable interface for Bezier curve shapes.
    Args:
        anchorFromCV (int?): Returns the Bezier anchor index from a given CV index  
                Properties: create
        cvFromAnchor (int?): Returns the CV index for a given Bezier anchor index  
                Properties: create
        isAnchorSelected (bool?): Returns 1 if an anchor CV is currently selected. 0, otherwise.  
                Properties: create
        isTangentSelected (bool?): Returns 1 if a tangent CV is currently selected. 0, otherwise.  
                Properties: create
        onlyAnchorsSelected (bool?): Returns 1 if the only CV components selected are anchor CVs. 0, otherwise.  
                Properties: create
        onlyTangentsSelected (bool?): Returns 1 if the only CV components selected are tangent CVs. 0, otherwise.  
                Properties: create

    Returns:
        int: Queried value

    Example:
    """

def binMembership(*args: str, query: bool = ..., addToBin: str = ..., exists: str = ..., inheritBinsFromNodes: str = ..., isValidBinName: str = ..., listBins: bool = ..., makeExclusive: str = ..., notifyChanged: bool = ..., removeFromBin: str = ...) -> bool:
    """Command to assign nodes to bins.binMembership
    Args:
        addToBin (str?): Add the nodes in a node list to a bin.  
                Properties: create
        exists (str?): Query if a node exists in a bin.  The exists flag can take only one node.  
                Properties: create
        inheritBinsFromNodes (str?): Let the node in the flag's argument inherit bins from nodes  
                in the specified node list.  The node list is specified as the  
                object of the command.  
                Properties: create
        isValidBinName (str?): Query if the specified bin name is valid.  If so, return true.  
                Otherwise, return false.  
                Properties: create
        listBins (bool?): Query and return a list of bins a list of nodes belong to.  
                If a bin contains any of the nodes in the selection list,  
                then it should be included  
                in the returned bin list.  
                Properties: create, query
        makeExclusive (str?): Make the specified nodes belong exclusively in the specified bin.  
                Properties: create
        notifyChanged (bool?): This flag is used to notify that binMembership has been changed.  
                Properties: create
        removeFromBin (str?): Remove the nodes in a node list from a bin.  
                Properties: create

    Returns:
        bool: Command result

    Example:
    """

def bindSkin(*args: str, edit: bool = ..., query: bool = ..., byClosestPoint: bool = ..., byPartition: bool = ..., colorJoints: bool = ..., delete: bool = ..., doNotDescend: bool = ..., enable: bool = ..., name: str = ..., partition: str = ..., toAll: bool = ..., toSelectedBones: bool = ..., toSkeleton: bool = ..., unbind: bool = ..., unbindKeepHistory: bool = ..., unlock: bool = ...) -> str:
    """This command binds the currently selected objects to the
    currently selected skeletons.  Shapes which can be bound are:
    meshes, nurbs curves, nurbs surfaces, lattices, subdivision
    surfaces, and API shapes. Multiple shapes and multiple skeletons can be
    bound at once by selecting them or specifying them on the command
    line. Selection order is not important.The skin is bound using the so-called "rigid" bind, in which
    the components are rigidly attached to the closest bone in the
    skeleton. Flexors can later be added to the skeleton to
    smooth out the skinning around joints.The skin(s) can be bound either to the entire skeleton hierarchy
    of the selected joint(s), or to only the selected joints. The
    entire hierarchy is the default. The -tsb/-toSelectedBones flag
    allows binding to only the selected bones.This command can also be used to detach the skin from the skeleton.
    Detaching the skin is useful in a variety of situations, such as:
    inserting additional bones, deleting bones, changing the bind
    position of the skeleton or skin, or simply getting rid of the
    skinning nodes altogether. The options to use when detaching the
    skin depend on how much of the skinning info you want to get rid
    of. Namely: (1) -delete or -unbind: remove all skinning nodes, (2) -unbindKeepHistory: remove the skinning sets, but keep the weights, (3) -disable: disable the skinning but keep the skinning sets and the weights.
    Args:
        byClosestPoint (bool?): bind each point in the object to the segment closest to the point.  
                The byClosestPoint and byPartition flags are mutually  
                exclusive.  The byClosestPoint flag is the default.  
                Properties: create
        byPartition (bool?): bind each group in the partition to the segment  
                closest to the group's centroid. A partition must be specified  
                with the -p/-partition flag  
                Properties: create
        colorJoints (bool?): In bind mode, this flag assigns colors to the joints based  
                on the colors assigned to the joint's skin set.  
                In delete and unlock mode, this flag removes the colors from  
                joints that are no longer bound as skin.  
                In disable and unbindKeepHistory mode, this flag does nothing.  
                Properties: create
        delete (bool?): Detach the skin on the selected skeletons and remove all bind-  
                related construction history.  
                Properties: create
        doNotDescend (bool?): Do not descend to shapes that are parented below the selected  
                object(s).  
                Bind only the selected objects.  
                Properties: create
        enable (bool?): Enable or disable a bind that has been disabled on the selected  
                skeletons.  
                To enable the bind on selected bones only, select the bones and  
                use the -tsb flag with the -en flag. This flag is used when you  
                want to temporarily disable the bind without losing the set  
                information or the weight information of the skinning, for example  
                if you want to modify the bindPose.  
                Properties: create
        name (str?): This flag is obsolete.  
                Properties: create
        partition (str?): Specify a partition to bind by. This is only valid when  
                used with the -bp/-byPartition flag.  
                Properties: create
        toAll (bool?): objects will be bound to the entire selected skeletons. Even bones with zero influence  
                will be bound, whereas the toSkeleton will only bind non-zero influences.  
                Properties: create
        toSelectedBones (bool?): objects will be bound to the selected bones only.  
                Properties: create
        toSkeleton (bool?): objects will be bound to the selected skeletons. The toSkeleton, toAll  
                and toSelectedBones flags are mutually exclusive. The toSkeleton flag is the default.  
                Properties: create
        unbind (bool?): unbind the selected objects. They will no longer move with  
                the skeleton. Any bindSkin history that is no longer used  
                will be deleted.  
                Properties: create
        unbindKeepHistory (bool?): unbind the selected objects. They will no longer move with  
                the skeleton. However, existing weights on the skin  
                will be kept for use the next time the skin is bound. This option  
                is appropriate if you want to modify the skeleton without losing  
                the weighting information on the skin.  
                Properties: create
        unlock (bool?): unlock the selected objects. Since bindSkin will no longer give  
                normal results if bound objects are moved away from the skeleton,  
                bindSkin locks translate, rotate and scale. This command unlocks  
                the selected objects translate, rotate and scale.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def blend(*args: str, edit: bool = ..., query: bool = ..., autoDirection: bool = ..., caching: bool = ..., crvsInFirstRail: int = ..., constructionHistory: bool = ..., flipLeft: bool = ..., flipRight: bool = ..., frozen: bool = ..., leftParameter: float = ..., multipleKnots: bool = ..., name: str = ..., nodeState: int = ..., object: bool = ..., polygon: int = ..., positionTolerance: float = ..., rightParameter: float = ..., tangentTolerance: float = ...) -> None: ...
def blend2(*args: str, edit: bool = ..., query: bool = ..., autoAnchor: bool = ..., autoNormal: bool = ..., caching: bool = ..., flipLeftNormal: bool = ..., flipRightNormal: bool = ..., leftAnchor: Queryable[float] = ..., leftEnd: Queryable[float] = ..., leftStart: Queryable[float] = ..., multipleKnots: bool = ..., nodeState: Queryable[int] = ..., positionTolerance: Queryable[float] = ..., reverseLeft: bool = ..., reverseRight: bool = ..., rightAnchor: Queryable[float] = ..., rightEnd: Queryable[float] = ..., rightStart: Queryable[float] = ..., tangentTolerance: Queryable[float] = ..., constructionHistory: bool = ..., crvsInFirstRail: Queryable[int] = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], bool, float, int]:
    """This command creates a surface by blending between given curves.
    This is an enhancement (more user control) compared to blend
    which is now obsolete.
    Args:
        autoAnchor (bool?): If true and both paths are closed, automatically determine the value on the right rail so that they match  
                Default: true  
                Properties: create, query, edit
        autoNormal (bool?): If true, the direction of each starting tangent is computed based on given geometry.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        flipLeftNormal (bool?): If true, flip the starting tangent off the left boundary.  
                Default: false  
                Properties: create, query, edit
        flipRightNormal (bool?): If true, flip the starting tangent off the right boundary.  
                Default: false  
                Properties: create, query, edit
        leftAnchor (Queryable[float]?): The reference parameter on the left boundary where the blend surface starts in the case of the closed rail.  
                Default: 0.0  
                Properties: create, query, edit
        leftEnd (Queryable[float]?): The reference parameter on the left boundary where the blend surface ends.  
                Default: 1.0  
                Properties: create, query, edit
        leftStart (Queryable[float]?): The reference parameter on the left boundary where the blend surface starts.  
                Default: 0.0  
                Properties: create, query, edit
        multipleKnots (bool?): If true, use the new blend which produces fully multiple interior knots  
                Default: true  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        positionTolerance (Queryable[float]?): The positional C(0) tolerance of the blend surface to the adjacent surfaces.  
                Default: 0.1  
                Properties: create, query, edit
        reverseLeft (bool?): If true, reverse the direction off the left boundary.  autoDirection must be false for this value to be considered.  
                Default: false  
                Properties: create, query, edit
        reverseRight (bool?): If true, reverse the direction of the right boundary.  autoDirection must be false for this value to be considered.  
                Default: false  
                Properties: create, query, edit
        rightAnchor (Queryable[float]?): The reference parameter on the right boundary where the blend surface starts in the case of the closed rail.  
                Default: 0.0  
                Properties: create, query, edit
        rightEnd (Queryable[float]?): The reference parameter on the right boundary where the blend surface ends.  
                Default: 1.0  
                Properties: create, query, edit
        rightStart (Queryable[float]?): The reference parameter on the right boundary where the blend surface starts.  
                Default: 0.0  
                Properties: create, query, edit
        tangentTolerance (Queryable[float]?): The tangent G(1) continuity tolerance of the blend surface to the adjacent surfaces.  
                Default: 0.1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        crvsInFirstRail (Queryable[int]?): Number of curves in the first rail of the blend.  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def blendCtx(*args: Any, **kwargs: Any) -> None: ...
def blendShape(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., automatic: bool = ..., before: bool = ..., components: bool = ..., copyDelta: Tuple[int, int, int] = ..., copyInBetweenDelta: Tuple[int, int, int, int] = ..., copyWeights: Tuple[int, int, int] = ..., deformerTools: bool = ..., envelope: Queryable[float] = ..., exclusive: Queryable[str] = ..., export: str = ..., exportTarget: Multiuse[Tuple[int, int]] = ..., flipTarget: Multiuse[Tuple[int, int]] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., ip: str = ..., inBetween: bool = ..., inBetweenIndex: int = ..., inBetweenType: str = ..., includeHiddenSelections: bool = ..., mergeSource: Multiuse[int] = ..., mergeTarget: int = ..., mirrorDirection: int = ..., mirrorTarget: Multiuse[Tuple[int, int]] = ..., name: str = ..., normalizationGroups: bool = ..., origin: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., resetTargetDelta: Multiuse[Tuple[int, int]] = ..., selectedComponents: bool = ..., split: bool = ..., suppressDialog: bool = ..., symmetryAxis: Queryable[str] = ..., symmetryEdge: Queryable[Multiuse[str]] = ..., symmetrySpace: Queryable[int] = ..., tangentSpace: bool = ..., target: Queryable[Multiuse[Tuple[str, int, str, float]]] = ..., topologyCheck: bool = ..., transform: Queryable[str] = ..., useComponentTags: bool = ..., weight: Queryable[Multiuse[Tuple[int, float]]] = ..., weightCount: Queryable[int] = ...) -> Union[List[str], bool, float, str, Multiuse[str], int, Multiuse[Tuple[str, int, str, float]], Multiuse[Tuple[int, float]]]:
    """This command creates a blendShape deformer, which blends in specified
    amounts of each target shape to the initial base shape.
    Each base shape is deformed by its own set of target shapes.
    Every target shape has an index that associates it with one of
    the shape weight values.In the create mode the first item on the selection list is treated
    as the base and the remaining inputs as targets. If the first item
    on the list has multiple shapes grouped beneath it, the targets must
    have an identical shape hierarchy. Additional base shapes
    can be added in edit mode using the deformers -g flag.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        automatic (bool?): The -automatic flag is used to specify deformer ordering in a way that  
                choses between -frontOfChain and -before automatically. If the geometry being  
                deformed is only affected by invertible deformers, the -frontOfChain mode is used, otherwise  
                the -before mode is used.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        copyDelta (Tuple[int, int, int]?): Set the base, source, and destination delta index values.  
                Properties: edit
        copyInBetweenDelta (Tuple[int, int, int, int]?): Set the base, target, source, and destination delta index values.  
                Properties: edit
        copyWeights (Tuple[int, int, int]?): Copy base, source, and destination weight index values.  
                Properties: edit
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        envelope (Queryable[float]?): Set the envelope value for the deformer, controlling  
                how much of the total deformation gets applied. Default is 1.0.  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        export (str?): Export the shapes to the named file path.  
                Properties: edit
        exportTarget (Multiuse[Tuple[int, int]]?): Specify the base and target index pairs for the export.  
                Properties: edit, multiuse
        flipTarget (Multiuse[Tuple[int, int]]?): Flip the list of base and target pairs.  
                Properties: edit, multiuse
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        ip (str?): Import the shapes from the named file path.  
                Properties: edit
        inBetween (bool?): Indicate that the specified target should serve as  
                an inbetween. An inbetween target is one that serves as an  
                intermediate target between the base shape and another target.  
                Properties: create, edit
        inBetweenIndex (int?): Only used with the -rtd/-resetTargetDelta flag to remove delta values  
                for points in the inbetween target geometry defined by this index.  
                Properties: edit
        inBetweenType (str?): Specify if the in-between target to be created is relative to the hero  
                target or if it is absolute.  
                If it is relative to hero targets, the in-between target will get any changes made to the hero target.  
                Valid values are "relative" and "absolute".  
                This flag should always be used with the -ib/-inBetween and -t/-target flags.  
                Properties: create, edit
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        mergeSource (Multiuse[int]?): List of source indexes for a merge.  
                Properties: edit, multiuse
        mergeTarget (int?): Target index of a merge  
                Properties: edit
        mirrorDirection (int?): Mirror direction; 0 = negative, 1 = positive  
                Properties: edit
        mirrorTarget (Multiuse[Tuple[int, int]]?): Mirror the list of base and target pairs.  
                Properties: edit, multiuse
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        normalizationGroups (bool?): Returns a list of the used normalization group IDs.  
                Properties: query
        origin (str?): blendShape will be performed with respect to the  
                world by default. Valid values are "world" and "local". The local flag will cause the blend  
                shape to be performed with respect to the shape's local  
                origin.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        resetTargetDelta (Multiuse[Tuple[int, int]]?): Remove all delta values for points in the target geometry,  
                including all sequential targets defined by target index.  
                Parameter list:  
              
                uint: the base object index  
                uint: the target index  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        suppressDialog (bool?): Suppress dialog box and run the command as defined by the user.  
                Properties: create, edit
        symmetryAxis (Queryable[str]?): Axis for symmetry. Valid values are "X", "Y", and "Z".  
                Properties: query, edit
        symmetryEdge (Queryable[Multiuse[str]]?): One or two symmetry edge names, separated by a ".". See the blendShape node's  
                symmetryEdge attribute for legal values.  
                Properties: query, edit, multiuse
        symmetrySpace (Queryable[int]?): Space for symmetry. 0 = Topological, 1 = Object, 2 = UV  
                Properties: query, edit
        tangentSpace (bool?): Indicate that the delta of the specified target should be relative to  
                the tangent space of the surface.  
                Properties: create, edit
        target (Queryable[Multiuse[Tuple[str, int, str, float]]]?): Set target object as the index target shape for the base shape base  
                object. The full influence of target shape takes effect when its shape  
                weight is targetValue.  
                Parameter list:  
              
                string: the base object  
                int: index  
                string: the target object  
                double: target value  
                Properties: create, query, edit, multiuse
        topologyCheck (bool?): Set the state of checking for a topology match between the  
                shapes being blended. Default is on.  
                Properties: create
        transform (Queryable[str]?): Set transform for target, then the deltas will become relative to a post transform. Typically the  
                best workflow for this option is to choose a joint that is related to the fix you have introduced.  
                This flag should be used only if the "Deformation order" of blendShape node is "Before".  
                Properties: query, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        weight (Queryable[Multiuse[Tuple[int, float]]]?): Set the weight value (second parameter) at index (first parameter).  
                Properties: create, query, edit, multiuse
        weightCount (Queryable[int]?): Set the number of shape weight values.  
                Properties: create, query, edit

    Returns:
        List[str]: (the blendShape node name)

    Example:
    """

def blendShapeEditor(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., targetControlList: bool = ..., targetList: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., verticalSliders: bool = ...) -> Union[str, bool]:
    """This command creates an editor that derives from the base editor
    class that has controls for blendShape, control nodes.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        targetControlList (bool?):   
                Properties: query
        targetList (bool?):   
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalSliders (bool?):   
                Properties: create, query, edit

    Returns:
        str: The name of the editor

    Example:
    """

def blendShapePanel(*args: Any, edit: bool = ..., query: bool = ..., blendShapeEditor: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command creates a panel that derives from the base panel
    class that houses a blendShapeEditor.
    Args:
        blendShapeEditor (bool?): Query only flag that returns the name of an editor to be associated with the panel.  
                Properties: query
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the panel

    Example:
    """

def blendTwoAttr(*args: str, edit: bool = ..., query: bool = ..., attribute: Multiuse[str] = ..., attribute0: Queryable[str] = ..., attribute1: Queryable[str] = ..., blender: Queryable[str] = ..., controlPoints: bool = ..., driver: Queryable[int] = ..., name: Queryable[str] = ..., shape: bool = ..., time: NullableRange[float] = ...) -> Union[List[str], str, int]:
    """A blendTwoAttr nodes takes two inputs, and blends the values of the inputs
    from one to the other, into an output value. The blending of the two
    inputs uses a blending function, and the following formula:The blendTwoAttr command can be used to blend the animation of an
    object to transition smoothly between the animation of two other
    objects.When the blendTwoAttr command is issued, it creates a blendTwoAttr
    node on the specified attributes, and reconnects whatever was previously
    connected to the attributes to the new blend nodes. You may also
    specify which two attributes should be used to blend together.The driver is used when you want to keyframe an object after it is
    being animated by a blend node. The current driver index specifies
    which of the two blended attributes should be keyframed.
    Args:
        attribute (Multiuse[str]?): A list of attributes for the selected nodes for which a  
                blendTwoAttr node will be created.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        attribute0 (Queryable[str]?): The attribute that should be connected to the first input  
                of the new blendTwoAttr node.  
                When queried, it returns a string.  
                Properties: create, query, edit
        attribute1 (Queryable[str]?): The attribute that should be connected to the second input  
                of the new blendTwoAttr node.  
                When queried, it returns a string.  
                Properties: create, query, edit
        blender (Queryable[str]?): The blender attribute. This is the attribute that will be  
                connected to the newly created blendTwoAttr node(s) blender attribute.  
                This attribute controls how much of each of the two attributes  
                to use in the blend. If this flag is not specified, a new  
                animation curve is created whose value goes from 1 to 0  
                throughout the time range specified by the -t flag. If -t is not  
                specified, an abrupt change from the value of the first to the  
                value of the second attribute will occur at the current time  
                when this command is issued.  
                Properties: create, query, edit
        controlPoints (bool?): Explicitly specify whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  
                Properties: create
        driver (Queryable[int]?): The index of the driver attribute for this blend node (0 or 1)  
                When queried, it returns an integer.  
                Properties: create, query, edit
        name (Queryable[str]?): name for the new blend node(s)  
                Properties: create, query
        shape (bool?): Consider all attributes of shapes below transforms as well,  
                except "controlPoints". Default: true  
                Properties: create
        time (NullableRange[float]?): The time range between which the blending between the 2 attributes  
                should occur. If a single time is specified, then the blend will  
                cause an abrupt change from the first to the second attribute at  
                that time.  If a range is specified, a smooth blending will occur  
                over that time range. The default is to make a sudden transition  
                at the current time.  
                Properties: create

    Returns:
        List[str]: The names of the blendTwoAttr dependency nodes that were created.

    Example:
    """

def blindDataType(*, dataType: Multiuse[str] = ..., longDataName: Multiuse[str] = ..., longNames: bool = ..., query: bool = ..., shortDataName: Multiuse[str] = ..., shortNames: bool = ..., typeId: int = ..., typeNames: bool = ...) -> str:
    """This command creates a blind data type, which is represented by a
    blindDataTemplate node in the DG. A blind data type can have one
    or more attributes. On the command line, the attributes should be
    ordered by type for best memory utilization, largest first:
    string, binary, double, float, int, and finally boolean.
    Once a blind data type is created, blind data of that type may
    be assigned using the polyBlindData command. Note that as well
    as polygon components, blind data may be assigned to objects
    and to NURBS patches. A blind data type may not be modified
    after it is created: in order to do so it must be deleted and
    recreated. Any existing blind data of that type would also need
    to be deleted and recreated.
    When used with the query flag, this command will return information
    about the attributes of the specified blind data type.create, blinddata, type
    Args:
        dataType (Multiuse[str]?): Specifies the dataTypes that are part of BlindData node being created.  
                Allowable strings are "int", "float", "double", "string", "boolean" and "binary".  
                Must be used togeter with the -ldn and -sdn flags to specify each attribute.  
                Properties: create, multiuse
        longDataName (Multiuse[str]?): Specifies the long names of the datas that are part of BlindData node being  
                created. Must be used togeter with the -dt and -sdn flags to specify each attribute.  
                Properties: create, multiuse
        longNames (bool?): Specifies that for a query command the long attributes names be listed.  
                Properties: create
        query (bool?): Specifies that this is a special query type command.  
                Properties: create
        shortDataName (Multiuse[str]?): Specifies the short names of the data that are part of BlindData node being  
                created. Must be used togeter with the -dt and -ldn flags to specify each attribute.  
                Properties: create, multiuse
        shortNames (bool?): Specifies that for a query command the short attribute names be listed.  
                Properties: create
        typeId (int?): Specifies the typeId of the BlindData type being created.  
                Properties: create
        typeNames (bool?): Specifies that for a query command the data types be listed.  
                Properties: create

    Returns:
        str: Name of nodes created

    Example:
    """

def boneLattice(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., bicep: Queryable[float] = ..., components: bool = ..., deformerTools: bool = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., joint: Queryable[str] = ..., lengthIn: Queryable[float] = ..., lengthOut: Queryable[float] = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., split: bool = ..., transform: str = ..., tricep: Queryable[float] = ..., useComponentTags: bool = ..., widthLeft: Queryable[float] = ..., widthRight: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[str]]:
    """This command creates/edits/queries a boneLattice deformer. The name of
    the created/edited object is returned. Usually you would make use of
    this functionality through the higher level flexor command.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        bicep (Queryable[float]?): Affects the bulging of lattice points on the inside of  
                the bend. Positive/negative values cause the points to bulge  
                outwards/inwards. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        joint (Queryable[str]?): Specifies which joint will be used to drive the bulging  
                behaviors.  
                Properties: create, query, edit
        lengthIn (Queryable[float]?): Affects the location of lattice points along the upper  
                half of the bone. Positive/negative values cause the points  
                to move away/towards the center of the bone.  Changing this  
                parameter also modifies the regions affected by the creasing,  
                rounding and width parameters. Default value is 0.0. When  
                queried, this flag returns a float.  
                Properties: create, query, edit
        lengthOut (Queryable[float]?): Affects the location of lattice points along the lower  
                half of the bone. Positive/negative values cause the points  
                to move away/towards the center of the bone.  Changing this  
                parameter also modifies the regions affected by the creasing,  
                rounding and width parameters. Default value is 0.0. When  
                queried, this flag returns a float.  
                Properties: create, query, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        transform (str?): Specifies which dag node is being used to rigidly transform  
                the lattice which this node is going to deform.  If this flag is  
                not specified an identity matrix will be assumed.  
                Properties: create
        tricep (Queryable[float]?): Affects the bulging of lattice points on the outside  
                of the bend. Positive/negative values cause the points to bulge  
                outwards/inwards. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        widthLeft (Queryable[float]?): Affects the bulging of lattice points on the left side  
                of the bend. Positive/negative values cause the points to bulge  
                outwards/inwards. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        widthRight (Queryable[float]?): Affects the bulging of lattice points on the right  
                side of the bend. Positive/negative values cause the points to  
                bulge outwards/inwards. Default value is 0.0. When queried, this  
                flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: Name of bone lattice algorithm node created/edited.

    Example:
    """

def boundary(arg0: str = ..., arg1: str = ..., arg2: str = ..., arg3: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., endPoint: bool = ..., endPointTolerance: Queryable[float] = ..., nodeState: Queryable[int] = ..., order: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., range: bool = ...) -> Union[List[str], bool, float, int]:
    """This command produces a boundary surface given 3 or 4 curves.
    This resulting boundary surface passes through two of the given curves
    in one direction, while in the other direction the shape is
    defined by the remaining curve(s).  If the "endPoint" option
    is on, then the curve endpoints must touch before a surface
    will be created.   This is the usual situation where a boundary
    surface is useful.Note that there is no tangent continuity option with this command.
    Unless all the curve end points are touching, the resulting
    surface will not pass through all curves.  Instead, use the birail
    command.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        endPoint (bool?): True means the curve ends must touch before a surface will be created.  
                Default: false  
                Properties: create, query, edit
        endPointTolerance (Queryable[float]?): Tolerance for end points, only used if endPoint attribute is true.  
                Default: 0.1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        order (bool?): True if the curve order is important.  
                Default: true  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def boxDollyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., toolName: Queryable[str] = ...) -> Union[str, bool]:
    """This command can be used to create, edit, or query a dolly
    context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query

    Returns:
        str: The name of the context

    Example:
    """

def boxZoomCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., zoomScale: Queryable[float] = ...) -> Union[str, float]:
    """This command can be used to create, edit, or query a box zoom
    context. If this context is used on a perspective camera, the
    field of view and view direction are changed. If the camera is
    orthographic, the orthographic width and eye point are
    changed. The left and middle mouse interactively zoom the
    view. The control key can be used to enable box zoom. A box
    starting from left to right will zoom in, and a box starting from
    right to left will zoom out.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        zoomScale (Queryable[float]?): Scale the zoom.  
                Properties: create, query, edit

    Returns:
        str: The name of the context

    Example:
    """

def bufferCurve(*args: str, query: bool = ..., animation: str = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., exists: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., overwrite: bool = ..., shape: bool = ..., swap: bool = ..., time: Multiuse[NullableRange[float]] = ..., useReferencedCurve: bool = ...) -> Union[int, bool]:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command helps manage buffer curve for animated objects
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        exists (bool?): Returns true if a buffer curve currently exists on the  
                specified attribute; false otherwise.  
                Properties: query
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        overwrite (bool?): Create a buffer curve.  "true" means create a buffer curve  
                whether or not one already existed.  "false" means if a  
                buffer curve exists already then leave it alone.  If no  
                flag is specified, then the command defaults to -overwrite false  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        swap (bool?): For animated attributes which have buffer curves, swap  
                the buffer curve with the current animation curve  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        useReferencedCurve (bool?): In create mode, sets the buffer curve to the referenced curve.  
                Curves which are not from file references will ignore this flag.  
                In query mode, returns true if the selected keys are displaying their  
                referenced curve as the buffer curve, and false if they are not.  
                Properties: create, query

    Returns:
        int: Number of buffer curves

    Example:
    """

def buildBookmarkMenu(arg0: str = ..., /, *, editor: str = ..., type: str = ...) -> bool:
    """This command handles building the "dynamic" Bookmark
    menu, to show all bookmarks ("sets") of a specified
    type ("sets -text")menuName is the string returned by the "menu" command.
    Args:
        editor (str?): Name of the editor which this menu belongs to  
                Properties: create
        type (str?): Type of bookmark (sets -text) to display  
                Properties: create

    Returns:
        bool:

    Example:
    """

def buildKeyframeMenu(arg0: str = ..., /) -> bool:
    """This command handles building the "dynamic" Keyframe
    menu, to show attributes of currently selected objects,
    filtered by the current manipulator.menuName is the string returned by the "menu" command.
    The target menu will entries appended to it (and deleted from it) to always
    show what's currently keyframable.
    Returns:
        bool:

    Example:
    """

def buildSendToBackburnerDialog() -> None: ...
def button(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., actOnPress: bool = ..., actionIsSubstitute: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., command: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., recomputeSize: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], Callable[..., Any], int]:
    """Create a button control capable of displaying a textual label and
    executing a command when selected by the user.
    Args:
        actOnPress (bool?): If true then the command specified by the command flag  
                will be executed when a mouse button is pressed.  If false then  
                that command will be executed after the mouse button is released.  
                The default value is false.  
                Properties: create, query, edit
        actionIsSubstitute (bool?): This flag is obsolete and should no longer be used.  
                Properties: create, query, edit
        align (Queryable[str]?): This flag is obsolete and should no longer be used.  
                The button label will always be center-aligned.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        command (Queryable[Callable[..., Any]]?): Command executed when the control is pressed.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text.  The default label is the name of  
                the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        recomputeSize (bool?): If true then the control will recompute it's size to  
                just fit the size of the label.  If false then the control size  
                will remain fixed as you change the size of the label.  The  
                default value of this flag is true.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def buttonManip(arg0: Callable[..., Any] = ..., arg1: str = ..., /, *, icon: str = ...) -> bool:
    """This creates a button manipulator. This manipulator has a position in
    space and a triad manip for positioning. When you click on the top
    part of the manip, the command defined by the first argument is
    executed. The command is associated with the manipulator when it is
    created.If a dag object is included on the command line, the manip will be
    parented to the object. This means moving the object will move the
    manip. You can move the manip independently of the object using its
    triad.Note that a buttonManip may not be parented to more than one object.
    Args:
        icon (str?): Specify an icon to represent the manipulator.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def cacheAppend() -> None: ...
def cacheAppendOpt() -> None: ...
def cacheEvaluator(*args: str, edit: bool = ..., query: bool = ..., cacheFillMode: Queryable[str] = ..., cacheFillOrder: Queryable[str] = ..., cacheInvalidate: NullableRange[float] = ..., cacheName: str = ..., cachedFrames: bool = ..., cachingPoints: bool = ..., creationParameters: bool = ..., delegateEvaluation: bool = ..., dynamicsAsyncRefresh: bool = ..., dynamicsSupportActive: bool = ..., dynamicsSupportEnabled: bool = ..., flushCache: str = ..., flushCacheRange: Tuple[NullableRange[float], bool] = ..., flushCacheSync: bool = ..., flushCacheWait: bool = ..., hybridCacheMode: Queryable[str] = ..., layeredEvaluationActive: bool = ..., layeredEvaluationCachingPoints: bool = ..., layeredEvaluationEnabled: bool = ..., listCacheNames: bool = ..., listCachedNodes: bool = ..., listValueNames: bool = ..., newAction: str = ..., newActionParam: str = ..., newFilter: str = ..., newFilterParam: str = ..., newRule: str = ..., newRuleParam: str = ..., pauseInvalidation: bool = ..., preventFrameSkip: bool = ..., resetRules: bool = ..., resourceUsage: bool = ..., resumeInvalidation: bool = ..., safeMode: bool = ..., safeModeMessages: bool = ..., safeModeTriggered: bool = ..., valueName: str = ..., waitForCache: float = ...) -> Union[str, bool, List[str], List[int]]:
    """This command controls caching configuration.  It allows interaction with the
    caching system.Caching configuration is done through a set of rules.  Most rules are composed
    of a "filter", which is the test to be perform in order to determine if the rule
    should be applied, and an "action", which is the effect that the rule application
    should have on nodes that satisfy the criteria.A caching mode is therefore a set of rules that determines which nodes are
    being cached.  This mode can be serialized to a JSON string using the
    "creationParameters" flag in query mode.A few cache configuration rules, filters and actions are provided in order to
    support the built-in default caching modes.Note that any combination of cache configuration rules other than the default modes
    is considered unsupported and to be used at one's own risk.  The default modes
    are "Evaluation cache", "VP2 software cache" and "VP2 hardware cache".  The sets
    of rules used to enable each mode are listed in the code examples.In order to get a cache configuration value for a given node or list of nodes,
    theflag can be used in query mode.  Without any additional
    parameters, this query is the same as if theflag was set to
    "active", i.e. it queries whether the given cache is active or not.If the queried node is not a caching point, there will be no caching
    configuration information associated with it and the query will return an
    empty string (which is basically the same as all cache modes being inactive).
    If the queried node is a caching point, the returned string will be the
    requested information from the given cache.  For example, querying the
    "active" value can return "0" or "1".Caching
    Args:
        cacheFillMode (Queryable[str]?): Specifies the cache fill mode. Valid values are: "syncOnly" to fill cache  
                during playback, "syncAsync" to cache during playback and in background,  
                 and "asyncOnly" to fill cache only in background. Query returns current mode.  
                Properties: create, query
        cacheFillOrder (Queryable[str]?): Specifies in which order the cache fills the timeline. Valid values are:  
                "forward" to fill cache in forward direction, "backward" to fill cache backwards,  
                "bidirectional" to fill cache in forward and backward directions simultaneously,  
                 and "forwardFromBegin" to fill cache in forward direction from animation start.  
                 Query returns current cache fill mode.  
                Properties: create, query
        cacheInvalidate (NullableRange[float]?): Specifies the frame range in which cache should be invalidated. The range  
                should be specified as a pair of positive integers.  
              
                    Usage examples:  
                  
                 -ci "10. 20"{Python equivalent: ('10','20')} means all frames  
                        in the range from 10 to 20, inclusive, in the current time unit.   
              
              
                    Omitting one end of a range means using either end of the animation range  
                     (or both), as in the following examples:  
                  
                 -ci "10. " means all frames from time 10 (in the current time unit)  
                        onwards to the maximum time in the animation range (on the timeline).   
                 -ci ":10" means all frames from the minimum time on the animation range  
                        (on the timeline) up to (and including) time 10 (in the current time unit).   
                 -ci ":" is a short form to specify all frames, from minimum to  
                        maximum time on the current animation range.  
                Properties: create
        cacheName (str?): Specifies the name of the cache from which to query a value.  
                			In query mode, this flag needs a value.  
                Properties: query
        cachedFrames (bool?): Get the list of frames with valid cache data.  
                The result is an integer array containing multiple triplets of (cache-status, begin-frame, end-frame)  
                For example,  
                The result is an array of 9 integers [(0b01, 1, 3), (0b10, 7, 10), (0b11, 13, 15)].  
                In MEL, the result is typed as "int[9]".  
                In Python, the result is typed as "Tuple[int,int,int][3]".  
                The result suggests frames 1. 3 (1,2,3), 7. 10 (7,8,9,19), and 13. 15 (13,14,15) are cached.  
                No other frames contain valid cache data.  
                The cache-status numbers are always 1 if "layeredEvaluationActive" is false.  
                The cache-status can be one of {1,2,3}, when "layeredEvaluationActive" is true.  
                It represents whether the frame is valid on animation cache or dynamics cache, the encoding is:  
              
                1 (0b01) : only animation cache is valid  
                2 (0b10) : only dynamics cache is valid  
                3 (0b11) : both animation and dynamics cache are valid  
              
                In the above example, it suggests:  
                frames 1. 3 are only valid in animation cache.  
                frames 7. 10 are only valid in dynamics cache.  
                frames 13. 15 are valid in both and considered as 'fully-cached'.  
                Properties: query
        cachingPoints (bool?): Get list of nodes marked as caching points, i.e. nodes with at least one  
                type of cache active.  
                Properties: query
        creationParameters (bool?): Get the current mode creation parameters.  The result is a JSON string which  
                represents an array with an element for each rule.  Each element is an  
                association between the parameter name and its value when creating the rule.  
                Properties: query
        delegateEvaluation (bool?): Returns whether the specified node(s) are delegating to evaluation.  
                Properties: query
        dynamicsAsyncRefresh (bool?): Enable / Disable Asynchronous Refresh in Dynamics Support mode.  
                Traditionally, edits related to the simulation system require the user to re-playback the scene to see the result.  
                When Asynchronous Refresh is active, Maya will process the simulation in the background and refresh the viewport once the result is ready.  
                Note, the automatic refresh will not happen if the frame contains temproary edits. For example, an object is moved without setting the keyframe.  
                Properties: create, query
        dynamicsSupportActive (bool?): Query if the Dynamics Support mode is active.  
                Dynamics Support mode is used to support Physics Simulation, such as Hair, or Fluid.  
                It will be activated if such nodes are detected in the scene, and "enableDynamicsSupport" is set to true.  
                When Dynamics Support mode is active, you will notice the following behavior:  
              
                Dynamics nodes will be frozen for uncached frame  
                A separate dynamics cache line will appear on the Time Slider  
                Dynamics cache starts after the animation cache was filled  
                Dynamics cache only fills in the background  
                Dynamics cache always fills forward from the beginning  
                Dynamics cache evaluation may refresh foreground dynamics nodes (see the flag "dynamicsAsyncRefresh")  
                Properties: query
        dynamicsSupportEnabled (bool?): Specifies if Dynamics nodes are allowed to participate in Cached Playback  
                When disabled, Dynamics nodes will trigger "Safe mode" and prevent caching.  
                When enabled, Dynamics nodes will participate in caching and trigger "Dynamics support mode".  
                For more information check flag "dynamicsSupportActive".  
                Properties: create, query
        flushCache (str?): Specifies to flush the current cache. Valid values are: "keep" to store the existing  
                cache as backup, and "destroy" to delete the current cache.  
                Properties: create
        flushCacheRange (Tuple[NullableRange[float], bool]?): Specifies the frame range in which cache should be flushed. By default it will  
                destroy the cache - if the 'flushCache' is also set then it will define what  
                to do with the cache range being flushed.  
                The range should be specified as a pair of positive integers and a boolean.  
              
                    Usage examples:  
                  
                 -flushCacheRange "10. 20" on {Python equivalent: ('10','20',True)}  
                                means all frames in the range from 10 to 20, inclusive, in the current time unit.   
                 -flushCacheRange "12. 18" off {Python equivalent: ('12','18',False)}  
                                means all frames before 12 and after 18, not inclusive, in the current time unit.   
              
              
                    Omitting one end of a range means using either end of the animation range  
                     (or both), as in the following examples:  
                  
                 -flushCacheRange "10. " on means all frames from time 10 (in the current time unit)  
                        onwards to the maximum time in the animation range (on the timeline).   
                 -flushCacheRange ":10" on means all frames from the minimum time on the animation range  
                        (on the timeline) up to (and including) time 10 (in the current time unit).   
                 -flushCacheRange ":" on is a short form to specify all frames, from minimum to  
                        maximum time on the current animation range.  
                Properties: create
        flushCacheSync (bool?): Specifies how to flush the cache: synchronously or asynchronously. True for synchronous, False for asynchronous.  
                Properties: create, query
        flushCacheWait (bool?): Wait for the cache destruction to be completed.  
                Properties: create
        hybridCacheMode (Queryable[str]?): Specifies the hybrid cache mode. Valid values are: "disabled", not to use  
                hybrid cache; "smp", to evaluate on the GPU meshes with GPU-supported deformation  
                stacks if they use Smooth Mesh Preview (instead of caching them);  
                "all", to evaluate on the GPU all meshes with PU-supported deformation stacks  
                (instead of caching them). Query returns current mode.  
                Properties: create, query
        layeredEvaluationActive (bool?): Query if the Layered Evaluation mode is active.  
                When Layered Evaluation is active, the background cache fill process will be split into multiple passes for different contents (evaluation nodes).  
                These contents are referred as different 'evaluation layers', representing different level of details (LoD) in animation evaluation.  
                For example:  
              
                The first layer contains regular animations like a character motion.   
                The second layer contains dynamics simulations like a character's hair and cloth.   
              
                Maya will create separated cache and cache fill pass for each of the layers.  
                Additional cache bars will be added to the Time Slider UI to represent these layers.  
                The background cache fill pass for each of the layer will start in order.  
                In the above example, two passes of background cache fill will be observed.  
                In the first pass of background-cache-fill or playback-fill, only Character motions will be evaluated and filled, Hair and Clothes are frozen in-place.  
                After the cache for first layer have been filled for all the frames,  
                the second pass of cache fill will start to simulate Hairs and Clothes physics and fill the cache for the 2nd layer.  
                Once the cache for the 2nd layer is filled for a frame, users can scrub the timeline to view the fully updated effects.  
                Note, when layered evaluation is active, any foreground playback or manipulation will only evaluate the first evaluation layer,  
                and all the FX contents will be frozen in the viewport until the background simulation is complete.  
                For example, when rotating a characterâ€™s head, its hair will not follow in real time.  
                If the flag "dynamicsAsyncRefresh" is enabled, the FX contents will be updated automatically after simulation cached up. Please refer to the flag for more detail.  
                Properties: query
        layeredEvaluationCachingPoints (bool?): Get the list of nodes marked as caching points because of layered evaluation.  
                Properties: query
        layeredEvaluationEnabled (bool?): Enable / Disable Layered Evaluation in Dynamics Support mode.  
                Refering to flags "dynamicsSupportActive" and "layeredEvaluationActive" for details about layered evaluation enabled behavior.  
                This flag is provided to support plugin developers for testing purpose.  
                Disabling this option in production is not recommended.  
                When disabled, dynamics nodes will share the same cache with regular animation.  
                Allows dynamics nodes to be evaluated and stored to cache in the foreground.  
                Background "cacheFillOrder" option will be locked to "forwardFromBegin".  
                When used with cacheFillMode="syncOnly", it can also be used to support legacy dynamics nodes that cannot evaluate in the background.  
                Properties: create, query
        listCacheNames (bool?): Return the list of existing cache names.  
                Properties: query
        listCachedNodes (bool?): Returns the list of cached nodes.  
                Properties: query
        listValueNames (bool?): Return the list of value names that can be queried for the given cache.  
                Properties: query
        newAction (str?): Specifies the name of the new action to create in the new filter/action rule.  
                Properties: create
        newActionParam (str?): Specifies the parameter string to pass to the new action to create in the new filter/action rule.  
                Properties: create
        newFilter (str?): Specifies the name of the new filter to create in the new filter/action rule.  
                Properties: create
        newFilterParam (str?): Specifies the parameter string to pass to the new filter to create in the new filter/action rule.  
                Properties: create
        newRule (str?): Specifies the name of the new rule to create.  
                Properties: create
        newRuleParam (str?): Specifies the parameter string to pass to the new rule to create.  
                Properties: create
        pauseInvalidation (bool?): Pause all incoming invalidation of the cache. Work in symmetry with resumeInvalidation flag.  
                PauseInvalidation can be called several time, useful in nesting situation. The same number of resume need to be called to resume the invalidation.  
                If queried it will return how much time caching is paused, 0 means it is resumed.  
                Properties: create, query
        preventFrameSkip (bool?): Specifies if frame skipping is enabled. Following behavior is seen when frame  
                skipping is enabled, and playback is set to play in real-time.  
              
                If cache can't be filled at real-time frame rate, frames will NOT be skipped.  
                Once all frames have been looped over(and therefore all frames are cached), and if  
                    playing back from cache still can't be done at real-time frame rate; frames WILL be skipped.  
                If memory limit is reached before all frames are cached, frames WILL be skipped.  
                If cache is invalidated will playing(like flushing it), frames will NOT  
                    be skipped(until the cache is full again).  
                Properties: create, query
        resetRules (bool?): Reset the cache configuration rules to an empty set of rules.  
                Properties: create
        resourceUsage (bool?): Returns the current state of the resource usage as a string. 'unlimited' = the resource limits  
                are being ignored, 'out' = the memory limit has been reached, 'low' = the memory usage is at  
                90% of the specified limit, 'okay' = memory usage is under 90% of the specified limit.  
                Properties: query
        resumeInvalidation (bool?): Resume all incoming invalidation of the cache. Work in symmetry with pauseInvalidation flag.  
                PauseInvalidation can be called several time, useful in nesting situation. The same number of resume need to be called to resume the invalidation.  
                If queried it will return true if cache is resumed, false otherwise.  
                Properties: create, query
        safeMode (bool?): Turns safe mode on or off. In query mode, it returns the status of the safe mode for cache evaluator.  
                Properties: create, query
        safeModeMessages (bool?): Prints the safe mode messages to the console.  
                Properties: query
        safeModeTriggered (bool?): Returns if the safe mode was triggered for cache evaluator.  
                Properties: query
        valueName (str?): Specifies the name of the parameter for which to query the value.  
                			In query mode, this flag needs a value.  
                Properties: query
        waitForCache (float?): Specifies to wait for cache to fill in background, with [Time to wait in seconds] timeout.  
                Properties: create

    Returns:
        str: The state of whether the memory limit has been reached or not ('out', 'okay', 'low', or 'unlimited' with the 'resourceUsage' flag)
        bool: The state of whether the safe mode is enabled (with the 'safeMode' flag)
        bool: The state of whether the safe mode was triggered (with the 'safeModeTriggered' flag)
        bool: The state of whether prevent frame skipping is enabled (with the 'preventFrameSkip' flag)
        bool: The state of whether cache in background was calculated (with the 'waitForCache' flag)
        List[str]: The available cache names (with the 'listCacheNames' flag)
        str: The list of nodes currently cached by the cache evaluator (with the 'listCachedNodes' flag).
        List[str]: The available value names (with the 'listValueNames' flag)
        List[str]: The parameter value for the requested node(s) (with the 'cacheName' flag)
        List[str]: The state of whether delegate evaluation is enabled for the requested node(s) (with the 'delegateEvaluation' flag)
        str: The creation parameters for the current mode as a JSON array (with the 'creationParameters' flag)
        List[str]: The list of nodes marked as caching point (with the 'cachingPoints' flag)
        List[str]: The list of nodes forced as caching points because of layered evaluation (with the 'layeredEvaluationCachingPoints' flag)
        List[int]: The list of frames being cached (with the 'cachedFrames' flag)
        str: The current cache fill mode (with the 'cacheFillMode' flag)
        str: The current cache fill order (with the 'cacheFillOrder' flag)
        str: The list of all the safe mode messages (with the 'safeModeMessages' flag)
        str: The current hybrid cache mode (with the 'hybridCacheMode' flag)

    Example:
    """

def cacheFile(*args: str, edit: bool = ..., query: bool = ..., appendFrame: bool = ..., attachFile: bool = ..., cacheFileNode: Multiuse[str] = ..., cacheFormat: Queryable[str] = ..., cacheInfo: Queryable[Multiuse[str]] = ..., cacheableAttrs: Queryable[str] = ..., cacheableNode: Multiuse[str] = ..., channelIndex: bool = ..., channelName: Queryable[Multiuse[str]] = ..., convertPc2: bool = ..., createCacheNode: bool = ..., creationChannelName: Multiuse[str] = ..., dataSize: bool = ..., deleteCachedFrame: bool = ..., descriptionFileName: bool = ..., directory: Queryable[str] = ..., doubleToFloat: bool = ..., endTime: int = ..., fileName: Queryable[str] = ..., format: str = ..., geometry: bool = ..., inAttr: Multiuse[str] = ..., inTangent: str = ..., interpEndTime: int = ..., interpStartTime: int = ..., noBackup: bool = ..., outAttr: Multiuse[str] = ..., outTangent: str = ..., pc2File: str = ..., pointCount: bool = ..., points: Multiuse[str] = ..., pointsAndNormals: Multiuse[str] = ..., prefix: bool = ..., refresh: bool = ..., replaceCachedFrame: bool = ..., replaceWithoutSimulating: bool = ..., runupFrames: Queryable[int] = ..., sampleMultiplier: Queryable[int] = ..., simulationRate: Queryable[int] = ..., singleCache: bool = ..., startTime: int = ..., staticCache: bool = ..., worldSpace: bool = ...) -> Union[str, Multiuse[str], bool, int]:
    """Creates one or more cache files on disk to store attribute data for a span of
    frames. The caches can be created for points/normals on a geometry (using
    the pts/points or pan/pointsAndNormals flag), for vectorArray output data
    (using the oa/outAttr flag), or for additional node specific data (using the
    cnd/cacheableNode flag for those nodes that support it).When the ia/inAttr flag is used, connects a cacheFile node that
    associates the data file on disk with the attribute.Frames can be replaced/appended to an existing cache with the
    rcf/replaceCachedFrame and apf/appendFrame flag.  Replaced frames are never deleted.
    They are stored in the same directory as the original cache files with the
    name provided by the f/fileName flag. If no file name is provided,
    the cacheFile name is prefixed with "backup" followed by a unique number.Single file caches are backed up in their entirety. To revert to an older
    version, simply attach to this cache. One file per frame caches only backup
    the description file and the frames that were replaced. To recover these
    types of caches, the user must rename these files to the original name.cache, file, disk
    Args:
        appendFrame (bool?): Appends data to the cache for the times specified by the startTime and endTime flags. If no  
                time is provided, appends the current time. Must be used in conjunction  
                with the pts/points or cnd/cacheableNode flag. Any overwritten frames will not be  
                deleted, but renamed as specified by the f/fileName flag.  
                Properties: create
        attachFile (bool?): Used to indicate that rather than creating a cache file, that an  
                existing cache file on disk should be attached to an attribute in the scene.  
                The inAttr flag is used to specify the attribute.  
                Properties: create
        cacheFileNode (Multiuse[str]?): Specifies the name of the cache file node(s) we are appending/replacing to  
                if more than one cache is attached to the specified geometries.  
                			In query mode, this flag needs a value.  
                Properties: create, multiuse
        cacheFormat (Queryable[str]?): Cache file format, default is Maya's .mcx format, but others available via plugin  
                Properties: create, query
        cacheInfo (Queryable[Multiuse[str]]?): In create mode, used to specify a mel script returning a string array. When  
                creating the cache, this mel script will be executed and the returned strings  
                will be written to the .xml description file of the cache.  
                In query mode, returns descriptive info stored in the cacheFile such as  
                the user name, Maya scene name and maya version number.  
                Properties: create, query, multiuse
        cacheableAttrs (Queryable[str]?): Returns the list of cacheable attributes defined on the accompanying cache node.  
                This argument requires the use of the cacheableNode flag.  
                Properties: query
        cacheableNode (Multiuse[str]?): Specifies the name of a cacheable node whose contents will be cached.  
                A cacheable node is a node that is specially designed to work with  
                the caching mechanism.  An example of a cacheable node is a nCloth node.  
                			In query mode, this flag needs a value.  
                Properties: create, multiuse
        channelIndex (bool?): A query-only flag which returns the channel index for the selected geometry  
                for the cacheFile node specified using the cacheFileNode flag.  
                Properties: create, query
        channelName (Queryable[Multiuse[str]]?): When attachFile is used, used to indicate the channel in the file that  
                should be attached to inAttr.  If not specified, the first channel in  
                the file is used. In query mode, allows user to query the channels associated  
                with a description file.  
                Properties: create, query, multiuse
        convertPc2 (bool?): Convert a PC2 file to the Maya cache format (true), or convert Maya cache to pc2 format (false)  
                Properties: create
        createCacheNode (bool?): Used to indicate that rather than creating a cache file, that a cacheFile  
                node should be created related to an existing cache file on disk.  
                Properties: create
        creationChannelName (Multiuse[str]?): When creating a new cache, this multi-use flag specifies the channels to be cached.  
                The names come from the cacheable channel names defined by the object being cached.  
                If this flag is not used when creating a cache, then all cacheable channels are cached.  
                Properties: create, multiuse
        dataSize (bool?): This is a query-only flag that returns the size of the data being cached per frame.  
                This flag is to be used in conjunction with the cacheableNode, points,  
                pointsAndNormals and outAttr flags.  
                Properties: query
        deleteCachedFrame (bool?): Deletes cached data for the times specified by the startTime/endTime flags.  
                If no time is provided, deletes the current frame. Must be used in conjunction  
                with the pts/points or cnd/cacheableNode flag. Deleted frames will not be  
                removed from disk, but renamed as specified by the f/fileName flag.  
                Properties: create
        descriptionFileName (bool?): This is a query-only flag that returns the name of the description file  
                for an existing cacheFile node. Or if no cacheFile node is specified, it  
                returns the description file name that would be created based on the other  
                flags specified.  
                Properties: query
        directory (Queryable[str]?): Specifies the directory where the cache files will be located. If the  
                directory flag is not specified, the cache files will be placed in the  
                project data directory.  
                Properties: create, query
        doubleToFloat (bool?): During cache creation, double data is stored in the file as floats.  This helps cut down  
                file size.  
                Properties: create
        endTime (int?): Specifies the end frame of the cache range.  
                Properties: create
        fileName (Queryable[str]?): Specifies the base file name for the cache files. If more than one object is  
                being cached and the format is OneFilePerFrame, each cache file will be  
                prefixed with this base file name. In query mode, returns the files  
                associated with the specified cacheFile node.  
                When used with rpf/replaceCachedFrame or apf/appendFrame specifies the name of the backup files.  
                If not specified, replaced frames will be stored with a default name.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        format (str?): Specifies the distribution format of the cache.  Valid values are "OneFile" and "OneFilePerFrame"  
                Properties: create
        geometry (bool?): A query flag which returns the geometry controlled by the specified cache node  
                Properties: query
        inAttr (Multiuse[str]?): Specifies the name of the attribute that the cache file will drive.  
                This file is optional when creating cache files.  
                If this flag is not used during create mode, the cache files will  
                be created on disk, but will not be driving anything in the scene.  
                This flag is required when the attachFile flag is used.  
                Properties: create, multiuse
        inTangent (str?): Specifies the in-tangent type when interpolating frames before the replaced  
                frame(s). Must be used with the ist/interpStartTime and iet/interpEndTime flags.  
                Valid values are "linear", "smooth" and "step".  
                Properties: create
        interpEndTime (int?): Specifies the frame until which there will be linear interpolation, beginning  
                at endTime. Must be used with the rpf/replaceCachedFrame or apf/appendFrame flag.  
                Interpolation is achieved by removing frames between endTime and  
                interpEndTime from the cache. Removed frames will be renamed as specified  
                by the f/fileName flag.  
                Properties: create
        interpStartTime (int?): Specifies the frame from which to begin linear interpolation, ending at  
                startTime. Must be used with the rpf/replaceCachedFrame or apf/appendFrame flags.  
                Interpolation is achieved by removing  frames between interpStartTime and  
                startTime from the cache. These removed frames will will be renamed as  
                specified by the f/fileName flag.  
                Properties: create
        noBackup (bool?): Specifies that backup files should not be created for any files that may be over-written during  
                append, replace or delete cache frames. Can only be used with the apf/appendFrame,  
                rpf/replaceCachedFrame or dcf/deleteCachedFrame flags.  
                Properties: create
        outAttr (Multiuse[str]?): Specifies the name of the attribute that will be cached to disk.  
                			In query mode, this flag needs a value.  
                Properties: create, multiuse
        outTangent (str?): Specifies the out-tangent type when interpolating frames after the replaced  
                frame(s). Must be used with the ist/interpStartTime and iet/interpEndTime flags.  
                Valid values are "linear", "smooth" and "step".  
                Properties: create
        pc2File (str?): Specifies the full path to the pc2 file.  Must be used in conjunction with the pc2 flag.  
                Properties: create
        pointCount (bool?): A query flag which returns the number of points stored in the cache file.  
                The channelName flag should be used to specify the channel to be queried.  
                Properties: query
        points (Multiuse[str]?): Specifies the name of a geometry whose points will be cached.  
                			In query mode, this flag needs a value.  
                Properties: create, multiuse
        pointsAndNormals (Multiuse[str]?): Specifies the name of a geometry whose points and normals will be cached.  
                The normals is per-vertex per-polygon. The normals cache cannot be imported  
                back to geometry.  
                This flag can only be used to export cache file. It cannot be used with  
                the apf/appendFrame, dcf/deleteCachedFrame and rpf/replaceCachedFrame flags.  
                			In query mode, this flag needs a value.  
                Properties: create, multiuse
        prefix (bool?): Indicates that the specified fileName should be used as a prefix for the  
                cacheName.  
                Properties: create
        refresh (bool?): When used during cache creation, forces a screen refresh during caching.  
                This causes the cache creation to be slower but allows you to see how the  
                simulation is progressing during the cache.  
                Properties: create
        replaceCachedFrame (bool?): Replaces cached data for the times specified by the startTime/endTime  
                flags. If no time is provided, replaces cache file for the current time.  
                Must be used in conjunction with the pts/points or cnd/cacheableNode flag.  
                Replaced frames will not be deleted, but renamed as specified by the  
                f/fileName flag.  
                Properties: create
        replaceWithoutSimulating (bool?): When replacing cached frames, this flag specifies whether the replacement should  
                come from the cached node without simulating or from advancing time and letting  
                the simulation run.  This flag is valid only when neither the startTime nor endTime flags  
                are used or when both the startTime and endTime flags specify the same time value.  
                Properties: edit
        runupFrames (Queryable[int]?): Specifies the number of frames of runup to simulate ahead of the starting frame.  
                The value must be greater than or equal to 0.  The default is 2.  
                Properties: create, query, edit
        sampleMultiplier (Queryable[int]?): Specifies the sample rate when caches are being created as a multiple of  
                simulation Rate. If the value is 1, then a sample will be cached everytime  
                the time is advanced.  If the value  
                is 2, then every other sample will be cached, and so on.  The default is 1.  
                Properties: create, query, edit
        simulationRate (Queryable[int]?): Specifies the simulation rate when caches are being created.  During cache  
                creation, the time will be advanced by the simulation rate, until the end  
                time of the cache is reached or surpassed.  The value is given in frames.  
                The default value is 1 frame.  
                Properties: create, query, edit
        singleCache (bool?): When used in conjunction with the points, pointsAndNormal or cacheableNode  
                flag, specifies whether multiple geometries should be put into a single  
                cache or to create one cache per geometry (default).  
                Properties: create
        startTime (int?): Specifies the start frame of the cache range.  
                Properties: create
        staticCache (bool?): If false, during cache creation, do not save a cache for the object if it  
                appears to have no animation or deformation. If true, save a cache even if  
                the object appears to have no animation or deformation. Default is true. In  
                query mode, when supplied a shape, the flag returns true if the shape appears  
                to have no animation or deformation.  
                Properties: create, query
        worldSpace (bool?): If the points flag is used, turning on this flag will result in the world  
                space positions of the points being written. The expected use of this  
                flag is for cache export.  
                Properties: create

    Returns:
        str: name of created cache description file(s)

    Example:
    """

def cacheFileCombine(*args: str, edit: bool = ..., query: bool = ..., cacheIndex: bool = ..., channelName: Multiuse[str] = ..., connectCache: Queryable[str] = ..., keepWeights: bool = ..., layerNode: bool = ..., nextAvailable: bool = ..., object: str = ..., objectIndex: Queryable[int] = ...) -> Union[str, bool, int]:
    """Creates a cacheBlend node that can be used to combine, layer or blend multiple cacheFiles for a given object.cache, file, disk, blend
    Args:
        cacheIndex (bool?): A query only flag that returns the index related to the  
                cache specified with the connectCache flag.  
                Properties: query
        channelName (Multiuse[str]?): Used in conjunction with the connectCache flag to indicate the channel(s) that  
                should be connected.  If not specified, the first channel in the file is used.  
                Properties: edit, multiuse
        connectCache (Queryable[str]?): An edit flag that specifies a cacheFile node that should be connected to the next available index on the specified cacheBlend node. As a query flag, it returns a string array containing the cacheFiles that feed into the specified cacheBlend node.  
                			In query mode, this flag can accept a value.  
                Properties: query, edit
        keepWeights (bool?): This is a flag for use in combination with the connectCache flag only. By default, the connectCache flag will set all weights other than the newly added cacheWeight to 0 so that the new cache gets complete control. This flag disables that behavior so that all existing blend weights are retained.  
                Properties: edit
        layerNode (bool?): A query flag that returns a string array of the existing cacheBlends on the selected object(s). Returns an empty string array if no cacheBlends are found.  
                Properties: query
        nextAvailable (bool?): A query flag that returns the next available index on the selected cacheBlend node.  
                Properties: query
        object (str?): This flag is used in combination with the objectIndex flag. It is  
                used to specify the object whose index you wish to query.  
                			In query mode, this flag needs a value.  
                Properties: query
        objectIndex (Queryable[int]?): In edit mode, used in conjunction with the connectCache flag to indicate  
                the objectIndex to be connected.  
                In query mode, returns the index related to the object specified with  
                the object flag.  
                Properties: query, edit

    Returns:
        str: Name of created cache layer node(s)

    Example:
    """

def cacheFileMerge(*args: str, edit: bool = ..., query: bool = ..., endTime: int = ..., geometry: bool = ..., startTime: int = ...) -> Union[List[float], List[str], bool]:
    """If selected/specified caches can be successfully merged, will return the start/end frames of the new cache followed by the
    start/end frames of any gaps in the merged cache for which no data should be written to file. In query mode, will return
    the names of geometry associated with the specified cache file nodes.cache, file, merge, disk
    Args:
        endTime (int?): Specifies the end frame of the merge range. If not specified, will figure  
                out range from times of caches being merged.  
                Properties: create
        geometry (bool?): Query-only flag used to find the geometry nodes associated with the specified cache files.  
                Properties: query
        startTime (int?): Specifies the start frame of the merge range. If not specified, will figure  
                out range from the times of the caches being merged.  
                Properties: create

    Returns:
        List[float]: The start and end times of merged cache followed by start/end of any gaps
        List[str]: Names of geometry associated with specified cache in query mode.

    Example:
    """

def cacheFileTrack(*args: str, edit: bool = ..., query: bool = ..., insertTrack: int = ..., lock: bool = ..., mute: bool = ..., removeEmptyTracks: bool = ..., removeTrack: int = ..., solo: bool = ..., track: Queryable[int] = ...) -> Union[bool, int]:
    """This command is used for inserting and removing tracks related to the caches displayed in the trax editor. It can also be used to modify the track state, for example, to lock or mute a track.cache, file, disk, blend, trax, track
    Args:
        insertTrack (int?): This flag is used to insert a new empty track at the track index  
                specified.  
                Properties: create
        lock (bool?): This flag specifies whether clips on a track are to be locked or not.  
                Properties: create, query, edit
        mute (bool?): This flag specifies whether clips on a track are to be muted or not.  
                Properties: create, query, edit
        removeEmptyTracks (bool?): This flag is used to remove all tracks that have no clips.  
                Properties: create
        removeTrack (int?): This flag is used to remove the track with the specified index.  The  
                track must have no clips on it before it can be removed.  
                Properties: create
        solo (bool?): This flag specifies whether clips on a track are to be soloed or not.  
                Properties: create, query, edit
        track (Queryable[int]?): Used to specify a new track index for a cache to be displayed. Track-indices are 1. based.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def caddyManip(*args: Any, **kwargs: Any) -> None: ...
def callbacks(*args: str, addCallback: Callable[..., Any] = ..., clearAllCallbacks: bool = ..., clearCallbacks: bool = ..., describeHooks: bool = ..., dumpCallbacks: bool = ..., executeCallbacks: bool = ..., hook: str = ..., listCallbacks: bool = ..., owner: str = ..., removeCallback: Callable[..., Any] = ...) -> List[str]:
    """This command allows you to add callbacks at key times during UI creation so
    that the Maya UI can be extended.
    The list of standard Maya hooks, as well as the arguments which will be passed
    to the callback based on the context are enumerated in thesection below.
    Custom hooks can also be added if third parties want to add UI extensibility to
    their plugins.ui, callback
    Args:
        addCallback (Callable[..., Any]?): Add a callback for the specified hook. The owner must also be specified  
                when adding callbacks.  
                Properties: create
        clearAllCallbacks (bool?): Clear all the callbacks for all hooks and owners. This is generally  
                only used during plugin development and testing as it affects all callbacks  
                registered by Maya and other third parties.  
                Properties: create
        clearCallbacks (bool?): Clear all the callbacks for the specified owner. If a hook is specified,  
                only the callbacks for that hook and owner will be cleared.  
                Properties: create
        describeHooks (bool?): List the standard Maya hooks. Below is a list of the hooks and their associated arguments  
                and return values. Custom hooks added by third parties are not listed.  
              
              
                hyperShadePanelBuildCreateMenu  
              
                This hook is called to add content to the Hypershade panel create menu. It will  
                be called after the standard Maya node entries have been created.  
              
                This callback does not have any arguments or return values. In order to preserve  
                the desired look in the Maya UI, these callbacks should add a menu item divider just  
                before returning using: menuItem -divider true.  
              
                hyperShadePanelBuildCreateSubMenu  
              
                This hook is called to get a classification string for the custom renderer  
                shading nodes, to prevent them from being listed with the standard Maya nodes.  
              
                This callback does not have any arguments.  
              
                returns: a classification string, such as rendernode/myrenderer  
              
              
                hyperShadePanelPluginChange  
              
                This hook is called when a plugin change event (loading / unloading) has occurred to inform Maya whether the  
                Hypershade panel needs to be rebuilt.  
              
                classification (string): classification string belonging to a plugin node,  
                    possibly from another plugin  
                changeType (string): either loadPlugin or unloadPlugin  
                returns: (int) non-zero if your plugin is responsible for nodes of this classification,  
                    and a Hypershade rebuild is required  
              
              
                createRenderNodeSelectNodeCategories  
              
                This hook is called when the Create Render Node dialog is being constructed, and allows  
                a third party to have their nodes selected by default. A flag of the form -allWithMyRendererUp  
                is the standard form, and the selection can be set up in the tree lister in the callback.  
              
                There is no return value for this callback.  
              
                flag (string): flag passed to the Create Render Node dialog command with the leading minus (-) removed  
                treeLister (string): the tree lister widget which should be affected  
              
              
                For example, your callback might look like:  
              
              
                global proc myRendererCreateRenderNodeSelectNodeCategoriesCallback(string $flag, string $treeLister){  
                    if($flag == "allWithMyRendererUp") {  
                        treeLister -e -selectPath "myrenderer" $treeLister;  
                    }  
                }  
              
              
                createRenderNodePluginChange  
              
                This hook is called when a plugin change event has occurred to decide if the  
                Create Render Node dialog needs to be closed.  
              
                classification (string): classification string belonging to a plugin node,  
                    possibly from another plugin  
                returns: (int) non-zero if your plugin is responsible for nodes of this classification,  
                    and the Create Render Node dialog needs to be closed  
              
              
                renderNodeClassification  
              
                This hook is called to get a classification string for the custom renderer  
                shading nodes.  This is used to determine if a given node type belongs to  
                a plugin renderer.  
              
                This callback does not have any arguments.  
              
                returns: a classification string, such as rendernode/myrenderer  
              
              
                createRenderNodeCommand  
              
                This hook is called to give plugin renderers the chance to register their own command for  
                creating their nodes from the render node treeLister and Node Editor. The callback should  
                determine from the classification of the node type in question if it is theirs, and if so,  
                return the appropriate command for creating new nodes of that type.  
              
              
                postCommand (string): command to be run after the create command  
                type (string): nodeType  
                returns: (string) MEL create command  
              
              
                buildRenderNodeTreeListerContent  
              
                This hook is called to give plugin renderers the chance to add their content to the render node  
                tree lister.  
              
              
                renderNodeTreeLister (string): the render node tree lister  
                postCommand (string): command to be run post-creation  
                filterString (string): a space delimited list of filters  
              
              
                AETemplateCustomContent  
              
                This hook is called to give plugins a chance to add content to the Attribute Editor for nodes which source AEdependNodeTemplate.  
              
              
                nodeName (string): the name of the node for which the Attribute Editor is being constructed  
              
              
                firstConnectedShader  
              
                This hook is called to determine the primary custom shader connected to the given Shading Engine.  
              
              
                nodeName (string): the name of the Shading Engine  
                returns (string): the name of the custom shader if applicable  
              
              
                allConnectedShaders  
              
                This hook is called to determine all the shaders connected to the given Shading Engine.  
              
              
                nodeName (string): the name of the Shading Engine  
                returns (string): a colon separated list of the connected custom shaders (shader1. shader2. shader3)  
              
              
                renderLayerPresetMenu  
              
                This hook is called to give plugins a chance to add presets to a renderLayer node.  
              
              
                nodeName (string): the name of the renderLayer node  
              
              
                addBakingMenuItems  
              
                This hook is called to give plugins a chance to add baking menu items to the global Render - Lighting/Shading menu.  
              
              
                menuItemAnchor (string): the name of the menuItem which the new baking menu items should be inserted after.   
              
              
                addVertexBakingMenuItems  
              
                This hook is called to give plugins a chance to add baking menu items to the global Polygon - Color menu.  
              
              
                addPrelightMenuItems  
              
                This hook is called to give plugins a chance to add pre-lighting menu items to the global Polygon - Color Set Editor menu.  
              
              
                addRMBBakingMenuItems  
              
                This hook is called to give plugins a chance to add baking menu items to the RMB menu.  
              
              
                objectName (string): the name of the object the right mouse button event occured on.  
              
              
                addMayaRenderingPreferences  
              
                This hook is called to give plugins a chance to add custom preferences to the Maya's Rendering Preferences section.  
              
              
                updateMayaRenderingPreferences  
              
                This hook is called to give plugins a chance to update custom preferences of the Maya's Rendering Preferences section.  
              
              
                addMayaMuscleMenuItems  
              
                This hook is called to give plugins a chance to add menu items to the Maya muscle Displace menu.  
              
              
                menuItemAnchor (string): the name of the menuItem which the new Maya muscle menu items should be inserted after.   
              
              
                addMayaMuscleShelfButtons  
              
                This hook is called to give plugins a chance to add items to the Maya muscle shelves.  
              
              
                addBackburnerRendererMenuItems  
              
                This hook is called to give plugins a chance to add items to Maya's Backburner list of available renderers. Note: The menuItem added must be named with the short name equivalent of the renderer. eg: The Maya software renderer adds a menuItem named 'sw'.  
              
              
                provideAETemplateForNodeType  
              
                This hook is called to give plugins a chance to provide a UI template for nodes which do not have a corresponding AE'nodeType'Template procedure.  
              
              
                nodeType (string): the type of the node for which the AE is being constructed.   
                returns (string): the name of a MEL command or procedure to use as the AETemplate for the requested node type.   
              
              
                AEnewMultiHandler  
              
                This hook is called to give plugins a chance to provide a UI creation handler for multi attributes.  
              
              
                nodeName (string): the name of the node for which the AE is being constructed.   
                atributeName (string): the name of the multi attribute.  
                uiName (string): the UI name of the attribute.  
                changedCommand (string): the MEL command or procedure to be executed when the value of the multi attribute is changed.  
                elementIndexString (string): a colon separated list of indices at which the elements of the multi attribute live.  
                returns (string): if the callback handled the attribute then it should return the full name of the topmost UI element that it created, otherwise it should return an empty string.  
              
              
                AEreplaceMultiHandler  
              
                This hook is called to give plugins a chance to provide an update handler for multi attributes.  
              
              
                layoutName (string): the well defined name of the Maya UI component which represents the multi attribute (.  
                nodeName (string): the name of the node for which the AE is being constructed.   
                atributeName (string): the name of the multi attribute.  
                changedCommand (string): the MEL command or procedure to be executed when the value of the multi attribute is changed.  
                elementIndexString (string): a colon separated list of indices at which the elements of the multi attribute live.  
                returns (int): Return 1 if the callback handled the multi attribute, Return 0 if Maya should provide its default handling.  
              
              
                AEnewAttributeHandler  
              
                This hook is called to give plugins a chance to provide a UI creation handler for attributes.  
              
              
                nodeName (string): the name of the node for which the AE is being constructed.   
                atributeName (string): the name of the attribute.  
                uiName (string): the UI name of the attribute.  
                changedCommand (string): the MEL command or procedure to be executed when the value of the attribute is changed.  
                returns (string): if the callback handled the attribute then it should return the full name of the topmost UI element that it created, otherwise it should return an empty string.  
              
              
                AEreplaceAttributeHandler  
              
                This hook is called to give plugins a chance to provide an update handler for attributes.  
              
              
                nodeName (string): the name of the node for which the AE is being constructed.   
                atributeName (string): the name of the attribute.  
                changedCommand (string): the MEL command or procedure to be executed when the value of the attribute is changed.  
                returns (int): Return 1 if the callback handled the attribute, Return 0 if Maya should provide its default handling.  
              
              
                provideClassificationStrings  
              
                This hook must be supplied by all third parties that add nodes to the 'shader/surface' classification namespace.  
              
              
                returns (string): a colon separated list representing the different plugin node classifications.  
              
              
                provideClassificationExclusionStrings  
              
                This hook is called to give plugins a chance to provide a list of classifications which should be filtered out from a nodeTreeLister category. For example a plugin might want to filter out nodes classified as both 'material' and 'legacy' out of the 'material' category.  
              
              
                classification (string): the classification the nodeTreeBuilder is inquiring about.  
                returns (string): a colon separated list representing the different classifications that should be excluded from the classification the nodeTreeBuilder is inquiring about.  
              
              
                provideClassificationStringsForFilteredTreeLister  
              
                This hook is called by 'createAssignNewMaterialTreeLister' and gives plugins a chance to append to the classification filter passed to the Tree Lister builder. It must return a string where each new classification is separated by a white space.  
              
              
                currentFilterString (string): a white-space-separated string representing the current classifications.  
              
              
                nodeCanBeUsedAsMaterial  
              
                The hook is used by the RMB 'Assign Favorite Material' menu to determine which shading nodes can be used as materials. It must return 1 if the node can be used as a material node and 0 otherwise.  
              
              
                nodeId (string): the node Id of the shading node being queried.  
                nodeOwner (string): the name of the plugin the node belongs to.  
              
              
                addHeaderContentToMayaLambertianShadersAE  
              
                This hook is called to give plugins a chance to add content to the header of the Attribute Editor of Maya's Lambertian-â€‹derived shaders.  
              
              
                nodeName (string): the name of the node for which the Attribute Editor is being constructed.  
              
              
                provideNodeToAttrConnection  
              
                This hook is called to give plugins a chance to provide which output attribute should be used when a node is connected to an input attribute.  
                If an input attribute type is given an output attribute of matching type should be returned. If no attribute type is specified (empty string)  
                a preferred output attribute of any type can be returned. If no output attribute of matching type is available an empty string should be returned.  
              
              
                nodeType (string): the node type of the node queried.  
                attributeType (string): the data type of the input attribute.  
                returns (string): the name of the output attribute to use.  
              
              
                provideNodeToNodeConnection  
              
                This hook is called to give plugins a chance to provide which attributes should be connected when a node to node connection is made.  
                Both the source and destination attributes should be returned in a colon separated list, e.g. "src1. dst1. src2. dst2. src3. dst3"  
              
              
                srcType (string): the node type of the source node.  
                dstType (string): the node type of the destination node.  
                returns (string): A colon separated list of source and destination attribute names.  
              
              
                provideOutputAttributeNameForTextureNode  
              
                This hook is called to give plugins a chance to provide a different output attribute name for Texture nodes. If this hook isn't provided 'outColor' is used.  
              
              
                nodeName (string): the name of the texture node queried.  
                returns (string): the output attribute name of the Texture node.  
              
              
                addItemsToHypergraphNodePopupMenu  
              
                This hook is called to give plugins a chance to add items to the Hypergraph node popup menu.  
                Plugins should add a menu item divider (using: menuItem -divider true) before adding any more items to the popup menu.  
              
              
                nodeName (string): the name of the node for which the Hypergraph node menu is being constructed.  
              
              
                addItemsToOutlinerNodePopupMenu  
              
                This hook is called to give plugins a chance to add items to the Outliner node popup menu.  
                Plugins should add a menu item divider (using: menuItem -divider true) before adding any more items to the popup menu.  
              
              
                nodeName (string): the name of the node or Ufe path string for which the Outliner node menu is being constructed.  
              
              
                addItemsToRenderLayerEditorPopupMenu  
              
                This hook is called to give plugins a chance to add items to the Render Layer Editor popup menu.  
                Plugins should add a menu item divider (using: menuItem -divider true) before adding any more items to the popup menu.  
              
              
                layerName (string): the name of the render layer for which the popup menu is being constructed.  
              
              
                preventMaterialDeletionFromCleanUpSceneCommand  
              
                This hook is called by the cleanUpScene command and gives the plugin a chance to communicate that a material node is still in use and shouldn't be deleted. The hook is called once per plug/connection pair of each shader instance.  
              
              
                shader (string): the name of the shader node being deleted.  
                plug (string): the name of the plug queried.  
                connection (string): the name of the connection queried.  
              
              
                connectNodeToNodeOverrideCallback  
              
                This hook is called to give plugins a chance to redefine the behavior of drag and drop.  
              
              
                srcNode (string): the name of the source node (the dragged node).  
                dstNode (string): the name of the destination node (the dropped-on node).  
                returns (int): Return 1 if Maya should perform the operation that would normally result from this connection. Return 0 to override and provide custom behavior.  
              
              
                prepareRenderChanged  
              
                This hook is called after an edit on a traversal set with the prepareRender command.  
              
              
                enableRenderPassMenuOfRenderView  
              
                This hook is called to give plugins a chance to tell Maya it should enable the render pass menu of the render view (under File->Load Render Pass). 'addRenderPassMenuItemsToRenderView' can be used to add items to this menu.  
              
              
                returns (int): Return 1 if the plugin wants the render pass menu of the render view to be enabled. Return 0 otherwise.  
              
              
                addItemsToRenderPassMenuOfRenderView  
              
                This hook is called to give plugins a chance to add menu items to the 'render pass' menu of the render view (under File->Load Render Pass). 'enableRenderPassMenuOfRenderView' can be used to enable the render pass menu of the render view.  
              
              
                addItemsToRMBMenuOfTreeLister  
              
                This hook is called to give plugins a chance to populate the RMB menu of nodes listed in a tree lister. Plugins should add a menu item divider (using: menuItem -divider true) before adding any more items to the RMB menu.  
              
              
                nodeType (string): The node type of the tree lister node for which the RMB menu is being built.  
                scriptCommand (string): The script command associated with the tree lister node for which the RMB menu is being built.  
                returns (int): Return 0 if Maya should append its own items to the menu of the current node type. This should be the return value for all node types a plugin isn't explicitly interested in. Return 1 if Maya shouldn't add any of its items to the menu of the current node type. Note: All menu items related to managing the 'Favorites' section of the tree lister will always be added to the RMB menu regardless of the return value (those are treated as special cases).  
              
              
                saveCustomNodePresetAttributes  
              
                This hook is called to give plugins a chance to store extra commands in the node preset file being saved.  
              
              
                presetNodeToSave (string): The name of the preset node being saved.  
                returns (string): The custom procedure to use to generate the mel script to be appended to the nodePreset -custom flag of the current presetNode save event (see the documentation of the nodePreset command for more information on the format of the -custom flag).  
              
              
                addItemToFileMenu  
              
                This hook is called to give plugins a chance to add menu items to the main File menu.  
              
              
                addItemToCreateLightMenu  
              
                This hook is called to give plugins a chance to add menu items to the create light menu.  
              
                textureReload  
              
                This hook is called to give plugins a chance to update all nodes that reference the texture file.  
              
              
                file (string): the file path of the texture to reload.  
              
              
                renderSettingsBuilt  
              
                This hook is called after the render settings window has been built.  
              
                rendererAddOneTabToGlobalsWindowCreateProc  
              
                This hook is called to allow renderers the opportunity to add renderer specific tabs to the unified render globals window (render settings window).  
              
              
                createProc (string): the name of the procedure used to create the content of the tab.   
              
              
                shouldEarlyReturnFromUpdateMultiCameraBufferNamingMenu  
              
                This hook is called to allow users to early return from the updateMultiCameraBufferNamingMenu() function by returning "true" in the callback handler.  
              
              
                returns (string): Returns "true" if the caller wishes to early return from the updateMultiCameraBufferNamingMenu() function.  
              
              
                shouldEarlyReturnFromUpdateMayaSoftwareImageFormatControl  
              
                This hook is called to allow users to early return from the updateMayaSoftwareImageFormatControl() function by returning "true" in the callback handler.  
              
              
                returns (string): Returns "true" if the caller wishes to early return from the updateMayaSoftwareImageFormatControl() function.  
              
              
                shouldEarlyReturnFromUpdateDefaultTraversalSetMenu  
              
                This hook is called to allow users to early return from the updateDefaultTraversalSetMenu() function by returning "true" in the callback handler.  
              
              
                returns (string): Returns "true" if the caller wishes to early return from the updateDefaultTraversalSetMenu() function.  
              
              
                shouldEarlyReturnFromShouldAppearInNodeCreateUI  
              
                This hook is called to allow users to early return from the shouldAppearInNodeCreateUI() function by returning "true" in the callback handler.  
              
              
                returns (string): Returns "true" if the caller wishes to early return from the shouldAppearInNodeCreateUI() function.  
              
              
                updateAE  
              
                This hook is called at the end of the updateAE() function.  
                Properties: create
        dumpCallbacks (bool?): Gives a list of all the registered callbacks for all hooks and owners. Can be  
                useful for debugging.  
                Properties: create
        executeCallbacks (bool?): Execute the callbacks for the specified hook, passing the extra arguments to  
                each callback when it is executed.  Returns an array (MEL) or list (Python)  
                containing the return values from each callback that was executed.  
                If a callback returns no value, the array will contain an empty string (MEL)  
                or None (Python).  
                Properties: create
        hook (str?): The name of the hook for which the callback should be registered.  
                Properties: create
        listCallbacks (bool?): Get the list of callbacks for the specified hook name. If the owner is  
                specified, only callbacks for the specified hook and owner will be listed.  
                Properties: create
        owner (str?): The name of the owner registering the callback. This is typically a plugin name.  
                Properties: create
        removeCallback (Callable[..., Any]?): Remove an existing callback for the specified hook name. The owner must  
                also be specified when removing a callback.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def camera(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., aspectRatio: Queryable[float] = ..., cameraScale: Queryable[float] = ..., centerOfInterest: Queryable[float] = ..., clippingPlanes: bool = ..., depthOfField: bool = ..., displayFieldChart: bool = ..., displayFilmGate: bool = ..., displayFilmOrigin: bool = ..., displayFilmPivot: bool = ..., displayGateMask: bool = ..., displayResolution: bool = ..., displaySafeAction: bool = ..., displaySafeTitle: bool = ..., fStop: Queryable[float] = ..., farClipPlane: Queryable[float] = ..., farFocusDistance: Queryable[float] = ..., filmFit: Queryable[str] = ..., filmFitOffset: Queryable[float] = ..., filmRollOrder: Queryable[str] = ..., filmRollValue: Queryable[float] = ..., filmTranslateH: Queryable[float] = ..., filmTranslateV: Queryable[float] = ..., focalLength: Queryable[float] = ..., focusDistance: Queryable[float] = ..., homeCommand: Queryable[str] = ..., horizontalFieldOfView: Queryable[float] = ..., horizontalFilmAperture: Queryable[float] = ..., horizontalFilmOffset: Queryable[float] = ..., horizontalPan: Queryable[float] = ..., horizontalRollPivot: Queryable[float] = ..., horizontalShake: Queryable[float] = ..., journalCommand: bool = ..., lensSqueezeRatio: Queryable[float] = ..., lockTransform: bool = ..., motionBlur: bool = ..., name: Queryable[str] = ..., nearClipPlane: Queryable[float] = ..., nearFocusDistance: Queryable[float] = ..., orthographic: bool = ..., orthographicWidth: Queryable[float] = ..., overscan: Queryable[float] = ..., panZoomEnabled: bool = ..., position: Queryable[Tuple[float, float, float]] = ..., postScale: Queryable[float] = ..., preScale: Queryable[float] = ..., renderPanZoom: bool = ..., rotation: Queryable[Tuple[float, float, float]] = ..., shakeEnabled: bool = ..., shakeOverscan: Queryable[float] = ..., shakeOverscanEnabled: bool = ..., shutterAngle: Queryable[float] = ..., startupCamera: bool = ..., stereoHorizontalImageTranslate: Queryable[float] = ..., stereoHorizontalImageTranslateEnabled: bool = ..., verticalFieldOfView: Queryable[float] = ..., verticalFilmAperture: Queryable[float] = ..., verticalFilmOffset: Queryable[float] = ..., verticalLock: bool = ..., verticalPan: Queryable[float] = ..., verticalRollPivot: Queryable[float] = ..., verticalShake: Queryable[float] = ..., worldCenterOfInterest: Queryable[Tuple[float, float, float]] = ..., worldUp: Queryable[Tuple[float, float, float]] = ..., zoom: Queryable[float] = ...) -> Union[List[str], float, bool, str, Tuple[float, float, float]]:
    """Create, edit, or query a camera with the specified properties.The resulting camera can be repositioned using the viewPlace
    command. Many of the camera settings only affect the resulting
    rendered image. E.g. the F/Stop, shutter speed, the film related
    options, etc. Scaling the camera icon does not change any camera
    properties.
    Args:
        aspectRatio (Queryable[float]?): The ratio of the film back width to the film back height.  
                Properties: create, query, edit
        cameraScale (Queryable[float]?): Scale the camera.  
                Properties: create, query, edit
        centerOfInterest (Queryable[float]?): Set the linear distance from the camera's eye point to the  
                center of interest.  
                Properties: create, query, edit
        clippingPlanes (bool?): Activate manual clipping planes.  
                Properties: create, query, edit
        depthOfField (bool?): Determines whether a depth of field calculation is performed  
                to give varying focus depending on the distance of the  
                objects.  
                Properties: create, query, edit
        displayFieldChart (bool?): Activate display of the video field chart when looking through  
                the camera.  
                Properties: create, query, edit
        displayFilmGate (bool?): Activate display of the film gate icons when looking through  
                the camera.  
                Properties: create, query, edit
        displayFilmOrigin (bool?): Activate the display of the film origin guide when  
                looking through the camera.  
                Properties: create, query, edit
        displayFilmPivot (bool?): Activate display of the film pivot guide when looking  
                through the camera.  
                Properties: create, query, edit
        displayGateMask (bool?): Display the gate mask, file or resolution, as a shaded area  
                to the edge of the viewport.  
                Properties: create, query, edit
        displayResolution (bool?): Activate display of the current rendering resolution (as  
                defined in the render globals) when looking through the  
                camera.  
                Properties: create, query, edit
        displaySafeAction (bool?): Activate display of the video Safe Action guide  
                when looking through the camera.  
                Properties: create, query, edit
        displaySafeTitle (bool?): Activate display of the video Safe Title guide  
                when looking through the camera.  
                Properties: create, query, edit
        fStop (Queryable[float]?): A real lens normally contains a diaphragm or other stop which  
                blocks some of the light that would otherwise pass through  
                it. This stop is usually approximately round, and its diameter  
                as seen from the front of the lens is called the lens  
                diameter. The lens diameter is often described by its relation  
                to the focal length of the lens. A lens whose diameter is  
                one-eighth its local length is said to have an F-stop of  
                8. This is an optical property of the lens.  
                Properties: create, query, edit
        farClipPlane (Queryable[float]?): Specify the distance to the far clipping plane.  
                Properties: create, query, edit
        farFocusDistance (Queryable[float]?): Linear distance to the far focus plane.  
                Properties: create, query, edit
        filmFit (Queryable[str]?): This describes how the digital image (in pixels) relates to  
                the film back. Since the film back is defined in terms of real  
                numbers with some arbitrary film aspect, and the digital image  
                is defined in integer pixels with an equally arbitrary (and  
                different) resolution, relating the two can get  
                complicated. There are 4 choices:   
              
                horizontal   
                In this case the digital image is made to fit the film  
                back exactly in the horizontal direction. This then gives each  
                pixel a horizontal size = (film back width) / (horizontal  
                resolution). The pixel height is then = (pixel width) / (pixel  
                aspect ratio). Now that the pixel has a size, resolution gives  
                us a complete image. That image will match the film back  
                exactly in width. It will almost never match in height, either  
                being too tall or too short. By playing with the numbers you  
                can get it pretty close though.  
                vertical  
                This is the same idea as horizontal fit, only applied  
                vertically. Thus the digital image will match the film back  
                exactly in height, but miss in width.  
                fill  
                This is a convenience item. The system calculates both  
                horizontal and vertical fits and then applies the one that  
                makes the digital image larger than the film back.  
                overscan  
                Overscanning the film gate in the camera view allows us  
                to choreograph action outside of the frustum from within the  
                camera view without having to resort to a dolly or zoom. This  
                feature is also essential for animating image planes.  
                Properties: create, query, edit
        filmFitOffset (Queryable[float]?): Since we know from the above that the digital image may not  
                match the film back exactly, we now have the question of how  
                to position one relative to the other. Thus fit  
                offset. Normally the centers are aligned. Fit offset lets you  
                move the smaller image within the larger one. Specify the  
                distance for film offset (inches).  
                Properties: create, query, edit
        filmRollOrder (Queryable[str]?): Specifies how the roll is applied with respect to the  
                pivot value.  
              
                Rotate-Translate  
                The film back is first rotated then translated by the  
                pivot point value.  
                Translate-Rotate  
                The film back is first translated then rotated by the  
                film roll value.  
                Properties: create, query, edit
        filmRollValue (Queryable[float]?): This specifies that amount of rotation around the film back.  
                The roll value is specified in degrees. The rotation occurs around  
                the specified pivot point. This value is used to compute a film  
                roll matrix, which is a component of the post-projection matrix.  
                Properties: create, query, edit
        filmTranslateH (Queryable[float]?): The horizontal film translation. Values are normalized to  
                the viewing area.  
                Properties: create, query, edit
        filmTranslateV (Queryable[float]?): The vertical film translation. Values are normalized to the  
                viewing area.  
                Properties: create, query, edit
        focalLength (Queryable[float]?): This is the distance along the lens axis between the lens and  
                the film plane when "focal distance" is infinitely large. This  
                is an optical property of the lens. This double precision  
                parameter is always specified in millimeters.  
                Properties: create, query, edit
        focusDistance (Queryable[float]?): Set the focus at a certain distance in front of the camera.  
                Properties: create, query, edit
        homeCommand (Queryable[str]?): Specify the command to execute when "viewSet -home" is applied  
                to this camera. All occurances of "%camera" will be replaced  
                with the cameras name before viewSet runs the command.  
                Properties: create, query, edit
        horizontalFieldOfView (Queryable[float]?): This is the film back width as seen by the lens when focused  
                at infinity (ie., focal length away) measured as an  
                angle. Note that it has nothing to do with pixels or the  
                digital image or any aspects. Angle of view is a derived  
                field, that is, it is not used internally by Alias and can be  
                completely determined from other information. It is included  
                as a convenience for the user. Its derivation is aov = 2 *  
                atan( fbw / (2 * f) ) where "aov" is the angle of view, "fbw"  
                is the film back width and "f" is the focal length.  
                Properties: create, query, edit
        horizontalFilmAperture (Queryable[float]?): The horizontal width of the camera's film plane. The camera's  
                film is located on the film plane. The extent of the film  
                which will be exposed to an image of the scene in front of the  
                lens is limited to a rectangular area described by the film  
                back. This double precision parameter is always specified in  
                inches.  
                Properties: create, query, edit
        horizontalFilmOffset (Queryable[float]?): Horizontal offset from the center of the film back. Normally  
                the film back will be centered on the lens axis. However, this  
                need not be so. Film offset is the displacement of the center  
                of the film back from the lens axis, also measured in  
                inches. Note that offsetting the film back will distort the  
                image, but will not alter the focus. This double precision  
                parameter is always specified in inches.  
                Properties: create, query, edit
        horizontalPan (Queryable[float]?): Horizontal 2D camera pan (inches)  
                Properties: create, query, edit
        horizontalRollPivot (Queryable[float]?): The horizontal pivot point from the center of the film back.  
                The pivot point is used during rotation of the film back.  The pivot  
                is the point where the rotation occurs around. This double precision  
                parameter corresponds to the normalized viewport. This value is a  
                part of the post projection matrix.  
                Properties: create, query, edit
        horizontalShake (Queryable[float]?): Another horizontal offset from the center of the film back,  
                which can be used and stored on the camera in addition to the  
                horizonal film offset attribute.  This allows for film-based  
                camera shake internal to the camera.  This works in exactly the same  
                units and coordinates that the film offset attribute does.  
                The effect of this attribute is toggled by the shake enabled attribute.  
                Properties: create, query, edit
        journalCommand (bool?): Journal interactive camera commands. Commands can be undone  
                when a camera is journaled.  
                Properties: create, query, edit
        lensSqueezeRatio (Queryable[float]?): This is presently just an information field in the camera  
                editor is meant to convey the horizontal distortion of the  
                anamorphic lens normally used with some film formats. If it  
                were used, it would do something like pixel aspect. Remember  
                however that lens distortion (intentional or not) is slightly  
                different than the output hardware's quantization. The fact  
                that a "net" distortion parameter could be used for both may  
                or may not confuse the issue.  
                Properties: create, query, edit
        lockTransform (bool?): Lock the camera. When a camera is locked, its transformation information,  
                that is, its Translate and Rotate properties cannot be adjusted, and the  
                center of interest point cannot be moved.  
                For orthographic cameras, Orthographic Width is also locked.  
                For camera groups, Aim and Up locator's translate is also locked.  
                For stereo cameras, the root camera is locked.  
                Properties: create, query, edit
        motionBlur (bool?): Determines whether the camera's image is motion blured (as  
                opposed to an object's image). For example, if you want to  
                blur the camera movement when you are performing a flyby.  
                Properties: create, query, edit
        name (Queryable[str]?): Name of the camera.  
                Properties: create, query, edit
        nearClipPlane (Queryable[float]?): Specify the distance to the NEAR clipping plane.  
                Properties: create, query, edit
        nearFocusDistance (Queryable[float]?): Linear distance to the near focus plane.  
                Properties: create, query, edit
        orthographic (bool?): Activate the orthographic camera.  
                Properties: create, query, edit
        orthographicWidth (Queryable[float]?): Set the orthographic projection width.  
                Properties: create, query, edit
        overscan (Queryable[float]?): Set the percent of overscan.  
                Properties: create, query, edit
        panZoomEnabled (bool?): Toggle camera 2D pan and zoom  
                Properties: create, query, edit
        position (Queryable[Tuple[float, float, float]]?): Three linear values can be specified to translate the camera.  
                Properties: create, query, edit
        postScale (Queryable[float]?): The post-scale value.  This value multiplied against  
                the computed projection matrix. It is applied after the  
                the film roll.  
                Properties: create, query, edit
        preScale (Queryable[float]?): The pre-scale value. The value is multiplied against  
                the computed projection matrix. It is applied before the film  
                roll.  
                Properties: create, query, edit
        renderPanZoom (bool?): Toggle camera 2D pan and zoom in render  
                Properties: create, query, edit
        rotation (Queryable[Tuple[float, float, float]]?): Three angular values can be specified to rotate the camera.  
                Properties: create, query, edit
        shakeEnabled (bool?): Toggles the effect of the horizontal and vertical shake  
                attributes.  
                Properties: create, query, edit
        shakeOverscan (Queryable[float]?): Controls the amount of overscan in the output rendered image.  
                For use when adding film-based camera shake.  Acts as a multiplier  
                to the film aperture on the camera.  
                Properties: create, query, edit
        shakeOverscanEnabled (bool?): Toggles the effect of the shake overscan attribute.  
                Properties: create, query, edit
        shutterAngle (Queryable[float]?): Specify the shutter angle (degrees).  
                Properties: create, query, edit
        startupCamera (bool?): A startup camera is marked undeletable and implicit. This flag  
                can be used to set or query the startup state of a  
                camera. There must always be at least one startup camera.  
                Properties: create, query, edit
        stereoHorizontalImageTranslate (Queryable[float]?): A film-back offset for use in stereo camera rigs.  
                Properties: create, query, edit
        stereoHorizontalImageTranslateEnabled (bool?): Toggles the effect of the stereo HIT attribute.  
                Properties: create, query, edit
        verticalFieldOfView (Queryable[float]?): Set the vertical field of view.  
                Properties: create, query, edit
        verticalFilmAperture (Queryable[float]?): The vertical height of the camera's film plane. This double  
                precision parameter is always specified in inches.  
                Properties: create, query, edit
        verticalFilmOffset (Queryable[float]?): Vertical offset from the center of the film back. This double  
                precision parameter is always specified in inches.  
                Properties: create, query, edit
        verticalLock (bool?): Lock the size of the vertical film aperture.  
                Properties: create, query, edit
        verticalPan (Queryable[float]?): Vertical 2D camera pan (inches)  
                Properties: create, query, edit
        verticalRollPivot (Queryable[float]?): Vertical pivot point used for rotating the film back. This  
                double precision parameter corresponds to the normalized viewport.  
                This value is used to compute the film roll matrix, which is a  
                component of the post projection matrix.  
                Properties: create, query, edit
        verticalShake (Queryable[float]?): Vertical offset from the center of the film back.  See horizontal  
                shake attribute description.  This is toggled by the shake enabled  
                attribute.  
                Properties: create, query, edit
        worldCenterOfInterest (Queryable[Tuple[float, float, float]]?): Camera world center of interest point.  
                Properties: create, query, edit
        worldUp (Queryable[Tuple[float, float, float]]?): Camera world up vector.  
                Properties: create, query, edit
        zoom (Queryable[float]?): The percent over the film viewable frustum to display  
                Properties: create, query, edit

    Returns:
        List[str]: (transform name and shape name)

    Example:
    """

def cameraSet(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., active: bool = ..., appendTo: bool = ..., camera: Queryable[str] = ..., clearDepth: bool = ..., deleteAll: bool = ..., deleteLayer: bool = ..., insertAt: bool = ..., layer: Queryable[int] = ..., name: Queryable[str] = ..., numLayers: bool = ..., objectSet: Queryable[str] = ..., order: Queryable[int] = ...) -> Union[str, bool, int]:
    """This command manages camera set nodes. Camera sets allow the users to
    break a single camera shot into layers. Instead of drawing all objects
    with a single camera, you can isolate the camera to only focus on
    certain objects and layer another camera into the viewport that draws
    the other objects. The situation to use camera sets primarily occurs
    when building stereoscopic scenes.For example, a set of stereo parameters may make the background
    objects divergent beyond the tolerable range of the human perceptual
    system. However, you like the settings because the main focus is in
    the foreground and the depth is important to the visual look of the
    scene.  You can use camera sets to break apart the shot into a
    foreground stereo camera and background stereo camera. The foreground
    stereo camera will retain the original parameters; however, it will
    only focus on the foreground elements.  The background stereo camera
    will have a different set of stereo parameters and will only draw the
    background element.Camera sets can be viewed using the stereo viewer and are currently only
    designed to work with stereo camera rigs.
    Args:
        active (bool?): Gets / sets the active camera layer.  
                Properties: create, query, edit
        appendTo (bool?): Append a new camera and/or object set to then end of the cameraSet layer  
                list. This flag cannot be used in conjunction with insert flag. Additionally,  
                it requires the camera and/or objectSet flag to be used.  
                Properties: create, edit
        camera (Queryable[str]?): Set/get the camera for a particular layer. When in query mode, You  
                must specify the layer with the layer flag.  
                Properties: create, query, edit
        clearDepth (bool?): Specifies if the drawing buffer should be cleared before beginning the draw  
                for that layer.  
                Properties: create, query, edit
        deleteAll (bool?): Delete all camera layers  
                Properties: create, edit
        deleteLayer (bool?): Delete a layer from the camera set. You must specify the layer using the  
                layer flag.  
                Properties: create, edit
        insertAt (bool?): Inserts the specified camera and/or object set at the specified layer.  
                This flag cannot be used in conjunction with the append flag. Additionally,  
                this flag requires layer and camera (or objectSet) flag to be used.  
                Properties: create, edit
        layer (Queryable[int]?): Specifies the layer index to be used when accessing layer information  
                Properties: create, query, edit
        name (Queryable[str]?): Gets or sets the name for the created camera set.  
                Properties: create, query
        numLayers (bool?): Returns the number of layers defined in the specified cameraSet  
                Properties: create, query
        objectSet (Queryable[str]?): Set/get the objectSet for a particular layer. When in query mode, you must  
                specify the layer with the layer flag.  
                Properties: create, query, edit
        order (Queryable[int]?): Set the order in which a particular layer is processed. This flag must be  
                used in conjunction with the layer flag.  
                Properties: create, query, edit

    Returns:
        str: The new cameraSet node (when in create mode)

    Example:
    """

def cameraView(arg0: str = ..., /, *, edit: bool = ..., addBookmark: bool = ..., animate: bool = ..., bookmarkType: int = ..., camera: str = ..., name: str = ..., removeBookmark: bool = ..., setCamera: bool = ..., setView: bool = ...) -> str:
    """This command creates a preset view for a camera which is then
    independent of the camera. The view stores a camera's eye point,
    center of interest point, up vector, tumble pivot, horizontal
    aperture, vertical aperature, focal length, orthographic width,
    and whether the camera is orthographic or perspective by default.
    Or you can only store 2D pan/zoom attributes by setting the
    bookmarkType to 1. These settings can be applied to any other
    camera through the set camera flag.This command can be used for creation or edit of camera view
    objects.  This command can only be executed with one of the add
    bookmark, or remove bookmark and one of set camera, or the set
    view flags set.
    Args:
        addBookmark (bool?): Associate this view with the camera specified or the camera in  
                the active model panel. This flag can be used for creation or  
                edit.  
                Properties: create, edit
        animate (bool?): Set the animation capability for view switches.  
                Properties: create, edit
        bookmarkType (int?): Specify the bookmark type, which can be: 0. 3D bookmark; 1. 2D  
                Pan/Zoom bookmark.  
                Properties: create
        camera (str?): Specify the camera to use. This flag should be used in  
                conjunction with the add bookmark, remove bookmark, set  
                camera, or set view flags. If this flag is not specified the  
                camera in the active model panel will be used.  
                Properties: edit
        name (str?): Set the name of the view. This flag can only be used for  
                creation.  
                Properties: create
        removeBookmark (bool?): Remove the association of this view with the camera specified  
                or the camera in the active model panel. This can only be used  
                with edit.  
                Properties: edit
        setCamera (bool?): Set this view into a camera specified by the camera flag or the  
                camera in the active model panel. This flag can only be used  
                with edit.  
                Properties: edit
        setView (bool?): Set the camera view to match a camera specified or the active  
                model panel. This flag can only be used with edit.  
                Properties: edit

    Returns:
        str: (name of the camera view)

    Example:
    """

def canCreateCaddyManip(*args: Any) -> bool:
    """This command returns true if there can be a manipulator made for
    the specified selection, false otherwise.
    Returns:
        bool: The queried value

    Example:
    """

def canCreateManip(*args: str) -> bool:
    """This command returns true if there can be a manipulator made for
    the specified selection, false otherwise.
    Returns:
        bool: Command result

    Example:
    """

def canvas(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hsvValue: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., pressCommand: Callable[..., Any] = ..., preventOverride: bool = ..., rgbValue: Queryable[Tuple[float, float, float]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Creates a control capable of displaying a color swatch. This control can
    also accept a command to be called when the colour swatch is pressed by
    the user.Note: The -dgc/dragCallback and -dpc/dropCallback are not available
    for this control.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hsvValue (Queryable[Tuple[float, float, float]]?): Three float values corresponding to the hue, saturation, and  
                value color components, where the hue value ranges from 0.0 to 360.0  
                and the saturation and value components range from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        pressCommand (Callable[..., Any]?): Command to be executed when there is a mouse press.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rgbValue (Queryable[Tuple[float, float, float]]?): Three float values corresponding to the red, green, and blue  
                color components, all of which range from 0.0 to 1.0.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the canvas.

    Example:
    """

def changeSubdivComponentDisplayLevel(*args: Any, query: bool = ..., level: Queryable[int] = ..., relative: bool = ...) -> Union[int, bool]:
    """Explicitly forces the subdivision surface to display components at a
    particular level of refinement.subdivision, surface, display, level, fine, coarse, level
    Args:
        level (Queryable[int]?): Specifies the display level of components.  
                Properties: create, query
        relative (bool?): If set, level refers to the relative display level  
                Properties: create, query

    Returns:
        int: Command result

    Example:
    """

def changeSubdivRegion(*args: Any, action: int = ..., level: int = ...) -> bool:
    """Changes a subdivision surface region based on the command parameters.
    The command operates on the selected subdivision surfaces.subdivision, surface, select, region
    Args:
        action (int?): Specifies the action to the selection region  
                     1 = delete selection region  
                     2 = enlarge selection region  
                Properties: create
        level (int?): Specify the level of the subdivision surface to perform the operation  
                Properties: create

    Returns:
        bool: Command result

    Example:
    """

def channelBox(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., attrBgColor: Queryable[Tuple[float, float, float]] = ..., attrColor: Queryable[Tuple[float, float, float]] = ..., attrFilter: Queryable[str] = ..., attrRegex: Queryable[str] = ..., attributeEditorMode: bool = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., containerAtTop: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enableLabelSelection: bool = ..., execute: Tuple[str, bool] = ..., exists: bool = ..., fieldWidth: Queryable[int] = ..., fixedAttrList: Queryable[List[str]] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., historyObjectList: bool = ..., hyperbolic: bool = ..., inputs: bool = ..., isObscured: bool = ..., labelWidth: Queryable[int] = ..., longNames: bool = ..., mainListConnection: Queryable[str] = ..., mainObjectList: bool = ..., manage: bool = ..., maxHeight: Queryable[int] = ..., maxWidth: Queryable[int] = ..., niceNames: bool = ..., noBackground: bool = ..., nodeRegex: Queryable[str] = ..., numberOfPopupMenus: bool = ..., outputObjectList: bool = ..., outputs: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: Queryable[int] = ..., preventOverride: bool = ..., rebuildCommand: Queryable[Callable[..., Any]] = ..., select: Multiuse[str] = ..., selectedHistoryAttributes: bool = ..., selectedMainAttributes: bool = ..., selectedOutputAttributes: bool = ..., selectedShapeAttributes: bool = ..., shapeObjectList: bool = ..., shapes: bool = ..., showNamespace: bool = ..., showTransforms: bool = ..., speed: Queryable[float] = ..., statusBarMessage: str = ..., takeFocus: bool = ..., ufeFixedAttrList: Queryable[Tuple[str, List[str]]] = ..., update: bool = ..., useManips: Queryable[str] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, List[str], Callable[..., Any], float, Tuple[str, List[str]]]:
    """This command creates a channel box, which is sensitive to the active
    list.  It displays certain attributes (channels) of the last node on
    the active list, and provides a two-way connection to keep the widget
    up to date.Note: when setting the color of attribute names, that color is only valid
    for its current Maya session; each subsequent session will display the default
    color for the attribute name(s) listed in the Channel Box. Any subsequent
    attributes that are added to the Channel Box will be affected by prior
    regular expressions in their current Maya session.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attrBgColor (Queryable[Tuple[float, float, float]]?): Controls the background text color of specific attribute names. As with the foreground  
                option, this text coloring also depends on the node name choice for the nodeRegex flag.  
                Arguments correspond to the red, green, and blue color components.  
                Each component ranges in value from 0.0 to 1.0. If attrRegex is  
                unspecified then it will assume a value of "*" for a regular expression.  
                The same idea simultaneously applies to the flag nodeRegex.  
                Note: nodes that are renamed will have their node name coloring be affected  
                in the channel box.  
                Properties: create, query, edit
        attrColor (Queryable[Tuple[float, float, float]]?): Controls the foreground text color of specific attribute names. This  
                text coloring also depends on the node name choice for the nodeRegex flag.  
                Arguments correspond to the red, green, and blue color components.  
                Each component ranges in value from 0.0 to 1.0. If attrRegex is  
                unspecified then it will assume a value of "*" for a regular expression.  
                The same idea simultaneously applies to the flag nodeRegex.  
                Note: nodes that are renamed will have their node name coloring be affected  
                in the channel box.  
                Properties: create, query, edit
        attrFilter (Queryable[str]?): Specifies the name of an itemFilter object to be placed on the channel box.  
                This filters the attributes displayed. A filter of "0" can be used to reset the  
                filter.  
                Properties: query, edit
        attrRegex (Queryable[str]?): Specifies a valid regular expression to specify which attribute names  
                should be selected for foreground text coloring. If attrRegex is  
                unspecified then it will assume a value of "*" for a regular expression.  
                The same idea simultaneously applies to the flag nodeRegex.  
                The attrColor flag is required to be specified.  
                Note: this regular expression will be treated as though it were case-insensitve  
                Properties: create, query, edit
        attributeEditorMode (bool?): Modifies what appears in the channel box for use in the  
                attribute editor. Default is false. Queried, returns a boolean.  
                Properties: query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        containerAtTop (bool?): This flag can be used to specify whether or not the container is drawn at the  
                top of the channel box when a node in the container is selected.  
                Properties: query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enableLabelSelection (bool?): Enables the selection of attributes in the channelBox  
                when used in conjunction with -attributeEditorMode.  
                Default is false.  Queried, returns a boolean.  
                Properties: query, edit
        execute (Tuple[str, bool]?): Immediately executes the command string once for every cell (or every  
                selected cell, if the boolean argument is TRUE) in the  
                channel box, for every matching selected object (ie, for every object would  
                be affected if you changed a cell value.)  Before the command is executed,  
                "#A" is substituted with the name of the attribute, and "#N" with the name  
                of the node, and "#P" with the full path name of the node.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fieldWidth (Queryable[int]?): An optional flag which is used to modify the width assigned  
                to fields appearing in the channelBox.  
                Properties: query, edit
        fixedAttrList (Queryable[List[str]]?): Forces the channel box to only display attributes with the  
                specified names, in the order they are specified.  If an empty  
                list is specified, then the channel box will revert to its default  
                behaviour of listing all keyable attributes.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        historyObjectList (bool?): Returns a list of strings, the names of every INPUT node associated with  
                an object on the main object list that is of the same type as the node  
                displayed in the INPUT section of the channel box.  
                Properties: query
        hyperbolic (bool?): Determines whether or not the distance that the mouse has been dragged  
                should be interpreted as a linear or hyperbolic function.  The default  
                is set to hyperbolic being false.  
                Properties: create, query, edit
        inputs (bool?): Returns the items shown under the 'INPUTS' heading in the channel box.  
                Properties: query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        labelWidth (Queryable[int]?): An optional flag which is used to modify the width assigned  
                to labels appearing in the channelBox.  
                Properties: query, edit
        longNames (bool?): Controls whether long or short attribute names will be used  
                in the interface.  Note that this flag is ignored if the -niceNames  
                flag is set.  Default is short names. Queried, returns a boolean.  
                Properties: query, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object which the  
                editor will use as its source of content.  The channel box will  
                only display the (last) item contained in the selectionConnection object.  
                If a NULL string ("") is specified, then the channel box will revert  
                to its default behaviour of working on the active list.  
                Properties: create, query, edit
        mainObjectList (bool?): Returns a list of strings, the names of every object on the active  
                list that is the same type as the object displayed in the top (main)  
                section of the channel box.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxHeight (Queryable[int]?): An optional flag which is used to limit the height of the  
                channelBox.  
                Properties: query, edit
        maxWidth (Queryable[int]?): An optional flag which is used to limit the width of the  
                channelBox.  
                Properties: query, edit
        niceNames (bool?): Controls whether the attribute names will be displayed in  
                a more user-friendly, readable way.  When this is on, the longNames  
                flag is ignored.  When this is off, attribute names will be displayed  
                either long or short, according to the longNames flag.  
                Default is on. Queried, returns a boolean.  
                Properties: query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        nodeRegex (Queryable[str]?): Specifies a valid regular expression to specify which node names should  
                (potentially) have their attributes selected for foreground text coloring.  
                If nodeRegex is unspecified then it will assume a value of "*' for a  
                regular expression. The same idea simultaneously applies to the flag  
                attrRegex. The attrColor flag is required to be specified.  
                Note: this regular expression will be treated as though it were case-insensitve  
                Note: nodes in namespaces have regular expressions applied as though those  
                nodes weren't in namespaces  
                Properties: create, query, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        outputObjectList (bool?): Returns a list of strings, the names of every OUTPUT node associated  
                an object on the main object list that is of the same type as the node  
                displayed in the OUTPUT section of the channel box.  
                Properties: query
        outputs (bool?): Returns the items shown under the 'OUTPUTS' heading in the channel box.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (Queryable[int]?): Controls the number of digits to the right of the decimal  
                point that will be displayed for float-valued channels.  
                Default is 3.  Queried, returns an int.  
                Properties: query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rebuildCommand (Queryable[Callable[..., Any]]?): Command that gets executed when the channel box is rebuilt, e.g. when a new  
                object is selected.  
                Properties: create, query, edit
        select (Multiuse[str]?): Allows programmatic selection of items (nodes or plugs) in the channel box.  
                Selection is equivalent to clicking the item with the mouse; therefore  
                only items currently shown in the channel box can be selected this way.  
                Properties: edit, multiuse
        selectedHistoryAttributes (bool?): Returns a list of strings, the names of all the selected attributes  
                in the INPUT section of the channel box.  
                Properties: query
        selectedMainAttributes (bool?): Returns a list of strings, the names of all the selected attributes in the  
                top section of the channel box.  
                Properties: query
        selectedOutputAttributes (bool?): Returns a list of strings, the names of all the selected attributes  
                in the OUTPUT section of the channel box.  
                Properties: query
        selectedShapeAttributes (bool?): Returns a list of strings, the names of all the selected attributes  
                in the middle (shape) section of the channel box.  
                Properties: query
        shapeObjectList (bool?): Returns a list of strings, the names of every shape associated with  
                an object on the main object list that is of the same type as the object  
                displayed in the middle (shape) section of the channel box.  
                Properties: query
        shapes (bool?): Returns the items shown under the 'SHAPES' heading in the channel box.  
                Properties: query
        showNamespace (bool?): Controls whether or not the namespace of an object is displayed  
                if the object is not in the root namespace.  
                Properties: create, query, edit
        showTransforms (bool?): Controls whether this control will display transform attributes  
                only, or all other attributes. False by default. Queried, returns a  
                boolean.  
                Properties: query, edit
        speed (Queryable[float]?): Controls the speed at which the attributes are changed based on the  
                distance the mouse has been dragged.  Common settings for  
                slow/medium/fast are 0.1/1.0/10.0 respectively.  The default is 1.0.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        takeFocus (bool?): causes the channel box to take over the keyboard focus, if it can.  
                Properties: edit
        ufeFixedAttrList (Queryable[Tuple[str, List[str]]]?): Forces the channel box to only display attributes for the given  
                UFE runtime with the specified names, in the order they are specified.  
                The attribute list accepts wildcard ('?' for one char, '*' for many) and  
                will use pattern matching for finding attributes to display.  
                If an empty list is specified, then the channel box will display no  
                attributes for the given UFE runtime (since there is no keyable  
                attribute concept in UFE).  
                      In query mode, this flag can accept a value.  
                Properties: create, query, edit
        update (bool?): This flag can be used to force an update of the channel box display, for  
                example after changing a display preference.  
                Properties: edit
        useManips (Queryable[str]?): When you click on a field or label in the channel box, the  
                tool switches to a manipulator that can change that value if you  
                drag in the 3d view.  This flag controls the kind of manips.  Allowed  
                values are "none" (self-explanatory), "invisible" (you won't see anything,  
                but dragging in the window will adjust any of the selected attributes),  
                and "standard" (the same as invisible, except for scale, rotate, and  
                translate, which will be represented by their usual manips.)  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: (the name of the new channel box)

    Example:
    """

def character(*args: str, edit: bool = ..., query: bool = ..., addElement: str = ..., addOffsetObject: Queryable[str] = ..., anyMember: str = ..., characterPlug: bool = ..., clear: str = ..., empty: bool = ..., excludeDynamic: bool = ..., excludeRotate: bool = ..., excludeScale: bool = ..., excludeTranslate: bool = ..., excludeVisibility: bool = ..., flatten: str = ..., forceElement: str = ..., include: str = ..., intersection: Queryable[str] = ..., isIntersecting: Queryable[str] = ..., isMember: Queryable[str] = ..., library: bool = ..., memberIndex: Queryable[int] = ..., name: str = ..., noWarnings: bool = ..., nodesOnly: bool = ..., offsetNode: bool = ..., remove: str = ..., removeOffsetObject: str = ..., root: str = ..., scheduler: bool = ..., split: str = ..., subtract: Queryable[str] = ..., text: Queryable[str] = ..., union: Queryable[str] = ..., userAlias: Queryable[str] = ...) -> Union[str, List[str], bool, int]:
    """This command is used to manage the membership of a character.  Characters
    are a type of set that gathers together the attributes of a node or nodes
    that a user wishes to animate as a single entity.
    Args:
        addElement (str?): Adds the list of items to the given character.  If some of the  
                items cannot be added to the character because they are in another  
                character, the command will fail.  When another character is passed to  
                to -addElement, is is added as a sub character.  When a node is  
                passed in, it is expanded into its keyable attributes, which are  
                then added to the character.  
                Properties: edit
        addOffsetObject (Queryable[str]?): Indicates that the selected character member objects should be used when  
                calculating and applying offsets. The flag argument is used to specify the  
                character.  
                Properties: query, edit
        anyMember (str?): An operation which tests whether any of the given items  
                are members of the given set.  
                Properties: create
        characterPlug (bool?): Returns the plug on the character that corresponds to the  
                specified character member.  
                Properties: query
        clear (str?): An operation which removes all items from the given character.  
                Properties: edit
        empty (bool?): Indicates that the character to be created should be empty. (i.e.  
                it ignores any arguments identifying objects to be added to  
                the character.  
                Properties: create
        excludeDynamic (bool?): When creating the character, exclude dynamic attributes.  
                Properties: create
        excludeRotate (bool?): When creating the character, exclude rotate attributes from  
                transform-type nodes.  
                Properties: create
        excludeScale (bool?): When creating the character, exclude scale attributes from  
                transform-type nodes.  
                Properties: create
        excludeTranslate (bool?): When creating the character, exclude translate attributes from  
                transform-type nodes. For example, if your character contains  
                joints only, perhaps you only want to include rotations in the  
                character.  
                Properties: create
        excludeVisibility (bool?): When creating the character, exclude visibility attribute from  
                transform-type nodes.  
                Properties: create
        flatten (str?): An operation that flattens the structure of the given character. That is,  
                any characters contained by the given character will be replaced by its  
                members so that the character no longer contains other characters but contains  
                the other characters' members.  
                Properties: edit
        forceElement (str?): For use in edit mode only. Forces addition of the items  
                to the character. If the items are in another character which  
                is in the character partition, the items will be removed  
                from the other character in order to keep the characters in the  
                character partition mutually exclusive with respect to membership.  
                Properties: edit
        include (str?): Adds the list of items to the given character.  If some of the  
                items cannot be added to the character, a warning will be issued.  
                This is a less strict version of the -add/addElement operation.  
                Properties: edit
        intersection (Queryable[str]?): An operation that returns a list of items which are members of  
                all the character in the list.  In general, characters should be  
                mutually exclusive.  
                Properties: query
        isIntersecting (Queryable[str]?): An operation which tests whether or not the characters in the list have  
                common members.  In general, characters should be mutually exclusive, so  
                this should always return false.  
                Properties: query
        isMember (Queryable[str]?): An operation which tests whether or not all the given items  
                are members of the given character.  
                Properties: query
        library (bool?): Returns the clip library associated with this character, if there is one. A clip library will only exist if you have created clips on your character.  
                Properties: query
        memberIndex (Queryable[int]?): Returns the memberIndex of the specified character member if used after the query flag. Or if used before the query flag, returns the member that corresponds to the specified index.  
                Properties: query
        name (str?): Assigns string as the name for a new character. Valid for operations that  
                create a new character.  
                Properties: create
        noWarnings (bool?): Indicates that warning messages should not be reported such  
                as when trying to add an invalid item to a character. (used by UI)  
                Properties: create
        nodesOnly (bool?): This flag modifies the results of character membership queries.  
                When listing the attributes (e.g. sphere1.tx) contained in the  
                character, list only the nodes.  Each node will only be listed  
                once, even if more than one attribute or component of the node  
                exists in the character.  
                Properties: query
        offsetNode (bool?): Returns the name of the characterOffset node used to add offsets to the root of the character.  
                Properties: query
        remove (str?): Removes the list of items from the given character.  
                Properties: edit
        removeOffsetObject (str?): Indicates that the selected character offset objects should be removed  
                as offsets. The flag argument is used to specify the character.  
                Properties: edit
        root (str?): Specifies the transform node which will act as the root of the character being created.  
                This creates a characterOffset node in addition to the character node, which can be used to add offsets  
                to the character to change the direction of the character's animtion without inserting additional nodes  
                in its hierarchy.  
                Properties: create
        scheduler (bool?): Returns the scheduler associated with this character, if there is one. A scheduler will only exist if you have created clips on your character.  
                Properties: query
        split (str?): Produces a new set with the list of items and removes  
                each item in the list of items from the given set.  
                Properties: create
        subtract (Queryable[str]?): An operation between two characters which returns the members of the  
                first character that are not in the second character. In general,  
                characters should be mutually exclusive.  
                Properties: query
        text (Queryable[str]?): Defines an annotation string to be stored with the character.  
                Properties: create, query, edit
        union (Queryable[str]?): An operation that returns a list of all the members of all characters  
                listed.  
                Properties: query
        userAlias (Queryable[str]?): Returns the user defined alias for the given attribute on  
                the character or and empty string if there is not one.  Characters  
                automatically alias the attributes where character animation data  
                is stored.  A user alias will exist when the automatic aliases are  
                overridden using the aliasAttr command.  
                Properties: query

    Returns:
        str: For creation operations (name of the character that was created or edited)
        List[str]: For query operation (names of items in the character)
        bool: For isMember operation

    Example:
    """

def characterMap(*args: str, edit: bool = ..., query: bool = ..., mapAttr: Queryable[Tuple[str, str]] = ..., mapMethod: str = ..., mapNode: Queryable[Tuple[str, str]] = ..., mapping: Queryable[str] = ..., proposedMapping: bool = ..., unmapAttr: Tuple[str, str] = ..., unmapNode: Tuple[str, str] = ...) -> Union[str, Tuple[str, str], bool]:
    """This command is used to create a correlation between the attributes of 2 or more characters.character, clip, animation
    Args:
        mapAttr (Queryable[Tuple[str, str]]?): In query mode, this flag can be used to query the mapping stored by the specified map node. It returns an array of strings.  
                In non-query mode, this flag can be used to create a mapping between the specified character members. Any previous mapping on the attributes is removed in favor of the newly specified mapping.  
                Properties: create, query, edit
        mapMethod (str?): This is is valid in create mode only. It specifies how the mapping should be done. Valid options are: "byNodeName", "byAttrName", and "byAttrOrder". "byAttrOrder" is the default. The flags mean the following: "byAttrOrder" maps using the order that the character stores the attributes internally, "byAttrName" uses the attribute name to find a correspondence, "byNodeName" uses the node name *and* the attribute name to find a correspondence.  
                Properties: create
        mapNode (Queryable[Tuple[str, str]]?): This flag can be used to map all the attributes on the source node to their matching attributes on the destination node.  
                Properties: create, query
        mapping (Queryable[str]?): This flag is valid in query mode only. It must be used before the query flag with a string argument. It is used for querying the mapping for a particular attribute.  A string array is returned.  
                Properties: query
        proposedMapping (bool?): This flag is valid in query mode only. It is used to get an array of the mapping that the character map would prvide if called with the specified characters and the (optional) specified mappingMethod. If a character map exists on the characters, the map is not affected by the query operation.  A string array is returned.  
                Properties: query
        unmapAttr (Tuple[str, str]?): This flag can be used to unmap the mapping stored by the specified map node.  
                Properties: create, edit
        unmapNode (Tuple[str, str]?): This flag can be used to unmap all the attributes on the source node to their matching attributes on the destination node. Note that mapped attributes which do not have matching names, will not be unmapped.  
                Properties: create

    Returns:
        str: characterMap name

    Example:
    """

def characterize(*args: str, edit: bool = ..., query: bool = ..., activatePivot: bool = ..., addAuxEffector: bool = ..., addFloorContactPlane: bool = ..., addMissingEffectors: bool = ..., attributeFromHIKProperty: Queryable[str] = ..., attributeFromHIKPropertyMode: Queryable[str] = ..., autoActivateBodyPart: bool = ..., changePivotPlacement: bool = ..., effectors: str = ..., fkSkeleton: str = ..., name: str = ..., pinHandFeet: bool = ..., placeNewPivot: bool = ..., posture: str = ..., sourceSkeleton: str = ..., stancePose: Queryable[str] = ..., type: str = ...) -> Union[str, bool]:
    """This command is used to scan a joint hierarchy for predefined joint names or
    labels. If the required joints are found, human IK effectors will be created
    to control the skeleton using full-body IK.
    Alternatively, you can manually create all of the components
    required for fullbody IK, and use this command to hook them up.
    Fullbody IK needs 3 major components: the
    user input skeleton (sk), the fk skeleton on which keys are set (fk) and the
    hik effectors (ik).  Together fk and ik provide parameters to the fullbody IK
    engine, which solves for the output and plots it onto sk. This command usage
    is used internally by Maya when importing data from fbx files, but is not generally recommended.Note that a minimum set of required joint names or joint labels  must be
    found in order for the characterize command to succeed. Please refer to the
    Maya documentation for details on properly naming or labeling your skeleton.
    The skeleton should also be z-facing, with its y-axis up, its
    left hand parallel to positive x-axis and right hand parallel to
    negative x-axis.
    END_COMMENTcharacterize, effectors, fullbody, IK
    Args:
        activatePivot (bool?): Activates a pivot that has been properly placed.  After activating this new  
                pivot, you will now be able to rotate and translate about this pivot.  
                A pivot behaves in all ways the same as an effector (it IS an  
                effector, except that it is offset from the normal position of the effector  
                to allow one to rotate about a different point.  
                Properties: edit
        addAuxEffector (bool?): Adds an auxilliary (secondary) effector to an existing effector.  
                Properties: edit
        addFloorContactPlane (bool?): Adds a floor contact plane to one of the hands or feet.  With this plane,  
                you will be able to adjust the floor contact height.  Select a hand or foot  
                effector and then issue the characterize command with this flag.  
                Properties: edit
        addMissingEffectors (bool?): This flag tells the  
                characterize command to look for any effectors that can be added to the  
                skeleton. For example, if the user has deleted some effectors or added fingers  
                to an existing skeleton, "characterize -e -addMissingEffectors" can be used to  
                restore them.  
                Properties: edit
        attributeFromHIKProperty (Queryable[str]?): Query for the attribute name associated with a MotionBuilder property.  
                Properties: query
        attributeFromHIKPropertyMode (Queryable[str]?): Query for the attribute name associated with a MotionBuilder property mode.  
                Properties: query
        autoActivateBodyPart (bool?): Query or change whether auto activation of character nodes representing body parts  
                should be enabled.  
                Properties: query, edit
        changePivotPlacement (bool?): Reverts a pivot back into pivot placement mode.  A pivot that is in placement  
                mode will not participate in full body manipulation until it has been activated  
                with the -activatePivot flag.  
                Properties: edit
        effectors (str?): Specify the effectors to be used by human IK by providing  
                2 pieces of information for each effector:  1) the partial path of the  
                effector and 2) the name of the full body effector this represents.  1) and  
                2) are to be separated by white space, and multiple entries separated by ",".  
                Normally, the effectors are automatically created.  This flag is  
                for advanced users only.  
                Properties: create
        fkSkeleton (str?): Specify the fk skeleton to be used by human IK by providing 2 pieces of  
                information for each joint of the FK skeleton:  1) the partial path of the  
                joint and 2) the name of the full body joint this represents.  1) and 2) are  
                to be separated by white space, and multiple entries separated by ",".  
                Normally, the fk control skeleton is automatically created.  This  
                flag is for advanced users only.  
                Properties: create, edit
        name (str?): At characterization (FBIK creation) time, use this flag to name your FBIK character.  
                This will affect the name of the hikHandle node and the control rig will be put  
                into a namespace that matches the name of your character.  If you do not specify  
                the character name, a default one will be used.  
                At the moment edit and query of the character name is not supported.  
                Properties: create
        pinHandFeet (bool?): When the character is first being characterized, pin the hands and feet by default.  
                Properties: create
        placeNewPivot (bool?): Creates a new pivot and puts it into placement mode.  Note that you will  
                not be able to do full body manipulation about this pivot until you have  
                activated it with the -activatePivot flag. A pivot behaves in all ways the  
                same as an effector (it IS an effector, except that it is offset from the  
                normal position of the effector to allow one to rotate about a different  
                point). A new pivot created with this flag allow you to adjust the offset  
                interactively before activating it.  
                Properties: edit
        posture (str?): Specifies the posture of the character. Valid options are "biped" and  
                "quadruped". The default is "biped".  
                Properties: create
        sourceSkeleton (str?): This flag can be used to characterize a skeleton that has not been named or  
                labelled according to the FBIK guidelines. It specifies the association  
                between the actual joint names and the expected FBIK joint names. The format  
                of the string is as follows: For each  
                joint that the user wants to involve in the solve:  1) the partial path of  
                the joint and 2) the name of the full body joint this represents.  1) and 2)  
                are to be separated by white space, and multiple entries separated by ",".  
                Properties: create, edit
        stancePose (Queryable[str]?): Specify the default stance pose to be used by human IK.  The stance pose is  
                specified by providing 2 pieces of information for each joint involved in  
                the solve:  
                1) the partial path to the joint and 2) 9 numbers representing translation  
                rotation and scale.  
                1) and 2) are to be separated by white space, and multiple entries separated  
                by ",".  
                Normally, the stance pose is taken from the selected skeleton.  This flag is  
                for advanced users only.  
                Properties: create, query
        type (str?): Specifies the technique used by the characterization to identify the joint  
                type. Valid options are "label" and "name". When "label" is used, the joints  
                must be labelled using the guidelines described in the Maya documentation.  
                When name is used, the joint names must follow the naming conventions  
                described in the Maya documentation. The default is "name". This flag  
                cannot be used in conjunction with the sourceSkeleton flag.  
                Properties: create

    Returns:
        str: Names of full body IK effectors that were created.

    Example:
    """

def checkBox(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., offCommand: Queryable[Callable[..., Any]] = ..., onCommand: Queryable[Callable[..., Any]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., recomputeSize: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., value: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int]:
    """This command creates a check box.  A check box is a simple control
    containing a text label and a state of either on or off.  Commands
    can be attached to any or all of the following events:  when the
    check box is turned on, turned off, or simply when it's state is
    changed.
    Args:
        align (Queryable[str]?): This flag is obsolete and should no longer be used.  
                The check box label will always be left-aligned.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Queryable[Callable[..., Any]]?): Command executed when the check box's state is changed.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of the check box from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the check box.  By default, this flag is  
                set to true and the check box value may be changed by clicking on  
                it.  If false then the check box is 'read only' and can not be  
                clicked on. The value of the check box can always be changed with  
                the -v/value flag regardless of the state of  
                the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text. The default label is the name of  
                the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Queryable[Callable[..., Any]]?): Command executed when the check box is turned off.  
                Properties: create, query, edit
        onCommand (Queryable[Callable[..., Any]]?): Command executed when the check box is turned on.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        recomputeSize (bool?): If true then the control will recompute it's size to  
                just fit the size of the label.  If false then the control size  
                will remain fixed as you change the size of the label.  The  
                default value of this flag is true.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (bool?): State of the check box.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def checkBoxGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., changeCommand1: Callable[..., Any] = ..., changeCommand2: Callable[..., Any] = ..., changeCommand3: Callable[..., Any] = ..., changeCommand4: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enable1: bool = ..., enable2: bool = ..., enable3: bool = ..., enable4: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., label1: Queryable[str] = ..., label2: Queryable[str] = ..., label3: Queryable[str] = ..., label4: Queryable[str] = ..., labelArray2: Queryable[Tuple[str, str]] = ..., labelArray3: Queryable[Tuple[str, str, str]] = ..., labelArray4: Queryable[Tuple[str, str, str, str]] = ..., manage: bool = ..., noBackground: bool = ..., numberOfCheckBoxes: int = ..., numberOfPopupMenus: bool = ..., offCommand: Callable[..., Any] = ..., offCommand1: Callable[..., Any] = ..., offCommand2: Callable[..., Any] = ..., offCommand3: Callable[..., Any] = ..., offCommand4: Callable[..., Any] = ..., onCommand: Callable[..., Any] = ..., onCommand1: Callable[..., Any] = ..., onCommand2: Callable[..., Any] = ..., onCommand3: Callable[..., Any] = ..., onCommand4: Callable[..., Any] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., value1: bool = ..., value2: bool = ..., value3: bool = ..., value4: bool = ..., valueArray2: Queryable[Tuple[bool, bool]] = ..., valueArray3: Queryable[Tuple[bool, bool, bool]] = ..., valueArray4: Queryable[Tuple[bool, bool, bool, bool]] = ..., vertical: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Tuple[str, str], Tuple[str, str, str], Tuple[str, str, str, str], Tuple[bool, bool], Tuple[bool, bool, bool], Tuple[bool, bool, bool, bool], Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates from one to four check boxes in a single row.
    They can have an optional text label.TelfBaseGrpCmd.cpp
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the group changes state.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of a check box from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, edit
        changeCommand1 (Callable[..., Any]?):   
                Properties: create, edit
        changeCommand2 (Callable[..., Any]?):   
                Properties: create, edit
        changeCommand3 (Callable[..., Any]?):   
                Properties: create, edit
        changeCommand4 (Callable[..., Any]?): Specify a changed state command for each respective check  
                box.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the group.  By default, this flag  
                is set to true and the check box values may be changed by  
                clicking on them.  If false then the check boxes are 'read only'  
                and can not be clicked on. The value of the check boxes can  
                always be changed with the -v/value flags regardless of  
                the state of the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enable1 (bool?):   
                Properties: create, query, edit
        enable2 (bool?):   
                Properties: create, query, edit
        enable3 (bool?):   
                Properties: create, query, edit
        enable4 (bool?): Enable state of the individual check boxes.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): When present on creation an optional text label will be  
                built with the group.  The string specifes the label text.  
                Properties: create, query, edit
        label1 (Queryable[str]?):   
                Properties: create, query, edit
        label2 (Queryable[str]?):   
                Properties: create, query, edit
        label3 (Queryable[str]?):   
                Properties: create, query, edit
        label4 (Queryable[str]?): Specify label strings for the respective check boxes in  
                the group.  
                Properties: create, query, edit
        labelArray2 (Queryable[Tuple[str, str]]?):   
                Properties: create, query, edit
        labelArray3 (Queryable[Tuple[str, str, str]]?):   
                Properties: create, query, edit
        labelArray4 (Queryable[Tuple[str, str, str, str]]?): Specify multiple labels in a single flag.  These flags  
                are ignored if the number of radio buttons doesn't match.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfCheckBoxes (int?): Number of check boxes in the group (1. 4).  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Callable[..., Any]?): Command executed when any check box turns off.  
                Properties: create, edit
        offCommand1 (Callable[..., Any]?):   
                Properties: create, edit
        offCommand2 (Callable[..., Any]?):   
                Properties: create, edit
        offCommand3 (Callable[..., Any]?):   
                Properties: create, edit
        offCommand4 (Callable[..., Any]?): Off command for each respective check box.  
                Properties: create, edit
        onCommand (Callable[..., Any]?): Command executed when any check box turns on.  
                Properties: create, edit
        onCommand1 (Callable[..., Any]?):   
                Properties: create, edit
        onCommand2 (Callable[..., Any]?):   
                Properties: create, edit
        onCommand3 (Callable[..., Any]?):   
                Properties: create, edit
        onCommand4 (Callable[..., Any]?): On command for each respective check box.  
                Properties: create, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value1 (bool?):   
                Properties: create, query, edit
        value2 (bool?):   
                Properties: create, query, edit
        value3 (bool?):   
                Properties: create, query, edit
        value4 (bool?): Values for the respective check boxes in the group.  
                Properties: create, query, edit
        valueArray2 (Queryable[Tuple[bool, bool]]?):   
                Properties: create, query, edit
        valueArray3 (Queryable[Tuple[bool, bool, bool]]?):   
                Properties: create, query, edit
        valueArray4 (Queryable[Tuple[bool, bool, bool, bool]]?): Specifies multiple values in a single flag.  These flags  
                are ignored if the number of check boxes doesn't match.  
                Properties: create, query, edit
        vertical (bool?): Whether the orientation of the checkbox controls in this group  
                are horizontal (default) or vertical.  
                Properties: create, query
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def checkDefaultRenderGlobals(arg0: str = ..., /) -> bool:
    """To query whether or not the defaultRenderGlobals node has been modified since the last file save, use `ls -modified`. To force the scene to be dirty/clean use `file -modified`checkDefaultRenderGlobals, registration
    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def choice(*args: str, edit: bool = ..., query: bool = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., index: Queryable[int] = ..., name: Queryable[str] = ..., selector: Queryable[str] = ..., shape: bool = ..., sourceAttribute: str = ..., time: Multiuse[int] = ...) -> Union[List[str], int, str]:
    """The choice command provides a mechanism for changing the inputs
    to an attribute based on some (usually time-based) criteria.
    For example, an object could be animated from
    frames 1 to 30 by a motion path, then from frames 30 to 50 it
    follows keyframe animation, and after frame 50 it returns to
    the motion path. Or, a revolve surface could change its input
    curve depending on some transform's rotation value.The choice command creates a choice node (if one does not already
    exist) on all specified attributes of the selected objects.
    If the attribute was already connected to something, that something
    is now reconnected to the i'th index of the choice node's input (or
    the next available input if the -in/index flag is not specified).
    If a source attribute is specified, then that attribute is connected
    to the choice node's i'th input instead.The choice node operates by using the value of its selector attribute
    to determine which of its input attributes to pass through to its output.
    The input attributes can be of any type. For example, if the selector
    attribute was connected by an animation curve with keyframes at
    (1,1), (30,2) and (50,1), then that would mean that the choice node
    would pass on the data from input[1] from time 1 to 30, and after time 50,
    and the data from input[2] between times 30 and 50.This command returns the names of the created or modified choice nodes,
    and if a keyframe was added to the animation curve, it specifies the
    index (or value on the animation curve).
    Args:
        attribute (Multiuse[str]?): specifies the attributes onto which choice node(s) should  
                be created. The default is all keyable attributes of the given  
                objects. Note that although this flag is not queryable, it can  
                be used to qualify which attributes of the given objects to query.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): Explicitly specify whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  
                Properties: create
        index (Queryable[int]?): specifies the multi-input index of the choice node to connect  
                the source attribute to. When queried, returns a list of integers  
                one per specified -t/time that indicates the multi-index of the  
                choice node to use at that time.  
                Properties: create, query
        name (Queryable[str]?): the name to give to any newly created choice node(s).  
                When queried, returns a list of strings.  
                Properties: create, query
        selector (Queryable[str]?): specifies the attribute to be used as the choice node's  
                selector. The value of the selector at a given time  
                determines which of the choice node's multi-indices should  
                be used as the output of the choice node at that time.  
                This flag is only editable (it cannot be specified  
                at creation time).  
                When queried, returns a list of strings.  
                Properties: create, query
        shape (bool?): Consider all attributes of shapes below transforms as well,  
                except "controlPoints". Default: true  
                Properties: create
        sourceAttribute (str?): specifies the attribute to connect to the choice node  
                that will be selected at the given time(s) specified by -t/time.  
                Properties: create
        time (Multiuse[int]?): specifies the time at which the choice should use the given  
                source attribute, or the currently connected attribute if  
                source attribute is not specified. The default is the curren time.  
                Note that although this flag is not queryable, it can be used  
                to qualify the times at which to query the other attributes.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse

    Returns:
        List[str]: The newly created and/or modified choice nodes, with the attribute
            for which a selector keyframe was created.
            For example: choice1.input[3] choice2.input[3]

    Example:
    """

def circle(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., center: Queryable[Tuple[float, float, float]] = ..., centerX: Queryable[float] = ..., centerY: Queryable[float] = ..., centerZ: Queryable[float] = ..., degree: Queryable[int] = ..., first: Queryable[Tuple[float, float, float]] = ..., firstPointX: Queryable[float] = ..., firstPointY: Queryable[float] = ..., firstPointZ: Queryable[float] = ..., fixCenter: bool = ..., nodeState: Queryable[int] = ..., normal: Queryable[Tuple[float, float, float]] = ..., normalX: Queryable[float] = ..., normalY: Queryable[float] = ..., normalZ: Queryable[float] = ..., radius: Queryable[float] = ..., sections: Queryable[int] = ..., sweep: Queryable[float] = ..., tolerance: Queryable[float] = ..., useTolerance: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, Tuple[float, float, float], float, int]:
    """The circle command creates a circle or partial circle (arc)
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        center (Queryable[Tuple[float, float, float]]?): The center point of the circle.  
                Properties: create, query, edit
        centerX (Queryable[float]?): X of the center point.  
                Default: 0  
                Properties: create, query, edit
        centerY (Queryable[float]?): Y of the center point.  
                Default: 0  
                Properties: create, query, edit
        centerZ (Queryable[float]?): Z of the center point.  
                Default: 0  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting circle:  
                1. linear,  
                3. cubic  
                Default: 3  
                Properties: create, query, edit
        first (Queryable[Tuple[float, float, float]]?): The start point of the circle if fixCenter is false.  
                Determines the orientation of the circle if fixCenter is true.  
                Properties: create, query, edit
        firstPointX (Queryable[float]?): X of the first point.  
                Default: 1  
                Properties: create, query, edit
        firstPointY (Queryable[float]?): Y of the first point.  
                Default: 0  
                Properties: create, query, edit
        firstPointZ (Queryable[float]?): Z of the first point.  
                Default: 0  
                Properties: create, query, edit
        fixCenter (bool?): Fix the center of the circle to the specified center point.  
                Otherwise the circle will start at the specified first point.  
                Default: true  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normal (Queryable[Tuple[float, float, float]]?): The normal of the plane in which the circle will lie.  
                Properties: create, query, edit
        normalX (Queryable[float]?): X of the normal direction.  
                Default: 0  
                Properties: create, query, edit
        normalY (Queryable[float]?): Y of the normal direction.  
                Default: 0  
                Properties: create, query, edit
        normalZ (Queryable[float]?): Z of the normal direction.  
                Default: 1  
                Properties: create, query, edit
        radius (Queryable[float]?): The radius of the circle.  
                Default: 1.0  
                Properties: create, query, edit
        sections (Queryable[int]?): The number of sections determines the resolution of the circle.  
                Used only if useTolerance is false.  
                Default: 8  
                Properties: create, query, edit
        sweep (Queryable[float]?): The sweep angle determines the completeness of the circle.  
                A full circle is 2Pi radians, or 360 degrees.  
                Default: 6.2831853  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to build a circle.  
                Used only if useTolerance is true  
                Default: 0.01  
                Properties: create, query, edit
        useTolerance (bool?): Use the specified tolerance to determine resolution.  
                Otherwise number of sections will be used.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def circularFillet(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., positionTolerance: Queryable[float] = ..., primaryRadius: Queryable[float] = ..., secondaryRadius: Queryable[float] = ..., tangentTolerance: Queryable[float] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, int, float]:
    """The cmd is used to compute the rolling ball surface
    fillet ( circular fillet ) between two given NURBS surfaces.
    To generate trim curves on the surfaces, use -cos true.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        positionTolerance (Queryable[float]?): C(0) Tolerance For Fillet Surface  
                Default: 0.01  
                Properties: create, query, edit
        primaryRadius (Queryable[float]?): primary Radius  
                Default: 1.0  
                Properties: create, query, edit
        secondaryRadius (Queryable[float]?): secondary Radius  
                Default: 1.0  
                Properties: create, query, edit
        tangentTolerance (Queryable[float]?): G(1) Tolerance For Fillet Surface  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name, node name.

    Example:
    """

def clearCache(*args: str, allNodes: bool = ..., computed: bool = ..., dirty: bool = ...) -> int:
    """Even though dependency graph values are computed or dirty they may still
    occupy space temporarily within the nodes.  This command goes in to all of
    the data that can be regenerated if required and removes it from the caches (datablocks), thus clearing up space in memory.dependency, graph, cache, optimize, performance, memory
    Args:
        allNodes (bool?): If toggled then all nodes in the graph are cleared.  Otherwise only those  
                nodes that are selected are cleared.  
                Properties: create
        computed (bool?): If toggled then remove all data that is computable.  (Warning: If the data  
                is requested for redraw then the recompute will immediately fill the data  
                back in.)  
                Properties: create
        dirty (bool?): If toggled then remove all heavy data that is dirty.  
                Properties: create

    Returns:
        int: Number of items removed from caches

    Example:
    """

def clearDynStartState() -> None: ...
def clearNClothStartState() -> None: ...
def clearShear(*args: str) -> None: ...
def clip(*args: str, edit: bool = ..., query: bool = ..., absolute: bool = ..., absoluteRotations: bool = ..., active: Queryable[str] = ..., addTrack: bool = ..., allAbsolute: bool = ..., allClips: bool = ..., allRelative: bool = ..., allSourceClips: bool = ..., animCurveRange: bool = ..., character: bool = ..., constraint: bool = ..., copy: bool = ..., defaultAbsolute: bool = ..., duplicate: bool = ..., endTime: Queryable[int] = ..., expression: bool = ..., ignoreSubcharacters: bool = ..., isolate: bool = ..., leaveOriginal: bool = ..., mapMethod: str = ..., name: Queryable[Multiuse[str]] = ..., newName: str = ..., paste: bool = ..., pasteInstance: bool = ..., remove: bool = ..., removeTrack: bool = ..., rotationOffset: Queryable[Tuple[float, float, float]] = ..., rotationsAbsolute: bool = ..., scheduleClip: bool = ..., sourceClipName: bool = ..., split: int = ..., startTime: Queryable[int] = ..., translationOffset: Queryable[Tuple[float, float, float]] = ..., useChannel: Multiuse[str] = ...) -> Union[List[str], str, bool, int, Multiuse[str], Tuple[float, float, float]]:
    """This command is used to create, edit and query character clips.character, clip, animation
    Args:
        absolute (bool?): This flag is now deprecated.  Use aa/allAbsolute, ar/allRelative, ra/rotationsAbsolute, or da/defaultAbsolute instead.  This flag controls whether the clip follows its keyframe values or whether they are offset by a value to maintain a smooth path. Default is true.  
                Properties: create
        absoluteRotations (bool?): This flag is now deprecated.  Use aa/allAbsolute, ar/allRelative, ra/rotationsAbsolute, or da/defaultAbsolute instead. If true, this overrides the -absolute flag so that rotation channels are always calculated with absolute offsets. This allows you to have absolute offsets on rotations and relative offsets on all other channels.  
                Properties: create
        active (Queryable[str]?): Query or edit the active clip. This flag is not valid in create mode. Making a  
                clip active causes its animCurves to be hooked directly to the character attributes in addition to being attached to the clip library node. This makes it easier to access the animCurves if you want to edit, delete or add additional animCruves to the clip.  
                Properties: query, edit
        addTrack (bool?): This flag is now obsolete. Use the insertTrack flag on the clipSchedule command instead.
        allAbsolute (bool?): Set all channels to be calculated with absolute offsets.  This flag cannot be used in conjunction with the ar/allRelative, ra/rotationsAbsolute or da/defaultAbsolute flags.  
                Properties: create
        allClips (bool?): This flag is used to query all the clips in the scene. Nodes of type "animClip" that are storing poses, are not returned by this command.  
                Properties: query
        allRelative (bool?): Set all channels to be calculated with relative offsets.  This flag cannot be used in conjunction with the aa/allAbsolute, ra/rotationsAbsolute or da/defaultAbsolute flags.  
                Properties: create
        allSourceClips (bool?): This flag is used to query all the source clips in the scene. Nodes of type "animClip" that are storing poses or clip instances, are not returned by this command.  
                Properties: query
        animCurveRange (bool?): This flag can be used at the time you create the clip instead of the startTime and endTime flags. It specifies that you want the range of the clip to span the range of keys in the clips associated animCurves.  
                Properties: create
        character (bool?): This is a query only flag which operates on the specified clip. It returns the names of any characters that a clip is associated with.  
                Properties: query
        constraint (bool?): This creates a clip out of any constraints on the character. The constraint will be moved off of the character and into the clip, so that it is only active for the duration of the clip, and its value can be scaled/offset/cycled according to the clip attributes.  
                Properties: create
        copy (bool?): This flag is used to copy a clip or clips to the clipboard. It should be used in conjunction with the name flag to copy the named clips on the specified character and its subcharacters. In query mode, this flag allows you to query what, if anything, has been copied into the clip clipboard.  
                Properties: create, query
        defaultAbsolute (bool?): Sets all top-level channels except rotations in the clip to relative, and the remaining channels to absolute. This is the default during clip creation if no offset flag is specified.  This flag cannot be used in conjunction with the aa/allAbsolute, ar/allRelative, or ra/rotationsAbsolute flags.  
                Properties: create
        duplicate (bool?): Duplicate the clip specified by the name flag. The start time of the new clip should be specified with the startTime flag.  
                Properties: query
        endTime (Queryable[int]?): Specify the clip end  
                Properties: create, query, edit
        expression (bool?): This creates a clip out of any expressions on the character. The expression will be moved off of the character and into the clip, so that it is only active for the duration of the clip, and its value can be scaled/offset/cycled according to the clip attributes.  
                Properties: create
        ignoreSubcharacters (bool?): During clip creation, duplication and isolation, subcharacters are included by default. If you want to create a clip on the top level character only, or you want to duplicate the clip on the top level character without including subCharacters, use the ignoreSubcharacters flag.  
                Properties: create
        isolate (bool?): This flag should be used in conjunction with the name flag to specify that a clip or clips should be copied to a new clip library. The most common use of this flag is for export, when you want to only export certain clips from the character, without exporting all of the clips.  
                Properties: create
        leaveOriginal (bool?): This flag is used when creating a clip to specify that the animation curves should be copied to the clip library, and left on the character.  
                Properties: create
        mapMethod (str?): This is is valid with the paste and pasteInstance flags only. It specifies how the mapping should be done. Valid options are: "byNodeName", "byAttrName", "byCharacterMap", "byAttrOrder", "byMapOrAttrName" and "byMapOrNodeName". "byAttrName" is the default. The flags mean the following: "byAttrOrder" maps using the order that the character stores the attributes internally, "byAttrName" uses the attribute name to find a correspondence, "byNodeName" uses the node name *and* the attribute name to find a correspondence, "byCharacterMap" uses the existing characterMap node to do the mapping. "byMapOrAttrName" uses a character map if one exists, otherwise uses the attribute name. "byMapOrNodeName" uses a character map if one exists, otherwise uses the attribute name.  
                Properties: create
        name (Queryable[Multiuse[str]]?): In create mode, specify the clip name. In query mode, return a list of all the clips. In duplicate mode, specify the clip to be duplicated. In copy mode, specify the clip to be copied. This flag is multi-use, but multiple use is only supported with the copy flag. For use during create and with all other flags, only the first instance of the name flag will be utilized.  
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        newName (str?): Rename a clip. Must be used in conjunction with the clip name flag, which is used to specify the clip to be renamed.  
                Properties: create
        paste (bool?): This flag is used to paste a clip or clips from the clipboard to a character. Clips are added to the clipboard using the c/copy flag.  
                Properties: create
        pasteInstance (bool?): This flag is used to paste an instance of a clip or clips from the clipboard to a character. Unlike the p/paste flag, which duplicates the animCurves from the original source clip, the pi/pasteInstance flag shares the animCurves from the source clip.  
                Properties: create
        remove (bool?): Remove the clip specified by the name flag. The clip will be  
                permanently removed from the library and deleted from any times  
                where it has been scheduled.  
                Properties: query
        removeTrack (bool?): This flag is now obsolete. Use removeTrack flag on the clipSchedule command instead.  
                Properties: create
        rotationOffset (Queryable[Tuple[float, float, float]]?): Return the channel offsets used to modify the clip's rotation.  
                Properties: create, query
        rotationsAbsolute (bool?): Set all channels except rotations to be calculated with relative offsets.  Rotation channels will be calculated with absolute offsets.  This flag cannot be used in conjunction with the aa/allAbsolute, ar/allRelative or da/defaultAbsolute flags.  
                Properties: create
        scheduleClip (bool?): This flag is used when creating a clip to specify whether or not the clip should immediately be scheduled at the current time. If the clip is not scheduled, the clip will be placed in the library for future use, but will not be placed on the timeline. This flag is for use only when creating a new clip or duplicating an existing. The default is true.  
                Properties: create
        sourceClipName (bool?): This flag is for query only. It returns the name of the source clip that controls an instanced clip.  
                Properties: query
        split (int?): Split an existing clip into two clips. The split occurs around the specified time.  
                Properties: create, edit
        startTime (Queryable[int]?): Specify the clip start  
                Properties: create, query, edit
        translationOffset (Queryable[Tuple[float, float, float]]?): Return the channel offsets used to modify the clip's translation.  
                Properties: create, query
        useChannel (Multiuse[str]?): Specify which channels should be acted on. This flag is valid only in  
                conjunction with clip creation, and the isolate flag. The specified channels  
                must be members of the character.  
                Properties: create, multiuse

    Returns:
        List[str]: clip names

    Example:
    """

def clipEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allTrackHeights: int = ..., autoFit: Queryable[str] = ..., autoFitTime: Queryable[str] = ..., clipDropCmd: str = ..., clipStyle: Queryable[int] = ..., control: bool = ..., defineTemplate: str = ..., deleteCmd: str = ..., deselectAll: bool = ..., displayActiveKeyTangents: str = ..., displayActiveKeys: str = ..., displayInfinities: str = ..., displayKeys: str = ..., displayTangents: str = ..., displayValues: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., frameAll: bool = ..., frameRange: Queryable[Tuple[float, float]] = ..., highlightConnection: Queryable[str] = ..., highlightedBlend: Queryable[Tuple[str, str]] = ..., highlightedClip: Queryable[Tuple[str, str]] = ..., initialized: bool = ..., listAllCharacters: bool = ..., listCurrentCharacters: bool = ..., lockMainConnection: bool = ..., lookAt: str = ..., mainListConnection: Queryable[str] = ..., manageSequencer: bool = ..., menuContext: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectBlend: Queryable[Tuple[str, str, str]] = ..., selectClip: Queryable[Tuple[str, str]] = ..., selectionConnection: Queryable[str] = ..., snapTime: Queryable[str] = ..., snapValue: Queryable[str] = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, int, bool, Tuple[float, float], Tuple[str, str], Tuple[str, str, str]]:
    """Create a clip editor with the given name.
    Args:
        allTrackHeights (int?): OBSOLETE flag. Use clipStyle instead.
        autoFit (Queryable[str]?): on | off | tgl  
                Auto fit-to-view.  
                Properties: query, edit
        autoFitTime (Queryable[str]?): on | off | tgl  
                Auto fit-to-view along the time axis, as well.  
                Properties: query, edit
        clipDropCmd (str?): Command executed when clip node is dropped on the TraX editor  
                Properties: edit
        clipStyle (Queryable[int]?): Set/return the clip track style in the specified editor. Default is 2. Valid values are 1. 3.  
                Properties: query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteCmd (str?): Command executed when backspace key is pressed  
                Properties: edit
        deselectAll (bool?): Deselect all clips and blends in the editor.  
                Properties: edit
        displayActiveKeyTangents (str?): on | off | tgl  
                Display active key tangents in the editor.  
                Properties: edit
        displayActiveKeys (str?): on | off | tgl  
                Display active keys in the editor.  
                Properties: edit
        displayInfinities (str?): on | off | tgl  
                Display infinities in the editor.  
                Properties: edit
        displayKeys (str?): on | off | tgl  
                Display keyframes in the editor.  
                Properties: edit
        displayTangents (str?): on | off | tgl  
                Display tangents in the editor.  
                Properties: edit
        displayValues (str?): on | off | tgl  
                Display active keys and tangents values in the editor.  
                Properties: edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        frameAll (bool?): Frame view around all clips in the editor.  
                Properties: edit
        frameRange (Queryable[Tuple[float, float]]?): The editor's current frame range.  
                Properties: query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        highlightedBlend (Queryable[Tuple[str, str]]?): Returns the highlighted blend, listed as scheduler and index  
                Properties: query
        highlightedClip (Queryable[Tuple[str, str]]?): Returns the highlighted clip, listed as scheduler and index  
                Properties: query
        initialized (bool?): Returns whether the clip editor is fully initialized, and has a port to draw through.  
                If not, the -frameRange and -frameAll flags will fail.  
                Properties: query
        listAllCharacters (bool?): List all characters in the editor and outliner.  
                Properties: edit
        listCurrentCharacters (bool?): List only the characters in the editor and outliner.  
                Properties: edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lookAt (str?): all | selected | currentTime  
                FitView helpers.  
                Properties: edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        manageSequencer (bool?): Sets/returns whether the clip editor should manage sequencer nodes.  If so,  
                animation clips and characters are not represented.  
                Properties: create, query, edit
        menuContext (Queryable[str]?): Returns a string array denoting the type of data object the cursor  
                is over.  Returned values are:  
                {"timeSlider"}  
                {"nothing"}  
                {"track", "track index", "character node name", "group name"}  
                {"clip", "clip node name"}  
                Properties: query
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectBlend (Queryable[Tuple[str, str, str]]?): Select the blends specified by the scheduler name and the indicies  
                of the two clips used in the blend.  
                When queried, a string containing the scheduler name and the  
                two clip indicies for all of the selected blends is returned.  
                Properties: query, edit
        selectClip (Queryable[Tuple[str, str]]?): Selects the clip specified by the scheduler name and the clip index.  
                When queried, a string containing the scheduler and clip index  
                of all of the selected clips is returned.  
                Properties: query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        snapTime (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in time.  
                Properties: query, edit
        snapValue (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in values.  
                Properties: query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Editor name

    Example:
    """

def clipEditorCurrentTimeCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command creates a context which may be used to change current time
    within the track area of a clip editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def clipMatching(*args: str, clipDst: Tuple[str, float] = ..., clipSrc: Tuple[str, float] = ..., matchRotation: int = ..., matchTranslation: int = ...) -> bool:
    """This command is used to compute an offset to apply on a source clip in order to
    automatically align it to a destination clip at a specified match element.
    For this command to work, offset objects must be specified for the character.character, clip, animation
    Args:
        clipDst (Tuple[str, float]?): The clip to match so that the source clip can be offsetted correctly.  This flag  
                takes in a clip name and the percentage value ranging from 0.0 to 1.0 in order  
                to have the source clip match at a certain time in the destination clip.  
                Properties: create
        clipSrc (Tuple[str, float]?): The clip to offset so that it aligns with the destination clip.  This flag takes  
                in a clip name and the percentage value ranging from 0.0 to 1.0 in order to  
                have it match at a certain time in the clip.  
                Properties: create
        matchRotation (int?): This flag sets the rotation match type. By default, it is set to not match the  
                rotation.  
                0. None  
                1. Match full rotation  
                2. Match projected rotation on ground plane  
                Properties: create
        matchTranslation (int?): This flag sets the translation match type. By default, it is set to not match  
                the translation.  
                0. None  
                1. Match full translation  
                2. Match projected translation on ground plane  
                Properties: create

    Returns:
        bool:

    Example:
    """

def clipSchedule(*args: str, edit: bool = ..., query: bool = ..., allAbsolute: bool = ..., allRelative: bool = ..., blend: Queryable[Tuple[int, int]] = ..., blendNode: Queryable[Tuple[int, int]] = ..., blendUsingNode: str = ..., character: bool = ..., clipIndex: Queryable[int] = ..., cycle: Queryable[float] = ..., defaultAbsolute: bool = ..., enable: bool = ..., group: bool = ..., groupIndex: Multiuse[int] = ..., groupName: Queryable[str] = ..., hold: Queryable[int] = ..., insertTrack: int = ..., instance: str = ..., listCurves: bool = ..., listPairs: bool = ..., lock: bool = ..., mute: bool = ..., name: Queryable[str] = ..., postCycle: Queryable[float] = ..., preCycle: Queryable[float] = ..., remove: bool = ..., removeBlend: Tuple[int, int] = ..., removeEmptyTracks: bool = ..., removeTrack: int = ..., rotationsAbsolute: bool = ..., scale: Queryable[float] = ..., shift: int = ..., shiftIndex: Multiuse[int] = ..., solo: bool = ..., sourceClipName: bool = ..., sourceEnd: Queryable[int] = ..., sourceStart: Queryable[int] = ..., start: Queryable[int] = ..., track: Queryable[int] = ..., weight: Queryable[float] = ..., weightStyle: Queryable[int] = ...) -> Union[str, bool, Tuple[int, int], int, float]:
    """This command is used to create, edit and query clips and blends in the Trax editor. It operates on the clipScheduler node attached to the character. In query mode, if no flags are specified, returns an array of strings in this form:
     (clipName,clipIndex,clipStart,clipSourceStart,clipSourceEnd,clipScale,clipPreCycle,clipPostCycle,clipHold)character, clip, animation
    Args:
        allAbsolute (bool?): Set all channels to be calculated with absolute offsets.  This flag cannot be used in conjunction with the ar/allRelative, ra/rotationsAbsolute or da/defaultAbsolute flags.  
                Properties: query, edit
        allRelative (bool?): Set all channels to be calculated with relative offsets.  This flag cannot be used in conjunction with the aa/allAbsolute, ra/rotationsAbsolute or da/defaultAbsolute flags.  
                Properties: query, edit
        blend (Queryable[Tuple[int, int]]?): This flag is used to blend two clips, whose indices are provided as flag arguments.  
                Properties: create, query
        blendNode (Queryable[Tuple[int, int]]?): This query only flag list all of the blend nodes associated with the blend defined by the two clip indices. This flag returns a string array.  
                			In query mode, this flag can accept a value.  
                Properties: query
        blendUsingNode (str?): This flag is used to blend using an existing blend node. It is used in conjunction with the blend flag. The blend flag specifies the clip indices for the blend. The name of an existing animBlend node should be supplied supplied as an argument for the blendUsingNode flag.  
                Properties: create
        character (bool?): This flag is used to query which characters this scheduler controls. It returns an array of strings.  
                Properties: query
        clipIndex (Queryable[int]?): Specify the index of the clip to schedule. In query mode, returns  
                an array of strings in this form:  
                (clipName,index,start,sourceStart,sourceEnd,scale,preCycle,postCycle)  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        cycle (Queryable[float]?): This flag is now obsolete. Use the postCycle flag instead.  
                Properties: create, query
        defaultAbsolute (bool?): Sets all top-level channels except rotations in the clip to relative, and the remaining channels to absolute. This is the default during clip creation if no offset flag is specified.  This flag cannot be used in conjunction with the aa/allAbsolute, ar/allRelative, or ra/rotationsAbsolute flags.  
                Properties: query, edit
        enable (bool?): This flag is used to enable or disable a clip. It must be used in conjunction with the ci/clipIndex flag. The specified clip will be enabled or disabled.  
                Properties: create, query
        group (bool?): This flag is used to add (true) or remove (false) a list of clips (specified with groupIndex) into a group.  
                Properties: create
        groupIndex (Multiuse[int]?): This flag specifies a multiple number of clips to be added or removed from a group.  
                Properties: create, multiuse
        groupName (Queryable[str]?): This flag is used to specify the group that should be added to.  If no group  
                by that name exists and new group is created with that name.  By default if  
                this is not specified a new group will be created.  
                Properties: create, query
        hold (Queryable[int]?): Specify how long to hold the last value of the clip after its normal or cycled end.  
                Properties: create, query
        insertTrack (int?): This flag is used to insert a new empty track at the track index  
                specified.  
                Properties: create
        instance (str?): Create an instanced copy of the named clip. An instanced clip is one that is linked to an original clip. Thus, changes to the animation curve of the original curve will also modify all instanced clips. The name of the instanced clip is returned  
                as a string.  
                Properties: create
        listCurves (bool?): This flag is used to list the animation curves associated with a clip. It should be used in conjunction with the clipIndex flag, which specifies the clip of interest.  
                Properties: create, query
        listPairs (bool?): This query only flag returns a string array containing the channels  
                in a character that are used by a clip and the names of the animation  
                curves that drive the channels. Each string in the string array consists  
                of the name of a channel, a space, and the name of the animation curve  
                animating that channel. This flag must be used with the ci/clipIndex flag.  
                Properties: query
        lock (bool?): This flag specifies whether clips on a track are to be locked or not.  
                Must be used in conjuction with the track flag.  
                Properties: query, edit
        mute (bool?): This flag specifies whether clips on a track are to be muted or not.  
                Must be used in conjuction with the track flag.  
                Properties: query, edit
        name (Queryable[str]?): This flag is used to query the name of the clip node associated with the specified clip index, or to specify the name of the instanced clip during instancing.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        postCycle (Queryable[float]?): Specify the number of times to repeat the clip after its normal end.  
                Properties: create, query
        preCycle (Queryable[float]?): Specify the number of times to repeat the clip before its normal start.  
                Properties: create, query
        remove (bool?): This flag is used to remove a clip from the timeline. It must be used in conjunction with the ci/clipIndex flag. The specified clip will be removed from the timeline, but will still exist in the library and any instanced clips will remain in the timeline. To permanently remove a clip from the scene, the clip command should be used instead.  
                Properties: create
        removeBlend (Tuple[int, int]?): This flag is used to remove an existing blend between two clips, whose indices are provided as flag arguments.  
                Properties: create
        removeEmptyTracks (bool?): This flag is used to remove all tracks that have no clips.  
                Properties: create
        removeTrack (int?): This flag is used to remove the track with the specified index.  The  
                track must have no clips on it before it can be removed.  
                Properties: create
        rotationsAbsolute (bool?): Set all channels except rotations to be calculated with relative offsets.  Rotation channels will be calculated with absolute offsets.  This flag cannot be used in conjunction with the aa/allAbsolute, ar/allRelative or da/defaultAbsolute flags.  
                Properties: query, edit
        scale (Queryable[float]?): Specify the amount to scale the clip. Values must be greater than 0.  
                Properties: create, query
        shift (int?): This flag allows multiple clips to be shifted by a certain number of tracks  
                and works in conjunction with the shiftIndex flag.  The flag specifies the  
                number of tracks to shift the associated clips.  Positive values shift the  
                clips down an negative values shift the clips up.  
                Properties: create
        shiftIndex (Multiuse[int]?): This flag allows multiple clips to be shifted by a certain number of tracks  
                and works in conjunction with the shiftAmount flag.  The flag specifies the  
                index of the clip to shift.  This flag can be used multiple times on the command  
                line to specify a number of clips to shift.  
                Properties: create, multiuse
        solo (bool?): This flag specifies whether clips on a track are to be soloed or not.  
                Must be used in conjuction with the track flag.  
                Properties: query, edit
        sourceClipName (bool?): This flag is used to query the name of the source clip node associated with the specified clip index.  
                Properties: create, query
        sourceEnd (Queryable[int]?): Specify where to end in the source clip's animation curves  
                Properties: create, query
        sourceStart (Queryable[int]?): Specify where to start in the source clip's animation curves  
                Properties: create, query
        start (Queryable[int]?): Specify the placement of the start of the clip  
                Properties: create, query
        track (Queryable[int]?): Specify the track to operate on. For example, which track to place  
                a clip on, which track to mute/lock/solo.  In query mode, it may be used  
                in conjuction with the clipIndex flag to return the track number of a clip,  
                where track 1 is the first track of the character.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        weight (Queryable[float]?): This flag is used in to set or query the weight of the clip associated with the specified clip index.  
                Properties: create, query
        weightStyle (Queryable[int]?): This flag is used to set or query the weightStyle attribute of the clip associated with the specified clip index.  
                Properties: create, query

    Returns:
        str: Clip name

    Example:
    """

def clipSchedulerOutliner(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clipScheduler: str = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates/edits/queries a clip scheduler outliner control.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clipScheduler (str?): Name of the clip scheduler for which to display information.  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the outliner control.

    Example:
    """

def closeCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., blendBias: Queryable[float] = ..., blendKnotInsertion: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., parameter: Queryable[float] = ..., preserveShape: Queryable[int] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], float, bool, int]:
    """The closeCurve command closes a curve, making it periodic.
    The pathname to the newly closed curve and the name
    of the resulting dependency node are returned.  If a curve
    is not specified in the command, then the first active curve
    will be used.
    Args:
        blendBias (Queryable[float]?): Skew the result toward the first or the second curve depending  
                on the blend value being smaller or larger than 0.5.  
                Default: 0.5  
                Properties: create, query, edit
        blendKnotInsertion (bool?): If set to true, insert a knot in one of the original curves  
                (relative position given by the parameter attribute below)  
                in order to produce a slightly different effect.  
                Default: false  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[float]?): The parameter value for the positioning of the newly inserted knot.  
                Default: 0.1  
                Properties: create, query, edit
        preserveShape (Queryable[int]?): 0. without preserving the shape  
                1. preserve shape  
                2. blend  
                Default: 1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def closeSurface(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., blendBias: Queryable[float] = ..., blendKnotInsertion: bool = ..., caching: bool = ..., direction: Queryable[int] = ..., nodeState: Queryable[int] = ..., parameter: Queryable[float] = ..., preserveShape: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], float, bool, int]:
    """The closeSurface command closes a surface in the U, V, or both
    directions, making it periodic. The close direction is controlled
    by the direction flag. If a surface is not specified in the
    command, then the first selected surface will be used.The pathname to the newly closed surface and the name of the resulting
    dependency node are returned.This command also handles selected surface isoparms. For example, if
    an isoparm is specified, surface1.u[0.33], then the surface will be
    closed in V, regardless of the direction flag.
    Args:
        blendBias (Queryable[float]?): Skew the result toward the first or the second surface depending on the blend value being smaller or larger than 0.5.  
                Default: 0.5  
                Properties: create, query, edit
        blendKnotInsertion (bool?): If set to true, insert a knot in one of the original surfaces (relative position given by the parameter attribute below) in order to produce a slightly different effect.  
                Default: false  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[int]?): The direction in which to close:  
                0. U,  
                1. V,  
                2. Both U and V  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[float]?): The parameter value for the positioning of the newly inserted knot.  
                Default: 0.1  
                Properties: create, query, edit
        preserveShape (Queryable[int]?): 0. without preserving the shape  
                1. preserve shape  
                2. blend  
                Default: 1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def cluster(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., bindState: bool = ..., components: bool = ..., deformerTools: bool = ..., envelope: Queryable[float] = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., relative: bool = ..., remove: Multiuse[bool] = ..., resetGeometry: bool = ..., selectedComponents: bool = ..., split: bool = ..., useComponentTags: bool = ..., weightedNode: Queryable[Tuple[str, str]] = ...) -> Union[List[str], bool, float, str, Multiuse[str], Tuple[str, str]]:
    """The cluster command creates a cluster or edits the membership of
    an existing cluster. The command returns the name of the cluster
    node upon creation of a new cluster.After creating a cluster, the cluster's weights can be modified
    using the percent command or the set editor window.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        bindState (bool?): When turned on, this flag adds in a compensation to ensure  
                the clustered objects preserve their spatial position  
                when clustered. This is required to prevent the geometry  
                from jumping at the time the cluster is created  
                in situations when the  
                cluster transforms at cluster time are not identity.  
                Properties: create
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        envelope (Queryable[float]?): Set the envelope value for the deformer. Default is 1.0  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        relative (bool?): Enable relative mode for the cluster. In relative mode,  
                Only the transformations directly above the cluster are used  
                by the cluster. Default is off.  
                Properties: create
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        resetGeometry (bool?): Reset the geometry matrices for the objects being deformed  
                by the cluster. This flag is used to get rid of undesirable  
                effects that happen if you scale an object that  
                is deformed by a cluster.  
                Properties: edit
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        weightedNode (Queryable[Tuple[str, str]]?): Transform node in the DAG above the cluster to which all percents are  
                applied. The second DAGobject specifies the descendent of the first  
                DAGobject from where the transformation matrix is evaluated. Default is  
                the cluster handle.  
                Properties: create, query, edit

    Returns:
        List[str]: (the cluster node name and the cluster handle name)

    Example:
    """

def cmdFileOutput(*, query: bool = ..., close: int = ..., closeAll: bool = ..., open: str = ..., status: Queryable[int] = ...) -> int:
    """This command will open a text file to receive all of the commands
    and results that normally get printed to the Script Editor
    window or console. The file will stay open until an explicit -close
    with the correct file descriptor or a -closeAll, so care should be
    taken not to leave a file open.To enable logging to commence as soon as Maya starts up, the
    environment variable MAYA_CMD_FILE_OUTPUT may be specified prior
    to launching Maya. Setting MAYA_CMD_FILE_OUTPUT to a filename
    will create and output to that given file. To access the descriptor
    after Maya has started, use the -query and -open flags together.
    Args:
        close (int?): Closes the file corresponding to the given descriptor.  
                If -3 is returned, the file did not exist. -1 is returned  
                on error, 0 is returned on successful close.  
                Properties: create
        closeAll (bool?): Closes all open files.  
                Properties: create
        open (str?): Opens the given file for writing (will overwrite if it exists  
                and is writable). If successful, a value is returned to enable  
                status queries and file close. -1 is returned if the file cannot  
                be opened for writing. The -open flag can also be specified in  
                -query mode. In query mode, if the named file is currently opened,  
                the descriptor for the specified file is returned, otherwise -1 is  
                returned. This is an easy way to check if a given file is  
                currently open.  
                      In query mode, this flag needs a value.  
                Properties: create, query
        status (Queryable[int]?): Queries the status of the given descriptor. -3 is returned  
                if no such file exists, -2 indicates the file is not open,  
                -1 indicates an error condition, 0 indicates file is ready  
                for writing.  
                Properties: create, query

    Returns:
        int: : On open, returns a value (descriptor) that can be used to query
            the status or close the file. Otherwise, a status code
            indicating status of file

    Example:
    """

def cmdScrollFieldExecuter(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., appendText: str = ..., autoCloseBraces: bool = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clear: bool = ..., commandCompletion: bool = ..., copySelection: bool = ..., currentLine: Queryable[int] = ..., cutSelection: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., execute: bool = ..., executeAll: bool = ..., exists: bool = ..., fileChangedCommand: Callable[..., Any] = ..., filename: bool = ..., filterKeyPress: Queryable[Callable[..., Any]] = ..., fullPathName: bool = ..., hasFocus: bool = ..., hasSelection: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., insertText: str = ..., isObscured: bool = ..., load: bool = ..., loadContents: str = ..., loadFile: str = ..., manage: bool = ..., modificationChangedCommand: Callable[..., Any] = ..., modified: bool = ..., noBackground: bool = ..., numberOfLines: Queryable[int] = ..., numberOfPopupMenus: bool = ..., objectPathCompletion: bool = ..., parent: Queryable[str] = ..., pasteSelection: bool = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., redo: bool = ..., removeStoredContents: str = ..., replaceAll: Tuple[str, str] = ..., saveFile: str = ..., saveSelection: str = ..., saveSelectionToShelf: bool = ..., searchAndSelect: bool = ..., searchDown: bool = ..., searchMatchCase: bool = ..., searchString: Queryable[str] = ..., searchWraps: bool = ..., select: Tuple[int, int] = ..., selectAll: bool = ..., selectedText: bool = ..., showLineNumbers: bool = ..., showTabsAndSpaces: bool = ..., showTooltipHelp: bool = ..., source: bool = ..., sourceType: Queryable[str] = ..., spacesPerTab: Queryable[int] = ..., statusBarMessage: str = ..., storeContents: str = ..., tabsForIndent: bool = ..., text: Queryable[str] = ..., textLength: bool = ..., undo: bool = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Callable[..., Any]]:
    """A script editor executer control used to issue script commands to
    Maya.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        appendText (str?): Appends text to the end of this field.  
                Properties: create, edit
        autoCloseBraces (bool?): Specifies whether a closing brace should automatically be added when  
                hitting enter after an opening brace. (default on)  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clear (bool?): Clears the field.  
                Properties: create, edit
        commandCompletion (bool?): Enable/disable command completion  
                Properties: create, query, edit
        copySelection (bool?): Copies the current selection from this field.  
                Properties: create, edit
        currentLine (Queryable[int]?): Sets/returns the current line which the cursor is on.  
                Properties: create, query, edit
        cutSelection (bool?): Cuts the current selection from this field.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        execute (bool?): Executes the current selection.  If there is no selection, all text is executed.  
                Properties: create, edit
        executeAll (bool?): Executes all text.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fileChangedCommand (Callable[..., Any]?): Only valid when this field contains a file.  
                Sets a script which will be called whenever the file is externally modified,  
                renamed or removed from disk.  
                In MEL, the function should have the following signature:  
              
                proc fileChanged(string $file)  
                Properties: create, edit
        filename (bool?): Returns the full path + filename of the script which was either loaded or saved.  
                If there isn't one returns an empty string.  
                Properties: query
        filterKeyPress (Queryable[Callable[..., Any]]?): Sets a script which will be called to handle key-press events.  
                The function should have the following signature:  
              
                proc int filterKeyPress(int $modifiers, string $key)  
              
                modifiers: a bit mask where Shift is bit 1, Ctrl is bit 3,  
                Alt is bit 4, and bit 5 is the 'Windows' key on Windows keyboards  
                and the Command key on Mac keyboards.  
              
                key: Specifies what key was pressed. The key is either a single  
                ascii character or one of the keyword strings for the special  
                keyboard characters. For example:  
                Up, Down, Right, Left,  
                Home, End, Page_Up, Page_Down, Insert  
                Return, Space  
                F1 to F12  
              
                The function should return 1 to indicate that they key event has been  
                handled, and 0 to indicate that it has not been handled.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        hasFocus (bool?): Whether this control is currently in focus.  
                Properties: query
        hasSelection (bool?): Whether this control currently has a selection or not.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        insertText (str?): Inserts the specified text into the position under the cursor,  
                replacing any currently selected text. The selection and cursor  
                position can be set using the select flag. Appends text to the  
                end of this field.  
                Properties: create, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        load (bool?): Prompts the user for a script to load into this field.  The loaded filename becomes  
                associated with this executer field and saving will save directly to the file.  
                Properties: create, edit
        loadContents (str?): Loads the contents of the specified filename into this field.  The path and extension for this filename  
                is provided internally.  This command is only intended for loading the contents of this executer field from a previous  
                instance of this executer field.  
                Properties: create, edit
        loadFile (str?): If the provided string is a fully specified file path, then attempts to load the  
                file contents into this field.  If the string is empty or not valid then prompts  
                the user for a script to load into this field.  In both cases the filename becomes  
                associated with this executer field and saving will save directly to the file.  
                Properties: create, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        modificationChangedCommand (Callable[..., Any]?): Sets a script which will be called whenever the content of this field changes in  
                a way that affects the modification state.  
                In MEL, the function should have the following signature:  
              
                proc modificationChanged(int $m)  
              
                If $m is true, the field has been modified; otherwise it is false.  
                Properties: create, edit
        modified (bool?): Sets or returns whether the field has been modified.  
                Properties: query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfLines (Queryable[int]?): Returns the total number of lines in the document.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        objectPathCompletion (bool?): Enable/disable path completion  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        pasteSelection (bool?): Pastes text into this field at the current caret position.  
                Properties: create, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        redo (bool?): Redo the last operation.  
                Properties: create, edit
        removeStoredContents (str?): Removes the stored contents of this field with the specified filename.  The path and extension for the file is  
                provided internally.  This command is only intended for removing previously stored contents of this executer field.  
                Properties: create, edit
        replaceAll (Tuple[str, str]?): Replaces all instances of the first string in the field text with the  
                second string.  The case sensitivity of this operation is set with the  
                -searchMatchCase flag.  
                Properties: create, edit
        saveFile (str?): Saves the entire script contents of this field directly to the specified file path.  
                Properties: create, edit
        saveSelection (str?): Prompts to save the current selection to a file.  The default filename prompt will be prepended with the given string.  
                Properties: create, edit
        saveSelectionToShelf (bool?): Prompts to save the current selection to an item in the shelf.  
                Properties: create, edit
        searchAndSelect (bool?): Searches for (and selects) the specified search string using the  
                specified search options.  
                Properties: query
        searchDown (bool?): Specifies whether to search from the cursor down, or up.  
                Properties: create, query, edit
        searchMatchCase (bool?): Specifies whether the search is to be case sensitive or not.  
                Properties: create, query, edit
        searchString (Queryable[str]?): Specifies the string to search for.  
                Properties: create, query, edit
        searchWraps (bool?): Specifies whether the search should wrap around.  
                Properties: create, query, edit
        select (Tuple[int, int]?): Selects text within a specified range.  
                Properties: create, edit
        selectAll (bool?): Selects all text.  
                Properties: create, edit
        selectedText (bool?): The text in the current selection range.  
                Properties: query
        showLineNumbers (bool?): Shows/hides the line numbes column.  
                Properties: create, query, edit
        showTabsAndSpaces (bool?): Visually show tab and space indicators. (default off)  
                Properties: create, query, edit
        showTooltipHelp (bool?): Enable/disable tooltips in the command execution window  
                Properties: create, query, edit
        source (bool?): Prompts the user for a script to source (execute without loading).  
                Properties: create, edit
        sourceType (Queryable[str]?): Sets the source type for this command executer field.  
                Valid values are "mel" (enabled by default)  
                and "python".  
                Properties: create, query
        spacesPerTab (Queryable[int]?): Specifies the number of spaces equivalent to one tab stop. (default 4)  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        storeContents (str?): If the provided string is a fully specified file path, then attempts to store the contents of this field  
                to that path. Otherwise, uses the provided string as a filename only and uses an internally generated  
                path and extension for the file, as used by the -loadContents and -removeStoredContents flags.  
                In both cases, a new unique filename will be generated if the specified name exists.  
                Returns the filename of the file saved upon completion, and an empty string otherwise.  
                Properties: create, edit
        tabsForIndent (bool?): Specifies whether tab characters should be inserted when indenting. (default on)  
                Properties: create, query, edit
        text (Queryable[str]?): Replaces the field text with the given string.  
                Properties: create, query, edit
        textLength (bool?): The number of characters in this text field.  
                Properties: query
        undo (bool?): Undo the last operation.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the executer control

    Example:
    """

def cmdScrollFieldReporter(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clear: bool = ..., copySelection: bool = ..., cutSelection: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., echoAllCommands: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., filterSourceType: Queryable[str] = ..., fullPathName: bool = ..., hasFocus: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., lineNumbers: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., pasteSelection: bool = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., receiveFocusCommand: Callable[..., Any] = ..., saveSelection: str = ..., saveSelectionToShelf: bool = ..., select: Tuple[int, int] = ..., selectAll: bool = ..., stackTrace: bool = ..., statusBarMessage: str = ..., suppressErrors: bool = ..., suppressInfo: bool = ..., suppressResults: bool = ..., suppressStackTrace: bool = ..., suppressWarnings: bool = ..., text: Queryable[str] = ..., textLength: bool = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """A script editor reporter control used to receive and display the history of processed commmands.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clear (bool?): Clears the field.  
                Properties: create, edit
        copySelection (bool?): Copies the current selection from this field.  
                Properties: create, edit
        cutSelection (bool?): Cuts the current selection from this field.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        echoAllCommands (bool?): Echo all commands.    (Global parameter, affects all command reporters)  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filterSourceType (Queryable[str]?): Filters the specified source type from showing in this command reporter.  
                Currently supports either "mel", "python", or "" (default).  
                Setting the filter to the empty string ("") will remove all filtering and show both "mel" and "python" results.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        hasFocus (bool?): Whether this control is currently in focus.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        lineNumbers (bool?): Show line numbers (in Error/Warning messages).    (Global parameter, affects all command reporters)  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        pasteSelection (bool?): Pastes text into this field at the current caret position.  
                Properties: create, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        receiveFocusCommand (Callable[..., Any]?): Command executed when the field receives focus.  
                Properties: create, edit
        saveSelection (str?): Prompts to save the current selection to a file. The default filename prompt will be prepended with the given string.  
                Properties: create, edit
        saveSelectionToShelf (bool?): Prompts to save the current selection to an item in the shelf.  
                Properties: create, edit
        select (Tuple[int, int]?): Selects text within a specified range.  
                Properties: create, edit
        selectAll (bool?): Selects all text.  
                Properties: create, edit
        stackTrace (bool?): Show stack trace.    (Global parameter, affects all command reporters)  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        suppressErrors (bool?): Suppress errors.  
                Properties: create, query, edit
        suppressInfo (bool?): Suppress info.  
                Properties: create, query, edit
        suppressResults (bool?): Suppress results.  
                Properties: create, query, edit
        suppressStackTrace (bool?): Suppress stack trace.  
                Properties: create, query, edit
        suppressWarnings (bool?): Suppress warnings.  
                Properties: create, query, edit
        text (Queryable[str]?): Replaces the field text with the given string.  
                Properties: create, query, edit
        textLength (bool?): The number of characters in this text field.  
                Properties: query
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the reporter control

    Example:
    """

def cmdShell(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clear: bool = ..., command: Queryable[str] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfHistoryLines: Queryable[int] = ..., numberOfPopupMenus: bool = ..., numberOfSavedLines: Queryable[int] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., prompt: Queryable[str] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a scrolling field that behaves similar to
    a unix shell for entering user input.  You may specify the number
    of lines that will be remembered by the field with
    the -nsl/numberOfSavedLines flag.  The default number of lines saved
    is 100.  The shellField also maintains a command history buffer.
    You can specify the number of input lines that will be saved with
    the -hlc/historyLineCount flag.  The default size of this buffer is 10.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clear (bool?): Erases all visible text, and also deletes any text that had  
                scrolled of the top of the field.  After clearing the field  
                it will be blank, and you will not be able to scroll up to  
                see previous lines.  This flag does not affect the command  
                history buffer, however.  
                Properties: create
        command (Queryable[str]?): Command executed when the contents change.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfHistoryLines (Queryable[int]?): The number of input lines to be saved in the  
                command history buffer.  You can cycle through this buffer by  
                pressing the up and down arrow keys.  Valid values are 0 through  
                32767.  Any value less than 0 will be handled as if 0 was  
                specified.  Similarly, any value greater than 32767 will be  
                handled as if 32767 was specified.  
                Properties: create, query, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfSavedLines (Queryable[int]?): The total number of lines (the scrolled lines and  
                currently visible lines) that will be remembered by the field.  
                Any lines beyond this number will be lost, and the user will not  
                be able to review them by scrolling.  Valid values are 1 through  
                32767.  Any value less than 1 will be handled as if 1 was  
                specified.  Similarly, any value greater than 32767 will be  
                handled as if 32767 was specified.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        prompt (Queryable[str]?): The text that is used as a prompt.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def coarsenSubdivSelectionList(*args: Any) -> bool:
    """Coarsens a subdivision surface set of components based on the selection list. The
    selected components are selected at a coarser level.subdivision, surface, select, region, coarsen, level, coarse, fine
    Returns:
        bool: Command result

    Example:
    """

def collision(*args: str, edit: bool = ..., query: bool = ..., friction: Queryable[float] = ..., name: Queryable[str] = ..., offset: Queryable[float] = ..., resilience: Queryable[float] = ...) -> Union[List[str], float, str]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    The collision command causes particles to collide with geometry.
    It also allows you to specify values for the surface properties
    (friction and resilience) of the collision.  These values are stored
    in the geoConnector node for the geometry object.  Unlike earlier versions
    of Maya, there is no separate "collision node."If a soft object is in the selection list, the collision command assumes
    that you want to make it a collider.  In order to make the soft object
    collide with something use, use connectDynamic -c.  The collision menu
    option sorts this out using the lead object rule and issues the necessary
    commands.
    On creation, this command returns aof the geometry names that were setup for particle collision.When the command is used to query information, there are several possible return types.
    These include:
    Args:
        friction (Queryable[float]?): Friction of the surface.  This is the amount of the colliding particle's  
                velocity parallel to the surface which is removed when the particle collides.  
                A value of 0 will mean that no tangential velocity is lost, while a value  
                of 1 will cause the particle to reflect straight along the normal of  
                the surface.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        offset (Queryable[float]?): Offset value for the connector.  
                Properties: query, edit
        resilience (Queryable[float]?): Resilience of the surface.  This is the amount of the colliding particle's  
                velocity reflected along the normal of the surface.  A value of 1 will  
                give perfect reflection, while a value of 0 will have no reflection along  
                the normal of the surface.  
                Properties: query, edit

    Returns:
        List[str]: Geometry names that were setup for particle collision.

    Example:
    """

def color(*args: str, rgbColor: Tuple[float, float, float] = ..., userDefined: int = ...) -> bool:
    """This command sets the dormant wireframe color of the specified
    objects to be their class color or if the -ud/userDefined flag is
    specified, one of the user defined colors. The -rgb/rgbColor flags
    can be specified if the user requires floating point RGB colors.
    Args:
        rgbColor (Tuple[float, float, float]?): Specifies and rgb color to set the selected object to.  
                Properties: create
        userDefined (int?): Specifies the user defined color index to set selected  
                object to. The valid range of numbers is [1. 8].  
                Properties: create

    Returns:
        bool:

    Example:
    """

def colorAtPoint(*args: str, coordU: Multiuse[float] = ..., coordV: Multiuse[float] = ..., maxU: float = ..., maxV: float = ..., minU: float = ..., minV: float = ..., output: str = ..., samplesU: int = ..., samplesV: int = ...) -> bool:
    """Thecommand is used to query textures or ocean
              shaders at passed in uv coordinates.
          (For ocean shaders uv is x and z in worldspace ).
              The return value is a floating point array whose size is
              determined by either the number of input uv arguments passed in and the
              the queried value.  One can query alpha only, rgb only, or rgba values.
              The returned array is only single indexed, so if rgb is specified then
              the index for red values would be index * 3. Blue is index * 3 + 1, and
              green is index * 3 + 2. For rgba use a multiple of 4 instead of 3.
              For alpha only one can simply use the index.
              There are two basic argument formats that may be used:
              colorAtPoint -u 0 -v 0   -u .2 -v .1  etc.. for all points
              or
              colorAtPoint -mu 0 -mv 0  -xu 1 -xv 1 -su 10 -sv 10 // samples 100 points
              If one is sampling several points and they are all in a regular grid
              formation it is more efficient to call this routine with the latter
              method, which uses a min/max uv and number of samples, rather than
              a long argument list of uv coords.texture, color, alpha, uv, ocean, outColor, paramUV
    Args:
        coordU (Multiuse[float]?): Input u coordinate to sample texture at.  
                Properties: create, multiuse
        coordV (Multiuse[float]?): Input v coordinate to sample texture at.  
                Properties: create, multiuse
        maxU (float?): DEFAULT 1.0  
                Maximum u bounds to sample.  
                Properties: create
        maxV (float?): DEFAULT 1.0  
                Maximum v bounds to sample.  
                Properties: create
        minU (float?): DEFAULT 0.0  
                Minimum u bounds to sample.  
                Properties: create
        minV (float?): DEFAULT 0.0  
                Minimum v bounds to sample.  
                Properties: create
        output (str?): Type of data to output:  
                        A        = alpha only  
                        RGB  = color only  
                        RGBA = color and alpha  
                Properties: create
        samplesU (int?): DEFAULT 1  
                The number of points to sample in the U dimension.  
                Properties: create
        samplesV (int?): DEFAULT 1  
                The number of points to sample in the V dimension.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def colorEditor(*, query: bool = ..., alpha: Queryable[float] = ..., hsvValue: Queryable[Tuple[float, float, float]] = ..., mini: bool = ..., parent: str = ..., position: Tuple[int, int] = ..., result: bool = ..., rgbValue: Queryable[Tuple[float, float, float]] = ...) -> Union[str, float, Tuple[float, float, float], bool]:
    """Thecommand displays a modal dialog that may be used
    to specify colors in RGB or HSV. The default behaviour
    when no arguments are specified is to provide an initial color of
    black (rgb 0.0 0.0 0.0).The command will return the user's color component values along with a
    boolean to indicate whether the dialog was dismissed by pressing
    the "OK" button.  As an alternative to responding to
    thecommand's return string you can now query
    the, andflags to get the same information.
    Args:
        alpha (Queryable[float]?): Float values corresponding to the alpha transparency component,  
                , which ranges from 0.0 to 1.0.  Use this flag to specify the  
                initial alpha value of the Color Editor, or query  
                this flag to determine the alpha value set in the editor.  
                Properties: create, query
        hsvValue (Queryable[Tuple[float, float, float]]?): Three float values corresponding to the hue, saturation, and  
                value color components, where the hue value ranges from 0.0 to 360.0  
                and the saturation and value components range from 0.0 to 1.0.  Use  
                this flag to specify the initial color of the Color Editor, or query  
                this flag to determine the color set in the editor.  
                Properties: create, query
        mini (bool?): Enable the mini color editor mode.  
                Properties: create
        parent (str?): Specify the parent window for the dialog.  The dialog will  
                be centered on this window and raise and lower with it's parent.  
                By default, the dialog is not parented to a particular window and  
                is simply centered on the screen.  
                Properties: create
        position (Tuple[int, int]?): Specify the window position for the dialog.  
                Properties: create
        result (bool?): This query only flag returns true if the dialog's "OK" button  
                was pressed, false otherwise.  If you query this flag immediately  
                after showing the Color Editor then it will return the same value  
                as the boolean value returned in the colorEditor command's  
                return string.  
                Properties: query
        rgbValue (Queryable[Tuple[float, float, float]]?): Three float values corresponding to the red, green, and blue  
                color components, all of which range from 0.0 to 1.0.  Use this  
                flag to specify the initial color of the Color Editor, or query  
                this flag to determine the color set in the editor.  
                Properties: create, query

    Returns:
        str: The string format is "float float float boolean". The first three
            float values correspond to the color components.
            
            The final argument is 1 if the dialog's "OK" button was pressed,
            and 0 if the "Cancel" button was pressed.

    Example:
    """

def colorIndex(arg0: int = ..., arg1: float = ..., arg2: float = ..., arg3: float = ..., /, *, query: bool = ..., active: bool = ..., dormant: bool = ..., hueSaturationValue: bool = ..., resetToFactory: bool = ..., resetToSaved: bool = ..., userColor: bool = ...) -> Union[int, bool]:
    """The index specifies a color index in the color palette.
    The r, g, and b values (between 0-1) specify the RGB values
    (or the HSV values if the -hsv flag is used) for the color.
    Args:
        active (bool?): Combined with query mode, with given index, query the active color palette.  
                Properties: create
        dormant (bool?): Combined with query mode, with given index, query the dormant color palette.  
                Properties: create
        hueSaturationValue (bool?): Indicates that rgb values are really hsv values.  
                Upon query, returns the HSV valuses as an array of 3 floats.  
                Properties: create, query
        resetToFactory (bool?): Resets all color index palette entries to their  
                factory defaults.  
                Properties: create
        resetToSaved (bool?): Resets all color palette entries to their saved values.  
                Properties: create
        userColor (bool?): Combined with query mode, with given index, query the user color palette.  
                Properties: create

    Returns:
        int: Returns 1 on success.

    Example:
    """

def colorIndexSliderGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., forceDragRefresh: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., invisible: Queryable[int] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., value: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a color slider group consisting of a label, a
    color canvas and a slider. The value of the slider defines a color
    index into the a color table. The corresponding color is displayed
    in the canvas.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when the value changes by dragging the  
                slider's value marker.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): Sets the string to be the text for the extra label.  
                Properties: create, query, edit
        forceDragRefresh (bool?): If used then force refresh on drag  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        invisible (Queryable[int]?): Set the invisible color index.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the group.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): Maximum color index.  
                Properties: create, query, edit
        minValue (Queryable[int]?): Minimum color index.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[int]?): Color index.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def colorInputWidgetGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., alphaValue: Queryable[float] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., forceDragRefresh: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hsvValue: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rgbValue: Queryable[Tuple[float, float, float]] = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, float, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.Create a color slider group consisting of a label, a color canvas,
    RGB and HSV sliders.  Clicking on the canvas will bring up the
    color editor.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        alphaValue (Queryable[float]?): Alpha (transparency) of the color. Will show the alpha UI.  
                Alpha will be set only if RGB or HSV is also set at the same time.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when slider value changes.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        forceDragRefresh (bool?): If used then force refresh on drag  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hsvValue (Queryable[Tuple[float, float, float]]?): Color in hue, saturation, and value format.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the group.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rgbValue (Queryable[Tuple[float, float, float]]?): Color in red, green, and blue format.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: (the name of the created group)

    Example:
    """

def colorManagementCatalog(*, addTransform: str = ..., editUserTransformPath: str = ..., listSupportedExtensions: bool = ..., listTransformConnections: bool = ..., path: str = ..., queryUserTransformPath: bool = ..., removeTransform: str = ..., transformConnection: str = ..., type: str = ...) -> bool:
    """This non-undoable action performs additions and removals of custom color
    transforms from the Autodesk native color transform catalog.  Once a custom
    color transform has been added to the catalog, it can be used in the same way
    as the builtin Autodesk native color transforms.color, management
    Args:
        addTransform (str?): Add transform to collection.  
                Properties: create
        editUserTransformPath (str?): Edit the user transform directory. By changing the directory, all custom  
                transforms currently added could be changed, and new ones could appear.  
                Properties: create
        listSupportedExtensions (bool?): List the file extensions that are supported by add transform.  This list is  
                valid for all transform types, and therefore this flag does not require  
                use of the type flag.  
                Properties: create
        listTransformConnections (bool?): List the transforms that can be used as source (for "view" and "output" types)  
                or destination (for "input" and "rendering space" types) to connect a custom  
                transform to the rest of the transform collection.  
                Properties: create
        path (str?): In addTransform mode, the path to the transform data file.  
                Properties: create
        queryUserTransformPath (bool?): Query the user transform directory.  
                Properties: create
        removeTransform (str?): Remove transform from collection.  
                Properties: create
        transformConnection (str?): In addTransform mode, an existing transform to which the added transform  
                will be connected. For an input transform or rendering space transform, this  
                will be a destination. For a view or output transform, this will be a source.  
                Properties: create
        type (str?): The type of transform added, removed, or whose transform connections are to  
                be listed. Must be one of "view", "rendering space", "input", or "output".  
                Properties: create

    Returns:
        bool:

    Example:
    """

def colorManagementConvert(*, toDisplaySpace: Tuple[float, float, float] = ...) -> bool:
    """This command can be used to convert rendering (a.k.a. working) space color values to display space
    color values. This is useful if you create custom UI with colors painted to screen, where you need
    to handle color management yourself. The current view transform set in the Color Management user
    preferences will be used.color, management
    Args:
        toDisplaySpace (Tuple[float, float, float]?): Converts the given RGB value to display space.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def colorManagementFileRules(*args: str, edit: bool = ..., query: bool = ..., addRule: str = ..., colorSpace: Queryable[str] = ..., colorSpaceDescription: str = ..., colorSpaceFamilies: str = ..., colorSpaceNames: bool = ..., down: str = ..., enabled: bool = ..., evaluate: str = ..., extension: Queryable[str] = ..., listRules: bool = ..., load: bool = ..., moveUp: str = ..., pattern: Queryable[str] = ..., remove: str = ..., restoreDefaults: bool = ..., save: bool = ...) -> Union[bool, str]:
    """This non-undoable action manages the list of rules that Maya uses to assign
    an initial input color space to dependency graph nodes that read in color
    information from a file.  Rules are structured in a chain of
    responsibility, from highest priority rule to lowest priority rule, each
    rule matching a file path pattern and extension.  If a rule matches a given
    file path, its color space is returned as the result of rules evaluation,
    and no further rule is considered.  The lowest priority rule will always
    return a match.
    Rules can be added, removed, and changed in priority in the list.  Each
    rule can have its file path pattern, extension, and color space changed.
    The rule list can be saved to user preferences, and loaded from user
    preferences.color, management
    Args:
        addRule (str?): Add a rule with the argument name to the list of rules, as the  
                highest-priority rule.  If this flag is used, the pattern, extension, and  
                colorSpace flags must be used as well, to specify the file rule pattern,  
                extension, and color space, respectively.  
                Properties: create
        colorSpace (Queryable[str]?): The input color space for the rule.  If the rule matches a file path, this  
                is the color space that is returned.  This color space must match an existing  
                color space in the input color space list.  
                Properties: create, query, edit
        colorSpaceDescription (str?): Returns the description for a specific color space.  
                			In query mode, this flag needs a value.  
                Properties: query
        colorSpaceFamilies (str?): Returns the list of families for a specific color space. Used to add submenus  
                when populating the color spaces UI popup of a rule.  
                			In query mode, this flag needs a value.  
                Properties: query
        colorSpaceNames (bool?): Returns the list of available color spaces. Used to populate the color  
                spaces UI popup of a rule.  
                Properties: query
        down (str?): Move the rule with the argument name down one position towards lower priority.  
                Properties: create
        enabled (bool?): Are the file rules enabled?  
                Properties: query
        evaluate (str?): Evaluates the list of rules and returns the input color space name that  
                corresponds to the argument file path.  
                Properties: create
        extension (Queryable[str]?): The file extension for the rule is case insensitive  
                Properties: create, query, edit
        listRules (bool?): Returns an array of rule name strings, in order, from lowest-priority (rule 0)  
                to highest-priority (last rule in array).  
                Properties: create
        load (bool?): Read the rules from Maya preferences.  Any existing rules are cleared.  
                Properties: create
        moveUp (str?): Move the rule with the argument name up one position towards higher priority.  
                Properties: create
        pattern (Queryable[str]?): The file path pattern for the rule.  This is the substring to match in the  
                file path, expressed as a glob pattern: for example, '*' matches all files.  
                For more information about glob pattern syntax, see  
                http://en.wikipedia.org/wiki/Glob_%28programming%29.  
                Properties: create, query, edit
        remove (str?): Remove the rule with the argument name from the list of rules.  
                Properties: create
        restoreDefaults (bool?): Restore the list of rules to the default ones only.  
                Properties: create
        save (bool?): Save the rules to Maya preferences.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def colorManagementPrefs(*, edit: bool = ..., query: bool = ..., cmConfigFileEnabled: bool = ..., cmEnabled: bool = ..., colorManageAllNodes: bool = ..., colorManagePots: bool = ..., colorManagedNodes: bool = ..., colorManagementSDKVersion: Queryable[str] = ..., configFilePath: Queryable[str] = ..., configFileVersion: Queryable[str] = ..., defaultInputSpaceName: Queryable[str] = ..., displayName: Queryable[str] = ..., displayNames: bool = ..., equalsToPolicyFile: str = ..., exportPolicy: str = ..., inhibitEvents: bool = ..., inputSpaceDescription: str = ..., inputSpaceFamilies: str = ..., inputSpaceNames: bool = ..., loadPolicy: str = ..., loadedDefaultInputSpaceName: Queryable[str] = ..., loadedDisplayName: Queryable[str] = ..., loadedOutputTransformName: Queryable[str] = ..., loadedRenderingSpaceName: Queryable[str] = ..., loadedViewName: Queryable[str] = ..., loadedViewTransformName: Queryable[str] = ..., missingColorSpaceNodes: bool = ..., ocioRulesEnabled: bool = ..., ociov2Enabled: bool = ..., outputTarget: str = ..., outputTransformEnabled: bool = ..., outputTransformName: Queryable[str] = ..., outputTransformNames: bool = ..., outputTransformUseColorConversion: bool = ..., outputUseViewTransform: bool = ..., policyFileName: Queryable[str] = ..., popupOnError: bool = ..., refresh: bool = ..., renderingSpaceName: Queryable[str] = ..., renderingSpaceNames: bool = ..., restoreDefaults: bool = ..., viewDisplayNames: str = ..., viewName: Queryable[str] = ..., viewNames: bool = ..., viewTransformName: Queryable[str] = ..., viewTransformNames: bool = ...) -> Union[bool, str]:
    """This command allows querying and editing the color management global data in a
    scene.  It also allows for setting the view transform and rendering space which
    automatically configures the color processing in the enabled views.color, management
    Args:
        cmConfigFileEnabled (bool?): Turn on or off applying an OCIO configuration file.  If set, the color  
                management configuration set in the preferences is used.  
                Properties: query, edit
        cmEnabled (bool?): Turn on or off color management in general.  If set, the color  
                management configuration set in the preferences is used.  
                Properties: query, edit
        colorManageAllNodes (bool?): Adds color management to all input nodes such as file texture nodes  
                Properties: create
        colorManagePots (bool?): Turn on or off color management of color pots in the UI.  If set, colors  
                in color pots are taken to be in rendering space, and are displayed after being  
                transformed by the view transform set in the preferences.  
                Properties: query, edit
        colorManagedNodes (bool?): Gets the names of all nodes that apply color management to bring pixels from an input color space  
                to the rendering space. Examples include file texture node.  
                Properties: query
        colorManagementSDKVersion (Queryable[str]?): Obtain the version of the color management SDK used by Maya.  
                Properties: query
        configFilePath (Queryable[str]?): The configuration file to be used, if color management is enabled.  
                Properties: query, edit
        configFileVersion (Queryable[str]?): Obtain the version of the config version.  
                Properties: query
        defaultInputSpaceName (Queryable[str]?): This flag is obsolete.  See the colorManagementFileRules command for more  
                information.  
                Properties: query, edit
        displayName (Queryable[str]?): The display from the (display, view) pair, to be applied by color managed viewers and color  
                managed UI controls.  
                Properties: query, edit
        displayNames (bool?): Returns the list of available displays.  Used to populate the color  
                management preference UI popup.  
                Properties: query
        equalsToPolicyFile (str?): Query if the current loaded policy settings is the same with the settings described  
                in the policy file which is the argument of the command.  
                			In query mode, this flag needs a value.  
                Properties: query
        exportPolicy (str?): Export the color management parameters to policy file  
                Properties: create
        inhibitEvents (bool?): Inhibit client-server notifications and event triggers which occur when changing  
                the color management settings.  
                Properties: create
        inputSpaceDescription (str?): Returns the description for a specific input color space.  
                			In query mode, this flag needs a value.  
                Properties: query
        inputSpaceFamilies (str?): Returns the list of families for a specific input color space. Used to add submenus  
                when populating the input color spaces UI popup.  
                			In query mode, this flag needs a value.  
                Properties: query
        inputSpaceNames (bool?): Returns the list of available input color spaces. Used to populate the input color  
                spaces UI popup.  
                Properties: query
        loadPolicy (str?): Load the color management policy file. This file overides the color management settings.  
                Properties: create
        loadedDefaultInputSpaceName (Queryable[str]?): This flag is obsolete.  
                Properties: query
        loadedDisplayName (Queryable[str]?): Gets the loaded display from the (display, view) pair.  Used by file open, import, and reference  
                to check for missing color spaces or transforms.  
                Properties: query
        loadedOutputTransformName (Queryable[str]?): Gets the loaded output transform.  Used by file open, import, and reference  
                to check for missing color spaces or transforms.  
                Properties: query
        loadedRenderingSpaceName (Queryable[str]?): Gets the loaded rendering space.  Used by file open, import, and reference  
                to check for missing color spaces or transforms.  
                Properties: query
        loadedViewName (Queryable[str]?): Gets the loaded view from the (display, view) pair.  Used by file open, import, and reference  
                to check for missing color spaces or transforms.  
                Properties: query
        loadedViewTransformName (Queryable[str]?): Gets the loaded view transform.  Used by file open, import, and reference  
                to check for missing color spaces or transforms.  
                Properties: query
        missingColorSpaceNodes (bool?): Gets the names of the nodes that have color spaces not defined in the selected transform collection  
                or in the selected config file. Note that an inactive color space is not a missing color space.  
                Properties: query
        ocioRulesEnabled (bool?): Turn on or off the use of colorspace assignment rules from the OCIO library.  
                Properties: query, edit
        ociov2Enabled (bool?): Is OCIOv2 the colour management system by default.  
                Properties: query
        outputTarget (str?): Indicates to which output the outputTransformEnabled or the outputTransformName  
                flags are to be applied. Valid values are "renderer" or "playblast".  
                			In query mode, this flag needs a value.  
                Properties: query, edit
        outputTransformEnabled (bool?): Turn on or off applying the output transform for out of viewport renders.  
                If set, the output transform set in the preferences is used.  
                Properties: query, edit
        outputTransformName (Queryable[str]?): The output transform to be applied for out of viewport renders.  Disables  
                output use view transform mode.  
                Properties: query, edit
        outputTransformNames (bool?): Returns the list of available output transforms.  
                Properties: query
        outputTransformUseColorConversion (bool?): Turn on or off selecting the color space conversion for the output color space  
                of viewport renders.  If set, a conversion color space is used; otherwise,  
                a view transform is used.  
                Properties: query, edit
        outputUseViewTransform (bool?): Turns use view transform mode on.  In this mode, the output transform is set  
                to match the view transform.  To turn the mode off, set an output transform  
                using the outputTransformName flag.  
                Properties: query, edit
        policyFileName (Queryable[str]?): Set the policy file name  
                Properties: query, edit
        popupOnError (bool?): Turn on or off displaying a modal popup on error (as well as the normal  
                script editor reporting of the error), for this invocation of the  
                command.  Default is off.  
                Properties: edit
        refresh (bool?): Refresh the color management.  
                Properties: create
        renderingSpaceName (Queryable[str]?): The color space to be used during rendering.  This is the  
                source color space to the viewing transform, for color managed viewers and  
                color managed UI controls, and the destination color space for color managed  
                input pixels.  
                Properties: query, edit
        renderingSpaceNames (bool?): Returns the list of available rendering spaces.  Used to populate the color  
                management preference UI popup.  
                Properties: query
        restoreDefaults (bool?): Restore the color management settings to their default value.  
                Properties: create
        viewDisplayNames (str?): Returns the list of available views for a specific display. Used to populate the view name  
                list UI for file and image plane nodes.  
                			In query mode, this flag needs a value.  
                Properties: query
        viewName (Queryable[str]?): The view from the (display, view) pair, to be applied by color managed viewers and color  
                managed UI controls.  
                Properties: query, edit
        viewNames (bool?): Returns the list of available views from the selected display.  Used to populate the color  
                management preference UI popup.  
                Properties: query
        viewTransformName (Queryable[str]?): The view transform to be applied by color managed viewers and color  
                managed UI controls.  
                Properties: query, edit
        viewTransformNames (bool?): Returns the list of available view transforms.  Used to populate the color  
                management preference UI popup.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def colorSliderButtonGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., alphaValue: Queryable[float] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., buttonCommand: Callable[..., Any] = ..., buttonLabel: Queryable[str] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., forceDragRefresh: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hsvValue: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rgbValue: Queryable[Tuple[float, float, float]] = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., symbolButtonCommand: Callable[..., Any] = ..., symbolButtonDisplay: bool = ..., useDisplaySpace: bool = ..., useTemplate: str = ..., useVpColorPicker: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, float, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command object creates a new color slider group with a button and a
    symbol button. This control is primarily used in the rendering UI. In this
    context, the button brings up a dialog that allows the user to assign a
    texture map to this parameter. Once a texture map is available, a symbol
    button shows up. When this symbol button is pressed, the user is taken to
    another dialog to edit the texture map.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        alphaValue (Queryable[float]?): Alpha (transparency) of the color. Will show the alpha UI.  
                Alpha will be set only if RGB or HSV is also set at the same time.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        buttonCommand (Callable[..., Any]?): Command string executed when the button is pressed.  
                Properties: create, edit
        buttonLabel (Queryable[str]?): The button text.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when slider value changes.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed when slider value marker is dragged.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        forceDragRefresh (bool?): If used then force refresh on drag  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hsvValue (Queryable[Tuple[float, float, float]]?): Color in hue, saturation, and value format.  
                Properties: create, query, edit
        image (Queryable[str]?): Image displayed on the symbol button.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the group.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rgbValue (Queryable[Tuple[float, float, float]]?): Color in red, green, and blue format.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        symbolButtonCommand (Callable[..., Any]?): Command string executed when the symbol button is pressed.  
                Properties: create, edit
        symbolButtonDisplay (bool?): Visibility of the symbol button.  
                Properties: create, query, edit
        useDisplaySpace (bool?): Set the command call to be done in display space. This sets the color picker to  
                display space. Using the flag when setting or getting the color also converts it  
                accordingly.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        useVpColorPicker (bool?): Enabled to sample the 32bit float version from the viewport instead of the 8 bit integer that QT sees.  
                Note that the viewport color picker does not allow to pick color on hud elements.  
                Properties: create, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def colorSliderGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., alphaValue: Queryable[float] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., forceDragRefresh: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hsvValue: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rgbValue: Queryable[Tuple[float, float, float]] = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useDisplaySpace: bool = ..., useTemplate: str = ..., useVpColorPicker: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, float, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a color Slider group consisting of a label, a
    color canvas and a slider.  Clicking on the canvas will bring up
    the color editor dialog.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        alphaValue (Queryable[float]?): Alpha (transparency) of the color. Will show the alpha UI.  
                Alpha will be set only if RGB or HSV is also set at the same time.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when slider value changes.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed when slider value marker is dragged.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        forceDragRefresh (bool?): If used then force refresh on drag  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hsvValue (Queryable[Tuple[float, float, float]]?): Color in hue, saturation, and value format.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the group.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rgbValue (Queryable[Tuple[float, float, float]]?): Color in red, green, and blue format.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useDisplaySpace (bool?): Set the command call to be done in display space. This sets the color picker to  
                display space. Using the flag when setting or getting the color also converts it  
                accordingly.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        useVpColorPicker (bool?): Enabled to sample the 32bit float version from the viewport instead of the 8 bit integer that QT sees.  
                Note that the viewport color picker does not allow to pick color on hud elements.  
                Properties: create, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def columnLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., columnAlign: str = ..., columnAttach: Tuple[str, int] = ..., columnOffset: Tuple[str, int] = ..., columnWidth: Queryable[int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowSpacing: Queryable[int] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a layout that arranges its children in a
    single column.
    Args:
        adjustableColumn (bool?): Sets the children of the layout to be attached on both sides.  
                They will stretch or shrink with the layout.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        columnAlign (str?): Sets the alignment of children containing text or pixmaps.  
                Align values: "left" | "right" | "center".  
                Properties: create, edit
        columnAttach (Tuple[str, int]?): Sets the attachment and offsets for the children of the  
                layout.  Side values: "left" | "right" | "both".  Left or both is  
                recommended.  
                Properties: create, edit
        columnOffset (Tuple[str, int]?): Sets the offsets for children of the layout.  
                Side values: "left" | "right" | "both".  
                Properties: create, edit
        columnWidth (Queryable[int]?): Sets the width of the column.  Unless the children are  
                attached to both sides of the column, the width cannot be enforced.  
                Larger children will expand layout.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowSpacing (Queryable[int]?): Sets the space between children.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def combinationShape(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., addDriver: bool = ..., allDrivers: bool = ..., blendShape: str = ..., combinationTargetIndex: int = ..., combinationTargetName: str = ..., combineMethod: Queryable[int] = ..., driverTargetIndex: Multiuse[int] = ..., driverTargetName: Multiuse[str] = ..., exist: bool = ..., removeDriver: bool = ...) -> Union[int, bool]:
    """Command to create or edit drive relationship of blend shape targetscombination, target
    Args:
        addDriver (bool?): Add drivers to the combination shape
        allDrivers (bool?): All drivers of the combination shape  
                Properties: query
        blendShape (str?): Associated blend shape node of the combination shape  
                			In query mode, this flag can accept a value.  
                Properties: create
        combinationTargetIndex (int?): Driven blend shape target index of the combination shape  
                			In query mode, this flag can accept a value.  
                Properties: create
        combinationTargetName (str?): Driven blend shape target name of the combination shape  
                			In query mode, this flag can accept a value.  
                Properties: create
        combineMethod (Queryable[int]?): Combine method of the combination shape:  
              
                0. Multiplication  
                1. Lowest Weighting  
                2. Lowest Weighting (Smooth)  
                Properties: create, query, edit
        driverTargetIndex (Multiuse[int]?): Driver blend shape target index of the combination shape  
                Properties: create, multiuse
        driverTargetName (Multiuse[str]?): Driver blend shape target name of the combination shape  
                Properties: create, multiuse
        exist (bool?): If the combination shape exist  
                Properties: query
        removeDriver (bool?): Remove drivers from the combination shape

    Returns:
        int: In edit mode, return the newly created combination shape node name.

    Example:
    """

def commandEcho(*, query: bool = ..., addFilter: List[str] = ..., filter: Queryable[List[str]] = ..., lineNumbers: bool = ..., state: bool = ...) -> Union[bool, List[str]]:
    """This command controls what is echoed to the command window.
    Args:
        addFilter (List[str]?): This flag allows you to append filters to the current list of filtered commands when echo all commands is enabled.  
                Just like the filter flag, you can provide a partial command name, so all commands that start with a substring specified in the addFilter entry will be filtered out.  
                Properties: create
        filter (Queryable[List[str]]?): This flag allows you to filter out unwanted commands when echo all commands is enabled.  
                You can provide a partial command name, so all commands that start with a substring specified in filter entry will be filtered out.  
                If filter is empty, all commands are echoed to the command window.  
                Properties: create, query
        lineNumbers (bool?): If true then file name and line number information is provided in  
                error and warning messages.  
                If false then no file name and line number information is provided  
                in error and warning messages.  
                Properties: create, query
        state (bool?): If true then all commands are echoed to the command window.  
                If false then only relevant commands are echoed.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def commandLine(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., command: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enterCommand: Callable[..., Any] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., holdFocus: bool = ..., inputAnnotation: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfHistoryLines: Queryable[int] = ..., numberOfPopupMenus: bool = ..., outputAnnotation: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., sourceType: Queryable[str] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a single line for command input/output.The left half is for input, the right half for output.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        command (Callable[..., Any]?): Command executed when the command line text changes.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enterCommand (Callable[..., Any]?): Command executed when the keypad 'Enter' key is pressed.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        holdFocus (bool?): Sets whether the command line should hold focus after exectuing a command.  
                Properties: create, query, edit
        inputAnnotation (Queryable[str]?): Annotate the input field with an extra string value.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfHistoryLines (Queryable[int]?): Sets the maximum number of commands saved to the  
                command line history. Up to -nhl/numberOfHistoryLines previous commands  
                will be available by pressing the up-arrow from within the input field.  
                The default value is 50.  
                Properties: create, query, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        outputAnnotation (Queryable[str]?): Annotate the output field with an extra string value.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        sourceType (Queryable[str]?): Sets the source type of this command line.  
                Currently supports "mel" (enabled by default)  
                and "python".  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: : Full path name to the control.

    Example:
    """

def commandLogging(*, query: bool = ..., historySize: Queryable[int] = ..., logCommands: bool = ..., logFile: Queryable[str] = ..., recordCommands: bool = ..., resetLogFile: bool = ...) -> Union[bool, int, str]:
    """This command controls logging of Maya commands,
    in memory and on disk.Note that if commands are logged in memory, they will
    be available to the crash reporter and appear in crash logs.
    Args:
        historySize (Queryable[int]?): Sets the number of entries  
                in the in-memory command history.  
                Properties: create, query
        logCommands (bool?): Enables or disables the on-disk logging  
                of commands.  
                Properties: create, query
        logFile (Queryable[str]?): Sets the filename to use for the on-disk log.  
                If logging is active, the current file will be closed  
                before the new one is opened.  
                Properties: create, query
        recordCommands (bool?): Enables or disables the in-memory logging  
                of commands.  
                Properties: create, query
        resetLogFile (bool?): Reset the log filename to the default  
                ('mayaCommandLog.txt' in the application folder,  
                alongside 'Maya.env' and the default projects folder).  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def commandPort(arg0: str = ..., /, *, query: bool = ..., bufferSize: int = ..., close: bool = ..., echoOutput: bool = ..., listPorts: bool = ..., name: str = ..., noreturn: bool = ..., pickleOutput: bool = ..., prefix: str = ..., returnNumCommands: bool = ..., securityWarning: bool = ..., sourceType: str = ...) -> bool:
    """Opens or closes the Maya command port. The command port comprises a socket
    to which a client program may connect. An example command port client
    "mcp" is included in the Motion Capture developers kit.It supports multi-byte commands and uses utf-8 as its transform
    format. It will receive utf8 command string and decode it to Maya native
    coding. The result will also be encoded to utf-8 before sending back.Care should be taken regarding INET domain sockets as no user
    identification, or authorization is required to connect to a given
    socket, and all commands (including "system(...)") are allowed and
    executed with the user id and permissions of the Maya user. The prefix
    flag can be used to reduce this security risk, as only the prefix
    command is executed.The query flag can be used to determine if a given command port exists.
    See examples below.
    Args:
        bufferSize (int?): Commands and results are each subject to size limits. This option allows  
                the user to specify the size of the buffer used to communicate with Maya. If  
                unspecified the default buffer size is 4096 characters.  
                Commands longer than bufferSize characters will cause the client connection to close.  
                Results longer that bufferSize characters are replaced with an error message.  
                Properties: create
        close (bool?): Closes the commandPort, deletes the pipes  
                Properties: create
        echoOutput (bool?): Sends a copy of all command output to the command port. Typically  
                only the result is transmitted. This option provides a copy of  
                all output.  
                Properties: create
        listPorts (bool?): Returns the available ports  
                Properties: create
        name (str?): Specifies the name of the command port which this command  
                creates. CommandPort names of the form name create a  
                UNIX domain socket on the localhost corresponding to  
                name. If name does not begin with "/",  
                then /tmp/name is used. If name begins  
                with "/", name denotes the full path to the socket.   
                Names of the form :port number create an INET domain  
                on the local host at the given port.  
                Properties: create
        noreturn (bool?): Do not write the results from executed commands back to the  
                command port socket. Instead, the results from executed  
                commands are written to the script editor window. As no information  
                passes back to the command port client regarding the execution  
                of the submitted commands, care must be taken not to overflow  
                the command buffer, which would cause the connection to close.  
                Properties: create
        pickleOutput (bool?): Python output will be pickled.  
                Properties: create
        prefix (str?): The string argument is the name of a Maya command taking one string  
                argument. This command is called each time data is sent to the command  
                port. The data written to the command port is passed as the argument to  
                the prefix command. The data from the command port is encoded as with  
                enocodeString and enclosed in quotes.   
                If newline characters are embedded in the command port data,  
                the input is split into individual lines.  
                These lines are treated as if they were separate  
                writes to the command port. Only the result to the last  
                prefix command is returned.  
                Properties: create
        returnNumCommands (bool?): Ignore the result of the command, but return the number of  
                commands that have been read and executed in this call. This  
                is a simple way to track buffer overflow. This flag is ignored  
                when the noreturn flag is specified.  
                Properties: create
        securityWarning (bool?): Enables security warning on command port input.  
                Properties: create
        sourceType (str?): The string argument is used to indicate which source type  
                would be passed to the commandPort, like "mel", "python".  
                The default source type is "mel".  
                Properties: create

    Returns:
        bool: - in query mode

    Example:
    """

def componentBox(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., execute: Tuple[str, bool] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., labelWidth: Queryable[int] = ..., manage: bool = ..., maxHeight: Queryable[int] = ..., maxWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: Queryable[int] = ..., preventOverride: bool = ..., rowHeight: int = ..., selectedAttr: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a component box, which is sensitive to the active
    list.  It displays certain components of the last node on the active list,
    and provides a two-way connection to keep the widget up to date.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        execute (Tuple[str, bool]?): Immediately executes the command string once for every cell (or every  
                selected cell, if the boolean argument is TRUE) in the  
                component box, for every matching selected object (ie, for every object would  
                be affected if you changed a cell value.)  Before the command is executed,  
                "#A" is substituted with the name of the attribute, and "#N" with the name  
                of the node, and "#P" with the full path name of the node.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        labelWidth (Queryable[int]?): An optional flag which is used to modify the width assigned  
                to labels appearing in the componentBox.  
                Properties: query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxHeight (Queryable[int]?): An optional flag which is used to limit the height of the  
                componentBox.  
                Properties: query, edit
        maxWidth (Queryable[int]?): An optional flag which is used to limit the width of the  
                componentBox.  
                Properties: query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (Queryable[int]?): Controls the number of digits to the right of the decimal  
                point that will be displayed for float-valued components.  
                Default is 3.  Queried, returns an int.  
                Properties: query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowHeight (int?): An optional flag which is used to set the height of all rows in the  
                componentBox.  
                Properties: edit
        selectedAttr (bool?): Returns a list of names of all the attributes that are selected.  
                This flag is ignored when not being queried.  
                Properties: query
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: (the name of the new component box)

    Example:
    """

def componentEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., floatField: Queryable[str] = ..., floatSlider: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., hidePathName: bool = ..., hideZeroColumns: bool = ..., highlightConnection: Queryable[str] = ..., justifyHeaders: Queryable[int] = ..., lockInput: bool = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., newTab: Tuple[str, str, str] = ..., normalizeWeights: int = ..., operationCount: bool = ..., operationLabels: bool = ..., operationType: Queryable[int] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., precision: Queryable[int] = ..., removeTab: str = ..., selected: bool = ..., selectionConnection: Queryable[str] = ..., setOperationLabel: Tuple[int, str] = ..., showNamespaces: bool = ..., showObjects: bool = ..., showSelected: bool = ..., sortAlpha: bool = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool, int]:
    """This command creates a new component editor
    in the current layout.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        floatField (Queryable[str]?): assigns a float field that the component editor will  
                use for editing groups of values.  
                Properties: create, query, edit
        floatSlider (Queryable[str]?): assigns a float slider that the component editor will  
                use for editing groups of values.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        hidePathName (bool?): Hides path name of displayed element.  By default  
                this flag is set to false.  
                Properties: create, query, edit
        hideZeroColumns (bool?): Hides columns whose elements are all zero.  By default  
                this flag is set to false.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        justifyHeaders (Queryable[int]?): Set justification mode for headers of columns.  Possible values  
                are 0 (right justify), or 1 (left justify). By default  
                this flag is set to 0.  
                Properties: create, query, edit
        lockInput (bool?): Prevents the editor from responding to changes in  
                the active list. Independent of selection connection.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        newTab (Tuple[str, str, str]?): Creates a new tab, named by the first argument, based on an existing tab, given as the second argument  
                using elements from a set, given in the third argument  
                Properties: create, edit
        normalizeWeights (int?): Specifies automatic normalization mode of skin clusters. Can be 0, meaning "None", or 1,  
                meaning "Interactive", or 2, meaning "Post". It corresponds to the "normalizeWeights" attribute  
                of skinCluster node.  
                Properties: edit
        operationCount (bool?): returns the total number of operation types  
                known to the component editor.  
                Properties: query
        operationLabels (bool?): returns a string array containing the names for all  
                operation types known to the editor.  
                Properties: query
        operationType (Queryable[int]?): Tells the editor which of its known operation types  
                it should be performing. This is a 0. based index.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        precision (Queryable[int]?): Specifies the maximum number of digits displayed to the right  
                of the decimal place.  Can be 0 to 20.  
                Properties: create, query, edit
        removeTab (str?): Removes the tab based on the set provided  
                Properties: edit
        selected (bool?): Returns a list of strings, containing the labels of the currently selected columns  
                Properties: query
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        setOperationLabel (Tuple[int, str]?): uses the string as the new name for the existing operation type  
                specified by the integer index. Note that there is no messaging  
                system which allows UI to be informed of changes made by this flag.  
                Properties: edit
        showNamespaces (bool?): Show the namespaces for objects, if any.  By default  
                this flag is set to true.  
                Properties: create, query, edit
        showObjects (bool?): Restricts the display to columns that are in the current active list.  
                Properties: create
        showSelected (bool?): Restricts the display to those columns which are currently selected. By default  
                this flag is set to false, so all columns are selected. The results from this flag  
                obey the current -hideZeroColumns setting.  
                Properties: create, edit
        sortAlpha (bool?): Controls alphabetical (true), or hierarchical sorting of columns  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The panel name

    Example:
    """

def componentTag(*args: str, create: bool = ..., delete: bool = ..., injectionLocation: str = ..., modify: str = ..., newTagName: str = ..., queryEdit: bool = ..., rename: bool = ..., tagName: Multiuse[str] = ...) -> Any:
    """This command allows you to create, delete and modify component tags
    Args:
        create (bool?): This creates a componentTag on the geometry. The name can be specified with the  
                -newTagName option. If no new name is specified one will be generated.  
                The name of the created tag is returned  
                Properties: create
        delete (bool?): This deletes the componentTags specified with the -tagName option.  
                Properties: create
        injectionLocation (str?): The name of the injection node at which the componentTag will be edited.  
                This is only necessary in the rare case where a particular componentTag  
                can be altered at multiple injection locations.  
                Properties: create
        modify (str?): This modifies the componentTag specified with the -tagName option.  
                The mode determines whether components are, replaced, cleared, added or removed.  
                Properties: create
        newTagName (str?): The name of the new componentTag to be created or the new name  
                of the componentTag that is being renamed.  
                Properties: create
        queryEdit (bool?): This returns what edits are allowed with the given parameters. When the command  
                is issued in Python a dictionary object containing what is allowed is returned.  
                Properties: create
        rename (bool?): This renames the componentTag specified with the -tagName option to the  
                name specified with the -newTagName option  
                Properties: create
        tagName (Multiuse[str]?): The name(s) of the componentTags to be edited. THis can be a single name or  
                a list of names. The names can contain wildcard like '*' to match multiple  
                existing componentTags.  
                Properties: create, multiuse

    Returns:
        Any: The name of the created componentTag, or whether the command succeeded or the information
            about what can be edited

    Example:
    """

def condition(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., delete: bool = ..., dependency: Multiuse[str] = ..., initialize: bool = ..., script: str = ..., state: bool = ...) -> bool:
    """This command creates a new named condition object whose true/false
    value is calculated by running a mel script. This new condition can
    then be used for dimming, or controlling other scripts, or whatever.
    Args:
        delete (bool?): Deletes the condition.  
                Properties: create
        dependency (Multiuse[str]?): Each -dependency flag specifies another condition that the  
                new condition will be dependent on.  When any of these conditions  
                change, the new-state-script will run, and the state of this  
                condition will be set accordingly.  It is possible to define infinite loops,  
                but they will be caught and handled correctly at run-time.  
                Properties: create, multiuse
        initialize (bool?): Initializes the condition, by forcing it to run its script  
                as soon as it is created.  If this flag is not specified, the  
                script will not run until one of the dependencies is triggered.  
                Properties: create
        script (str?): The script that determines the new state of  
                the condition.  
                Properties: create
        state (bool?): Sets the state of the condition. This can be used to create  
                a manually triggered condition: you could create a condition  
                without any dependencies and without a new-state-script. This  
                condition would only change state in response to the -st/state flag.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def cone(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., degree: Queryable[int] = ..., endSweep: Queryable[float] = ..., heightRatio: Queryable[float] = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., radius: Queryable[float] = ..., sections: Queryable[int] = ..., spans: Queryable[int] = ..., startSweep: Queryable[float] = ..., tolerance: Queryable[float] = ..., useOldInitBehaviour: bool = ..., useTolerance: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The cone command creates a new cone and/or a dependency
    node that creates one, and returns their names.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): The primitive's axis  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface:  
                1. linear,  
                3. cubic  
                Default: 3  
                Properties: create, query, edit
        endSweep (Queryable[float]?): The angle at which to end the surface of revolution.  
                Default is 2Pi radians, or 360 degrees.  
                Default: 6.2831853  
                Properties: create, query, edit
        heightRatio (Queryable[float]?): Ratio of "height" to "width"  
                Default: 2.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The primitive's pivot point  
                Properties: create, query, edit
        radius (Queryable[float]?): The radius of the object  
                Default: 1.0  
                Properties: create, query, edit
        sections (Queryable[int]?): The number of sections determines the resolution of the surface in the sweep direction.  
                Used only if useTolerance is false.  
                Default: 8  
                Properties: create, query, edit
        spans (Queryable[int]?): The number of spans determines the resolution of the surface in the opposite direction.  
                Default: 1  
                Properties: create, query, edit
        startSweep (Queryable[float]?): The angle at which to start the surface of revolution  
                Default: 0  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to build the surface.  
                Used only if useTolerance is true  
                Default: 0.01  
                Properties: create, query, edit
        useOldInitBehaviour (bool?): Create the cone with base on the origin as in Maya V8.0 and below  
                Otherwise create cone centred at origin  
                Default: false  
                Properties: create, query, edit
        useTolerance (bool?): Use the specified tolerance to determine resolution.  
                Otherwise number of sections will be used.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def confirmDialog(*, annotation: Multiuse[str] = ..., backgroundColor: Tuple[float, float, float] = ..., button: Multiuse[str] = ..., cancelButton: str = ..., defaultButton: str = ..., dismissString: str = ..., icon: str = ..., message: str = ..., messageAlign: str = ..., parent: str = ..., title: str = ...) -> str:
    """The confirmDialog command creates a modal dialog with a message to the
    user and a variable number of buttons to dismiss the dialog.  The
    dialog is dismissed when the user presses any button or chooses the
    close item from the window menu.  In the case where a button is
    pressed then the name of the button selected is returned.  If the
    dialog is dismissed via the close item then the string returned is
    specified by theflag.The default behaviour when no arguments are specified is to create an
    empty single button dialog.
    Args:
        annotation (Multiuse[str]?): set the annotation for the buttons  
                Properties: create, multiuse
        backgroundColor (Tuple[float, float, float]?): The background color of the dialog. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0. (Windows only flag)  
                Properties: create
        button (Multiuse[str]?): Create a button with the given string as it's text.  
                Properties: create, multiuse
        cancelButton (str?): The cancel button is activated by pressing the escape key.  
                Note that this flag does not create a button, it simply indicates  
                which button created via the button flag shall respond  
                to the escape key.  
                Properties: create
        defaultButton (str?): The default button is activated by pressing the enter key.  
                Note that this flag does not create a button, it simply indicates  
                which button created via the button flag shall respond  
                to the enter key.  
                Properties: create
        dismissString (str?): The string returned when the user selects the 'Close' item  
                from the Window Manager menu.  If this flag is not set then the  
                string "dismiss" is returned.  
                Properties: create
        icon (str?): The user can specify one of the four standard icons -- "question", "information", "warning" and "critical".  The question icon indicates that the messsage is asking a question.  The information icon indicates that the message is nothing out of the ordinary.  The warning icon indicates that the message is a warning, but can be dealt with.  The critical icon indicates that the message represents a critical problem.  
                When no icon flag is present, we assume the user does not want to  
                include any icon in the confirm dialog.  
                Properties: create
        message (str?): The message text appearing in the dialog.  
                Properties: create
        messageAlign (str?): Align the message left, center, or right.  
                Properties: create
        parent (str?): Specify the parent window for the dialog.  The dialog will  
                be centered on this window and raise and lower with it's parent.  
                By default, the dialog is not parented to a particular window and  
                is simply centered on the screen.  
                Properties: create
        title (str?): The dialog title.  
                Properties: create

    Returns:
        str: Indicates how the dialog was dismissed. If a button is
            pressed then the label of the button is returned. If the dialog is
            closed then the value for the flag dismissString is
            returned.

    Example:
    """

def connectAttr(arg0: str = ..., arg1: str = ..., /, *, force: bool = ..., lock: bool = ..., nextAvailable: bool = ..., referenceDest: str = ...) -> str:
    """Connect the attributes of two dependency nodes and return the
    names of the two connected attributes. The connected
    attributes must be be of compatible types. First argument is the
    source attribute, second one is the destination.Refer to dependency node documentation.
    Args:
        force (bool?): Forces the connection.  If the destination is already  
                connected, the old connection is broken and the new one  
                made.  
                Properties: create
        lock (bool?): If the argument is true, the destination attribute  
                is locked after making the connection. If the argument is false,  
                the connection is unlocked before making the connection.  
                Properties: create
        nextAvailable (bool?): If the destination multi-attribute has set the indexMatters  
                to be false with this flag specified, a connection is made to  
                the next available index. No index need be specified.  
                Properties: create
        referenceDest (str?): This flag is used for file io only. The flag indicates that  
                the connection replaces a connection made in a  
                referenced file, and the flag argument indicates the original  
                destination from the referenced file. This  
                flag is used so that if the reference file is modified, maya  
                can still attempt to make the appropriate connections in the  
                main scene to the referenced object.  
                Properties: create

    Returns:
        str: A phrase containing the names of the connected attributes.

    Example:
    """

def connectControl(arg0: str = ..., /, *args: str, fileName: bool = ..., index: int = ..., preventContextualMenu: bool = ..., preventOverride: bool = ...) -> bool:
    """This command attaches a UI widget, specified as the first argument, to
    one or more dependency node attributes. The attributes/nodes don't
    have to exist yet, they will get looked up as needed. With no flag
    specified, this command works on these kinds of controls: floatField,
    floatScrollBar, floatSlider, intField, intScrollBar, intSlider,
    floatFieldGrp, intFieldGrp, checkBox, radioCollection, and
    optionMenu. With theflag, It will also work on the
    individual components of all other groups.This command sets up abetween the control
    and the (first-specified) attribute. If this first attribute is
    changed in any way, the control will be appropriately updated to match
    its value.Summary: if you change the control, ALL the connected attributes
    change. If you change the FIRST attribute attached to the control,
    then the control will change.NOTE: the two-way connection will not be established if the attributes
    do not exist when thecommand is run. If the
    user later uses the control, the connection will be established at
    that time.To effectively usewith radioCollections and
    optionMenus, you must attach a piece of data to each radioButton and
    menuItem. This piece of data (an integer) can be attached using theflag in theandcommands. When the button/item is selected, the attribute will be set
    to the value of its data. When the attribute is changed, the
    collection (or optionMenu) will switch to the item that matches the
    new attribute value. If no item matches, it will be left unchanged.There are some specialized controls that have connection capability
    (and more) built right into them. See attrFieldSliderGrp,
    attrFieldGrp, and attrColorSliderGrp. Using these classes can be
    easier than using connectControl.
    Args:
        fileName (bool?): This flag causes the connection to be treated as a  
                filename, and the conversion from internal to external  
                filename representation is made as the data is  
                copied. This only applies to connections to Tfield  
                controls.  
                Properties: create
        index (int?): This flag enables you to pick out a sub-control from a  
                group that contains a number of different controls.  
                For example, you can connect one field of a  
                floatFieldGrp.  You must count each member of the  
                group, including any text labels that may exist.  For  
                example, if you have a check box group with a label,  
                the label will count as index 1, and the first check  
                box as index 2.  (Indices are 1. based)  
                Properties: create
        preventContextualMenu (bool?): If true, this flag will block the right mouse button menu  
                of the associated control attribute.  
                Properties: create
        preventOverride (bool?): If true, this flag disallows overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def connectDynamic(*args: str, addScriptHandler: Callable[..., Any] = ..., collisions: Multiuse[str] = ..., delete: bool = ..., emitters: Multiuse[str] = ..., fields: Multiuse[str] = ..., removeScriptHandler: int = ...) -> str:
    """Dynamic connection specifies that the force fields, emitters, or collisions
    of an object affect another dynamic object. The dynamic object that is
    connected to a field, emitter, or collision object is influenced by those
    fields, emitters and collision objects.Connections are made to individual fields, emitters, collisions.  So, if
    an object owns several fields, if the user wants some of the fields to
    affect an object, s/he can specify each field with a "-f" flag; but if
    the user wants to connect all the fields owned by an object, s/he can
    specify the object name with the "-f" flag. The same is true for
    emitters and collisions.
    Different connection types (i.e., for fields vs. emitters)
    between the same pair of objects are logically
    independent. In other words, an
    object can be influenced by another object's fields without being
    influenced by its emitters or collisions.Each connected object must be a dynamic object. The object connected to
    can be any object that
    owns fields, emitters, etc.; it need not be dynamic. Objects that can
    own influences are particles, geometry objects (nurbs and polys) and
    lattices.  You can specify either the shape name or the transform name of
    the object to be influenced.
    Args:
        addScriptHandler (Callable[..., Any]?): Registers a script that will be given a chance to handle calls to the  
                dynamicConnect command. This flag allows other dynamics systems to  
                override the behaviour of the connectDynamic command. You must pass a Python  
                function as the argument for this flag, and that function must take the  
                following keyword arguments: fields, emitters, collisionObjects and objects.  
                The python function must return True if it has handled the call to  
                connectDynamic. In the case that the script returns true, the connectDynamic  
                command will not do anything as it assumes that the work was handled by the  
                script. If all of the callbacks return false, the connectDynamic command will  
                proceed as normal.  
              
                The addScriptHandler flag may not be used with any other flags. When the  
                flag is used, the command will return a numerical id that can be used to  
                deregister the callback later (see the removeScriptHandler flag)  
                Properties: create
        collisions (Multiuse[str]?): Connects each object to the collision models of the given object.  
                Properties: create, multiuse
        delete (bool?): Deletes existing connections.  
                Properties: create
        emitters (Multiuse[str]?): Connects each object to the emitters of the given object.  
                Properties: create, multiuse
        fields (Multiuse[str]?): Connects each object to the fields of the given object.  
                Properties: create, multiuse
        removeScriptHandler (int?): This flag is used to remove a callback that was previously registered  
                with the addScriptHandler flag. The argument to this flag is the numerical  
                id returned by dynamicConnect when the addScriptHandler flag was used.  
                If this flag is called with an invalid id, then the command will do  
                nothing.  
              
                This flag may not be used with any other flag.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def connectJoint(arg0: str = ..., arg1: str = ..., /, *, connectMode: bool = ..., parentMode: bool = ...) -> bool:
    """This command will connect two skeletons based on the two selected joints.
    The first selected joint can be made a child of the parent of the second
    selected joint or a child of the second selected joint, depending on
    the flags used.Note1: The first selected joint must be the root of a skeleton.
    The second selected joint must have a parent.Note2: If a joint name is specified in the command line, it is used as the
    child and the first selected joint will be the parent. If no joint
    name is given at the command line, two joints must be selected.
    Args:
        connectMode (bool?): The first selected joint will be parented under the parent of the  
                second selected joint.  
                Properties: create
        parentMode (bool?): The first selected joint will be parented under the second selected  
                joint. Both joints will be in the active list(selection list).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def connectionInfo(arg0: str = ..., /, *, destinationFromSource: bool = ..., getExactDestination: bool = ..., getExactSource: bool = ..., getLockedAncestor: bool = ..., isDestination: bool = ..., isExactDestination: bool = ..., isExactSource: bool = ..., isLocked: bool = ..., isSource: bool = ..., sourceFromDestination: bool = ...) -> Union[bool, str, List[str]]:
    """Thecommand is used to get information about
    connection sources and destinations.  Unlike the isConnected command,
    this command needs only one end of the connection.
    Args:
        destinationFromSource (bool?): If the specified plug (or its ancestor) is a source, this flag returns  
                the list of destinations connected from the source. (array of strings,  
                empty array if none)  
                Properties: create
        getExactDestination (bool?): If the plug or its ancestor is connection destination, this returns the  
                name of the plug that is the exact destination. (empty string if there  
                is no such connection).  
                Properties: create
        getExactSource (bool?): If the plug or its ancestor is a connection source, this returns the  
                name of the plug that is the exact source. (empty string if there is  
                no such connection).  
                Properties: create
        getLockedAncestor (bool?): If the specified plug is locked, its name is returned.  If an  
                ancestor of the plug is locked, its name is returned.  If more  
                than one ancestor is locked, only the name of the closest one  
                is returned.  If neither this plug nor any ancestors are locked,  
                an empty string is returned.  
                Properties: create
        isDestination (bool?): Returns true if the plug (or its ancestor) is the destination  
                of a connection, false otherwise.  
                Properties: create
        isExactDestination (bool?): Returns true if the plug is the exact destination of a connection,  
                false otherwise.  
                Properties: create
        isExactSource (bool?): Returns true if the plug is the exact source of a connection,  
                false otherwise.  
                Properties: create
        isLocked (bool?): Returns true if this plug (or its ancestor) is locked  
                Properties: create
        isSource (bool?): Returns true if the plug (or its ancestor) is the source of a  
                connection, false otherwise.  
                Properties: create
        sourceFromDestination (bool?): If the specified plug (or its ancestor) is a destination, this flag returns  
                the source of the connection. (string, empty if none)  
                Properties: create

    Returns:
        bool: When asking for a property, depending on the flags used.
        str: When asking for a plug name.
        List[str]: When asking for a list of plugs.

    Example:
    """

def constrain(*args: str, edit: bool = ..., query: bool = ..., barrier: bool = ..., damping: Queryable[float] = ..., directionalHinge: bool = ..., hinge: bool = ..., interpenetrate: bool = ..., nail: bool = ..., name: Queryable[str] = ..., orientation: Queryable[Tuple[float, float, float]] = ..., pinConstraint: bool = ..., position: Queryable[Tuple[float, float, float]] = ..., restLength: Queryable[float] = ..., spring: bool = ..., stiffness: Queryable[float] = ...) -> Union[bool, float, str, Tuple[float, float, float]]:
    """This command constrains rigid bodies to the world or other rigid bodies.
    Args:
        barrier (bool?): Creates a barrier constraint.  This command requires one rigid bodies.  
                Properties: create, query
        damping (Queryable[float]?): Sets the damping constant.  
                Default value: 0.1  
                Range: -1000.0 to 1000.0  
                Properties: create, query, edit
        directionalHinge (bool?): Creates a directional hinge constraint.  This command requires two rigid bodies.  
                The directional hinge always maintains the initial direction of its axis.  
                Properties: create, query
        hinge (bool?): Creates a hinge constraint.  This command requires one or two rigid bodies.  
                Properties: create, query
        interpenetrate (bool?): Allows (or disallows) the rigid bodies defined in the constrain to ipenetrate.  
                Properties: create, query, edit
        nail (bool?): Creates a nail constraint.  This command requires one rigid body.  
                Properties: create, query
        name (Queryable[str]?): Names the rigid constraint.  
                Properties: create, query, edit
        orientation (Queryable[Tuple[float, float, float]]?): Set initial orientation of the constraint in world space.  This  
                command is only valid with hinge and barrier constraints  
                Default value: 0.0 0.0 0.0  
                Properties: create, query, edit
        pinConstraint (bool?): Creates a pin constraint.  This command requires two rigid bodies.  
                Properties: create, query
        position (Queryable[Tuple[float, float, float]]?): Set initial position of the constraint in world space.  
                Default value: 0.0 0.0 0.0 for uni-constraints, midpoint of bodies for deul constraint.  
                Properties: create, query, edit
        restLength (Queryable[float]?): Sets the rest length.  
                Default value: 1.0  
                Properties: create, query, edit
        spring (bool?): Creates a spring constraint.  This command requires one or two rigidies.  
                Properties: create, query
        stiffness (Queryable[float]?): Sets the springs stiffness constant.  
                Default value: 5.0  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def constructionHistory(*, query: bool = ..., toggle: bool = ...) -> bool:
    """This command turns construction history on or off.
    Args:
        toggle (bool?): Turns construction history on or off.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def container(*args: str, edit: bool = ..., query: bool = ..., addNode: List[str] = ..., asset: Queryable[List[str]] = ..., assetMember: str = ..., bindAttr: Queryable[Tuple[str, str]] = ..., connectionList: bool = ..., current: bool = ..., fileName: List[str] = ..., findContainer: List[str] = ..., force: bool = ..., includeHierarchyAbove: bool = ..., includeHierarchyBelow: bool = ..., includeNetwork: bool = ..., includeNetworkDetails: Multiuse[str] = ..., includeShaders: bool = ..., includeShapes: bool = ..., includeTransform: bool = ..., isContainer: bool = ..., name: str = ..., nodeList: bool = ..., nodeNamePrefix: bool = ..., parentContainer: bool = ..., preview: bool = ..., publishAndBind: Tuple[str, str] = ..., publishAsChild: Queryable[Tuple[str, str]] = ..., publishAsParent: Queryable[Tuple[str, str]] = ..., publishAsRoot: Queryable[Tuple[str, bool]] = ..., publishAttr: str = ..., publishConnections: bool = ..., publishName: Queryable[str] = ..., removeContainer: bool = ..., removeNode: List[str] = ..., type: Queryable[str] = ..., unbindAndUnpublish: str = ..., unbindAttr: Queryable[Tuple[str, str]] = ..., unbindChild: str = ..., unbindParent: str = ..., unpublishChild: str = ..., unpublishName: str = ..., unpublishParent: str = ..., unsortedOrder: bool = ...) -> Union[str, List[str], Tuple[str, str], bool, Tuple[str, bool]]:
    """This command can be used to create and query container
    nodes. It is also used to perform operations on containers such as:
    Args:
        addNode (List[str]?): Specifies the list of nodes to add to container.  
                Properties: create, edit
        asset (Queryable[List[str]]?): When queried, if all the nodes in nodeList belong to the same container, returns container's name.  
                Otherwise returns empty string. This flag is functionally equivalent to the findContainer flag.  
                Properties: query
        assetMember (str?): Can be used during query in conjunction with the bindAttr flag to query  
                for the only published attributes related to the specified node within the  
                container.  
                      In query mode, this flag needs a value.  
                Properties: query
        bindAttr (Queryable[Tuple[str, str]]?): Bind a contained attribute to an unbound published name on the interface of the  
                container; returns a list of bound published names.  
                The first string specifies the node and attribute name to be  
                bound in "node.attr" format. The second string specifies the name of the  
                unbound published name. In query mode, returns a string array of the published  
                names and their corresponding attributes. The flag can also be used in query  
                mode in conjunction with the -publishName, -publishAsParent, and  
                -publishAsChild flags.  
                Properties: query, edit
        connectionList (bool?): Returns a list of the exterior connections to the container node.  
                Properties: query
        current (bool?): In create mode, specify that the newly created asset should be current.  
                In edit mode, set the selected asset as current. In query, return the  
                current asset.  
                Properties: create, query, edit
        fileName (List[str]?): Used to query for the assets associated with a given file name.  
                      In query mode, this flag needs a value.  
                Properties: query
        findContainer (List[str]?): When queried, if all the nodes in nodeList belong to the same container, returns container's name.  
                Otherwise returns empty string.  
                      In query mode, this flag needs a value.  
                Properties: query
        force (bool?): This flag can be used in conjunction with -addNode and -removeNode flags only.  
                If specified with -addNode, nodes will be disconnected from their current containers before they are added to new one.  
                If specified with -removeNode, nodes will be removed from all containers, instead of remaining in the parent container if being removed from a nested container.  
                Properties: create, edit
        includeHierarchyAbove (bool?): Used to specify that the parent hierarchy of the supplied node list should  
                also be included in the container (or deleted from the container). Hierarchy  
                inclusion will stop at  
                nodes which are members of other containers.  
                Properties: create, edit
        includeHierarchyBelow (bool?): Used to specify that the hierarchy below the supplied node list should  
                also be included in the container (or delete from the container). Hierarchy  
                inclusion will stop at  
                nodes which are members of other containers.  
                Properties: create, edit
        includeNetwork (bool?): Used to specify that the node network connected to supplied node list  
                should also be included in the container.  
                Network traversal will stop at default nodes and nodes which are members of  
                other containers.  
                Properties: create, edit
        includeNetworkDetails (Multiuse[str]?): Used to specify specific parts of the network that should be included. Valid arguments to this flag are: "channels", "sdk", "constraints", "history" and "expressions", "inputs", "outputs". The difference between this flag and the includeNetwork flag, is that it will include all connected nodes regardless of their type. Note that dag containers include their children, so they will always include constraint nodes that are parented beneath the selected objects, even when constraints are not specified as an input.  
                Properties: create, edit, multiuse
        includeShaders (bool?): Used to specify that for any shapes included, their shaders will  
                also be included in the container.  
                Properties: create, edit
        includeShapes (bool?): Used to specify that for any transforms selected, their direct child shapes  
                will be included in the container (or deleted from the container). This flag  
                is not necessary when  
                includeHierarchyBelow is used since the child shapes and all other  
                descendents will automatically be included.  
                Properties: create, edit
        includeTransform (bool?): Used to specify that for any shapes selected, their parent transform  
                will be included in the container (or deleted from the container).  
                This flag is not necessary when  
                includeHierarchyAbove is used since the parent transform and  
                all of its parents will automatically be included.  
                Properties: create, edit
        isContainer (bool?): Return true if the selected or specified node is a container node.  
                If multiple containers are queried, only the state of the first will be  
                returned.  
                Properties: query
        name (str?): Sets the name of the newly-created container.  
                Properties: create
        nodeList (bool?): When queried, returns a list of nodes in container. The list will be sorted in the order they were added to the container.  
                This will also display any reordering done with the reorderContainer command.  
                Properties: query
        nodeNamePrefix (bool?): Specifies that the name of published attributes should be of the form "node_attr".  
                Must be used with the -publishConnections/-pc flag.  
                Properties: create, edit
        parentContainer (bool?): Flag to query the parent container of a specified container.  
                Properties: query
        preview (bool?): This flag is valid in create mode only. It indicates that you do not  
                want the container to be created, instead you want to preview its contents.  
                When this flag is used, Maya will select the  
                nodes that would be put in the container if you did create the  
                container. For example you can see what would go into the container  
                with -includeNetwork, then modify your selection as desired, and do a  
                create container with the selected objects only.  
                Properties: create
        publishAndBind (Tuple[str, str]?): Publish the given name and bind the attribute to the given name.  
                First string specifies the node and attribute name in "node.attr" format.  
                Second string specifies the name it should be published with.  
                Properties: edit
        publishAsChild (Queryable[Tuple[str, str]]?): Publish contained node to the interface of the container to indicate it can  
                be a child of external nodes. The second string is the name of the published  
                node. In query mode, returns a string of the published names and the  
                corresponding nodes. If -publishName flag is used in query mode, only  
                returns the published names; if -bindAttr flag is used in query mode, only  
                returns the name of the published nodes.  
                Properties: query, edit
        publishAsParent (Queryable[Tuple[str, str]]?): Publish contained node to the interface of the container to indicate it can  
                be a parent to external nodes. The second string is the name of the published  
                node. In query mode, returns a string of array of the published names and  
                the corresponding nodes. If -publishName flag is used in query mode, only  
                returns the published names; if -bindAttr flag is used in query mode, only  
                returns the name of the published nodes.  
                Properties: query, edit
        publishAsRoot (Queryable[Tuple[str, bool]]?): Publish or unpublish a node as a root. The significance of root transform  
                node is twofold. When container-centric selection is enabled, the root  
                transform will be selected if a container node in the hierarchy below it is  
                selected in the main scene view. Also, when exporting a container proxy,  
                any published root transformation attributes such as translate, rotate or  
                scale will be hooked up to attributes on a stand-in node.  
                In query mode, returns the node that has been published as root.  
                Properties: query, edit
        publishAttr (str?): In query mode, can only be used with the -publishName(-pn) flag, and takes  
                an attribute as an argument; returns the published name of the attribute, if  
                any.  
                      In query mode, this flag needs a value.  
                Properties: query
        publishConnections (bool?): Publish all connections from nodes inside the container to nodes outside  
                the container.  
                Properties: create, edit
        publishName (Queryable[str]?): Publish a name to the interface of the container, and returns the actual name  
                published to the interface.  In query mode, returns the  
                published names for the container. If the -bindAttr flag is specified, returns  
                only the names that are bound; if the -unbindAttr flag is specified, returns  
                only the names that are not bound; if the -publishAsParent/-publishAsChild  
                flags are specified, returns only names of published parents/children.  
                if the -publishAttr is specified with an attribute argument in the "node.attr"  
                format, returns the published name for that attribute, if any.  
                Properties: query, edit
        removeContainer (bool?): Disconnects all the nodes from container and deletes container node.  
                Properties: edit
        removeNode (List[str]?): Specifies the list of nodes to remove from container. If node is a member of a nested container, it will be added to the parent container. To remove from all containers completely, use the -force flag.  
                Properties: edit
        type (Queryable[str]?): By default, a container node will be created. Alternatively, the  
                type flag can be used to indicate that a different type of container  
                should be created. At the present time, the only other valid type of  
                container node is "dagContainer".  
                Properties: create, query
        unbindAndUnpublish (str?): Unbind the given attribute (in "node.attr" format) and unpublish its associated name.  
                Unbinding a compound may trigger unbinds of its compound parents/children. So the  
                advantage of using this one flag is that it will automatically unpublish the names  
                associated with these automatic unbinds.  
                Properties: edit
        unbindAttr (Queryable[Tuple[str, str]]?): Unbind a published attribute from its published name on the interface of the  
                container, leaving an unbound published name on the interface of the  
                container; returns a list of unbound published names.  
                The first string specifies the node and attribute name to be  
                unbound in "node.attr" format, and the second string specifies the name of  
                the bound published name. In query mode, can only be used with the -publishName,  
                -publishAsParent and -publishAsChild flags.  
                Properties: query, edit
        unbindChild (str?): Unbind the node published as child, but do not remove its published name  
                from the interface of the container.  
                Properties: edit
        unbindParent (str?): Unbind the node published as parent, but do not remove its published name  
                from the interface of the container.  
                Properties: edit
        unpublishChild (str?): Unpublish node published as child from the interface of the container  
                Properties: edit
        unpublishName (str?): Unpublish an unbound name from the interface of the container.  
                Properties: edit
        unpublishParent (str?): Unpublish node published as parent from the interface of the container  
                Properties: edit
        unsortedOrder (bool?): This flag has no effect on the operation of the container command (OBSOLETE).  
                Properties: query

    Returns:
        str: Name of the node created.

    Example:
    """

def containerBind(*args: str, edit: bool = ..., query: bool = ..., allNames: bool = ..., bindingSet: str = ..., bindingSetConditions: bool = ..., bindingSetList: bool = ..., force: bool = ..., preview: bool = ...) -> bool:
    """This is an accessory command to the container command which is used
    for some automated binding operations on the container. A container's
    published interface can be bound using a bindingSet on the
    associated container template.bind, container
    Args:
        allNames (bool?): Specifies that all published names on the container should be considered  
                during the binding operation.  By default only unbound published names  
                will be operated on.  Additionally specifying the 'force' option with 'all'  
                will cause all previously bound published names to be reset (or unbound)  
                before the binding operation is performed; in the event that there is no  
                appropriate binding found for the published name, it will be left in the  
                unbound state.  
                Properties: create
        bindingSet (str?): Specifies the name of the template binding set to use for the bind or  
                query operation.  
                This flag is not available in query mode.  
                			In query mode, this flag needs a value.  
                Properties: query
        bindingSetConditions (bool?): Used in query mode, returns a list of binding set condition entries from the  
                specified template binding set.  The list returned is composed of  
                of all published name / condition string pairs for each entry in the  
                binding set.  
                This flag returns all entries in the associated binding set and does not take  
                into account the validity of each entry with respect to the container's  
                list of published names, bound or unbound state, etc.  
                Properties: query
        bindingSetList (bool?): Used in query mode, returns a list of available binding sets that  
                are defined on the associated container template.  
                Properties: query, edit
        force (bool?): This flag is used to force certain operations to proceed that would normally  
                not be performed.  
                Properties: create
        preview (bool?): This flag will provide a preview of the results of a binding operation but  
                will not actually perform it.  A list of publishedName/boundName  
                pairs are returned for each published name that would be affected by the  
                binding action.  
                If the binding of a published name will not change as a result of the action it  
                will not be listed.  
                Published names that were bound but will become unbound are also listed,  
                in this case the associated boundName will be indicated by an empty string.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def containerProxy(*args: str, edit: bool = ..., query: bool = ..., fromTemplate: str = ..., type: str = ...) -> bool:
    """Creates a new container with the same published interface, dynamic attributes
    and attribute values as the specified container but with fewer container
    members. This proxy container can be used as a reference proxy so that values
    can be set on container attributes without loading in the full container.
    The proxy container will contain one or more locator nodes. The first locator
    has dynamic attributes that serve as stand-ins for the original published
    attributes. The remaining locators serve as stand-ins for any dag nodes
    that have been published as parent or as child and will be placed at the
    world space location of the published parent/child nodes.
    The expected usage of container proxies is to serve as a reference proxy
    for a referenced container. For automated creation, export and setup
    of the proxy see the doExportContainerProxy.mel script which is
    invoked by the "Export Container Proxy" menu item.proxy, container
    Args:
        fromTemplate (str?): Specifies the name of a template file which will be used to create the new  
                container proxy. Stand-in attributes will be created and published for all  
                the numeric attributes on the proxy.  
                Properties: create
        type (str?): Specifies the type of container node to use for the proxy. This flag is only  
                valid in conjunction with the fromTemplate flag. When creating a proxy for an  
                existing container, the type created will always be identical to that of the source  
                container. The default value for this flag is 'container'.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def containerPublish(*args: str, edit: bool = ..., query: bool = ..., bindNode: Queryable[Tuple[str, str]] = ..., bindTemplateStandins: bool = ..., inConnections: bool = ..., mergeShared: bool = ..., outConnections: bool = ..., publishNode: Queryable[Tuple[str, str]] = ..., unbindNode: Queryable[str] = ..., unpublishNode: Queryable[str] = ...) -> Union[bool, Tuple[str, str], str]:
    """This is an accessory command to the container command which is used
    for some advanced publishing operations on the container. For example,
    the "publishConnections" flag on the container will publish all the
    connections, but this command can be used to publish just the inputs,
    outputs, or to collapse the shared inputs into a single attribute
    before publishing.publish, container
    Args:
        bindNode (Queryable[Tuple[str, str]]?): Bind the specified node to the published node name.  
                Properties: create, query, edit
        bindTemplateStandins (bool?): This flag will create a temporary stand-in attribute for any  
                attributes that exist in the template but are not already bound.  
                This enables you to set values for unbound attributes.  
                Properties: create, query, edit
        inConnections (bool?): Specifies that the unpublished connections to nodes in the container  
                from external nodes should be published.  
                Properties: create
        mergeShared (bool?): For use with the inConnections flag. Indicates that when an external  
                attribute connects to multiple internal attributes within the container, a  
                single published attribute should be used to correspond to all of the  
                internal attributes.  
                Properties: create
        outConnections (bool?): Specifies that the unpublished connections from nodes in the container  
                to external nodes should be published.  
                Properties: create
        publishNode (Queryable[Tuple[str, str]]?): Publish a name and type. When first published, nothing will be bound.  
                To bind a node to the published name, use the bindNode flag.  
                Properties: create, query, edit
        unbindNode (Queryable[str]?): Unbind the node that is published with the name specified by the flag.  
                Properties: create, query, edit
        unpublishNode (Queryable[str]?): Unpublish the specified published node name.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def containerTemplate(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addBindingSet: str = ..., addNames: bool = ..., addView: str = ..., allKeyable: bool = ..., attribute: Multiuse[str] = ..., attributeList: Queryable[str] = ..., baseName: Queryable[str] = ..., bindingSetList: Queryable[str] = ..., childAnchor: bool = ..., delete: bool = ..., expandCompounds: bool = ..., fromContainer: str = ..., fromSelection: bool = ..., layoutMode: int = ..., matchName: str = ..., parentAnchor: bool = ..., publishedNodeList: Queryable[str] = ..., removeBindingSet: str = ..., removeView: str = ..., rootTransform: bool = ..., save: bool = ..., searchPath: Queryable[str] = ..., templateList: Queryable[str] = ..., updateBindingSet: str = ..., useHierarchy: bool = ..., exists: bool = ..., fileName: Queryable[str] = ..., force: bool = ..., load: bool = ..., matchFile: str = ..., silent: bool = ..., unload: bool = ..., viewList: Queryable[str] = ...) -> Union[bool, str]:
    """A container template is a description of a container's published interface.
    This command provides the ability to create and save a template file for a
    container or load an existing template file.  Once a template exists,
    the user can query the template information.container, template
    Args:
        addBindingSet (str?): This argument is used to add a new binding set with the given name to a template.  
                A default binding set will be created. If the binding set already exists, the  
                force flag must be used to replace the existing binding set.  
                When used with the fromContainer option, default bindings will be entered based  
                on the current bindings of the designated container.  
                When used without a reference container, the binding set will be made with  
                placeholder entries.  
                The template must be saved before the new binding set is permanently stored with  
                the template file.  
                Properties: create, edit
        addNames (bool?): In edit mode, when used with the fromContainer flag, any published name on the  
                container not present as an attribute on the template will be added to the  
                template.  
                Properties: edit
        addView (str?): This argument is used to add a new view with the given name to a template.  
                By default a view containing a flat list of all template attributes  
                will be created.  The layoutMode flag provides more layout options.  
                The template must be saved before the new view is permanently stored with  
                the template file.  
                Properties: create, edit
        allKeyable (bool?): Used when the fromSelection flag is true and fromContainer is false. If true we will use  
                all keyable attributes to define the template or the view, if false we use the attributes  
                passed in with the attribute flag.  
                Properties: create, edit
        attribute (Multiuse[str]?): If fromSelection is true and allKeyable is false, this  
                attribute name will be used to create an attribute item in the template file.  
                Properties: create, edit, multiuse
        attributeList (Queryable[str]?): Used in query mode, returns a list of attributes contained in the  
                template definition.  
                Properties: create, query, edit
        baseName (Queryable[str]?): Used in query mode, returns the base name of the template.  
                The basename is the template name with any package qualifiers stripped off.  
                Properties: create, query
        bindingSetList (Queryable[str]?): Used in query mode, returns a list of all binding sets defined on the template.  
                Properties: create, query
        childAnchor (bool?): This flag can be optionally specified when querying the publishedNodeList.  
                The resulting list will contain only childAnchor published nodes.  
                Properties: create, query
        delete (bool?): Delete the specified template and its file.  
                All objects that are associated with this template or contained in the  
                same template file will be deleted.  
                To simply unload a template without permanently deleting its file,  
                use unload instead.  
                Properties: create
        expandCompounds (bool?): This argument is used to determine how compound parent attributes  
                and their children will be added to generated views when both are published  
                to the container.  
                When true, the compound parent and all compound child attributes published to the  
                container will be included in the view.  
                When false, only the parent attribute is included in the view.  
                Note: if only the child attributes are published and not the parent, the children  
                will be included in the view, this flag is only used in the situation where both  
                parent and child attributes are published to the container.  
                The default value is false.  
                Properties: create, edit
        fromContainer (str?): This argument is used in create or edit mode to specify a container node  
                to be used for generating the template contents.  
                In template creation mode, the template definition will be created  
                based on the list of published attributes in the specified container.  
                In edit mode, when used with the addNames flag or with no other flag, any  
                published name on the container not present as an attribute  
                on the template will be added to the template.  
                This flag is also used in conjunction with flags such as addView.  
                Properties: create
        fromSelection (bool?): If true, we will use the active selection list to create the template or the view.  
                If allKeyable is also true then we will create the template from all keyable  
                attributes in the selection, otherwise we will create the template using the  
                attributes specified with the attribute flag.  
                Properties: create, edit
        layoutMode (int?): This argument is used to specify the layout mode when creating a view.  
                Values correspond as follows:  
                0. layout in flat list (default when not creating view from container)  
                1. layout grouped by node (default if creating view from container)  
                The fromContainer or fromSelection argument is required to provide the  
                reference container or selection for layout modes that require node  
                information.  Note that views can only refer to defined template attributes.  
                This means that when using the fromContainer or from Selection flag to  
                add a view to an existing template, only attributes that are defined on  
                both the template and the container or the current selection will be  
                included in the view (i.e. published attributes on the container that  
                are not defined in the template will be ignored).  
                Properties: create
        matchName (str?): Used in query mode in conjunction with other flags this flag specifies  
                an optional template name that is to be matched as part of the query operation.  
                The base template name is used for matching, any template with the same  
                basename will be matched even across different packages.  
                			In query mode, this flag needs a value.  
                Properties: query
        parentAnchor (bool?): This flag can be optionally specified when querying the publishedNodeList.  
                The resulting list will contain only parentAnchor published nodes.  
                Properties: create, query
        publishedNodeList (Queryable[str]?): Used in query mode, returns a list of published nodes contained in the  
                template definition.  
                By default all published nodes on the template will be returned.  
                The list of published nodes can be limited to only include certain types of  
                published nodes using one of the childAnchor, parentAnchor or rootTransform flags.  
                If an optional flag is are specified, only nodes of the specified type  
                will be returned.  
                Properties: create, query, edit
        removeBindingSet (str?): This argument is used to remove the named binding set from the template.  
                The template must be saved before the binding set is permanently removed from  
                the template file.  
                Properties: create, edit
        removeView (str?): This argument is used to remove the named view from the template.  
                The template must be saved before the view is permanently removed from  
                the template file.  
                Properties: create, edit
        rootTransform (bool?): This flag can be optionally specified when querying the publishedNodeList.  
                The resulting list will contain only rootTransform published nodes.  
                Properties: create, query
        save (bool?): Save the specified template to a file.  
                If a filename is specified for the template, the entire file  
                (and all templates associated with it) will be saved.  
                If no file name is specified, a default filename will be assumed,  
                based on the template name.  
                Properties: create
        searchPath (Queryable[str]?): The template searchPath is an ordered list of all locations that are being  
                searched to locate template files (first location searched to last location  
                searched).  
                The template search path setting is stored in the current workspace  
                and can also be set and queried as the file rule entry for 'templates'  
                (see the workspace command for more information).  
                In edit mode, this flag allows the search path setting to be customized.  
                When setting the search path value, the list should conform to a path list format  
                expected on the current platform.  This means that paths should be  
                separated by a semicolon (;) on Windows and a colon (:) on Linux and MacOSX.  
                Environment variables can also be used.  
                Additional built-in paths may be added automatically by maya to the customized  
                settings.  
                In query mode, this flag returns the current contents of the search path;  
                all paths, both customized and built-in, will be included in the query return  
                value.  
                Properties: query, edit
        templateList (Queryable[str]?): Used in query mode, returns a list of all loaded templates.  
                This query can be used with optional matchFile and matchName flags.  
                When used with the matchFile flag, the list of templates will be restricted  
                to those associated with the specified file.  When used with the matchName  
                flag, the list of templates will be restricted to those matching the specified  
                template name.  
                Properties: query
        updateBindingSet (str?): This argument is used to update an existing binding set with new bindings.  
                When used with the fromContainer argument binding set entries with be replaced  
                or merged in the binding set based on the bindings of the designated container.  
                If the force flag is used, existing entries in the binding set are replaced  
                with new values.  
                When force is not used, only new entries are merged into the binding set,  
                any existing entries will be left as-is.  
                When used without a reference container, the binding set will be updated  
                with placeholder entries.  
                The template must be saved before the new binding set is permanently stored with  
                the template file.  
                Properties: create, edit
        useHierarchy (bool?): If true, and the fromSelection flag is set, the selection list will expand  
                to include it's hierarchy also.  
                Properties: create, edit
        exists (bool?): Returns true or false depending upon whether the specified template exists.  
                When used with the matchFile argument, the query will return true if the  
                template exists and the filename it was loaded from matches the filename  
                given.  
                Properties: query
        fileName (Queryable[str]?): Specifies the filename associated with the template.  This argument can be  
                used in conjunction with load, save or query modes. If no filename is  
                associated with a template, a default file name based on the template  
                name will be used.  It is recommended but not required that the  
                filename and template name correspond.  
                Properties: create, query
        force (bool?): This flag is used with some actions to allow them to proceed with an  
                overwrite or destructive operation.  
                When used with load, it will allow an existing template to be reloaded  
                from a file.  When used in create mode, it will allow an existing template  
                to be recreated (for example when using fromContainer argument to  
                regenerate a template).  
                Properties: create
        load (bool?): Load an existing template from a file.  
                If a filename is specified for the template, the entire file  
                (and all templates in it) will be loaded.  
                If no file is specified, a default filename will be assumed,  
                based on the template name.
        matchFile (str?): Used in query mode in conjunction with other flags this flag specifies  
                an optional file name that is to be matched as part of the query operation.  
                			In query mode, this flag needs a value.  
                Properties: query
        silent (bool?): Silent mode will suppress any error or warning messages that would normally be  
                reported from the command execution.  The return values are unaffected.  
                Properties: create, query, edit
        unload (bool?): Unload the specified template.  This action will not delete the  
                associated template file if one exists, it merely removes the template  
                definition from the current session.  
                Properties: create
        viewList (Queryable[str]?): Used in query mode, returns a list of all views defined on the template.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def containerView(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., itemInfo: str = ..., itemList: bool = ..., viewDescription: bool = ..., viewLabel: bool = ..., viewList: bool = ..., viewName: Queryable[str] = ...) -> Union[bool, str]:
    """A container view defines the layout information for the published attributes of a
    particular container.  Container views can be selected from a set of
    built-in views or may be defined on an associated container template.
    This command queries the view-related information for a container node.
    The information returned from this command will be based on the view-related
    settings in force on the container node at the time of the query
    (i.e. the container's view mode, template name, view name attributes).container, view
    Args:
        itemInfo (str?): Used in query mode in conjunction with the itemList flag.  
                The command will return a list of information for each item in the view, the  
                information fields returned for each item are determined by this argument value.  
                The information fields will be listed in the string array returned.  
                The order in which the keyword is specified will determine the order in which  
                the data will be returned by the command.  
                One or more of the following keywords, separated by colons ':' are used to  
                specify the argument value.  
              
                itemIndex  : sequential item number (0. based)  
                itemName   : item name (string)  
                itemLabel  : item display label (string)  
                itemDescription : item description field (string)  
                itemLevel  : item hierarchy level (0. n)  
                itemIsGroup : (boolean 0 or 1) indicates whether or not this item is a group  
                itemIsAttribute : (boolean 0 or 1) indicates whether or not this item is an attribute  
                itemNumChildren: number of immediate children (groups or attributes) of this item  
                itemAttrType : item attribute type (string)  
                itemCallback : item callback field (string)  
              
                In query mode, this flag needs a value.  
                Properties: query
        itemList (bool?): Used in query mode, the command will return a list of information for each item in  
                the view.  The viewName flag is used to select the view to query.  
                The information returned about each item is determined by the itemInfo argument value.  
                For efficiency, it is best to query all necessary item information at one time  
                (to avoid recomputing the view information on each call).  
                Properties: query
        viewDescription (bool?): Used in query mode, returns the description field associated with the  
                selected view.  
                If no description was defined for this view, the value will be empty.  
                Properties: query
        viewLabel (bool?): Used in query mode, returns the display label associated with the view.  
                An appropriate label suitable for the user interface will be  
                returned based on the selected view.  Use of the view label  
                is usually more suitable than the view name for display purposes.  
                Properties: query
        viewList (bool?): Used in query mode, command will return a list of all views defined for the  
                given target (container or template).  
                Properties: query
        viewName (Queryable[str]?): Used in query mode, specifies the name of the queried view when used in  
                conjunction with a template target. When used in conjunction with a container  
                target, it requires no string argument, and returns the name of the currently  
                active view associated with the container; this value may be empty if the  
                current view is not a valid template view or is generated by one of the  
                built-in views modes. For this reason, the view label is generally more  
                suitable for display purposes.  
                			In query mode, this flag can accept a value.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def contentBrowser(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addContentPath: str = ..., context: Queryable[Union[Tuple[str], Tuple[str, str], Tuple[str, str, str]]] = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., location: str = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., preview: bool = ..., refreshTreeView: bool = ..., removeContentPath: str = ..., saveCurrentContext: bool = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., thumbnailView: bool = ..., treeView: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, Union[Tuple[str], Tuple[str, str], Tuple[str, str, str]], bool]:
    """This command is used to edit and query a Content Browser. The Content Browser is
    a unique panel, so only one instance of it can exist at a given time.
    The optional argument is the name of the control.
    Args:
        addContentPath (str?): Adds the given path(s) to the libraries displayed on the Examples tab.  
                Also updates the corresponding MAYA_CONTENT_PATH environment variable.  
                Properties: edit
        context (Queryable[Union[Tuple[str], Tuple[str, str], Tuple[str, str, str]]]?): Sets the default location for the given context. The two optional arguments  
                (Python only) are the category (tab) and location. To clear the content use  
                empty strings for category and location.  
              
                In query mode, it returns the context of the content browser in an array of 3 strings :  
                the name of the context, the default category name, the default location.  
                Properties: query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        location (str?): Switches to the Examples tab and selects the given library location.  
                Properties: edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        preview (bool?): Shows / hides the preview panel.  
                Note: this flag will not affect the currently opened Content Browser, but only  
                any subsequently opened ones.  
                Properties: edit
        refreshTreeView (bool?): Forces a refresh of the Examples tab tree view pane.  
                Properties: edit
        removeContentPath (str?): Removes the given path(s) from the libraries displayed on the Examples tab.  
                Also updates the corresponding MAYA_CONTENT_PATH environment variable.  
                Properties: edit
        saveCurrentContext (bool?): Saves the context for the current Content Browser tab.  
                Properties: edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        thumbnailView (bool?): Shows / hides the thumbnail panel.  
                Note: this flag will not affect the currently opened Content Browser, but only  
                any subsequently opened ones.  
                Properties: edit
        treeView (bool?): Shows / hides the tree view panel.  
                Note: this flag will not affect the currently opened Content Browser, but only  
                any subsequently opened ones.  
                Properties: edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the panel

    Example:
    """

def contextInfo(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., c: bool = ..., escapeContext: bool = ..., exists: bool = ..., image1: bool = ..., image2: bool = ..., image3: bool = ..., title: bool = ...) -> str:
    """This command allows you to get information on named contexts.
    Args:
        c (bool?): Return the class type of the named context.  
                Properties: create
        escapeContext (bool?): Return the command string that will allow you to exit the current tool.  
                Properties: create
        exists (bool?): Return true if the context exists, false if it does not  
                exists (or is internal and therefore untouchable)  
                Properties: create
        image1 (bool?): Returns the name of an xpm associated with the named context.  
                Properties: create
        image2 (bool?): Returns the name of an xpm associated with the named context.  
                Properties: create
        image3 (bool?): Returns the name of an xpm associated with the named context.  
                Properties: create
        title (bool?): Return the title string of the named context.  
                Properties: create

    Returns:
        str: Info requested

    Example:
    """

def control(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[bool, str, Tuple[float, float, float], int, Callable[..., Any]]:
    """This command allows you to edit or query the properties of any control.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def controller(*args: str, edit: bool = ..., query: bool = ..., allControllers: bool = ..., children: bool = ..., group: bool = ..., index: Queryable[int] = ..., isController: Queryable[str] = ..., parent: bool = ..., pickWalkDown: bool = ..., pickWalkLeft: bool = ..., pickWalkRight: bool = ..., pickWalkUp: bool = ..., unparent: bool = ...) -> Union[str, bool, int]:
    """Commands for managing animation sourcescontroller
    Args:
        allControllers (bool?): When this flag is queried, returns all dependNode attached to a controller in the scene.  
                Properties: create, query
        children (bool?): Return true if the specified dependNode is a controller.  
                Properties: query
        group (bool?): Create a controller that is not associated with any object. This new controller will be the parent of all the selected objects.  
                Properties: create, query
        index (Queryable[int]?): In query mode, returns the index of the controller in the parent controller's list of children.  
                In edit mode, reorder the parent controller's children connections so that the current controller is assigned the given index.  
                Properties: query, edit
        isController (Queryable[str]?): Returns true if the specified dependNode is a controller.  
                Properties: create, query
        parent (bool?): Set or query the parent controller of the selected controller node.  
                Properties: create, query, edit
        pickWalkDown (bool?): Return the first child.  
                Properties: query
        pickWalkLeft (bool?): Return the previous sibling.  
                Properties: query
        pickWalkRight (bool?): Return the next sibling.  
                Properties: query
        pickWalkUp (bool?): Return the parent.  
                Properties: query
        unparent (bool?): Unparent all selected controller objects from their respective parent.  
                Properties: edit

    Returns:
        str: Command result

    Example:
    """

def convertIffToPsd(*, query: bool = ..., iffFileName: Queryable[str] = ..., psdFileName: Queryable[str] = ..., xResolution: Queryable[int] = ..., yResolution: Queryable[int] = ...) -> Union[bool, str, int]:
    """Converts iff file to PSD file of given sizerenderlayers, psd, photoshop
    Args:
        iffFileName (Queryable[str]?): Input iff file name  
                Properties: create, query
        psdFileName (Queryable[str]?): Output file name  
                Properties: create, query
        xResolution (Queryable[int]?): X resolution of the image  
                Properties: create, query
        yResolution (Queryable[int]?): Y resolution of the image  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def convertSolidTx(*args: str, edit: bool = ..., query: bool = ..., alpha: bool = ..., antiAlias: bool = ..., backgroundColor: Tuple[int, int, int] = ..., backgroundMode: str = ..., camera: str = ..., componentRange: bool = ..., doubleSided: bool = ..., fileFormat: str = ..., fileImageName: str = ..., fillTextureSeams: bool = ..., force: bool = ..., fullUvRange: bool = ..., name: str = ..., pixelFormat: str = ..., resolutionX: int = ..., resolutionY: int = ..., reuseDepthMap: bool = ..., samplePlane: bool = ..., samplePlaneRange: Tuple[float, float, float, float] = ..., shadows: bool = ..., uvBBoxIntersect: bool = ..., uvRange: Tuple[float, float, float, float] = ..., uvSetName: str = ...) -> List[str]:
    """Command to convert a texture on a surface to a file texture. The first
    argument is a rendering node or attribute. If only the node is
    specified, the outColor attribute will be sampled. If the node does
    not have an outColor attribute, the first attribute on the node which
    is: readable, not writable, not hidden, connectable, and not a multi
    is used. If lighting is to be baked, a shading group must be specified
    as the texture.The current selection will be used if a texture and surface are not
    specified.An image file will be generated for each object and stored in your
    image segment of your project. The filename will be formatted using
    the texture and surface names as follows:However, if force is off and there is a name collision a version
    number will be determined and the filename will be formatted as
    follows:If uv/uvsetName option is specified the filename will include
    {surface}-{uvname} instead of {surface}.
    Args:
        alpha (bool?): Specify whether to compute the transparency when baking  
                lighting. The conversion will sample both the color and  
                transparency of the shading network; the alpha channel of the  
                file texture will be set to correspond to the result from sampling  
                the transparency. By default transparency is not computed.  
                Properties: create
        antiAlias (bool?): Perform anti-aliasing on the resulting image. Convert solid  
                texture will generally take four times longer than without  
                anti-aliasing. By default this flag is off.  
                Properties: create
        backgroundColor (Tuple[int, int, int]?): Set the background color to a specific value. Default is to  
                use the shader default color to fill the background. Valid  
                values range from 0 to 255 if the pixel format is 8 bits per channel,  
                or 0 to 65535 if the pixel format is 16 bits per channel.  
                This flag automatically sets -backgroundMode to "color".  
                Default is black: 0 0 0.  
                Properties: create
        backgroundMode (str?): Defines how the background of the texture should be  
                filled. Three modes are available:  
                "shader" or 1. uses the default shader color.  
                "color" or 2. uses the color given by  
                -backgroundColor flag.  
                "extend" or 3. extends outwards the color along the  
                seam edges.  
                Default is "shader".  
                Properties: create
        camera (str?): Specify a camera to use in baking lighting. If a camera is not  
                specified the camera in the active view will be used.  
                Properties: create
        componentRange (bool?): If one or more components have been selected to use, then  
                if this flag is set, then the uv range of the components  
                is used to fit into the texture map resolution. By default this  
                flag is set to false.  
                Properties: create
        doubleSided (bool?): Specify whether the sampler should flip the surface normal if the  
                sample point faces away from the camera. Note: flipping the normal  
                will make the result dependent on the camera (ie. one camera may  
                flip normals where different camera wouldn't). It's not recommended  
                that doubleSided be used in combination with shadows. By default  
                this flag is false.  
                Properties: create
        fileFormat (str?): File format to be used for output. IFF is the default if  
                unspecified. Other valid formats are:  
                als: Alias PIX  
                cin: Cineon  
                eps: EPS  
                gif: GIF  
                iff: Maya IFF  
                jpg: JPEG  
                yuv: Quantel  
                rla: Wavefront RLA  
                sgi: SGI  
                si: SoftImage (.pic)  
                tga: Targa  
                tif: TIFF  
                bmp: Windows Bitmap  
                Properties: create
        fileImageName (str?): Specify the output path and name of file texture image. If the  
                file name doesn't contain a directory separator, the image  
                will be written to source images of the current project. The  
                file will not be versioned if it already exists.  
                Properties: create
        fillTextureSeams (bool?): Specify whether or not to overscan the polygon beyond its outer  
                edges, when creating the file texture, in order to fill the texture  
                seams.  
                Default is true.  
                Properties: create
        force (bool?): If the output image already exists overwrite it. By default  
                this flag is off.  
                Properties: create
        fullUvRange (bool?): Sample using the full uv range of the surface. This flag  
                cannot be used with the -uvr flag. A 2D texture placement node  
                will be created and connected to the file texture. The placement's  
                translate and coverage will be set according to the full UV range of  
                the surface.  
                Properties: create
        name (str?): Set the name of the file texture node. Name conflict  
                resolution will be used to determine valid names when multiple  
                objects are specified.  
                Properties: create
        pixelFormat (str?): Specifies the pixel format of the image.  
                Note that not all file formats support all pixel formats.  
                Available options:  
                "8": 8 bits per channel, unsigned (0. 255)  
                "16": 16 bits per channel, unsigned (0. 65535)  
                Default is "8".  
                Properties: create
        resolutionX (int?): Set the horizontal image resolution. If this flag  
                is not specified, the resolution will be set to 256.  
                Properties: create
        resolutionY (int?): Set the vertical image resolution. If this flag  
                is not specified, the resolution will be set to 256.  
                Properties: create
        reuseDepthMap (bool?): Specify whether or not to reuse all the generated dmaps.  
                Default is false.  
                Properties: create
        samplePlane (bool?): Specify whether to sample using a virtual plane. This virtual plane  
                has texture coordinates in the rectangle defined by the  
                -samplePlaneRange flag. If the -samplePlaneRange flag is not set then  
                the virtual plane defaults to having texture coordinates in the  
                (0,0) to (1,1) square. If this option is set than all surface based  
                arguments will be ignored.  
                Properties: create
        samplePlaneRange (Tuple[float, float, float, float]?): Specify the uv range of the texture coordinates used to sample if  
                the -samplePlane option is set. There are four arguments corresponding  
                to uMin, uMax, vMin and vMax. By default the virtual plane is from  
                uMin 0 to uMax 1, and vMin 0 to vMax 1.  
                Properties: create
        shadows (bool?): Specify whether to compute shadows when baking lighting. Disk based  
                shadow maps will be used. Only lights with depth map shadows enabled  
                will contribute to the shading. By default shadows are not computed.  
                Properties: create
        uvBBoxIntersect (bool?): This flag is obsolete.  
                Properties: create
        uvRange (Tuple[float, float, float, float]?): Specify the uv range in which samples will be computed. There are  
                four arguments corresponding to uMin, uMax, vMin and vMax. Each  
                value should be specified based on the surface's uv space. A 2D  
                texture placement node will be created and connected to the file  
                texture. The placement's frame translate and coverage will be set  
                according to the uv range specified. By default the entire uv range  
                of the surface will be used.  
                Properties: create
        uvSetName (str?): Specify which uv set has to be used as the driving parametrization  
                for convert solid.  
                Properties: create

    Returns:
        List[str]: File texture nodes

    Example:
    """

def convertTessellation(*args: str, allCameras: bool = ..., camera: str = ...) -> bool:
    """Command to translate the basic tessellation attributes to advanced.
    If a camera flag is specified the translation will be based on the distance
    the surface is from the camera. The closer the surface is to the camera the
    more triangles there will be in the tessellation. If the "-allCameras" flags
    is specified, the renderable camera closest to the surface will be used to
    set the tessellation. The camera tessellation estimate is also dependent on
    the current render resolution; a higher resolution the result in a more
    finely tessellated surface.
    Multiple NURB surfaces may be specified on the command line, or if no
    command arguments are specified the surfaces on the active list will be
    used.
    This command operates by calculating the chord height such that smooth
    tessellation is achieved when the surface is rendered.  The advanced
    tessellation setting will be enabled on each surface specified, the
    primary tessellation parameters will be set, and chord height will be
    used as the secondary criteria.tessellation
    Args:
        allCameras (bool?): Specifies that all renderable cameras should be used in calculating  
                    the screen based tessellation.  
                Properties: create
        camera (str?): Specifies the camera which should be used in calculating the screen  
                    based tessellation.  
                Properties: create

    Returns:
        bool: Success or Failure.

    Example:
    """

def convertUnit(*args: str, fromUnit: str = ..., toUnit: str = ...) -> float:
    """This command converts values between different units of measure.  The
    command takes a string, because a string can incorporate unit
    names as well as values (see examples).
    Args:
        fromUnit (str?): The unit to convert from.  If not supplied, it is assumed to be the  
                system default.  The from unit may also be supplied as part of the  
                value e.g. 11.2m (11.2 meters).  
                Properties: create
        toUnit (str?): The unit to convert to.  If not supplied, it is assumed to be the  
                system default  
                Properties: create

    Returns:
        float: or string

    Example:
    """

def copyAttr(*args: str, edit: bool = ..., query: bool = ..., attribute: Multiuse[str] = ..., containerParentChild: bool = ..., inConnections: bool = ..., keepSourceConnections: bool = ..., outConnections: bool = ..., renameTargetContainer: bool = ..., values: bool = ...) -> bool:
    """Given two nodes, transfer the connections and/or the values from the first
    node to the second for all attributes whose names and data types match. When
    values are transferred, they are transferred directly. They are not mapped or
    modified in any way. The transferAttributes command can be used to transfer
    and remap some mesh attributes.
    The attributes flag can be used to specify a list of attributes to be
    processed. If the attributes flag is unused, all attributes will be
    processed. For dynamic attributes, the values and/or connections will only
    be transferred if the attributes names on both nodes match.
    This command does not support geometry shape nodes such as meshes, subds and
    nurbs. This command does not support transfer of multi-attribute values such
    as weight arrays.node, connection, copy, container
    Args:
        attribute (Multiuse[str]?): The name of the attribute(s) for which connections and/or values will be  
                transferred. If no attributes are specified, then all attributes will be  
                transferred.  
                Properties: create, multiuse
        containerParentChild (bool?): For use when copying from one container to another only. This option indicates  
                that the published parent and/or child relationships on the original container  
                should be transferred to the target container if the published names match.  
                Properties: create
        inConnections (bool?): Indicates that incoming connections should be transferred.  
                Properties: create
        keepSourceConnections (bool?): For use with the outConnections flag only. Indicates that the connections should be maintained on the first node, in addition to making them to the second node. If outConnections is used and keepSourceConnections is not used, the out connections on the source node will be broken and made to the target node.  
                Properties: create
        outConnections (bool?): Indicates that outgoing connections should be transferred.  
                Properties: create
        renameTargetContainer (bool?): For use when copying from one container to another only. This option will  
                rename the target container to the name of the original container, and  
                rename the original container to its old name + "Orig". You would want to  
                use this option if your original container was referenced and edited,  
                and you want those edits from the main scene to now apply to the  
                new container.  
                Properties: create
        values (bool?): Indicates that values should be transferred.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def copyDeformerWeights(*args: str, edit: bool = ..., query: bool = ..., destinationDeformer: Queryable[str] = ..., destinationShape: Queryable[str] = ..., mirrorInverse: bool = ..., mirrorMode: Queryable[str] = ..., noMirror: bool = ..., smooth: bool = ..., sourceDeformer: Queryable[str] = ..., sourceShape: Queryable[str] = ..., surfaceAssociation: Queryable[str] = ..., uvSpace: Queryable[Tuple[str, str]] = ...) -> Union[bool, str, Tuple[str, str]]:
    """Command to copy or mirror the deformer weights accross one
     of the three major axes.  The command can be used to mirror
     weights either from one surface to another or within the
     same surface.deformer, duplicate, mirror
    Args:
        destinationDeformer (Queryable[str]?): Specify the deformer used by the destination shape  
                Properties: create, query, edit
        destinationShape (Queryable[str]?): Specify the destination deformed shape  
                Properties: create, query, edit
        mirrorInverse (bool?): Values are mirrored from the positive side to the negative.  If this flag is used then the direction is inverted.  
                Properties: create, query, edit
        mirrorMode (Queryable[str]?): The mirrorMode flag defines the plane of mirroring (XY, YZ, or XZ) when the mirror flag is used. The default plane is XY.  
                Properties: create, query, edit
        noMirror (bool?): When the no mirror flag is used, the weights are copied instead of mirrored.  
                Properties: create, query, edit
        smooth (bool?): When the smooth flag is used, the weights are smoothly interpolated between the closest vertices, instead of assigned from the single closest.  
                Properties: create, query, edit
        sourceDeformer (Queryable[str]?): Specify the deformer whose weights should be mirrored.  When queried, returns the deformers used by the source shapes.  
                Properties: create, query, edit
        sourceShape (Queryable[str]?): Specify the source deformed shape  
                Properties: create, query, edit
        surfaceAssociation (Queryable[str]?): The surfaceAssociation flag controls how the weights are transferred between the  
                surfaces: "closestPoint", "rayCast", or "closestComponent". The default is closestComponent.  
                Properties: create, query, edit
        uvSpace (Queryable[Tuple[str, str]]?): The uvSpace flag indicates that the weight transfer should occur in UV space, based on the  
                source and destination UV sets specified.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def copyFlexor(*args: str) -> str:
    """This command copies an existing bone or joint flexor from one
    bone (joint) to another.  The attributes of the flexor and their
    connections as well as any tweaks in on the latticeFfd are copied
    from the original to the new flexor.  If the selected bone (joint)
    appears to be a mirror reflection of the bone (joint) of the
    existing flexor then the transform of the ffd lattice group gets
    reflected to the new bone (joint).  The arguments for the command
    are the name of the ffd Lattice and the name of the destination joint.
    If they are not specified at the command line, they will be picked
    up from the current selection list.
    Returns:
        str: The name of the new flexor node

    Example:
    """

def copyKey(*args: str, animLayer: str = ..., animation: str = ..., attribute: Multiuse[str] = ..., clipboard: str = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., forceIndependentEulerAngles: bool = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., option: str = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command copies curve segments's hierarchies from
    specified targets and puts them in the clipboard.  Source
    curves are unchanged.  The pasteKey command applies these
    curves to other objects.The shape of the copied curve placed in the clipboard
    depends on the copyKey "-option" specified.  Each of these options
    below will be explained using an example.  For all the explanations,
    let us assume that the source animation curve (from which keys will
    be copied) has 5 keyframes at times 10, 15, 20, 25, and 30.TbaseKeySetCmd.h
    Args:
        animLayer (str?): Specifies that the keys getting copied should come from this  
                specified animation layer. If no keys on the object exist  
                on this layer, then no keys are copied.  
                Properties: create
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        clipboard (str?): Specifies the clipboard to which animation is copied.  
                Valid clipboards are "api" and "anim".  The default clipboard  
                is: anim  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        forceIndependentEulerAngles (bool?): Specifies that the rotation curves should always be placed on the  
                clipboard as independent Euler Angles. The default value is false.  
                Properties: create
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        option (str?): The option to use when performing the copyKey operation.  
                Valid options are "keys," and "curve."  The default copy option  
                is: keys  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse

    Returns:
        int: Number of animation curves copied.

    Example:
    """

def copyNode(arg0: str = ..., arg1: str = ..., /) -> None: ...
def copySkinWeights(*args: str, edit: bool = ..., query: bool = ..., destinationSkin: Queryable[str] = ..., influenceAssociation: Queryable[Multiuse[str]] = ..., mirrorInverse: bool = ..., mirrorMode: Queryable[str] = ..., noBlendWeight: bool = ..., noMirror: bool = ..., normalize: bool = ..., sampleSpace: Queryable[int] = ..., selectedComponents: bool = ..., smooth: bool = ..., sourceSkin: Queryable[str] = ..., surfaceAssociation: Queryable[str] = ..., uvSpace: Queryable[Tuple[str, str]] = ...) -> Union[bool, str, Multiuse[str], int, Tuple[str, str]]:
    """Command to copy or mirror the skinCluster weights accross one
     of the three major axes.  The command can be used to mirror
     weights either from one surface to another or within the
     same surface.skinCluster, duplicate, mirror
    Args:
        destinationSkin (Queryable[str]?): Specify the destination skin shape  
                Properties: create, query, edit
        influenceAssociation (Queryable[Multiuse[str]]?): The influenceAssociation flag controls how the influences on the source and target skins  
                are matched up. The flag can be included multiple times to specify multiple association  
                schemes that will be invoked one after the other until all influences have been matched  
                up. Supported values are "closestJoint", "closestBone", "label", "name", "oneToOne". The  
                default is closestJoint.  
                Properties: create, query, edit, multiuse
        mirrorInverse (bool?): Values are mirrored from the positive side to the negative.  If this flag is used then the direction is inverted.  
                Properties: create, query, edit
        mirrorMode (Queryable[str]?): The mirrorMode flag defines the plane of mirroring (XY, YZ, or XZ) when the mirror flag is used. The default plane is XY.  
                Properties: create, query, edit
        noBlendWeight (bool?): When the no blend flag is used, the blend weights on the skin cluster will not be copied across to  
                the destination.  
                Properties: create, query, edit
        noMirror (bool?): When the no mirror flag is used, the weights are copied instead of mirrored.  
                Properties: create, query, edit
        normalize (bool?): Normalize the skin weights.  
                Properties: create, query, edit
        sampleSpace (Queryable[int]?): Selects which space the attribute transfer is performed in.  
                0 is world space, 1 is model space. The default is world space.  
                Properties: create, query, edit
        selectedComponents (bool?): The selectedComponents flag can be used in combination with the sourceSkin and destinationSkin  
                flags to specify that only the skin weights on the selected components should be copied.  
                Properties: create, query, edit
        smooth (bool?): When the smooth flag is used, the weights are smoothly interpolated between the closest vertices, instead of assigned from the single closest.  
                Properties: create, query, edit
        sourceSkin (Queryable[str]?): Specify the source skin shape  
                Properties: create, query, edit
        surfaceAssociation (Queryable[str]?): The surfaceAssociation flag controls how the weights are transferred between the  
                surfaces: "closestPoint", "rayCast", or "closestComponent". The default is closestComponent.  
                Properties: create, query, edit
        uvSpace (Queryable[Tuple[str, str]]?): The uvSpace flag indicates that the weight transfer should occur in UV space, based on the  
                source and destination UV sets specified.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def crashInfo(*, query: bool = ..., crashFile: bool = ..., crashLog: bool = ..., savedBeforeCrash: bool = ...) -> bool:
    """Provides an interface to the crash file information.
    Args:
        crashFile (bool?): Return the crash file full path name.  
                Properties: query
        crashLog (bool?): Return the crash log full path name.  
                Properties: query
        savedBeforeCrash (bool?): Return the saved file full path name before crash.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def crashInfoCmd(*args: Any, **kwargs: Any) -> None: ...
def createAttrPatterns(*, patternDefinition: str = ..., patternFile: str = ..., patternType: str = ...) -> str:
    """Create a new instance of an attribute pattern given a pattern type (e.g. XML) and a string or data file
    containing the description of the attribute tree in the pattern's format.attribute, pattern
    Args:
        patternDefinition (str?): Hardcoded string containing the pattern definition, for simpler formats that  
                don't really need a separate file for definition.  
                Properties: create
        patternFile (str?): File where the pattern information can be found  
                Properties: create
        patternType (str?): Name of the pattern definition type to use in creating this instance  
                of the pattern.  
                Properties: create

    Returns:
        str: Name of created pattern

    Example:
    """

def createDisplayLayer(*args: str, empty: bool = ..., makeCurrent: bool = ..., name: str = ..., noRecurse: bool = ..., number: int = ...) -> str:
    """Create a new display layer.  The display layer number will be assigned
    based on the first unassigned number not less than the base index number
    found in the display layer global parameters.  Normally all objects and
    their descendants will be added to the new display layer but if the '-nr'
    flag is specified then only the objects themselves will be added.displayLayer, display, layer, color, playback, render
    Args:
        empty (bool?): If set then create an empty display layer.  ie. Do not add the selected  
                items to the new display layer.  
                Properties: create
        makeCurrent (bool?): If set then make the new display layer the current one.  
                Properties: create
        name (str?): Name of the new display layer being created.  
                Properties: create
        noRecurse (bool?): If set then only add selected objects to the display layer.  Otherwise all  
                descendants of the selected objects will also be added.  
                Properties: create
        number (int?): Number for the new display layer being created.  
                Properties: create

    Returns:
        str: Name of display layer node that was created

    Example:
    """

def createEditor(arg0: str = ..., arg1: str = ..., /, *, noCloseOnDelete: bool = ..., queueForDelete: bool = ...) -> bool:
    """This command creates a property sheet for any dependency node. The
    second argument is the name of the node, and the first is the name of
    a layout into which the property sheet controls should be placed.The property sheets created by this command can by user-customized
    using thecommand.
    Args:
        noCloseOnDelete (bool?): If this flag is set then don't close the editor when the data is deleted  
                Properties: create
        queueForDelete (bool?): The specified layout is put on a queue.  When the queue  
                is full, layouts past the end of the queue are automatically  
                deleted.  If the layout is already on the queue, it is  
                moved to the front.  This allows us to dispose of editors  
                when they are no longer being used.  This flag should only be  
                used by the showEditor.mel script.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def createLayeredPsdFile(*args: Any, imageFileName: Multiuse[Tuple[str, str, str]] = ..., psdFileName: str = ..., xResolution: int = ..., yResolution: int = ...) -> bool:
    """Creates a  layered PSD file with image names as input to individual layers
    Args:
        imageFileName (Multiuse[Tuple[str, str, str]]?): Layer name, blend mode, Image file name  The image in the file will be  
                transferred to layer specified. The image file specified can be in any  
                of the formats supported by maya (ex. iff, jpg, gif, tif etc.). The blend  
                mode options are : "Normal", "Dissolve", "Dark", "Multiply", "Color Burn",  
                "Linear Burn", "Lighten", "Screen", "Color Dodge", "Linear Dogde", "Overlay",  
                "Soft Light", "Hard Light", "Dissolve", "Vivid Light", "Linear Light", "Pin Light",  
                "Hard Mix", "Difference", "Exclusion", "Hue", "Saturation", "Color",  "Luminosity"  
                Properties: create, multiuse
        psdFileName (str?): PSD file name.  
                Properties: create
        xResolution (int?): X - resolution of the image.  
                Properties: create
        yResolution (int?): Y - resolution of the image.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def createNode(arg0: str = ..., /, *, name: str = ..., parent: str = ..., shared: bool = ..., skipSelect: bool = ...) -> str:
    """This command creates a new node in the dependency graph of the
    specified type.
    Args:
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace doesn't exist, we  
                will create the namespace.  
                Properties: create
        parent (str?): Specifies the parent in the DAG under which the new node belongs.  
                Properties: create
        shared (bool?): This node is shared across multiple files, so only create it if  
                it does not already exist.  
                Properties: create
        skipSelect (bool?): This node is not to be selected after creation, the original selection  
                will be preserved.  
                Properties: create

    Returns:
        str: The name of the new node.

    Example:
    """

def createNurbsCircleCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsConeCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsCubeCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsCylinderCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsPlaneCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsSphereCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsSquareCtx(*args: Any, **kwargs: Any) -> None: ...
def createNurbsTorusCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyConeCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyCubeCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyCylinderCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyHelixCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyPipeCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyPlaneCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyPlatonicSolidCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyPrismCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyPyramidCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolySoccerBallCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolySphereCtx(*args: Any, **kwargs: Any) -> None: ...
def createPolyTorusCtx(*args: Any, **kwargs: Any) -> None: ...
def createRenderLayer(*args: str, empty: bool = ..., g: bool = ..., makeCurrent: bool = ..., name: str = ..., noRecurse: bool = ..., number: int = ...) -> str:
    """Create a new render layer.  The render layer number will be assigned
    based on the first unassigned number not less than the base index number
    found in the render layer global parameters.  Normally all objects and
    their descendants will be added to the new render layer but if '-noRecurse'
    is specified then only the objects themselves will be added. Only transforms
    and geometry will be added to the new render layer.renderLayer, 2d3d, layer, color, playback, render
    Args:
        empty (bool?): If set then create an empty render layer. The global flag or specified  
                member list will take precidence over  use of this flag.  
                Properties: create
        g (bool?): If set then create a layer that contains all DAG objects in the scene. Any  
                future objects created will also automatically become members of this layer.  
                The global flag will take precidence over use of the empty flag or specified  
                member list.  
                Properties: create
        makeCurrent (bool?): If set then make the new render layer the current one.  
                Properties: create
        name (str?): Name of the new render layer being created.  
                Properties: create
        noRecurse (bool?): If set then only add specified objects to the render layer.  Otherwise all  
                descendants will also be added.  
                Properties: create
        number (int?): Number for the new render layer being created.  
                Properties: create

    Returns:
        str: Name of render layer node that was created

    Example:
    """

def createSubdivRegion(*args: Any) -> bool:
    """Creates a subdivision surface region based on the selection list. Once
    a selection region is created, only the components in the selection list
    or converted from the selection list will be displayed and selectible
    through the UI.subdivision, surface, select, region
    Returns:
        bool: Command result

    Example:
    """

def ctxAbort() -> bool:
    """This command tells the current context to reset itself, losing
    what has been done so far.  If a escape context has been set
    it then makes that context current.
    Returns:
        bool:

    Example:
    """

def ctxCompletion() -> bool:
    """This command tells the current context to finish what it is
    doing and create any objects that is is working on.
    Returns:
        bool:

    Example:
    """

def ctxEditMode(*, buttonDown: bool = ..., buttonUp: bool = ...) -> bool:
    """This command tells the current context to switch edit modes.It acts as a toggle.
    Args:
        buttonDown (bool?): Edit mode is being invoked from a hotkey press event.  
                Properties: create
        buttonUp (bool?): Edit mode is being invoked from a hotkey release event.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def ctxTraverse(*, down: bool = ..., left: bool = ..., right: bool = ..., up: bool = ...) -> bool:
    """This command tells the current context to do a traversal.Some contexts will ignore this command. Individual contexts
    determine what up/down left/right mean.
    Args:
        down (bool?): Move "down" as defined by the current context.  
                Properties: create
        left (bool?): Move "left" as defined by the current context.  
                Properties: create
        right (bool?): Move "right" as defined by the current context.  
                Properties: create
        up (bool?): Move "up" as defined by the current context.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def currentCtx() -> str:
    """This command returns the currently selected tool context.
    Returns:
        str: : The name of the currently selected tool context.

    Example:
    """

def currentTime(arg0: int = ..., /, *, edit: bool = ..., query: bool = ..., update: bool = ...) -> int:
    """When given a time argument (with or without the -edit flag) this
    command sets the current global time.  The model updates and
    displays at the new time, unless "-update off" is present on the
    command line.
    Args:
        update (bool?): change the current time, but do not update the world.  
                Default value is true.  
                Properties: create

    Returns:
        int: Command result

    Example:
    """

def currentTimeCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command creates a context which may be used to change current time
    within the graph editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def currentUnit(*args: str, query: bool = ..., angle: Queryable[str] = ..., fullName: bool = ..., linear: Queryable[str] = ..., time: Queryable[str] = ..., updateAnimation: bool = ...) -> Union[str, bool]:
    """This command allows you to change the units in which you will work
    in Maya. There are three types of units: linear, angular and time.The current unit affects how all commands in Maya interpret their
    numeric values. For example, if the current linear unit is,
    then the command:will be interpreted as moving 5cm in X, -2cm in Y, 3cm in Z, and as
    creating a sphere with radius 4cm. Similarly, if the current time unit
    is Film (24 frames per second), then the command:will be interpreted as setting the current time to frame 6 in the Film
    unit, which is 6/24 or 0.25 seconds.You can always override the unit of a particular numeric value to a
    command be specifying it one the command. For example, using the above
    examples:would move the object 5 meters in X, -2 millimeters in Y, 3 centimeters
    in Z, create a sphere of radius 4 inches, and change the current time
    to 6 frames in the NTSC unit, which would be 0.2 seconds, or 4.8 frames
    in the current (Film) unit.
    Args:
        angle (Queryable[str]?): Set the current angular unit. Valid strings are:  
              
                [deg | degree | rad | radian]  
              
                When queried, returns a string which is the current angular unit  
                Properties: create, query
        fullName (bool?): A query only flag. When specified in conjunction with any of  
                the -linear/-angle/-time flags, will return the long form of the unit.  
                For example, mm and millimeter are the same unit, but  
                the former is the short form of the unit name, and the latter is the  
                long form of the unit name.  
                Properties: query
        linear (Queryable[str]?): Set the current linear unit. Valid strings are:  
              
                [mm | millimeter | cm | centimeter | m | meter | km | kilometer | in | inch | ft | foot | yd | yard | mi | mile]  
              
                When queried, returns a string which is the current linear unit  
                Properties: create, query
        time (Queryable[str]?): Set the current time unit. Valid strings are:  
              
                [hour | min | sec | millisec | game | film | pal | ntsc | show | palf | ntscf | 23.976fps | 29.97fps | 29.97df | 47.952fps | 59.94fps | 44100fps | 48000fps]  
              
                When queried, returns a string which is the current time unit  
              
                Note that there is no long form for any of the time units.  
                The non-seconds based time units are interpreted as the following  
                frames per second:  
              
                game: 15 fps  
                film: 24 fps  
                pal: 25 fps  
                ntsc: 30 fps  
                show: 48 fps  
                palf: 50 fps  
                ntscf: 60 fps  
                Properties: create, query
        updateAnimation (bool?): An edit only flag.  When specified in conjunction with the -time  
                flag indicates that times for keys are not updated.  By default when the  
                current time unit is changed, the times for keys are modified so that  
                playback timing is preserved.  For example a key set a frame 12film is  
                changed to frame 15ntsc when the current time unit is changed to ntsc,  
                since they both represent a key at a time of 0.5 seconds.  Specifying  
                -updateAnimation false would leave the key at frame 12ntsc.  
                Default is -updateAnimation true.  
                Properties: create

    Returns:
        str: The new current unit that has been set

    Example:
    """

def curve(*args: str, append: bool = ..., bezier: bool = ..., degree: float = ..., editPoint: Multiuse[Tuple[float, float, float]] = ..., knot: Multiuse[float] = ..., name: str = ..., objectSpace: bool = ..., periodic: bool = ..., point: Multiuse[Tuple[float, float, float]] = ..., pointWeight: Multiuse[Tuple[float, float, float, float]] = ..., replace: bool = ..., worldSpace: bool = ...) -> str:
    """The curve command creates a new curve from a list of control vertices
    (CVs).  A string is returned containing the pathname to the newly
    created curve.  You can create a curve from points either in world
    space or object (local) space, either with weights or without.
    You can replace an existing curve by using the "-r/replace"
    flag.  You can append a point to an existing curve by using the
    "-a/append" flag.To create a curve-on-surface, use the curveOnSurface command.To change the degree of a curve, use the rebuildCurve command.To change the of parameter range curve, use the rebuildCurve command.
    Args:
        append (bool?): Appends point(s) to the end of an existing curve.  
                If you use this flag, you must specify the name of the  
                curve to append to, at the end of the command.  (See examples below.)  
                Properties: create
        bezier (bool?): The created curve will be a bezier curve.  
                Properties: create
        degree (float?): The degree of the new curve.  Default is 3.  Note that you need  
                (degree+1) curve points to create a visible curve span.  eg. you  
                must place 4 points for a degree 3 curve.  
                Properties: create
        editPoint (Multiuse[Tuple[float, float, float]]?): The x, y, z position of an edit point.  "linear" means that this flag  
                can take values with units.  This flag can not be used with  
                the -point or the -pointWeight flags.  
                Properties: create, multiuse
        knot (Multiuse[float]?): A knot value in a knot vector.  One flag per knot value.  
                There must be (numberOfPoints + degree - 1) knots and the knot  
                vector must be non-decreasing.  
                Properties: create, multiuse
        name (str?): Name of the curve  
                Properties: create
        objectSpace (bool?): Points are in object, or "local" space.  This is the default.  
                You cannot specify both "-os" and "-ws" in the same command.  
                Properties: create
        periodic (bool?): If on, creates a curve that is periodic.  Default is off.  
                Properties: create
        point (Multiuse[Tuple[float, float, float]]?): The x, y, z position of a point.  "linear" means that this flag  
                can take values with units.  
                Properties: create, multiuse
        pointWeight (Multiuse[Tuple[float, float, float, float]]?): The x,y,z and w values of a point, where the w is a weight value.  
                A rational curve will be created if this flag is used.  
                "linear" means that this flag can take values with units.  
                Properties: create, multiuse
        replace (bool?): Replaces an entire existing curve.  
                If you use this flag, you must specify the name of the curve to  
                replace, at the end of the command.  (See examples below.)  
                Properties: create
        worldSpace (bool?): Points are in world space.  The default is "-os".  
                You cannot specify both "-os" and "-ws" in the same command.  
                Properties: create

    Returns:
        str: The path to the new curve or the replaced curve

    Example:
    """

def curveAddPtCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """The curveAddPtCtx command creates a new curve add points context,
    which adds either control vertices (CVs) or edit points to an
    existing curve.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def curveBezierCtx(*args: Any, **kwargs: Any) -> None: ...
def curveCVCtx(*args: Any, edit: bool = ..., query: bool = ..., bezier: bool = ..., degree: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., multEndKnots: bool = ..., name: str = ..., preserveShape: bool = ..., rational: bool = ..., refit: bool = ..., symmetry: bool = ..., uniform: bool = ...) -> Union[str, bool, int]:
    """The curveCVCtx command creates a new context for creating curves
    by placing control vertices (CVs).
    Args:
        bezier (bool?):   
                Properties: create, query, edit
        degree (Queryable[int]?): Curve degree  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        multEndKnots (bool?): Specify if multiple end knots are to be created.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        preserveShape (bool?): Set this flag to make the operation preserve the shape  
                Properties: create, query, edit
        rational (bool?): Should the curve be rational?  
                Properties: create, query, edit
        refit (bool?): Set this flag to refit the curve  
                Properties: create, query, edit
        symmetry (bool?): Specify if symmetry is to be used  
                Properties: create, query, edit
        uniform (bool?): Should the curve use uniform parameterization?  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def curveEPCtx(*args: Any, edit: bool = ..., query: bool = ..., bezier: bool = ..., degree: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., preserveShape: bool = ..., preserveShapeFraction: Queryable[float] = ..., refit: bool = ..., uniform: bool = ...) -> Union[str, bool, int, float]:
    """The curveEPCtx command creates a new context for creating curves
    by placing edit points.
    Args:
        bezier (bool?): Use bezier curves  
                Properties: create, query, edit
        degree (Queryable[int]?): Curve degree  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        preserveShape (bool?): Set this flag to make the operation preserve the shape  
                Properties: create, query, edit
        preserveShapeFraction (Queryable[float]?): Fraction value used when preserving the shape  
                Properties: create, query, edit
        refit (bool?): Set this flag to refit the curve  
                Properties: create, query, edit
        uniform (bool?): Should the curve use uniform parameterization?  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def curveEditorCtx(*args: Any, edit: bool = ..., query: bool = ..., direction: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., relativeTangentSize: Queryable[float] = ..., title: Queryable[str] = ...) -> Union[str, int, float]:
    """The curveEditorCtx command creates a new NURBS editor context, which
    is used to edit a NURBS curve or surface.
    Args:
        direction (Queryable[int]?): Query the current direction of the tangent control.  Always  
                zero for the curve case.  In the surface case, its 0 for the normal  
                direction, 1 for U direction and 2 for V direction.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        relativeTangentSize (Queryable[float]?): Relative size of the tangent manipulator handle.  Helps  
                to adjust as the surface parameterization controls the size of the  
                tangent, even if the shape of the surface remains the same.  
                The default is 4.  
                Properties: create, query, edit
        title (Queryable[str]?): The title for the tool.  
                Properties: query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def curveIntersect(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., direction: Queryable[Tuple[float, float, float]] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ..., useDirection: bool = ...) -> Union[str, bool, Tuple[float, float, float], float, int]:
    """You must specify two curves to intersect.This command either returns the parameter values at which the given
    pair of curves intersect, or returns a dependency node that provides
    the intersection information. If you want to find the intersection of
    the curves in a specific direction you must use BOTH the
    "-useDirection" flag and the "direction" flag.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        direction (Queryable[Tuple[float, float, float]]?): The direction that the input curves are projected in  
                before intersecting.  This vector is only used if  
                "useDirection" flag is true.  
                Properties: query, edit
        directionX (Queryable[float]?): The X component of the direction that the input curves are projected in  
                before intersecting.  This vector is only used if "useDirection" flag is true.  
                Properties: query, edit
        directionY (Queryable[float]?): The Y component of the direction that the input curves are projected in  
                before intersecting.  This vector is only used if "useDirection" flag is true.  
                Properties: query, edit
        directionZ (Queryable[float]?): The Z component of the direction that the input curves are projected in  
                before intersecting.  This vector is only used if "useDirection" flag is true.  
                Properties: query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance that the intersection is calculated with.  
                For example, given two curves end-to-end, the ends must be  
                within tolerance for an intersection to be returned.  
                Default: 0.001  
                Properties: query, edit
        useDirection (bool?): If true, use direction flag.  The input curves are first  
                projected in a specified direction and then intersected.  
                If false, this command will only find true 3D intersections.  
                Default: false  
                Properties: query, edit

    Returns:
        str: the parameter values at which two curves intersect.

    Example:
    """

def curveMoveEPCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """The curveMoveEPCtx command creates a new context for moving
    curve edit points using a manipulator.  Edit points can only be
    moved one at a time.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def curveOnSurface(*args: str, append: bool = ..., degree: float = ..., knot: Multiuse[float] = ..., name: str = ..., periodic: bool = ..., positionUV: Multiuse[Tuple[float, float]] = ..., replace: bool = ...) -> str:
    """The curve command creates a new curve from a list of control vertices
    (CVs).  A string is returned containing the pathname to the newly
    created curve.  You can create a curve from points either in world
    space or object (local) space, either with weights or without.
    You can replace an existing curve by using the "-r/replace"
    flag.  You can append a point to an existing curve by using the
    "-a/append" flag.To create a curve-on-surface, use the curveOnSurface command.To change the degree of a curve, use the rebuildCurve command.To change the of parameter range curve, use the rebuildCurve command.The curve-on-surface command creates a new curve-on-surface from a
    list of control vertices (CVs).  A string is returned containing
    the pathname to the newly created curve-on-surface.
    You can replace an existing curve by using the "-r/replace"
    flag. You can append points to an existing curve-on-surface by
    using the "-a/append" flag.
    See also the curve command, which describes how to query curve
    attributes.
    Args:
        append (bool?): Appends point(s) to the end of an existing curve.  
                If you use this flag, you must specify the name of the  
                curve to append to, at the end of the command.  (See examples below.)  
                Properties: create
        degree (float?): The degree of the new curve.  Default is 3.  Note that you need  
                (degree+1) curve points to create a visible curve span.  eg. you  
                must place 4 points for a degree 3 curve.  
                Properties: create
        knot (Multiuse[float]?): A knot value in a knot vector.  One flag per knot value.  
                There must be (numberOfPoints + degree - 1) knots and the knot  
                vector must be non-decreasing.  
                Properties: create, multiuse
        name (str?): Name of the curve  
                Properties: create
        periodic (bool?): If on, creates a curve that is periodic.  Default is off.  
                Properties: create
        positionUV (Multiuse[Tuple[float, float]]?): The uv position of a point.  
                Properties: create, multiuse
        replace (bool?): Replaces an entire existing curve.  
                If you use this flag, you must specify the name of the curve to  
                replace, at the end of the command.  (See examples below.)  
                Properties: create

    Returns:
        str: - name of new curve-on-surface
        str: The path to the new curve or the replaced curve

    Example:
    """

def curveRGBColor(arg0: str = ..., arg1: float = ..., arg2: float = ..., arg3: float = ..., /, *, query: bool = ..., hueSaturationValue: bool = ..., list: bool = ..., listNames: bool = ..., remove: bool = ..., resetToFactory: bool = ..., resetToSaved: bool = ...) -> Union[List[float], bool]:
    """This command creates, changes or removes custom curve colors,
    which are used to draw the curves in the Graph Editor.
    The custom curve names may contain the wildcards
    "?", which marches a single character, and
    "*", which matches any number of characters.
    These colors are part of the UI and not part of the saved
    data for a model.  This command is not undoable.
    Args:
        hueSaturationValue (bool?): Indicates that rgb values are really hsv values.  
                Properties: create, query
        list (bool?): Writes out a list of all curve color names and their values.  
                Properties: create
        listNames (bool?): Returns an array of all curve color names.  
                Properties: create
        remove (bool?): Removes the named curve color.  
                Properties: create
        resetToFactory (bool?): Resets all the curve colors to their factory defaults.  
                Properties: create
        resetToSaved (bool?): Resets all the curve colors to their saved values.  
                Properties: create

    Returns:
        List[float]: HSV values from querying the hsv flag

    Example:
    """

def curveSketchCtx(*args: Any, edit: bool = ..., query: bool = ..., degree: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> Union[str, int]:
    """The curveSketchCtx command creates a new curve sketch context,
    also known as the "pencil context".
    Args:
        degree (Queryable[int]?): Valid values are 1 or 3  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: (name of the new curve sketch context)

    Example:
    """

def cutKey(*args: str, animation: str = ..., attribute: Multiuse[str] = ..., clear: bool = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., option: str = ..., selectKey: bool = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).The cutKey command cuts curve segment hierarchies from specified
    targets and puts them in the clipboard.  The pasteKey command
    applies these curves to other objects.The shape of the cut curve placed in the clipboard, and
    the effect of the cutKey command on the source animation curve
    depends on the cutKey "-option" specified.  Each of these options
    below will be explained using an example.  For all the explanations,
    let us assume that the source animation curve (from which keys will
    be cut) has 5 keyframes at times 10, 15, 20, 25, and 30.TbaseKeySetCmd.h
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        clear (bool?): Just remove the keyframes (i.e. do not overwrite the clipboard)  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        option (str?): Option for how to perform the cutKey operation.  Valid  
                values for this flag are "keys", "curve",  
                "curveCollapse", "curveConnect", "areaCollapse".  The default cut  
                option is: keys  
                Properties: create
        selectKey (bool?): Select the keyframes of curves which have had keys removed  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse

    Returns:
        int: Number of animation curves cut.

    Example:
    """

def cycleCheck(*args: str, query: bool = ..., all: bool = ..., children: bool = ..., dag: bool = ..., evaluation: bool = ..., firstCycleOnly: bool = ..., firstPlugPerNode: bool = ..., lastPlugPerNode: bool = ..., list: bool = ..., listSeparator: str = ..., parents: bool = ..., secondary: bool = ..., timeLimit: int = ...) -> Union[bool, List[str]]:
    """This command searches for plug cycles in the dependency graph. If
    a plug or node is selected then it searches for cycles that
    that plug or node is involved with. Plugs or nodes can also be passed
    as arguments. If the -all flag is used then the entire graph is searched.Normally the return value is a boolean indicating whether or not the
    given items were involved in a cycle.  If the -list flag is used then
    the return value is the list of all plugs in cycles (involving the
    selected plug or node if any).Note that it is possible for evaluation cycles to occur even where
    no DG connections exist. Here are some examples:1) Nodes with evaluation-time dependent connections: An example is
    expression nodes, because we cannot tell what an expression
    node is actually referring to until it is evaluated, and such
    evaluation-time dependent nodes may behave differently based on
    the context (e.g. time) they are evaluated at. If you suspect a
    cycle due to such a connection, the best way to detect the
    cycle is through manual inspection.2) Cycles due to DAG hierarchy: noting that DAG nodes are implicitely
    connected through parenting, if a child DAG node connects an output into
    the input of a parent node, a cycle will exist if the plugs involved
    also affect each other. In order to enable detection of cycles
    involving the DAG, add the -dag flag to the command line.Note also that this command may incorrectly report a cycle on
    an instanced skeleton where some of the instances use IK.
    You will have to examine the reported cycle yourself to determine
    if it is truly a cycle or not.
    The evaluation time cycle checking will not report false cycles.
    Args:
        all (bool?): search the entire graph for cycles instead of the selection list.  
                (Note: if nothing is selected, -all is assumed).  
                Properties: create
        children (bool?): Do not consider cycles on the children, only the specified plugs  
                Properties: create
        dag (bool?): Also look for cycles due to relationships in the DAG. For each DAG node,  
                the parenting connection on its children is also considered when searching  
                for cycles.  
                Properties: create
        evaluation (bool?): Turn on and off cycle detection during graph evaluation  
                Properties: create, query
        firstCycleOnly (bool?): When -list is used to return a plug list, the list may contain  
                multiple cycles or partial cycles. When -firstCycleOnly is specified  
                only the first such cycle (which will be a full cycle) is returned.  
                Properties: create
        firstPlugPerNode (bool?): When -list is used to return a plug list, the list will typically contain  
                multiple plugs per node (e.g. ... A.output B.input B.output C.input ...),  
                reflecting internal "affects" relationships rather than external DG connections.  
                When -firstPlugPerNode is specified, only the first plug in the list for each  
                node is returned (B.input in the example).  
                Properties: create
        lastPlugPerNode (bool?): When -list is used to return a plug list, the list will typically contain  
                multiple plugs per node (e.g. ... A.output B.input B.output C.input ...),  
                reflecting internal "affects" relationships rather than external DG connections.  
                When -lastPlugPerNode is specified, only the last plug in the list for each  
                node is returned (B.output in the example).  
                Properties: create
        list (bool?): Return all plugs involved in one or more cycles.  If not  
                specified, returns a boolean indicating whether a cycle exists.  
                Properties: create
        listSeparator (str?): When -list is used to return a plug list, the list may contain  
                multiple cycles or partial cycles. Use -listSeparator to specify  
                a string that will be inserted into the returned string array  
                to separate the cycles.  
                Properties: create
        parents (bool?): Do not consider cycles on the parents, only the specified plugs  
                Properties: create
        secondary (bool?): Look for cycles on related plugs as well as the specified plugs  
                Default is "on" for the "-all" case and "off" for others  
                Properties: create
        timeLimit (int?): Limit the search to the given amount of time  
                Properties: create

    Returns:
        bool: in the general case.
        List[str]: When the list flag is used.

    Example:
    """

def cylinder(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., degree: Queryable[int] = ..., endSweep: Queryable[float] = ..., heightRatio: Queryable[float] = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., radius: Queryable[float] = ..., sections: Queryable[int] = ..., spans: Queryable[int] = ..., startSweep: Queryable[float] = ..., tolerance: Queryable[float] = ..., useTolerance: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The cylinder command creates a new cylinder and/or a
    dependency node that creates one, and returns their names.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): The primitive's axis  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface:  
                1. linear,  
                3. cubic  
                Default: 3  
                Properties: create, query, edit
        endSweep (Queryable[float]?): The angle at which to end the surface of revolution.  
                Default is 2Pi radians, or 360 degrees.  
                Default: 6.2831853  
                Properties: create, query, edit
        heightRatio (Queryable[float]?): Ratio of "height" to "width"  
                Default: 2.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The primitive's pivot point  
                Properties: create, query, edit
        radius (Queryable[float]?): The radius of the object  
                Default: 1.0  
                Properties: create, query, edit
        sections (Queryable[int]?): The number of sections determines the resolution of the surface in the sweep direction.  
                Used only if useTolerance is false.  
                Default: 8  
                Properties: create, query, edit
        spans (Queryable[int]?): The number of spans determines the resolution of the surface in the opposite direction.  
                Default: 1  
                Properties: create, query, edit
        startSweep (Queryable[float]?): The angle at which to start the surface of revolution  
                Default: 0  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to build the surface.  
                Used only if useTolerance is true  
                Default: 0.01  
                Properties: create, query, edit
        useTolerance (bool?): Use the specified tolerance to determine resolution.  
                Otherwise number of sections will be used.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def dagCommandWrapper() -> None: ...
def dagObjectCompare(*args: str, attribute: bool = ..., bail: str = ..., connection: bool = ..., namespace: str = ..., relative: bool = ..., short: bool = ..., type: bool = ...) -> bool:
    """dagObjectCompare can be used to compare to compare objects based on:dag, compare
    Args:
        attribute (bool?): Compare dag object attributes  
                Properties: create
        bail (str?): Bail on first error or bail on category. Legal values are  
                "never", "first", and "category".  
                Properties: create
        connection (bool?): Compare dag connections  
                Properties: create
        namespace (str?): The baseline namespace  
                Properties: create
        relative (bool?): dag relatives  
                Properties: create
        short (bool?): Compress output to short form (not as verbose)  
                Properties: create
        type (bool?): Compare based on dag object type  
                Properties: create

    Returns:
        bool:

    Example:
    """

def dagObjectHit(*, cache: bool = ..., multiple: bool = ..., menu: str = ..., targetSize: int = ...) -> None: ...
def dagPose(*args: str, edit: bool = ..., query: bool = ..., addToPose: bool = ..., atPose: bool = ..., bindPose: bool = ..., g: bool = ..., members: bool = ..., name: Queryable[str] = ..., remove: bool = ..., reset: bool = ..., restore: bool = ..., save: bool = ..., selection: bool = ..., worldParent: bool = ...) -> Union[str, bool]:
    """This command is used to save and restore the matrix information for
    a dag hierarchy. Specifically, the data stored will restore the
    translate, rotate, scale, scale pivot, rotate pivot, rotation order,
    and (for joints) joint order for all the objects on the hierarchy.
    Data for other attributes is not stored by this command.This command can also be used to store a bindPose for an object.
    When you skin an object, a dagPose is automatically created for the
    skin.
    Args:
        addToPose (bool?): Allows adding the selected items to the dagPose.  
                Properties: create
        atPose (bool?): Query whether the hierarchy is at same position as the pose.  
                Names of hierarchy members that are not at the pose position will  
                be returned. An empty return list indicates that the hierarchy is at the  
                pose.  
                Properties: query
        bindPose (bool?): Used to specify the bindPose for the selected hierarchy.  
                Each hierarchy can have only  
                a single bindPose, which is saved automatically at the time of a skin  
                bind. The bindPose is used when adding influence objects,  
                binding new skins, or adding flexors. Take care when modifying  
                the bindPose with the -rs/-reset  
                or -rm/-remove flags, since if the bindPose is ill-defined it can  
                cause problems with subsequent skinning operations.  
                Properties: create, query
        g (bool?): This flag can be used in conjunction with the restore flag to  
                signal that the members of the pose should be restored to the  
                global pose. The global pose means not only is each object  
                locally oriented with respect to its parents, it is also in the  
                same global position that it was at when the pose was saved.  
                If a hierarchy's parenting has been changed since the time that  
                the pose was saved, you may have trouble reaching the global pose.  
                Properties: create
        members (bool?): Query the members of the specified pose. The pose should be  
                specified using the selection list, the -bp/-bindPose or the -n/-name flag.  
                Properties: query
        name (Queryable[str]?): Specify the name of the pose. This can be used during create,  
                restore, reset, remove, and query operations to specify the pose  
                to be created or acted upon.  
                Properties: create, query
        remove (bool?): Remove the selected joints from the specified pose.  
                Properties: create
        reset (bool?): Reset the pose on the selected joints. If  
                you are resetting pose data for a bindPose, take care. It is appropriate  
                to use the -rs/-reset flag if a joint has been reparented and/or appears to  
                be exactly at the bindPose. However, a bindPose that is much different  
                from the exact bindPose can cause problems with subsequent skinning operations.  
                Properties: create
        restore (bool?): Restore the hierarchy to a saved pose. To specify the pose,  
                select the pose node, or use the -bp/-bindPose or -n/-name flag.  
                Properties: create
        save (bool?): Save a dagPose for the selected dag hierarchy. The name of the  
                new pose will be returned.  
                Properties: create
        selection (bool?): Whether or not to store a pose for all items in the hierarchy,  
                or for only the selected items.  
                Properties: create, query
        worldParent (bool?): Indicates that the selected pose member should be recalculated as if it is  
                parented to the world. This is typically used when you plan to reparent  
                the object to world as the next operation.  
                Properties: create

    Returns:
        str: Name of pose

    Example:
    """

def dataStructure(*, query: bool = ..., asFile: Queryable[str] = ..., asString: Queryable[str] = ..., dataType: bool = ..., format: Queryable[str] = ..., listMemberNames: Queryable[str] = ..., name: Queryable[str] = ..., remove: bool = ..., removeAll: bool = ...) -> Union[str, List[str], bool]:
    """Takes in a description of the structure and creates it, adding it to
    the list of available data structures. The structure definition can
    either be supplied in theflag or exist in a file that is
    referenced by theflag.If theflag is specified with aflag then the data
    structure will be removed. This is to keep all structure operations
    in a single command rather than create separate commands to create,
    remove, and query the data structures. When you use theflag then every existing metadata structure is removed. Use with care!
    Note that removed structures may still be in use in metadata Streams after
    removal, they are just no longer available for the creation of new Streams.Both the creation modes and the remove mode are undoable.Creation of an exact duplicate of an existing structure (including name)
    will succeed silently without actually creating a new structure.
    Attempting to create a new non-duplicate structure with the same name
    as an existing structure will fail as there is no way to disambiguate
    two structures with the same name.Querying modes are defined to show information both on the created
    structures and the structure serialization formats that have been
    registered. The serialization formats preserve the structure
    information as text (e.g. raw, XML, JSON). Since thestructure
    type is built in it will be assumed when none are specified.General query with no flags will return the list of names of all
    currently existing structures.Querying theflag will return the list of all registered structure
    serialization formats.Querying with thesupplied before theflag will
    show the detailed description of that particular structure
    serialization format.Querying theflag with a structure name and serialization
    format supplied before theflag will return a string
    representing the named data structure in the serialization format
    specified by theflag. Even if the format is the same as
    the one that created the structure the query return string may not
    be identical since the queried value is formatted in a standard
    way - original formatting is not preserved.Querying theflag with a structure name supplied before theflag will return the original file from which the structure
    was generated. If the structure was created using theflag or through the API then an empty string will be returned.Querying theflag returns the list of all structures created
    so far.metadata, component
    Args:
        asFile (Queryable[str]?): Specify a file that contains the serialized data which describes the  
                structure.  The format of the data is specified by the 'format' flag.  
                Properties: create, query
        asString (Queryable[str]?): Specify the string containing the serialized data which describes the  
                structure. The format of the data is specified by the 'format' flag.  
                Properties: create, query
        dataType (bool?): Used with the flag 'listMemberNames' to query the type of the member.  
                The type is appended after each relative member in the array.  
                For example, if the format is "name=idStructure:int32=id:string=name"  
                the returned array is "id int32 name string".  
                Properties: create, query
        format (Queryable[str]?): Format of data to expect in the structure description. "raw" is supported  
                natively and will be assumed if the format type is omitted. Others are  
                available via plug-in. You can query the available formats by using this  
                flag in query mode.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        listMemberNames (Queryable[str]?): Query the member names in the dataStructure. The member names will be  
                returned in an array. The name of the data structure will not be returned.  
                To get the type of each member, use 'dataType' together. Then the type of  
                the member will be appended in the array after their relative member.  
                For example, if the format is "name=idStructure:int32=id:string=name"  
                the returned array is "id int32 name string".  
                Properties: create, query
        name (Queryable[str]?): Query mode only.  Name of the data structure to be queried, or set to  
                list the available names.  
                			In query mode, this flag can accept a value.  
                Properties: query
        remove (bool?): Remove the named data structure. It's an error if it doesn't exist.  
                Properties: create
        removeAll (bool?): Remove all metadata structures. This flag can not be used in conjunction with  
                any other flags.  
                Properties: create

    Returns:
        str: Name of the resulting structure, should match the name defined in the structure description
        List[str]: Name(s) of the removed structures.

    Example:
    """

def date(*, date: bool = ..., format: str = ..., shortDate: bool = ..., shortTime: bool = ..., time: bool = ...) -> str:
    """Returns information about current time and date. Use the predefined formats, or theflag to specify the output format.time, date
    Args:
        date (bool?): Returns the current date. Format is YYYY/MM/DD  
                Properties: create
        format (str?): Specifies a string defining how the date and time should be represented. All  
                occurences of the keywords below will be replaced with the corresponding  
                values:  
              
                KeywordBecomes  
                YYYYCurrent year, using 4 digits  
                YYLast two digits of the current year  
                MMCurrent month, with leading 0 if necessary  
                DDCurrent day, with leading 0 if necessary  
                hhCurrent hour, with leading 0 if necessary  
                mmCurrent minute, with leading 0 if necessary  
                ssCurrent second, with leading 0 if necessary  
                Properties: create
        shortDate (bool?): Returns the current date. Format is MM/DD  
                Properties: create
        shortTime (bool?): Returns the current time. Format is hh:mm  
                Properties: create
        time (bool?): Returns the current time. Format is hh:mm:ss  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def dbcount(*, enabled: bool = ..., file: str = ..., keyword: str = ..., list: bool = ..., maxdepth: int = ..., quick: bool = ..., reset: bool = ..., spreadsheet: bool = ...) -> bool:
    """Thecommand is used to print and manage a list of statistics
    collected for counting operations.  These statistics are displayed
    as a list of hits on a particular location in code, with added reference
    information for pointers/strings/whatever.
    If -reset is not specified then statistics are printed.debug, count, filter
    Args:
        enabled (bool?): Set the enabled state of the counters ('on' to enable, 'off' to disable).  
                Returns the list of all counters affected.  
                Properties: create
        file (str?): Destination file of the enabled count objects.  Use the special names  
                stdout and stderr to redirect to your command window.  As  
                well, the special name msdev is available on NT to direct your  
                output to the debug tab in the output window of Developer Studio.  
                Properties: create
        keyword (str?): Print only the counters whose name matches this keyword (default is all).  
                Properties: create
        list (bool?): List all available counters and their current enabled status. (The only  
                thing you can do when counters are disabled.)  
                Properties: create
        maxdepth (int?): Maximum number of levels down to traverse and report. 0 is the default and  
                it means continue recursing as many times as are requested.  
                Properties: create
        quick (bool?): Display only a summary for each counter type instead of the full details.  
                Properties: create
        reset (bool?): Reset all counters back to 0 and remove all but the top level counters.  
                Returns the list of all counters affected.  
                Properties: create
        spreadsheet (bool?): Display in spreadsheet format instead of the usual nested braces.  
                This will include a header row that contains 'Count Level1 Level2 Level3...',  
                making the data suitable for opening directly in a spreadsheet table.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def dbfootprint(*args: str, query: bool = ..., allObjects: bool = ..., outputFile: str = ..., type: Queryable[str] = ...) -> Union[str, List[str]]:
    """This command lets you explore the memory usage of specific parts of the
    scene. Query the 'type' flag to see what all of the different types are,
    and query a specific type to get a description of what information it will
    provide.
    All output is in JSON format so that it can easily be processed and formatted
    to highlight areas of interest.dbtrace, dbpeek
    Args:
        allObjects (bool?): Ignore any specified or selected objects and measure all applicable  
                objects. The definition of "allObjects" will vary based on the type of  
                objects being measured - see the type documentation for details on  
                what it means for that type.  
                By default if no objects are selected or specified then it will behave  
                as though this flag were set.  
                Properties: create
        outputFile (str?): Specify the location of a file to which the information is to be  
                dumped. Default will return the value from the command.  Use the  
                special names stdout, cout, stderr, or cerr to redirect  
                to the standard output or error locations.  
                Properties: create
        type (Queryable[str]?): Specify the type of object footprint to measure. The various types are registered at  
                run time and can be listed by querying this flag without a value. If you query it  
                with a value then you get a description of what that particular type is going to  
                measure.  
                			In query mode, this flag can accept a value.  
                Properties: create, query

    Returns:
        str: JSON data representing the memory usage of the requested objects
        List[str]: List of types for which footprint measurements can be made (Query with no flags)
        str: Description of what a particular type will measure (Query with a 'type' flag)

    Example:
    """

def dbmessage(*, file: str = ..., list: bool = ..., monitor: bool = ..., type: str = ...) -> bool:
    """Thecommand is used to install monitors for certain
    message types, dumping debug information as they are sent so that the
    flow of messages can be examined.debug, message, filter
    Args:
        file (str?): Destination file of the message monitoring information.  Use the special names  
                stdout and stderr to redirect to your command window.  As  
                well, the special name msdev is available on NT to direct your  
                output to the debug tab in the output window of Developer Studio.  
                Default value is stdout.  
                Properties: create
        list (bool?): List all available message types and their current enabled status.  
                Properties: create
        monitor (bool?): Set the monitoring state of the message type ('on' to enable, 'off' to disable).  
                Returns the list of all message types being monitored after the change in state.  
                Properties: create
        type (str?): Monitor only the messages whose name matches this keyword (default is all).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def dbpeek(*args: str, query: bool = ..., allObjects: bool = ..., argument: Multiuse[str] = ..., count: Queryable[int] = ..., evaluationGraph: bool = ..., operation: Queryable[str] = ..., outputFile: Queryable[str] = ...) -> Union[List[str], str, int, bool]:
    """Thecommand is used to analyze the Maya data for
    information of interest. See a description of the flags for details
    on what types of things can be analyzed.debug, node, attribute
    Args:
        allObjects (bool?): Ignore any specified or selected objects and peek into all applicable  
                objects. The definition of "allObjects" will vary based on the peek  
                operation being performed - see the flag documentation for details on  
                what it means for a given operation.  
                By default if no objects are selected or specified then it will behave  
                as though this flag were set.  
                Properties: create, query
        argument (Multiuse[str]?): Specify one or more arguments to be passed to the operation. The acceptable  
                values for the argument string are documented in the flag to which they will be  
                applied. If the argument itself takes a value then the value will be of the  
                form "argname=argvalue".  
                			In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        count (Queryable[int]?): Specify a count to be used by the test. Different tests make different use of  
                the count, query the operation to find out how it interprets the value.  
                For example a performance test might use it as the number of iterations to run  
                in the test, an output operation might use it to limit the amount of output it  
                produces.  
                Properties: create, query
        evaluationGraph (bool?): Ignore any nodes that are not explicitly part of the evaluation graph.  
                Usually this means nodes that are affected either directly or indirectly  
                by animation. May also tailor the operation to be EM-specific in the  
                areas where the structure of the DG differs from the structure of the  
                EM, for example, plug configurations.  
                This is a filter on the currently selected nodes, including the use of  
                the "allObjects" flag.  
                Properties: create, query
        operation (Queryable[str]?): Specify the peeking operation to perform. The various operations are registered at  
                run time and can be listed by querying this flag without a value. If you  
                query it with a value then you get the detail values that peek operation accepts and  
                a description of what it does.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        outputFile (Queryable[str]?): Specify the location of a file to which the information is to be  
                dumped. Default will return the value from the command.  Use the  
                special names stdout and stderr to redirect to your  
                command window.  
                The special name msdev is available when debugging on Windows  
                to direct your output to the debug tab in the output window of Visual  
                Studio.  
                Properties: create, query

    Returns:
        List[str]: Query of operation yields a string array with available operations
        List[str]: Query of argument yields a string array with available argument definitions on the specified operation
        str: Query of specific operation without an output file returns a string with help information for that operation
        int: Query of specific operation with an output file dumps the help information for that operation to that file and returns the number of errors encountered

    Example:
    """

def dbtrace(*, query: bool = ..., filter: Queryable[str] = ..., info: bool = ..., keyword: Queryable[Multiuse[str]] = ..., mark: bool = ..., off: bool = ..., output: Queryable[str] = ..., timed: bool = ..., title: str = ..., verbose: bool = ...) -> Union[bool, str, Multiuse[str]]:
    """Thecommand is used to manipulate trace objects.
              The keyword is the only mandatory argument, indicating which trace
              object is to be altered.You can use the query mode to find out which keywords are currently
              active (query with no arguments) or inactive (query with theargument).
              You can enhance that query with or without a keyword argument to find
              out where their output is going (query with theargument), out what filters are currently applied (query with theargument), or if their output will be
              timestamped (query with theargument).debug, trace, filter
    Args:
        filter (Queryable[str]?): Set the filter object for these trace objects (see 'dgfilter')  
                Properties: create, query
        info (bool?): In query mode return a brief description of the trace object.  
                Properties: query
        keyword (Queryable[Multiuse[str]]?): Keyword of the trace objects to affect  
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        mark (bool?): Display a mark for all outputs of defined trace objects  
                Properties: create
        off (bool?): Toggle the traces off.  If omitted it will turn them on.  
                Properties: create
        output (Queryable[str]?): Destination file of the affected trace objects.  Use the special names  
                stdout and stderr to redirect to your command window.  
                The special name msdev is available on Windows to direct your  
                output to the debug tab in the output window of Visual Studio.  
                Properties: create, query
        timed (bool?): Turn on/off timing information in the output of the specified trace objects.  
                Properties: create, query
        title (str?): Display a title mark for all outputs of defined trace objects  
                Properties: create
        verbose (bool?): Include all traces in output and filter queries, not just those turned on.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def debug(*args: Any, **kwargs: Any) -> None: ...
def debugNamespace(*args: Any, **kwargs: Any) -> None: ...
def debugVar(*args: Any, **kwargs: Any) -> None: ...
def defaultLightListCheckBox(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: str = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., shadingGroup: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a checkBox that controls whether a
    shadingGroup is connected/disconnected from the defaultLightList.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (str?): Value of the checkbox label  
                Properties: create, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        shadingGroup (str?): The shading group that is to be connected/disconnected from the  
                defaultLightList.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full name to the control

    Example:
    """

def defaultNavigation(arg0: str = ..., arg1: str = ..., /, *, connectToExisting: bool = ..., createNew: bool = ..., defaultAttribute: bool = ..., defaultTraversal: bool = ..., defaultWorkingNode: bool = ..., delete: bool = ..., destination: str = ..., disconnect: bool = ..., force: bool = ..., ignore: bool = ..., navigatorDecisionString: str = ..., quiet: bool = ..., relatedNodes: bool = ..., source: str = ..., unignore: bool = ...) -> str:
    """The defaultNavigation command defines default behaviours when
    creating or manipulating connections between nodes and when
    navigating between nodes via those connections. This command is
    primarily used by attribute editors.
    Args:
        connectToExisting (bool?): Connect the destination (which is a node.attribute or simply  
                node) to an existing source. If the source is specified (as  
                node.attribute or simply as node), the command will proceed  
                immediately. If the source is not specified, the user will  
                be prompted to specify one. Once a source has been specified,  
                a best guess will be made about what the user is trying to  
                accomplish by connecting the two, based on the type of source and  
                type of destination. The command will connect the nodes/attributes  
                according to the best guess. The destination is specified using  
                the destination flag and the source specified using the  
                source flag.  
                Properties: create
        createNew (bool?): Create a new node and connect it to the node.attribute specified  
                using the destination flag.  
                Properties: create
        defaultAttribute (bool?): Returns the name of the attribute to which a connectNodeToNode  
                would connect, given the source (attribute) and destination  
                (node) flags.  
                Returns a string.  
                Properties: create
        defaultTraversal (bool?): Returns the name of the node to which it would make the most  
                sense to navigate to from the destination node.attribute specified.  
                The destination is specified using the destination flag.  
                Returns a string.  
                Properties: create
        defaultWorkingNode (bool?): Returns the name of the node which the user is most likely to  
                want to work with if they are interested in the attributes of  
                the destination node.  
                The destination is specified using the destination flag.  
                Returns a string.  
                Properties: create
        delete (bool?): Delete nodes with connections flowing into the node.attribute  
                specified by the destination flag.  
                Properties: create
        destination (str?): Specifies an existing destination attribute for a createNew or connectToExisting.  
                Properties: create
        disconnect (bool?): If used then disconnect the destination if it exists.  
                Properties: create
        force (bool?): If set to true, then an attempt to connect a source attribute to  
                a destination attribute which already has a source will cause the  
                existing source to be disconnected and the new source to be  
                connected in its place. Default value is true.  
                Properties: create
        ignore (bool?): Ignore any connections flowing into the node.attribute specified  
                by the destination flag.  
                Properties: create
        navigatorDecisionString (str?): This is your opportunity to pass the navigator a string that  
                can help it decide what behaviour to execute.  
                Properties: create
        quiet (bool?): If set to true, then under no circumstances should the user be  
                prompted for more information. Default value is false.  
                Properties: create
        relatedNodes (bool?): List nodes which are conceptually related to the node.attribute  
                specified by the destination. Related nodes may include,  
                but are not limited to, nodes which are directly or indirectly  
                connected to the destination.  
                The destination is specified using the destination flag.  
                Returns an array of strings.  
                Properties: create
        source (str?): Specifies an existing source attribute for a connectToExisting.  
                Properties: create
        unignore (bool?): Stop ignoring any connections flowing into the node.attribute  
                specified by the destination flag.  
                Properties: create

    Returns:
        str: or array of strings

    Example:
    """

def defineDataServer(*args: Any, device: str = ..., server: str = ..., undefine: bool = ...) -> bool:
    """Connects to the specified data servername, creating a named device which
    then can be attached to device handlers.When the device is defined, it queries queries the server for data axis
    information.  The "CapChannels" present are represented as axis in form
    "channelName"."usage" for scalar channels and "channelName"."component"
    for compound channels. Seeto list axis names.Note that undoingdoes not break the connection with the data server until it cannot be
    redone.  Executing any other command (sphere for example) will cause
    this to occur.  Similarly, the commanddoes not break the connection with the data server until it cannot be
    undone.  Either flushUndo, or the 'defineDataServer' command falling"
    off the end of the undo queue causes this to occur, and the connection.
    to be broken.No return value.
    Args:
        device (str?): specified the device name to be given to the server connection.  
                device name must be unique or the command fails.  
                Properties: create
        server (str?): specifies the name of the server with which the define  
                device connects, and can be specifiied in two ways  
              
              
                name -- the name of the server socket  
                Server names of the form name connect to the  
                server socket on the localhost corresponding to  
                name.  If name does not begin with "/",  
                then /tmp/name is used. This is the default behavior  
                of most servers. If name begins with "/",  
                name denotes the full path to the socket.   
                host:service - a udp service  
                on the specified host.  
                The service can be any one of a "udp service name,"  
                a "port number," or a named service of "tcpmux," and they are  
                found in that order. If  
                host is omitted, the localhost is used.   
              
                In any case, if the server cannot be found, the device is not  
                defined (created) and the command fails.  
                Properties: create
        undefine (bool?): undefines (destroys) the dataServer device, closing the connection  
                with the server.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def defineVirtualDevice(*args: Any, query: bool = ..., axis: int = ..., channel: str = ..., clear: bool = ..., create: bool = ..., device: str = ..., parent: str = ..., undefine: bool = ..., usage: str = ...) -> bool:
    """This command defines a virtual device. Virtual devices act like real
    devices and are useful to manipulate/playback data when an command
    device is not connected to the computer.
    Args:
        axis (int?): Specifies the axis number of the channel. All children have their  
                axis number determined by their parent's axis number and the width  
                of the parent channel. If this flag is not used, the order of the  
                channel determines the axis number.  
                Properties: create
        channel (str?): After a -create is started, channels may be added to the device  
                definition. The channel string wil be the name of the channel  
                being added to the device. The -channel flag must also be  
                accompanied by the -usage flag and optionally by the -axis flag.  
                Properties: create
        clear (bool?): The -clear option will end a device definition and throw away  
                any defined channels.  
                Properties: create
        create (bool?): Start defining a virtual device. If a device is currently being  
                defined, the -create flag will produce an error.  
                Properties: create
        device (str?): The -device flag ends the device definition. All of the channels  
                between the -create flag and the -device flag are added to  
                the specified device. If that device already exists, the command  
                will fail and the device should be redefined with another device  
                name. To see the currently defined devices, use the listInputDevices  
                command. The -device flag is also used with -undefine to undefine a  
                virtual device.  
                Properties: create
        parent (str?): Specified the parent channel of the channel being defined. If the  
                channel does not exist, or is an incompatible type, the command  
                will fail.  
                Properties: create
        undefine (bool?): Undefines the device specified with the -device flag.  
                Properties: create
        usage (str?): The -usage option is required for every -channel flag. It  
                describes what usage type the defined channel is. The usage  
                types are:  
              
              
                unknownscalar  
              
                posrot  
                posRotquaternionposQuaternion  
              
                rotXYZrotYZXrotZXY  
                rotXZYrotYXZrotZYX  
              
                posRotXYZposRotYZXposRotZXY  
                posRotXZYposRotXZYposRotZYX  
              
                posXposYposZrotX  
                rotYrotZ  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def deformableShape(*args: str, chain: bool = ..., createOriginalGeometry: bool = ..., createTweakNode: bool = ..., createUpstreamTagInjectionNode: bool = ..., deformShapeInAttr: bool = ..., deformShapeOutAttr: bool = ..., frontOfChain: bool = ..., localShapeInAttr: bool = ..., localShapeOutAttr: bool = ..., nodeChain: bool = ..., originalGeometry: bool = ..., outputPlugChain: bool = ..., plugChain: bool = ..., supportsComponentTags: bool = ..., tagInjectionList: bool = ..., tagInjectionNode: bool = ..., tweakNode: bool = ..., upstreamTagInjectionNode: bool = ..., worldShapeOutAttr: bool = ...) -> bool:
    """This command finds information about deforming shape(s).If no shapes are specified on the command then the curently selected
    shapes are used.
    Args:
        chain (bool?): This flag will return the list of deformers that deformer the specified shapes  
                Properties: create
        createOriginalGeometry (bool?): This creates an original geometry for the shape if it does not exist yet.  
                Properties: create
        createTweakNode (bool?): This creates a traditional tweak node if one did not exist yet.  
                Properties: create
        createUpstreamTagInjectionNode (bool?): This creates an upstream component tag injection node if an editable one does not exist yet.  
                Properties: create
        deformShapeInAttr (bool?): Returns the name of deform shape in attribute  
                Properties: create
        deformShapeOutAttr (bool?): Returns the name of deform shape out attribute  
                Properties: create
        frontOfChain (bool?): This flag will return the name of the plug on a shape node at the front end of  
                the deformation chain. This can return an empty plug when none exists.  
                Properties: create
        localShapeInAttr (bool?): Returns the name of local shape in attribute  
                Properties: create
        localShapeOutAttr (bool?): Returns the name of local shape out attribute  
                Properties: create
        nodeChain (bool?): This flag will return the list of nodes through which the geometry passes to get to this shape  
                Properties: create
        originalGeometry (bool?): This flag will return the name of a plug on a node in the deformation chain  
                (likely at the front end) that is the best candidate to be used as the  
                originalGeometry. This can return an empty plug when none exists.  
                Properties: create
        outputPlugChain (bool?): This flag will return the list of output plugs leading to the shape  
                Properties: create
        plugChain (bool?): This flag will return the list of plugs leading to the shape (both input and output plugs)  
                Properties: create
        supportsComponentTags (bool?): Returns whether the shape supports component tags  
                Properties: create
        tagInjectionList (bool?): This flag will return the list of nodes which are non-procedural componentTag injection nodes  
                Properties: create
        tagInjectionNode (bool?): This flag will return the name of the non-referenced component tag injection node as high  
                up in the deformation chain as possible. This can be the same as the input shape or an  
                empty string when none exists.  
                Properties: create
        tweakNode (bool?): This flag will return the name of the tweak node in the deformation chain.  
                This can return an empty string when none exists.  
                Properties: create
        upstreamTagInjectionNode (bool?): This flag will return the name of the non-referenced component tag injection node most  
                upstream from (but not including) the input shape.  
                This can be an empty string when none exists. If so, one can be created using the  
                cti/createUpstreamTagInjectionNode flag.  
                Properties: create
        worldShapeOutAttr (bool?): Returns the name of world shape out attribute  
                Properties: create

    Returns:
        bool:

    Example:
    """

def deformer(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., deformerTools: bool = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., split: bool = ..., type: str = ..., useComponentTags: bool = ...) -> Union[List[str], bool, str, Multiuse[str]]:
    """This command creates a deformer of the specified type. The deformer
    will deform the selected objects.This command creates a deformer node and connects it to a deformation chain.
    If the deformer does not already exist, it is created. If the deformer already
    exists, the command lets you modify parameters on the named deformer.
    Unlike commands for specialized deformers, this command does not create or manage
    deformer-specific setups. Using this command allows deformation chains to be
    managed in a more general manner.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        type (str?): Specify the type of deformer to create. This flag is  
                required in create mode. Typically the type should specify a loaded  
                plugin deformer. This command should typically not be used to create  
                one of the standard deformers  
                such as sculpt, lattice, blendShape, wire and cluster, since they have  
                their own customized commands which perform useful specialized functionality.  
                Properties: create
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        List[str]: Name of the algorithm node created/edited.

    Example:
    """

def deformerWeights(*args: str, edit: bool = ..., query: bool = ..., attribute: Queryable[Multiuse[str]] = ..., defaultValue: Queryable[float] = ..., deformer: Queryable[Multiuse[str]] = ..., export: bool = ..., format: Queryable[str] = ..., ignoreName: bool = ..., im: bool = ..., method: Queryable[str] = ..., path: Queryable[str] = ..., positionTolerance: Queryable[float] = ..., remap: Queryable[Multiuse[str]] = ..., shape: Queryable[Multiuse[str]] = ..., skip: Queryable[Multiuse[str]] = ..., vertexConnections: bool = ..., weightPrecision: Queryable[int] = ..., weightTolerance: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, Multiuse[str], float, bool, int]:
    """Command to import and export deformer weights to and from a simple XML
     file. The weight data is stored in a per-vertex fashion along with a
     "point cloud" corresponding to the vertices from the geometry input to
     the deformer.
     For example a cluster deformer would have the following information:On import the weights are then mapped back to a specified deformer
     based on the specified mapping method. Note that the geometry used to
     perform the mapping association is not the visible shape but rather
     the incoming geometry to the deformer. For example, in the case of a
     skin cluster this would be the bind pose geometry.deformer, export
    Args:
        attribute (Queryable[Multiuse[str]]?): Specify the long name of deformer attribute that should be imported/exported along with the deformerWeights. i.e. -at "envelope" -at "skinningMethod" etc.. No warning or error is given if a specified attribute does not exist on a particular deformer, making it possible to use this command with multiple deformers without aborting or slowing down the import/export process.  Currently supports numeric attributes and matrix attributes  
                Properties: create, query, edit, multiuse
        defaultValue (Queryable[float]?): Manually set the default value. Default values are values that are not written to file. For example, for blendShapes the default value is automatically set to 1.0 and these values are not written to disk. For skinClusters the value is 0.0. If all weights should be forced to be written to disk, set a defaultValue = -1.0.  
                Properties: create, query, edit
        deformer (Queryable[Multiuse[str]]?): Specify the deformer whose weights should be exported or imported. If a pattern is supplied for the deformer  
                name (i.e: cluster*), only the first deformer that matches the pattern will be imported/exported unless used  
                in conjunction with the -skip option  
                Properties: create, query, edit, multiuse
        export (bool?): Export the given deformer  
                Properties: create, query, edit
        format (Queryable[str]?): Specify either "XML" or "JSON" as the file extension to save as.  
                Properties: create, query, edit
        ignoreName (bool?): Ignore the names of the layers on import, just use the order of the layers instead. This can be used when  
                joint names have been changed. Leaving it on only name that match on import will be write to the deformer.  
                Properties: create, query, edit
        im (bool?): Import weights to the specified deformer. See the method flag for details  
                on how the weights will be mapped to the destination deformer.  
                Properties: create, query, edit
        method (Queryable[str]?): Specify the method used to map the weight during import. Valid values are:  
                "index", "nearest", "barycentric", "bilinear" and "over". The "index" method  
                uses the vertex index to map the weights onto the object. This is most useful  
                when the destination object shares the same topology as the exported data.  
                The "nearest" method finds the nearest vertex in the imported data set and  
                sets the weight value to that value. This is best used when mapping a higher  
                resolution mesh to a lower resolution. The "barycentric" and "bilinear" methods  
                are only supported with polygon mesh exported with -vc/vertexConnections flag.  
                The "barycentric" method finds the nearest triangle of the input geometry and  
                rescales the weights at the triangle vertices according to the barycentric  
                weights to each vertex of the nearest triangle. The "bilinear" method finds the  
                nearest convex quad of the input geometry and rescales the weights at the quad  
                vertices according to the bilinear weights to each vertex of the nearest convex  
                quad. For non-quad polygon, the "bilinear" method will fall back to "barycentric"  
                method. The "over" method is similar to the "index" method but the weights on the  
                destination mesh are not cleared prior to mapping, so that unmatched indices  
                keep their weights intact.  
                Properties: create, query, edit
        path (Queryable[str]?): The path to the given file. Default to the current project.  
                Properties: create, query, edit
        positionTolerance (Queryable[float]?): The position tolerance is used to determine the radius of search for the nearest method. This flag is only  
                used with import.  
                Defaults to a huge number.  
                Properties: create, query, edit
        remap (Queryable[Multiuse[str]]?): Remap maps source regular expression to destination format. It maps any name that matches the regular expression (before the semi-colon) to the expression format (after the semi-colon).  
                For example, -remap "test:(.*);$1" will rename all items in the test namespace to the global namespace. Accepts $1, $2, .., $9 as pattern holders in the expression format.  
                Remap flag must be used together with import or export. When working with import, the name of the object from the xml file matching the regular expression is remapped to object in scene. When working with export, the name of the object from the scene matching the regular expression is remapped to object in xml file.  
                Properties: create, query, edit, multiuse
        shape (Queryable[Multiuse[str]]?): Specify the source shape. Export will write out all the deformers on the shape node into one file.  
                If a pattern is supplied for the shape name (i.e: pCylinder*), only the first shape that matches the pattern will  
                be imported/exported unless used in conjunction with the -skip option.  
                Properties: create, query, edit, multiuse
        skip (Queryable[Multiuse[str]]?): Skip any deformer, shape, or layer that whose name matches the given regular expression string  
                Properties: create, query, edit, multiuse
        vertexConnections (bool?): Export vertex connection information, which is required for -m/-method "barycentric" and "bilinear". The flag is only used with -ex/-export flag. The vertex connection information is automatically loaded during import if available in xml file.  
                Properties: create, query, edit
        weightPrecision (Queryable[int]?): Sets the output decimal precision for exported weights. The default value is 3.  
                Properties: create, query, edit
        weightTolerance (Queryable[float]?): The weight tolerance is used to decide if a given weight value is close enough to the default value that it does not need to be included. This flag is only used with export. The default value is .001.  
                Properties: create, query, edit
        worldSpace (bool?): For spatially based association methods (nearest), the position should be based on the world space position  
                rather then the local object space.  
                Properties: create, query, edit

    Returns:
        str: path to the file imported/exported, if successful

    Example:
    """

def delete(*args: str, all: bool = ..., attribute: Multiuse[str] = ..., channels: bool = ..., constraints: bool = ..., constructionHistory: bool = ..., controlPoints: bool = ..., expressions: bool = ..., hierarchy: str = ..., inputConnectionsAndNodes: bool = ..., motionPaths: bool = ..., shape: bool = ..., staticChannels: bool = ..., timeAnimationCurves: bool = ..., unitlessAnimationCurves: bool = ...) -> bool:
    """This command is used to delete selected objects, or all objects, or
    objects specified along with the command. Flags are available to
    filter the type of objects that the command acts on.At times, more than just specified items will be deleted.  For
    example, deleting two CVs in the same "row" on a NURBS surface
    will delete the whole row.
    Args:
        all (bool?): Remove all objects of specified kind, in the scene. This flag  
                is to be used in conjunction with the following flags.  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        channels (bool?): Remove animation channels in the scene. Either all channels  
                can be removed, or the scope can be narrowed down by specifying  
                some of the above mentioned options.  
                Properties: create
        constraints (bool?): Remove selected constraints and constraints attached to the  
                selected nodes, or remove all constraints in the scene.  
                Properties: create
        constructionHistory (bool?): Remove the construction history on the objects specified or  
                selected.  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        expressions (bool?): Remove expressions in the scene. Either all expressions  
                can be removed, or the scope can be narrowed down by specifying  
                some of the above mentioned options.  
                Properties: create
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        inputConnectionsAndNodes (bool?): Break input connection to specified attribute and delete all  
                unconnected nodes that are left behind. The graph will be  
                traversed until a node that cannot be deleted is encountered.  
                Properties: create
        motionPaths (bool?): Remove motion paths in the scene. Either all  
                motion paths can be removed, or the scope can be narrowed down  
                by specifying some of the above mentioned options.  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        staticChannels (bool?): Remove static animation channels in the scene. Either all  
                static channels can be removed, or the scope can be narrowed down  
                by specifying some of the above mentioned options.  
                Properties: create
        timeAnimationCurves (bool?): Modifies the -c/channels and -sc/staticChannels flags.  
                When true, only channels connected to time-input  
                animation curves (for instance, those created by  
                'setKeyframe' will be deleted.  When false, no  
                time-input animation curves will be deleted.  
                Default: true.  
                Properties: create
        unitlessAnimationCurves (bool?): Modifies the -c/channels and -sc/staticChannels flags.  
                When true, only channels connected to  
                unitless-input animation curves (for instance,  
                those created by 'setDrivenKeyframe' will be  
                deleted.  When false, no unitless-input  
                animation curves will be deleted.  Default:  
                true.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def deleteAttr(*args: str, edit: bool = ..., query: bool = ..., attribute: str = ...) -> bool:
    """This command is used to delete a dynamic attribute
    from a node or nodes. The attribute can be specified
    by using either the long or short name. Only one
    dynamic attribute can be deleted at a time. Static
    attributes cannot be deleted. Children of a compound
    attribute cannot be deleted. You must delete the
    complete compound attribute. This command has no
    edit capabilities. The only query ability is to list
    all the dynamic attributes of a node.
    Args:
        attribute (str?): Specify either the long or short name of the attribute.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def deleteAttrPattern(*, allPatterns: bool = ..., patternName: str = ..., patternType: str = ...) -> str:
    """After a while the list of attribute patterns could become cluttered.
    This command provides a way to remove patterns from memory so that only
    the ones of interest will show.attribute, pattern
    Args:
        allPatterns (bool?): If specified it means delete all known attribute patterns.  
                Properties: create
        patternName (str?): The name of the pattern to be deleted.  
                Properties: create
        patternType (str?): Delete all patterns of the given type.  
                Properties: create

    Returns:
        str: Name(s) of deleted pattern(s)

    Example:
    """

def deleteExtension(*, attribute: str = ..., forceDelete: bool = ..., nodeType: str = ...) -> int:
    """This command is used to delete an extension attribute
    from a node type. The attribute can be specified
    by using either the long or short name. Only one
    extension attribute can be deleted at a time.
    Children of a compound attribute cannot be deleted,
    you must delete the complete compound attribute.
    This command has no undo, edit, or query capabilities.attribute, dependency, graph, delete, extension
    Args:
        attribute (str?): Specify either the long or short name of the attribute.  
                Properties: create
        forceDelete (bool?): If this flag is set and turned ON then data values for the extension  
                attributes are all deleted without confirmation. If it's set and turned  
                OFF then any extension attributes that have non-default values set on any  
                node will remain in place. If this flag is not set at all then the user  
                will be asked if they wish to preserve non-default values on this  
                attribute.  
                Properties: create
        nodeType (str?): The name of the node type.  
                Properties: create

    Returns:
        int: Number of nodes with altered data after the delete

    Example:
    """

def deleteGeometryCache() -> None: ...
def deleteHistoryAheadOfGeomCache() -> None: ...
def deleteNclothCache() -> None: ...
def deleteUI(*args: str, collection: bool = ..., control: bool = ..., editor: bool = ..., layout: bool = ..., menu: bool = ..., menuItem: bool = ..., panel: bool = ..., panelConfig: bool = ..., radioMenuItemCollection: bool = ..., toolContext: bool = ..., uiTemplate: bool = ..., window: bool = ...) -> bool:
    """This command deletes UI objects such as windows and controls.  Deleting
    a layout or window will also delete all of its children.  If a flag
    is used then all objects being deleted must be of the specified type.
    This command may not be edited or queried.NOTE: it is recommended that the type flags be used to disambiguate
    different kinds of objects with the same name.
    Args:
        collection (bool?): Object names for deletion are all radio or tool collections.  
                Properties: create
        control (bool?): Object names for deletion are all controls.  
                Properties: create
        editor (bool?): Object names for deletion are all editors.  
                Properties: create
        layout (bool?): Object names for deletion are all layouts.  
                Properties: create
        menu (bool?): Object names for deletion are all menus.  
                Properties: create
        menuItem (bool?): Object names for deletion are all menu items.  
                Properties: create
        panel (bool?): Object names for deletion are all panels.  
                Properties: create
        panelConfig (bool?): Object names for deletion are panel configurations.  
                Properties: create
        radioMenuItemCollection (bool?): Object names for deletion are all radio menu item collections.  
                Properties: create
        toolContext (bool?): Object names for deletion are all tool contexts.  
                Properties: create
        uiTemplate (bool?): Object names for deletion are all UI templates.  
                Properties: create
        window (bool?): Object names for deletion are all windows.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def deltaMush(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., deformerTools: bool = ..., envelope: Queryable[float] = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., inwardConstraint: Queryable[float] = ..., name: str = ..., outwardConstraint: Queryable[float] = ..., parallel: bool = ..., pinBorderVertices: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., smoothingIterations: Queryable[int] = ..., smoothingStep: Queryable[float] = ..., split: bool = ..., useComponentTags: bool = ...) -> Union[str, bool, float, Multiuse[str], int]:
    """This command is used to create, edit and query deltaMush nodes.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        envelope (Queryable[float]?): Envelope of the delta mush node. The envelope determines the percent of  
                deformation. Value is clamped to [0, 1] range.  
                Default is 1.  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        inwardConstraint (Queryable[float]?): Constrains the movement of the vertex to not move inward from the input  
                deforming shape to preserve the contour. Value is in the [0,1] range.  
                Default is 0.0.  
                Properties: create, query, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        outwardConstraint (Queryable[float]?): Constrains the movement of the vertex to not move outward from the input  
                deforming shape to preserve the contour. Value is in the [0,1] range.  
                Default is 0.0.  
                Properties: create, query, edit
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        pinBorderVertices (bool?): If enabled, vertices on mesh borders will be pinned to their current  
                position during smoothing. Default is true.  
                Properties: create, query, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        smoothingIterations (Queryable[int]?): Number of smoothing iterations performed by the delta mush node.  
                Default is 10.  
                Properties: create, query, edit
        smoothingStep (Queryable[float]?): Step amount used per smoothing iteration. Value is clamped to [0, 1] range.  
                A higher value may lead to instabilities but converges faster compared  
                to a lower value. Default is 0.5.  
                Properties: create, query, edit
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        str: Delta mush deformer node name

    Example:
    """

def detachCurve(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., keep: Queryable[Multiuse[bool]] = ..., nodeState: Queryable[int] = ..., parameter: Queryable[Multiuse[float]] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, Multiuse[bool], int, Multiuse[float]]:
    """The detachCurve command detaches a curve into pieces, given a list
    of parameter values.  You can also specify which pieces to keep and
    which to discard using the "-k" flag.
    The names of the newly detached curve(s) is returned.  If history is on,
    then the name of the resulting dependency node is also returned.You can use this command to open a periodic curve at a particular
    parameter value.  You would use this command with only one "-p" flag.If you are specifying "-k" flags, then you must specify one, none
    or all "-k" flags.  If you are specifying all "-k" flags, there
    must be one more "-k" flag than "-p" flags.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        keep (Queryable[Multiuse[bool]]?): Whether or not to keep a detached piece.  This multi attribute should be one element larger than the parameter multi attribute.  
                Default: true  
                Properties: create, query, edit, multiuse
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[Multiuse[float]]?): Parameter values to detach at  
                Default: 0.0  
                Properties: create, query, edit, multiuse
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def detachDeviceAttr(*args: Any, query: bool = ..., all: bool = ..., attribute: str = ..., axis: str = ..., device: str = ..., selection: bool = ...) -> bool:
    """This command detaches connections between device axes and node
    attributes.  The command line arguments are the same as for
    the corresponding attachDeviceAttr except for the clutch argument
    which can not be used in this command.
    Args:
        all (bool?): Delete all attachments on every device.  
                Properties: create
        attribute (str?): The attribute to detach. This flag must be used  
                with the -d/device flag.  
                Properties: create
        axis (str?): The axis to detach. This flag must be used with  
                the -d/device flag.  
                Properties: create
        device (str?): Delete the attachment for this device. If the -ax/axis  
                flag is not used, all of the attachments connected to this  
                device are detached.  
                Properties: create
        selection (bool?): Detaches selection attachments.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def detachSurface(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., direction: Queryable[int] = ..., keep: Queryable[Multiuse[bool]] = ..., nodeState: Queryable[int] = ..., parameter: Queryable[Multiuse[float]] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, Multiuse[bool], Multiuse[float]]:
    """The detachSurface command detaches a surface into pieces, given a list
    of parameter values and a direction.  You can also specify which
    pieces to keep and which to discard using the "-k" flag.
    The names of the newly detached surface(s) are returned.  If history
    is on, the name of the resulting dependency node is also returned.You can only detach in either U or V (not both) with a single detachSurface operation.You can use this command to open a closed surface at a particular
    parameter value.  You would use this command with only one "-p" flag.If you are specifying "-k" flags, then you must specify one, none
    or all "-k" flags.  If you are specifying all "-k" flags, there
    must be one more "-k" flag than "-p" flags.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[int]?): Direction in which to detach:  
                0. V direction,  
                1. U direction  
                Default: 1  
                Properties: create, query, edit
        keep (Queryable[Multiuse[bool]]?): Keep the detached pieces.  
                Default: true  
                Properties: create, query, edit, multiuse
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[Multiuse[float]]?): Parameter at which to detach.  
                Default: 0.0  
                Properties: create, query, edit, multiuse
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def deviceEditor(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., takePath: Queryable[str] = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This creates an editor for creating/modifying attachments to
    input devices.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        takePath (Queryable[str]?): The path used for writing/reading take data through the  
                editor.  
                Properties: query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: name of the editor

    Example:
    """

def deviceManager(*args: Any, edit: bool = ..., query: bool = ..., attachment: bool = ..., axisCoordChanges: bool = ..., axisIndex: Queryable[int] = ..., axisName: bool = ..., axisOffset: bool = ..., axisScale: bool = ..., deviceIndex: Queryable[int] = ..., deviceNameFromIndex: Queryable[int] = ..., numAxis: bool = ..., numDevices: bool = ...) -> Union[bool, int]:
    """This command queriers the internal device manager for information on attached devices.device
    Args:
        attachment (bool?): Returns the plugs that a device and axis are attached to.  Expects the -deviceIndex and  
                axisIndex to be used in conjunction.  
                Properties: query
        axisCoordChanges (bool?): Returns whether the axis coordinate changes.  Expects the -deviceIndex and -axisIndex flags to be used  
                in conjunction.  
                Properties: query
        axisIndex (Queryable[int]?): Used usually in conjunction with other flags, to indicate the index of the axis.  
                Properties: create, query, edit
        axisName (bool?): Returns the name of the axis.  Expects the -deviceIndex and -axisIndex flags to be used  
                in conjunction.  
                Properties: query
        axisOffset (bool?): Returns the offset of the axis.  Expects the -deviceIndex and -axisIndex flags to be used  
                in conjunction.  
                Properties: query
        axisScale (bool?): Returns the scale of the axis.  Expects the -deviceIndex and -axisIndex flags to be used  
                in conjunction.  
                Properties: query
        deviceIndex (Queryable[int]?): Used usually in conjunction with other flags, to indicate the index of the device.  
                Properties: create, query, edit
        deviceNameFromIndex (Queryable[int]?): Returns the name of the device with the given index.  
                Properties: query
        numAxis (bool?): Returns the number of axis this device has.  Expects the -deviceIndex flag to be used.  
                Properties: query
        numDevices (bool?): Returns the number of devices currently attached.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def devicePanel(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command is now obsolete. It is included only for the purpose of file compatibility. It creates a blank panel.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: name of panel

    Example:
    """

def dgControl(*args: Any, **kwargs: Any) -> None: ...
def dgInfo(*args: str, allNodes: bool = ..., connections: bool = ..., dirty: bool = ..., nodes: bool = ..., nonDeletable: bool = ..., outputFile: str = ..., propagation: bool = ..., short: bool = ..., size: bool = ..., subgraph: bool = ..., type: str = ...) -> bool:
    """This command prints information about the DG in plain text.
    The scope of the information printed is the entire graph
    if theflag is used, the nodes/plugs on the command line if
    they were specified, and the selection list, in that order.
    Each plug on a connection will have two pieces of state information
    displayed together at the end of the line on which they are printed.
    There are two possible values for each of the two states displayed.
    The values are updated when the DG pulls data across them, usually
    through evaluation, or pushes a dirty message through them. There
    are some subtleties in how the data is pulled through the connection
    but for simplicity it will be referred to as "evaluation".
    The values displayed will be CLEAN or DIRTY followed by PROP or BLOCK.
    The first keyword has these meanings:Note: the data on the node has its own dirty state that depends
    on other factors so having a clean connection doesn't necessarily
    mean the plug's data is clean, and vice versa.
    The second keyword has these meanings:The combinationshould never be seen in a valid DG.
    This indicates that while the plug connection has been evaluated since
    the last dirty message it will not propagate any new dirty messages
    coming in to it. That in turn means downstream nodes will not be
    notified that the graph is changing and they will not evaluate properly.
    Recovering from this invalid state requires entering the commandto mark everything dirty and restart proper evaluation.
    Think of this command as the reset/reboot of the DG world.
    Both state types behave differently depending on your connection type.There are some other exceptions to these rules:debug, dependency, graph, node, output, connection
    Args:
        allNodes (bool?): Use the entire graph as the context  
                Properties: create
        connections (bool?): Print the connection information  
                Properties: create
        dirty (bool?): Only print dirty/clean nodes/plugs/connections.  Default is both  
                Properties: create
        nodes (bool?): Print the specified nodes (or the entire graph if -all is used)  
                Properties: create
        nonDeletable (bool?): Include non-deletable nodes as well (normally not of interest)  
                Properties: create
        outputFile (str?): Send the output to the file FILE instead of STDERR  
                Properties: create
        propagation (bool?): Only print propagating/not propagating nodes/plugs/connections.  
                Default is both.  
                Properties: create
        short (bool?): Print using short format instead of long  
                Properties: create
        size (bool?): Show datablock sizes for all specified nodes. Return value is tuple of  
                all selected nodes (NumberOfNodes, NumberOfDatablocks, TotalDatablockMemory)  
                Properties: create
        subgraph (bool?): Print the subgraph affected by the node or plugs (or all nodes  
                in the graph grouped in subgraphs if -all is used)  
                Properties: create
        type (str?): Filter output to only show nodes of type NODETYPE  
                Properties: create

    Returns:
        bool:

    Example:
    """

def dgPerformance(*args: Any, **kwargs: Any) -> None: ...
def dgValidateCurve(*args: str, allCurves: bool = ..., verbose: bool = ...) -> int:
    """Thecommand is used to make sure the curve internal
    status matches their actual state.
    It forces checks on curves that might not be tagged as static, even if they are.
    The DG tracks static curves in order to optimize evaluation by not
    considering them animated.  Once keys are added and modified on the
    curve, it is no longer static.  Certain operations on the curve might
    make it flat / without animation, but the DG will not treat it as
    static because it expects it to be modified again soon.
    This command allows to explicitly request checks for the static state
    of animation curves.dg, dependency, graph, dirty, static, curve
    Args:
        allCurves (bool?): Ignore the selected or specified objects and work on all curves.  
                Properties: create
        verbose (bool?): Prints out all of the curves set static or not.  
                Properties: create

    Returns:
        int: Number of curves which changed their static status.

    Example:
    """

def dgcontrol(*args: Any, **kwargs: Any) -> None: ...
def dgdebug(*args: Any, **kwargs: Any) -> None: ...
def dgdirty(*args: str, query: bool = ..., allPlugs: bool = ..., clean: bool = ..., implicit: bool = ..., list: Queryable[str] = ..., propagation: bool = ..., showTiming: bool = ..., verbose: bool = ...) -> Union[List[str], int, bool, str]:
    """Thecommand is used to force a dependency graph
    dirty message on a node or plug.  Used for debugging to find
    evaluation problems.  If no nodes are specified then the current
    selection list is used.
    If theflag is used it will return the list of things
    currently marked as dirty (or clean if theflag was
    also used). The returned values will be the names of plugs either
    clean/dirty themselves, at both ends of a clean/dirty connection,
    or representing the location of clean/dirty data on the node.
    Be careful using this option in conjunction with
    theflag, the list could be huge.dg, dependency, graph, dirty, plug, state
    Args:
        allPlugs (bool?): Ignore the selected or specified objects and dirty (or clean)  
                all plugs.  
                Properties: create, query
        clean (bool?): If this flag is set then the attributes are cleaned.  Otherwise  
                they are set to dirty.  
                Properties: create, query
        implicit (bool?): If this flag is set then allow the implicit or default nodes to be  
                processed as well. Otherwise they will be skipped for efficiency.  
                Properties: create, query
        list (Queryable[str]?): When this flag is specified then instead of sending out dirty/clean  
                messages the list of currently dirty/clean objects will be returned.  
                The allPlugs and clean flags are respected to narrow  
                guide the values to be returned.  
                The value of the flag tells what will be reported.  
              
                "data" or "d" = show plugs that have dirty/clean data  
                "plug" or "p" = show plugs that have dirty/clean states  
                "connection" or "c" = show plugs with connections that have dirty/clean states  
                Query this flag to find all legal values of the flag. Query this flag with  
                its value already set to get a description of what that value means.  
              
                Note that "p" and "c" modes are restricted to plugs that have connections  
                or non-standard state information. Other attributes will not have state  
                information to check, though they will have data.  
                In the case of array attributes only the children that have values  
                currently set will be considered. No attempt will be made to evaluate  
                them in order to update the available child lists.  
                e.g. if you have a DAG with transform T1 and shape S1 the instanced  
                attribute S1.wm[0] will be reported. If in a script you create a second  
                instance T2. >S1 and immediately list the plugs again before evaluation  
                you will still only see S1.wm[0]. The new S1.wm[1] won't be reported  
                until it is created through an evaluation, usually caused by refresh,  
                a specific getAttr command, or an editor update.  
                Note that the list is only for selected nodes. Unlike when dirty  
                messages are sent this does not travel downstream.  
                Properties: create, query
        propagation (bool?): If this flag is set then the ability of dirty messages to flow through  
                the graph is left enabled.  
                Properties: create, query
        showTiming (bool?): If this flag is used then show how long the dirty messages took  
                to propagate.  
                Properties: create, query
        verbose (bool?): Prints out all of the plugs being set dirty on stdout.  
                Properties: create, query

    Returns:
        List[str]: List of dirty/clean plugs in list plug mode.
        List[str]: List of plugs with dirty/clean data in list data mode.
        List[str]: Pairs of dirty/clean connected plugs in list connection mode.
        int: Number of dirty/clean messages sent out in normal mode.

    Example:
    """

def dgeval(*args: str, src: bool = ..., verbose: bool = ...) -> bool:
    """Thecommand is used to force a dependency graph
    evaluate of a node or plug.  Used for debugging to find
    propagation problems.Normally the selection list is used to determine which objects to
    evaluate, but you can add to the selection list by specifying which
    objects you want on the command line.
    Args:
        src (bool?): This flag is obsolete. Do not use.  
                Properties: create
        verbose (bool?): If this flag is used then the results of the evaluation(s) is/are  
                printed on stdout.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def dgfilter(*args: Any, attribute: str = ..., list: bool = ..., logicalAnd: Tuple[str, str] = ..., logicalNot: str = ..., logicalOr: Tuple[str, str] = ..., name: str = ..., node: str = ..., nodeType: str = ..., plug: str = ...) -> Union[str, List[str], bool]:
    """Thecommand is used to define Dependency Graph filters
    that select DG objects based on certain criteria.  The command itself
    can be used to filter objects or it can be attached to aobject to selectively filter what output is traced.
    If objects are specified then apply the filter to those objects and
    return a boolean indicating whether they passed or not, otherwise
    return the name of the filter.  An invalid filter will pass all
    objects.  For multiple objects the return value is the logical
    "AND" of all object's return values.dg, dependency, graph, alias, attribute, name
    Args:
        attribute (str?): Select objects whose attribute names match the pattern.  
                Properties: create
        list (bool?): List the available filters.  If used in conjunction with the -name  
                flag it will show a description of what the filter is.  
                Properties: create
        logicalAnd (Tuple[str, str]?): Logical AND of two filters.  
                Properties: create
        logicalNot (str?): Logical inverse of filter.  
                Properties: create
        logicalOr (Tuple[str, str]?): Logical OR of two filters.  
                Properties: create
        name (str?): Use filter named FILTER (or create new filter with that name).  
                If no objects are specified then the name given to the filter  
                will be returned.  
                Properties: create
        node (str?): Select objects whose node names match the pattern.  
                Properties: create
        nodeType (str?): Select objects whose node type names match the pattern.  
                Properties: create
        plug (str?): Select objects whose plug names match the pattern.  
                Properties: create

    Returns:
        str: if creating filter or getting filter info
        List[str]: if listing filters
        bool: if applying filter

    Example:
    """

def dgmodified() -> List[str]:
    """Thecommand is used to find out which nodes in the
              dependency graph have been modified.  This is mostly useful for fixing
              instances where file new asks you to save when no changes have been
              made to the scene.debug, modified, nodes
    Returns:
        List[str]: list of all nodes that have been modified

    Example:
    """

def dgstats(*args: Any, **kwargs: Any) -> None: ...
def dgtimer(*, query: bool = ..., combineType: bool = ..., hide: Queryable[Multiuse[str]] = ..., hierarchy: bool = ..., maxDisplay: Queryable[int] = ..., name: Queryable[str] = ..., noHeader: bool = ..., outputFile: str = ..., overhead: bool = ..., rangeLower: float = ..., rangeUpper: float = ..., reset: bool = ..., returnCode: Queryable[str] = ..., returnType: Queryable[str] = ..., show: Queryable[Multiuse[str]] = ..., sortMetric: Queryable[str] = ..., sortType: Queryable[str] = ..., threshold: Queryable[float] = ..., timerOff: bool = ..., timerOn: bool = ..., trace: bool = ..., type: Queryable[str] = ..., uniqueName: bool = ..., updateHeatMap: int = ...) -> Union[float, bool, Multiuse[str], int, str]:
    """This command measures dependency graph node performance by managing
    timers on a per-node basis. Logically, each DG node has a timer
    associated with it which records the amount of real time spent
    in various operations on its plugs. The time measurement includes the cost
    of copying data to the node on behalf of the operation, MEL commands
    executed by an expression contained in an expression invoked by the
    node, and includes
    any wait time such as when a fileTexture node loads an image file from
    disk. Most DG operations are reported including compute, draw, and dirty
    propagation.The various operations we measure are called "metrics" and the types of
    timers are called "timer types". The various metrics are always measured
    when timing is on, but are only queried when specified via the -show and
    -hide flags. The metrics currently supported are listed in detail under
    the -show flag below. For each metric we support a standard set of timer
    types. There are three of these:
    "self" for self time (the time specific to the node and not its children),
    "inclusive" (time including children of the node), and
    "count" (number of operations of the given metric on the node).The timing mechanism which is used byis built into the DG
    itself, thus ALL depend nodes can be timed and there is no need for
    programmers writing plug-ins using the OpenMaya API to add any special
    code in order for their nodes to be timed -- its all
    handled transparently.Thecommand allows node timers to be turned on, off, reset
    to zero, and have their current value displayed, and these operations
    can be performed globally on all nodes or on a specific set of nodes
    defined by name, type or parentage. Note that all timer measurements are
    computed in "real time" (the same time measurement you get from a
    wristwatch) as opposed to "CPU time" (which only measures time when the
    processor is executing your code). All times are displayed in seconds.Use the -query flag to display the current timer values on a node,use -on to turn on timing,use -off to turn off timing,and -reset to reset timers to zero.To display the values measured during timing, there are two approaches.
    The first method is to use the -query flag can be used to report the information which
    has been measured. The second method is to use the query methods available on
    the OpenMaya class MFnDependencyNode (see the OpenMaya documentation for details).What follows is a description of what is generated via -query. The output
    is broken out into several sections and these are described as follows:Section 1 of the dgtimer output contains global information. This section
    can be disabled via the -hoHeader flag.
    These values are reset whenever a global timer reset
    occurs (i.e.is specified). The global values which are
    reported are:Section 2 of the dgtimer -query output contains per-node information. There is a header which
    describes the meaning of each column, followed by the actual per-node data, and this is
    ultimately followed by a footer which summarises the totals per column. Note that the data
    contained in the footer is the global total for each metric and will include any nodes that
    have been deleted since the last reset, so the value in the footer MAY exceed what you get when you total the
    individual values in the column. To prevent the header
    and footer from appearing, use the -noHeader flag to just display the per-node data.The columns which are displayed are as follows:Section 3 of the dgtimer -query output describes time spent in callbacks. Note that
    section 3 only appears when the CALLBACK metric is shown (see the -show flag).The first part is SECTION 3.1 lists the time per callback with each entry comprising:At the bottom of SECTION 3.1 is the per-column total. The values printed match the summation at
    the bottom of the listing in section 2. Note that the values from SECTION 3.1
    include any nodes that have been deleted since the last reset. The thresholding parameters
    (-threshold, -rangeLower, -rangeUpper and -maxDisplay) are honoured when generating the listing.
    The sorting of the
    rows and display of the Percent and Cumulative columns obeys the -sortType flag. As the listing
    can be long, zero entries are not displayed.The second part is SECTION 3.2 which lists the data per callbackId. As noted earlier, the
    callbackId is an identifying
    number which is unique to each client that is registered to a callback and can
    be deduced by the user, such as through the OpenMaya API. The entries in SECTION 3.2 appear
    as follows:The third part is SECTION 3.3 which lists data per-callback per-node. The
    nodes are sorted based on the -sortType flag, and for each node, the
    callbacks are listed, also sorted based on the -sortType flag. As this
    listing can be long, zero entries are not displayed. An important note for SECTION 3.3 is
    that only nodes which still exist are displayed. If a node has been deleted, no infromation
    is listed.dependency, graph, optimize, performance
    Args:
        combineType (bool?): Causes all nodes of the same type (e.g. animCurveTA) to be combined in the  
                output display.  
                Properties: query
        hide (Queryable[Multiuse[str]]?): This flag is the converse of -show. As with -show, it is a query-only  
                flag which can be specified multiple times. If you do specify -hide, we display  
                all columns except those listed by the -hide flags.  
                Properties: create, query, multiuse
        hierarchy (bool?): Used to specify that a hierarchy of the dependency graph be affected,  
                thus "-reset -hierarchy -name ball" will reset the timers on the node  
                named "ball" and all of its descendents in the dependency graph.  
                Properties: create, query
        maxDisplay (Queryable[int]?): Truncates the display so that only the most expenive "n" entries are  
                printed in the output display.  
                Properties: query
        name (Queryable[str]?): Used in conjunction with -reset or -query to specify the name of the node  
                to reset or print timer values for. When querying a single timer, only a  
                single line of output is generated (i.e. the global timers and header  
                information is omitted). Note that one can force output to the script editor  
                window via the "-outputFile MEL" option to make it easy to grab the values  
                in a MEL script. Note: the -name and -type flag cannot be used together.  
                Properties: create, query
        noHeader (bool?): Used in conjunction with -query to prevent any header or footer information  
                from being printed. All that will be output is the per-node timing data.  
                This option makes it easier to parse the output such as when you output the  
                query to a file on disk using the -outputFile option.  
                Properties: create, query
        outputFile (str?): Specifies where the output of timing or tracing is displayed. The flag takes a string  
                argument which accepts three possible values:  
              
              
                The name of a file on disk.  
                Or the keyword "stdout", which causes output to be displayed on the terminal window (Linux and Macintosh), and the status window on Windows.  
                Or the keyword "MEL", which causes output to be displayed in the Maya Script Editor (only supported with -query).  
              
                The "stdout" setting is the default behaviour.  
              
                This flag can be used with the -query flag as well as the -trace flag.  
              
                When used with the -trace flag, any tracing output will be displayed on the destination  
                specified by the -outputFile (or stdout if -outputFile is omitted). Tracing operations  
                will continue to output to the destination until you specify the -trace and -outputFile  
                flags again.  
              
                When used with the -query flag, timing output will be displayed to the destination  
                specified by the -outputFile (or "stdout" if -outputFile is omitted).  
              
                Here are some examples of how to use the -query, -trace and -outputFile flags:  
              
                Example: output the timing information to a single file on disk:  
              
              
                dgtimer -on;                                       // Turn on timing  
                create some animated scene content;  
                play -wait;                                        // Play the scene through  
                dgtimer -query -outputFile "/tmp/timing.txt"       // Output node timing information to a file on disk  
              
              
                Example: output the tracing information to a single file on disk:  
              
              
                dgtimer -on;                                       // Turn on timing  
                create some animated scene content;  
                dgtimer -trace on -outputFile "/tmp/trace.txt"     // Turn on tracing and output the results to file  
                play -wait;                                        // Play the scene through; trace info goes to /tmp/trace.txt  
                dgtimer -query;                                    // But the timing info goes to the terminal window  
                play -wait;                                        // Play the scene again, trace info still goes to /tmp/trace.txt  
              
              
                Example: two runs, outputting the trace information and timing information to separate files:  
              
              
                dgtimer -on;                                       // Turn on timing  
                create some animated scene content;  
                dgtimer -trace on -outputFile "/tmp/trace1.txt"    // Turn on tracing and output the results to file  
                play -wait;                                        // Play the scene through  
                dgtimer -query -outputFile "/tmp/query1.txt"       // Output node timing information to another file  
                dgtimer -reset;  
                dgtimer -trace on -outputFile "/tmp/trace2.txt"    // Output tracing results to different file  
                play -wait;                                        // Play the scene through  
                dgtimer -query -outputFile "/tmp/query2.txt"       // Output node timing information to another file  
              
              
                Tips and tricks:  
              
              
                Outputting the timing results to the script editor makes it easy to  
                use the results in MEL e.g. string $timing[] = `dgtimer -query -outputFile MEL`.  
                It is important to note that the -outputFile you specify with -trace is  
                totally independent from the one you specify with -query.  
                If the file you specify already exists, Maya will empty the file first  
                before outputting data to it (and if the file is not writable, an error is  
                generated instead).  
              
                In query mode, this flag needs a value.  
                Properties: query
        overhead (bool?): Turns on and off the measurement of timing overhead. Under ordinary circumstances the  
                amount of timing overhead is minimal compared with the events being measured, but in  
                complex scenes, one might find the overhead to be measurable. By default this option  
                is turned off. To enable it, specify "dgtimer -overhead true" prior to starting timing.  
                When querying timing, the overhead is reported in SECTION 1.2 of the dgtimer output and  
                is not factored out of each individual operation.  
                Properties: create, query
        rangeLower (float?): This flag can be specified to limit the range of nodes which are displayed  
                in a query, or the limits of the heat map with -updateHeatMap. The value  
                is the lower percentage cutoff for the nodes which are processed. There is also  
                a -rangeLower flag which sets the lower range limit. The default value is 0,  
                meaning that all nodes with timing value below the upper range limit are considered.  
                Properties: create
        rangeUpper (float?): This flag can be specified to limit the range of nodes which are displayed  
                in a query, or the limits of the heat map with -updateHeatMap. The value  
                is the upper percentage cutoff for the nodes which are processed. There is also  
                a -rangeLower flag which sets the lower range limit. The default value is 100,  
                meaning that all nodes with timing value above the lower range limit are considered.  
                Properties: create
        reset (bool?): Resets the node timers to zero. By default, the timers on all nodes as  
                well as the global timers are reset, but if specified with the -name or  
                -type flags, only the timers on specified nodes are reset.  
                Properties: create
        returnCode (Queryable[str]?): This flag has been replaced by the more general -returnType flag.  
                The -returnCode flag was unfortunately specific to the compute metric only.  
                It exists only for backwards compatability purposes.  
                It will be removed altogether in a future release.  
              
                Here are some handy equivalences:  
              
                To get the total number of nodes:  
                OLD WAY: dgtimer -rc nodecount -q;  
                // Result:325//  
              
                NEW WAY: dgtimer -returnType total -sortType none -q;  
                // Result:325//  
              
                OLD WAY: dgtimer -rc count -q;  
                // Result:1270//  
              
                To get the sum of the compute count column:  
                NEW WAY: dgtimer -returnType total -sortMetric compute -sortType count -q;  
                // Result:1270//  
              
                OLD WAY: dgtimer -rc selftime -q;  
                // Result:0.112898//  
              
                To get the sum of the compute self column:  
                NEW WAY: dgtimer -returnType total -sortMetric compute -sortType self -q;  
                // Result:0.112898//  
                Properties: create, query
        returnType (Queryable[str]?): This flag specifies what the double value returned by the dgtimer command represents.  
                By default, the value returned is the global total as displayed in SECTION 1 for the  
                column we are sorting on in the per-node output (the sort column can be specified  
                via the -sortMetric and -sortType flags). However, instead of the  
                total being returned, the user can instead request the individual entries for  
                the column. This flag is useful mainly for querying without forcing any output.  
                The flag accepts the values "total", to just display the column total, or  
                "all" to display all entries individually.  
              
                For example, if you want to get the total of draw self time without any other  
                output simply specify the following:  
              
                dgtimer -returnType total -sortMetric draw -sortType self -threshold 100. noHeader -query;  
                // Result: 7718.01 //  
              
                To instead get each individual entry, change the above query to:  
              
                dgtimer -returnType all -sortMetric draw -sortType self -threshold 100. noHeader -query;  
                // Result: 6576.01 21.91 11.17 1108.92 //  
              
                To get the inclusive dirty time for a specific node, use -name as well as -returnType all:  
              
                dgtimer -name "virginia" -returnType all -sortMetric dirty -sortType inclusive -threshold 100. noHeader -query;  
              
                Note: to get the total number of nodes, use "-sortType none -returnType total".  To get  
                the on/off status for each node, use "-sortType none -returnType all".  
                Properties: query
        show (Queryable[Multiuse[str]]?): Used in conjunction with -query to specify which columns are to be displayed  
                in the per-node section of the output. -show takes an argument, which can  
                be  
                "all" (to display all columns),  
                "callback" (to display the time spent during any callback processing on the node not due to evaluation),  
                "compute" (to display the time spent in the node's compute methods),  
                "dirty" (to display time spent propagating dirtiness on behalf of the node),  
                "draw" (to display time spent drawing the node),  
                "compcb" (to display time spent during callback processing on node due to compute),  
                and  
                "compncb" (to display time spent during callback processing on node NOT due to compute).  
                The -show flag can be used multiple  
                times, but cannot be specified with -hide. By default, if neither -show,  
                -hide, or -sort are given, the effective display mode is:  
                "dgtimer -show compute -query".  
                Properties: create, query, multiuse
        sortMetric (Queryable[str]?): Used in conjunction with -query to specify which metric is to be sorted on  
                when the per-node section of the output is generated, for example "draw" time.  
                Note that the -sortType flag can also be specified to define which timer is  
                sorted on: for example "dgtimer -sortMetric draw -sortType count -query" will  
                sort the output by the number of times each node was drawn. Both -sortMetric and  
                -sortType are optional and you can specify one without the other. The -sortMetric  
                flag can only be specified at most once. The flag takes the following arguments:  
                "callback" (to sort on time spent during any callback processing on the node),  
                "compute" (to sort on the time spent in the node's compute methods),  
                "dirty" (to sort on the time spent propagating dirtiness on behalf of the node),  
                "draw" (to sort on time spent drawing the node),  
                "fetch" (to sort on time spent copying data from the datablock),  
                The default, if -sortMetric is omitted, is to sort on the first displayed column.  
                Note that the sortMetric is  
                independent of which columns are displayed via -show and -hide. Sort on a hidden  
                column is allowed.  
                The column selected by -sortMetric and -sortType specifies which total is returned  
                by the dgtimer command on the MEL command line.  
                This flag is also used with -updateHeatMap to specify which metric to build the heat map for.  
                Properties: create, query
        sortType (Queryable[str]?): Used in conjunction with -query to specify which timer is to be sorted on  
                when the per-node section of the output is generated, for example "self" time.  
                Note that the -sortMetric flag can also be specified to define which metric is  
                sorted on: for example "dgtimer -sortMetric draw -sortType count -query" will  
                sort the output by the number of times each node was drawn. Both -sortMetric and  
                -sortType are optional and you can specify one without the other. The -sortType  
                flag can be specified at most once. The flag takes the following arguments:  
                "self" (to sort on self time, which is the time specific to the node and not its children),  
                "inclusive" (to sort on the time including children of the node),  
                "count" (to sort on the number of times the node was invoked).  
                and  
                "none" (to sort on self time, but do not display the Percent and Cumulative columns  
                in the per-node display, as well as cause the total number of nodes in Maya to be  
                returned on the command line).  
                The default, if -sortType is omitted, is to sort on self time.  
                The column selected by -sortMetric and -sortType specifies which total is returned  
                by the dgtimer command on the MEL command line. The global total as displayed in  
                SECTION 1 of the listing is returned. The special case of "-sortType none"  
                causes the number of nodes in Maya to instead be returned.  
                This flag is also used with -updateHeatMap to specify which metric to build the heat map for.  
                Properties: create, query
        threshold (Queryable[float]?): Truncates the display once the value falls below the threshold value. The  
                threshold applies to whatever timer is being used for sorting. For example, if  
                our sort key is self compute time (i.e. -sortMetric is "compute" and -sortType  
                is "self") and the threshold parameter is 20.0, then only nodes with a compute  
                self-time of 20.0 or higher will be displayed. (Note that -threshold uses  
                absolute time. There are the similar -rangeUpper and -rangeLower parameters  
                which specify a range using percentage).  
                Properties: query
        timerOff (bool?): Turns off node timing. By default, the timers on all nodes are turned off,  
                but if specified with the -name or  
                -type flags, only the timers on specified nodes are turned off.  
                If the timers on all nodes become turned off, then global timing is also  
                turned off as well.  
                Properties: create, query
        timerOn (bool?): Turns on node timing. By default, the timers on all nodes are turned on,  
                but if specified with the -name or  
                -type flags, only the timers on specified nodes are turned on.  
                The global timers are also turned on by this command.  
                Note that turning on timing does NOT reset the timers to zero. Use the -reset  
                flag to reset the timers. The idea for NOT resetting the timers is to allow the  
                user to arbitrarily turn timing on and off and continue to add to the  
                existing timer values.  
                Properties: create, query
        trace (bool?): Turns on or off detailed execution tracing.  
                By default, tracing is off. If enabled, each timeable operation is logged when it starts and  
                again when it ends. This flag can be used in conjunction with -outputFile to specify where the  
                output is generated to. The following example shows how the output is formatted:  
              
                dgtimer:begin: compute 3 particleShape1Deformed particleShape1Deformed.lastPosition  
              
                The above is an example of the output when -trace is true that marks the start  
                of an operation. For specific details on each field: the "dgtimer:begin:" string  
                is an identifying marker to flag that this is a begin operation record. The  
                second argument, "compute" in our example, is the operation metric. You can view  
                the output of each given metric via "dgtimer -q" by specifying the -show flag.  
                The integer which follows (3 in this case) is the depth in the operation stack,  
                and the third argument is the name of the node (particleShape1Deformed). The  
                fourth argument is specific to the metric. For "compute", it gives the name of  
                the plug being computed. For "callback", its the internal Maya name of the callback.  
                For "dirty", its the name of the plug that dirtiness is being propagated from.  
              
                dgtimer:end: compute 3 particleShape1Deformed 0.000305685 0.000305685  
              
                The above is the end operation record. The "compute", "3" and "particleShapeDeformed"  
                arguments were described in the "dgtimer:begin" overview earlier. The two floating-point  
                arguments are self time and inclusive time for the operation measured in seconds.  
                The inclusive measure lists the total time since the matching "dgtimer:begin:" entry  
                for this operation, while the self measure lists the inclusive time minus any time  
                consumed by child operations which may have occurred during execution of the current operation.  
                As noted elsewhere in this document, these two times are "wall clock times", measuring  
                elapsed time including any time in which Maya was idle or performing system calls.  
              
                Since dgtimer can measure some non-node qualities in Maya, such as global message  
                callbacks, a "-" is displayed where the node name would ordinarily be displayed.  
                The "-" means "not applicable".  
                Properties: create
        type (Queryable[str]?): Used in conjunction with -reset or -query to specify the type of the node(s)  
                (e.g. animCurveTA) to reset or print timer values for.  
                When querying, use of the -combineType flag will cause all nodes of the  
                same type to be combined into one entry, and only one line of output is  
                generated (i.e. the global timers and header information is omitted).  
                Note: the -name and -type flag cannot be used together.  
                Properties: create, query
        uniqueName (bool?): Used to specify that the DAG nodes listed in the output should be  
                listed by their unique names.  The full DAG path to the object  
                will be printed out instead of just the node name.  
                Properties: create, query
        updateHeatMap (int?): Forces Maya's heat map to rebuild based on the specified parameters.  
                The heat map is an internal dgtimer structure used in mapping  
                intensity values to colourmap entries during display by the HyperGraph  
                Editor. There is one heat map shared by all editors that are using heat  
                map display mode. Updating the heat map causes the timer values on all  
                nodes to be analysed to compose the distribution of entries in the heat map.  
                The parameter is the integer number of divisions in the map and should equal  
                the number of available colours for displaying the heat map. This flag can  
                be specified with the -rangeLower and -rangeUpper flags  
                to limit the range of displayable to lie between the percentile range.  
                The dgtimer command returns the maximum timing value for all nodes in Maya  
                for the specified metric and type.  
                Note: when the display range includes 0, the special zeroth (exactly zero)  
                slot in the heat map is avilable.  
                Properties: create

    Returns:
        float: By default, the total of self-compute time for all nodes. Can be modified via the -returnType, -sortMetric and -sortType flags.

    Example:
    """

def dimWhen(arg0: str = ..., arg1: str = ..., /, *, clear: bool = ..., false: bool = ..., true: bool = ...) -> bool:
    """This method attaches the named UI object (first argument) to the named
    condition (second argument) so that the object will be dimmed when the
    condition is in a particular state.This command will fail if the object does not exist. If the condition
    does not exist (yet), that's okay --- a placeholder will be used until
    such a condition comes into existence.The UI object should be one of two things, either a control or a menu
    item.
    Args:
        clear (bool?): Remove the condition on the specified dimmable.  
                Properties: create
        false (bool?): Dim the object when the condition is false.  
                Properties: create
        true (bool?): Dim the object when the condition is true. (default)  
                Properties: create

    Returns:
        bool:

    Example:
    """

def directConnectPath() -> None: ...
def directKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., option: Queryable[str] = ..., selectedOnly: bool = ...) -> Union[str, bool]:
    """This command creates a context which may be used to directly manipulate keyframes
    within the graph editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        option (Queryable[str]?): Valid values are "move," "insert," "over," and  
                "segmentOver." When you "move" a key, the key will not cross over  
                (in time) any keys before or after it. When you "insert" a key,  
                all keys before or after (depending upon the -timeChange value)  
                will be moved an equivalent amount. When you "over" a key, the key  
                is allowed to move to any time (as long as a key is not there already).  
                When you "segmentOver" a set of keys (this option only has a  
                noticeable effect when more than one key is being moved) the first  
                key (in time) and last key define a segment (unless you specify a  
                time range). That segment is then allowed to move over other keys,  
                and keys will be moved to make room for the segment.  
                Properties: create, query, edit
        selectedOnly (bool?): Controls whether only selected curves/keys can be moved, or  
                all.  
                Properties: create, query, edit

    Returns:
        str: Context name

    Example:
    """

def directionalLight(*args: str, edit: bool = ..., query: bool = ..., decayRate: int = ..., discRadius: Queryable[float] = ..., exclusive: bool = ..., intensity: Queryable[float] = ..., name: Queryable[str] = ..., position: Queryable[Tuple[float, float, float]] = ..., rgb: Queryable[Tuple[float, float, float]] = ..., rotation: Queryable[Tuple[float, float, float]] = ..., shadowColor: Queryable[Tuple[float, float, float]] = ..., shadowDither: Queryable[float] = ..., shadowSamples: Queryable[int] = ..., softShadow: bool = ..., useRayTraceShadows: bool = ...) -> Union[List[float], int, str, float, bool, Tuple[float, float, float]]:
    """TlightCmd is the base class for other light commands.
    TnonAmbientLightCmd is a class that looks like a command but
    is not.  It is a base class for the extended/nonExtended
    lights.
    TnonExtendedLightCmd is a base class and not a real command. It is inherited by several
    lights: TpointLight, TdirectionalLight, TspotLight etc.
    The directionalLight command is used to edit the parameters
    of existing directionalLights, or to create new ones. The
    default behaviour is to create a new directionallight.This is the commmand that instantiates an directionalLight
    or edits the parameters of an existing one.
    TdirectionalLightCmd inherits from TnonExtendedLightCmd
    which defines softShadow flags.
    See TlightCmd for a global picture of the light commands.TdirectionalLightCmd behaves like any other command, it
    has flags, saves undo information etc. the only slightly
    different behaviour is that it calls up to
    TnonExtendedLightCmd to complete the functionality of
    the command.
    Args:
        decayRate (int?): Decay rate of the light (0. no decay, 1. slow, 2. realistic, 3. fast)  
                Properties: create
        discRadius (Queryable[float]?): Radius of shadow disc.  
                Properties: create, query
        exclusive (bool?): True if the light is exclusively assigned  
                Properties: create, query
        intensity (Queryable[float]?): Intensity of the light  
                Properties: create, query
        name (Queryable[str]?): Name of the light  
                Properties: create, query
        position (Queryable[Tuple[float, float, float]]?): Position of the light  
                Properties: create, query
        rgb (Queryable[Tuple[float, float, float]]?): RGB colour of the light  
                Properties: create, query
        rotation (Queryable[Tuple[float, float, float]]?): Rotation of the light for orientation, where applicable  
                Properties: create, query
        shadowColor (Queryable[Tuple[float, float, float]]?): Color of the light's shadow  
                Properties: create, query
        shadowDither (Queryable[float]?): Shadow dithering value.  
                Properties: create, query
        shadowSamples (Queryable[int]?): Numbr of shadow samples to use  
                Properties: create, query
        softShadow (bool?): True if soft shadowing is to be enabled  
                Properties: create, query
        useRayTraceShadows (bool?): True if ray trace shadows are to be used  
                Properties: create, query

    Returns:
        List[float]: when querying the rgb or shadowColor flags
            double when querying the intensity flag
            boolean when querying the useRayTraceShadows or exclusive flags
            linear[] when querying the position flag
            angle[] when querying the rotation flag
            string when querying the name flag
        int: rate of light decay, when querying the decayRate flag
        int: Number of shadow samples, when querying the shadowSamples flag
            boolean True if soft shadows are enabled, when querying the softShadow flag
            float Shadow dithering value, when querying the shadowDither flag
            float Disc radius value, when querying the discRadius flag
        str: Light shape name

    Example:
    """

def dirmap(arg0: str = ..., /, *, query: bool = ..., convertDirectory: str = ..., enable: bool = ..., getAllMappings: bool = ..., getMappedDirectory: str = ..., mapDirectory: Tuple[str, str] = ..., unmapDirectory: str = ...) -> Union[str, None, bool]:
    """Use this command to map a directory to another directory. The first
    argument is the directory to map, and the second is the destination
    directory to map to.Directories
    must both be absolute paths, and should be separated with forward
    slashes ('/'). The mapping is case-sensitive on all platforms.
    This command can be useful when moving projects to
    another machine where some textures may not be contained in the Maya
    project, or when a texture archive moves to a new location. This
    command is not necessary when moving a (self-contained) project from
    one machine to another - instead copy the entire project over and set
    the Maya project to the new location.For one-time directory moves, if the command is enabled and the mapping
    configured correctly, when a scene is opened and saved the mapped
    locations will be reflected in the filenames saved with the file.
    To set up a permanent mapping the command should
    be enabled and the mappings set up in a script which is executed every
    time you launch Maya (userSetup.mel is sourced on startup).
    The directory mappings and enabled state are not preserved between
    Maya sessions.
    This command requires one "main" flag that specifies the action to take.
    Flags are:
    Args:
        convertDirectory (str?): Convert a file or directory.  
                Returns the name of the mapped file or directory, if the command is  
                enabled. If the given string  
                contains one of the mapped directories, the return value will have that  
                substring replaced with the mapped one. Otherwise the given argument  
                string will be returned. If the command is disabled the given argument  
                is always returned. Checks are not  
                made for whether the file or directory exists. If the given string  
                is a directory it should have a trailing '/'.  
                Properties: create
        enable (bool?): Enable directory mapping.  
                Directory mapping is off when you start Maya. If enabled, when opening  
                Maya scenes, file texture paths (and other file paths) will be converted  
                when the scene is opened. The -cd flag only returns mapped directories  
                when -enable is true.  
                Query returns whether mapping has been enabled.  
                Properties: create, query
        getAllMappings (bool?): Get all current mappings.  
                Returns string array of current mappings in format:  
                [redirect1, replacement1, ... redirectN, replacementN]  
                Properties: create
        getMappedDirectory (str?): Get the mapped redirected directory. The given argument must  
                exactly match the first string used with the -mapDirectory flag.  
                Properties: create
        mapDirectory (Tuple[str, str]?): Map a directory - the first argument is mapped to the second.  
                Neither directory needs to exist on the local machine at the time  
                of invocation.  
                Properties: create
        unmapDirectory (str?): Unmap a directory. The given argument must exactly match the  
                argument used with the -mapDirectory flag.  
                Properties: create

    Returns:
        str: when convertDirectory is used
        None: when convertDirectory is not used

    Example:
    """

def disable(arg0: str = ..., /, *, value: bool = ...) -> bool:
    """This command enables or disables the control passed as argument.
    Args:
        value (bool?): If true, this command disables the control.  
                If false, this command enables the control.  
                Default value is true (disable)  
                Properties: create

    Returns:
        bool:

    Example:
    """

def disableIncorrectNameWarning() -> bool:
    """Disable the warning dialog which complains about incorrect node names when opening
    Maya files.
    Returns:
        bool:

    Example:
    """

def disconnectAttr(arg0: str = ..., arg1: str = ..., /, *, nextAvailable: bool = ...) -> str:
    """Disconnects two connected attributes. First argument is the source
    attribute, second is the destination.
    Args:
        nextAvailable (bool?): If the destination multi-attribute has set the indexMatters  
                to be false, the command will disconnect the first matching  
                connection.  No index needs to be specified.  
                Properties: create

    Returns:
        str: A phrase containing the names of the disconnected attributes.

    Example:
    """

def disconnectJoint(arg0: str = ..., /, *, attachHandleMode: bool = ..., deleteHandleMode: bool = ...) -> str:
    """This command will break a skeleton at the selected joint and delete
    any associated handles.
    Args:
        attachHandleMode (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        deleteHandleMode (bool?): Delete the handle on the associated joint.  
                Properties: create

    Returns:
        str: After the joint is disconnected, a new joint will be created. The return value is the name of the newly created joint and its ancestor.

    Example:
    """

def diskCache(*, query: bool = ..., append: bool = ..., cacheType: Queryable[str] = ..., close: Queryable[str] = ..., closeAll: bool = ..., delete: Queryable[str] = ..., deleteAll: bool = ..., empty: Queryable[str] = ..., emptyAll: bool = ..., enabledCachesOnly: bool = ..., endTime: Queryable[int] = ..., frameRangeType: Queryable[str] = ..., overSample: bool = ..., samplingRate: Queryable[int] = ..., startTime: Queryable[int] = ..., tempDir: bool = ...) -> Union[bool, str, int]:
    """Command to create, clear, or close disk cache(s).disk, cache
    Args:
        append (bool?): Append at the end and not to flush the existing cache  
                Properties: create, query
        cacheType (Queryable[str]?): Specifies the type of cache to overwrite.  "mcfp" for particle playback  
                cache, "mcfi" for particle initial cache. "mcj" for jiggle cache. This  
                option is only activated during the cache creation.  
                Properties: create, query
        close (Queryable[str]?): Close the cache given the disk cache node name.  If -eco/enabledCachesOnly  
                is "true" only enabled disk cache nodes are affected.  
                Properties: create, query
        closeAll (bool?): Close all disk cache files. If -eco/enabledCachesOnly  
                is "true" only enabled disk cache nodes are affected.  
                Properties: create, query
        delete (Queryable[str]?): Delete the cache given the disk cache node name.  If -eco/enabledCachesOnly  
                is "true" only enabled disk cache nodes are affected.  
                Properties: create, query
        deleteAll (bool?): Delete all disk cache files.  If -eco/enabledCachesOnly  
                is "true" only enabled disk cache nodes are affected.  
                Properties: create, query
        empty (Queryable[str]?): Clear the content of the disk cache with the given  
                disk cache node name.  If -eco/enabledCachesOnly  
                is "true" only enabled disk cache nodes are affected.  
                Properties: create, query
        emptyAll (bool?): Clear the content of all disk caches.  If -eco/enabledCachesOnly  
                is "true" only enabled disk cache nodes are affected.  
                Properties: create, query
        enabledCachesOnly (bool?): When present, this flag restricts the -ea/emptyAll,  
                so that only "enabled" disk caches (i.e., disk cache nodes  
                with the ".enable" attribute set to "true") are affected.  
                Properties: create, query
        endTime (Queryable[int]?): Specifies the end frame of the cache range.  
                Properties: create, query
        frameRangeType (Queryable[str]?): Specifies the type of frame range to use, namely "Render Globals",  
                "Time Slider", and "Start/End".  In the case of "Time Slider", startFrame  
                and endFrame need to be specified.  (This flag is now obsolete.  Please  
                use the -startTime and -endTime flags to specify the frame range explicitly.)  
                Properties: create, query
        overSample (bool?): Over sample if true. Otherwise, under sample.  
                Properties: create, query
        samplingRate (Queryable[int]?): Specifies how frequently to sample relative to each frame.  
                When over-sampling (-overSample has been specified),  
                this parameter determines how many times per frame the runup will be evaluated.  
                When under-sampling (the default, when -overSample has not been specified), the runup will evaluate only once per sr frames, where sr is the value specified to this flag.  
                Properties: create, query
        startTime (Queryable[int]?): Specifies the start frame of the cache range.  
                Properties: create, query
        tempDir (bool?): Query-only flag for the location of temporary diskCache files.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def dispatchGenericCommand(*args: Any, **kwargs: Any) -> Any: ...
def displacementToPoly(*args: str, edit: bool = ..., query: bool = ..., findBboxOnly: bool = ...) -> bool:
    """Command bakes geometry with displacement mapping into a polygonal object.displacement, to, polygon
    Args:
        findBboxOnly (bool?): When used, only the bounding box scale for the displaced object is found.  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def displayAffected(arg0: bool = ..., /) -> int:
    """Turns on/off the special coloring of objects that are affected by the
    objects that are currently in the selection list.If one of the curves in a loft were selected and this feature were
    turned on, then the lofted surface would be highlighted because it
    is affected by the loft curve.
    Returns:
        int: Affected display count

    Example:
    """

def displayColor(arg0: str = ..., arg1: int = ..., /, *, query: bool = ..., active: bool = ..., create: bool = ..., dormant: bool = ..., list: bool = ..., queryIndex: int = ..., resetToFactory: bool = ..., resetToSaved: bool = ...) -> bool:
    """This command changes or queries the display color for anything
    in the application that allows the user to set its color.
    The color is defined by a color index into either the dormant
    or active color palette.
    These colors are part of the UI and not part of the saved
    data for a model.  This command is not undoable.
    Args:
        active (bool?): Specifies the color index applies to active color palette.  
                name  
                Specifies the name of color to change.  
                index  
                The color index for the color.  
                Properties: create
        create (bool?): Creates a new display color which can be queried or set.  
                If is used only when saving color preferences.  
                Properties: create
        dormant (bool?): Specifies the color index applies to dormant color palette.  
                If neither of the dormant or active flags is specified, dormant  
                is the default.  
                Properties: create
        list (bool?): Writes out a list of all color names and their value.  
                Properties: create
        queryIndex (int?): Allows you to obtain a list of color names with the given color indices.  
                Properties: create
        resetToFactory (bool?): Resets all display colors to their factory defaults.  
                Properties: create
        resetToSaved (bool?): Resets all display colors to their saved values.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def displayCull(*args: str, query: bool = ..., backFaceCulling: bool = ...) -> bool:
    """This command is responsible for setting the display culling
    property of back faces of surfaces.
    Args:
        backFaceCulling (bool?): Enable/disable culling of back faces.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def displayLevelOfDetail(*, query: bool = ..., levelOfDetail: bool = ...) -> bool:
    """This command is responsible for setting the display level-of-detail
    for edit refreshes.  If enabled, objects will draw with lower detail
    based on their distance from the camera. When disabled objects will
    display at full resolution at all times.  This is not an undoable
    command
    Args:
        levelOfDetail (bool?): Enable/disable level of detail.

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def displayPref(*, query: bool = ..., activeObjectPivots: bool = ..., displayAffected: bool = ..., displayGradient: bool = ..., ghostFrames: Queryable[Tuple[int, int, int]] = ..., materialLoadingMode: Queryable[str] = ..., maxHardwareTextureResolution: bool = ..., maxTextureResolution: Queryable[int] = ..., purgeExistingTextures: bool = ..., regionOfEffect: bool = ..., shadeTemplates: bool = ..., textureDrawPixel: bool = ..., wireframeOnShadedActive: Queryable[str] = ...) -> Union[bool, Tuple[int, int, int], str, int]:
    """This command sets/queries the state of global display parameters.
    Args:
        activeObjectPivots (bool?): Sets the display state for drawing pivots for active objects.  
                Properties: create, query
        displayAffected (bool?): Turns on/off the special coloring of objects that are affected  
                by the objects that are currently in the selection list.  
                If one of the curves in a loft were selected and this feature were  
                turned on, then the lofted surface would be highlighted because it  
                is affected by the loft curve.  
                Properties: create, query
        displayGradient (bool?): Set whether to display the background using a colored gradient as opposed  
                to a constant background color.  
                Properties: create, query
        ghostFrames (Queryable[Tuple[int, int, int]]?): Obsolete - use the "ghosting" command to set these values.  
                Properties: create, query
        materialLoadingMode (Queryable[str]?): Sets the material loading mode when loading the scene.  Possible  
                values for the string argument are  
                "immediate", "deferred" and "parallel".  
                Properties: create, query
        maxHardwareTextureResolution (bool?): Query the maximum allowable hardware texture resolution  
                available on the current video card. This maximum can vary  
                between different video cards and different operating systems.  
                Properties: query
        maxTextureResolution (Queryable[int]?): Sets the maximum hardware texture resolution to be  
                used when creating hardware textures for display. The maximum  
                will be clamped to the maximum allowable texture determined  
                for the hardware at the time this command is invoked. Use  
                the -maxHardwareTextureResolution to retrieve this maximum value.  
                Existing hardware textures are not affected. Only newly created  
                textures will be clamped to this maximum.  
                Properties: create, query
        purgeExistingTextures (bool?): Purge any existing hardware textures. This will force  
                a re-evaluation of hardware textures used for display, and  
                thus may take some time to evaluate.  
                Properties: create
        regionOfEffect (bool?): Turns on/off the display of the region of curves/surfaces  
                that is affected by changes to selected CVs and edit points.  
                Properties: create, query
        shadeTemplates (bool?): Turns on/off the display of templated surfaces as shaded  
                in shaded display mode. If its off, templated surfaces appear  
                in wireframe.  
                Properties: create, query
        textureDrawPixel (bool?): Sets the display mode for drawing image planes. True for  
                use of gltexture calls for perspective views. This flag should  
                not normally be needed. Image Planes may display faster on  
                Windows but can result in some display artifacts.  
                Properties: create, query
        wireframeOnShadedActive (Queryable[str]?): Sets the display state for drawing the wireframe on active  
                shaded objects.  Possible values for the string argument are  
                "full", "reduced" and "none".  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def displayRGBColor(arg0: str = ..., arg1: float = ..., arg2: float = ..., arg3: float = ..., arg4: float = ..., /, *, query: bool = ..., alpha: bool = ..., create: bool = ..., hueSaturationValue: bool = ..., list: bool = ..., resetToFactory: bool = ..., resetToSaved: bool = ...) -> Union[str, bool]:
    """This command changes or queries the display color for anything
    in the application that allows the user to set its color.
    These colors are part of the UI and not part of the saved
    data for a model.  This command is not undoable.
    Args:
        alpha (bool?): Indicates that we want to query the alpha value of the color.  
                Upon query, returns RGBA or HSVA as an array of 4 floats.  
                Properties: query
        create (bool?): Creates a new RGB display color which can be queried or set.  
                If is used only when saving color preferences.  
                name  
                Specifies the name of color to change.  
                Properties: create
        hueSaturationValue (bool?): Indicates that rgb values are really hsv values.  
                Upon query, returns the HSV values as an array of 3 floats.  
                h s v  
                The HSV values for the color.  (Between 0. 1)  
                Properties: create, query
        list (bool?): Writes out a list of all RGB color names and their value.  
                Properties: create
        resetToFactory (bool?): Resets all the RGB display colors to their factory defaults.  
                Properties: create
        resetToSaved (bool?): Resets all the RGB display colors to their saved values.  
                Properties: create

    Returns:
        str: when the list flag is used, none otherwise

    Example:
    """

def displaySmoothness(*args: str, query: bool = ..., all: bool = ..., boundary: bool = ..., defaultCreation: bool = ..., divisionsU: Queryable[int] = ..., divisionsV: Queryable[int] = ..., full: bool = ..., hull: bool = ..., pointsShaded: Queryable[int] = ..., pointsWire: Queryable[int] = ..., polygonObject: Queryable[int] = ..., renderTessellation: bool = ..., simplifyU: Queryable[int] = ..., simplifyV: Queryable[int] = ...) -> Union[bool, int]:
    """This command is responsible for setting the display smoothness
    of NURBS curves and surfaces to either predefined or custom values.
    It also sets display modes for smoothness such as hulls and the
    hull simplification factors.
    At present, this command is NOT un-doable.
    Args:
        all (bool?): Change smoothness for all curves and surfaces  
                Properties: create, query
        boundary (bool?): Display wireframe surfaces using only the boundaries of the surface  
                Not fully implemented yet  
                Properties: create, query
        defaultCreation (bool?): The default values at creation (applies only -du, -dv, -pw, -ps)  
                Properties: create, query
        divisionsU (Queryable[int]?): Number of isoparm divisions per span in the U direction.  
                The valid range of values is [0,64].  
                Properties: create, query
        divisionsV (Queryable[int]?): Number of isoparm divisions per span in the V direction.  
                The valid range of values is [0,64].  
                Properties: create, query
        full (bool?): Display surface at full resolution - the default.  
                Properties: create, query
        hull (bool?): Display surface using the hull (control points are drawn rather  
                than surface knot points). This mode is a useful display performance  
                improvement when modifying a surface since it doesn't require  
                evaluating points on the surface.  
                Properties: create, query
        pointsShaded (Queryable[int]?): Number of points per surface span in shaded mode. The  
                valid range of values is [1,64].  
                Properties: create, query
        pointsWire (Queryable[int]?): Number of points per surface isoparm span  
                or the number of points per curve span in wireframe mode.  
                The valid range of values is [1,128].  
                Note: This is the only flag that also applies to nurbs curves.  
                Properties: create, query
        polygonObject (Queryable[int]?): Display the polygon objects with the given resolution  
                Properties: create, query
        renderTessellation (bool?): Display using render tesselation parameters when in shaded mode.  
                Properties: create, query
        simplifyU (Queryable[int]?): Number of spans to skip in the U direction when in  
                hull display mode.  
                Properties: create, query
        simplifyV (Queryable[int]?): Number of spans to skip in the V direction when in  
                hull display mode.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def displayStats() -> None:
    """This command is no longer supported, use the headsUpDisplay command instead."""

def displayString(arg0: str = ..., arg1: str = ..., arg2: str = ..., arg3: str = ..., /, *, query: bool = ..., delete: bool = ..., exists: bool = ..., keys: bool = ..., replace: bool = ..., value: Queryable[str] = ...) -> Union[bool, str]:
    """Assign a string value to a string identifier. Allows you define a string in
    one location and then refer to it by its identifier in many other locations.
    Formatted strings are also supported (NOTE however, this functionality is now
    provided in a more general fashion by the format command, use of format
    is recommended). You may embed up to 3 special character sequences
    ^1s, ^2s, and ^3s to perform automatic string replacement. The
    embedded characters will be replaced with the extra command arguments. See
    example section for more detail. Note the extra command arguments do not need
    to be display string identifiers.display, string
    Args:
        delete (bool?): This flag is used to remove an identifer string.  
                The command will fail if the identifier does not exist.  
                Properties: create
        exists (bool?): Returns true or false depending upon whether the specified identifier exists.  
                Properties: create
        keys (bool?): List all displayString keys that match the identifier string.  
                The identifier string may be a whole or partial key string.  
                The command will return a list of all identifier keys that contain this  
                identifier string as a substring.  
                Properties: create, query
        replace (bool?): Since a displayString command will fail if it tries to assign a new value  
                to an existing identifer, this flag is required to allow updates  
                to the value of an already-existing identifier.  If the identifier does  
                not already exist, a new identifier is added as if the -replace flag were  
                not present.  
                Properties: create, query
        value (Queryable[str]?): The display string\\'s value. If you do not specify this flag when  
                creating a display string then the value will be the same as the  
                identifier.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def displaySurface(*args: str, query: bool = ..., flipNormals: bool = ..., twoSidedLighting: bool = ..., xRay: bool = ...) -> bool:
    """This command toggles display options on the specified or active
    surfaces. Typically this command applies to NURBS or poly mesh
    surfaces and ignores other type of objects.
    Args:
        flipNormals (bool?): flip normal direction on the surface  
                Properties: query
        twoSidedLighting (bool?): toggle if the surface should be considered  
                two-sided.  If it's single-sided, drawing and rendering  
                may use single sided lighting and back face cull  
                to improve performance.  
                Properties: query
        xRay (bool?): toggle X ray mode (make surface transparent)  
                Properties: query

    Returns:
        bool: when in the query mode.

    Example:
    """

def distanceDimContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Command used to register the distanceDimCtx tool.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: - name of the context created

    Example:
    """

def distanceDimension(*args: str, endPoint: Tuple[float, float, float] = ..., startPoint: Tuple[float, float, float] = ...) -> str:
    """This command is used to create a distance dimension to display the
    distance between two specified points.
    Args:
        endPoint (Tuple[float, float, float]?): Specifies the point to measure distance to, from the startPoint.  
                Properties: create
        startPoint (Tuple[float, float, float]?): Specifies the point to start measuring distance from.  
                Properties: create

    Returns:
        str: - the shape name of the DAG node created.

    Example:
    """

def doBlur(*, colorFile: str = ..., length: float = ..., memCapSize: float = ..., sharpness: float = ..., smooth: float = ..., smoothColor: bool = ..., vectorFile: str = ...) -> str:
    """The doBlur command  will invoke the blur2d, which is a Maya
    stand-alone application to do 2.5 motion blur given the color image
    and the motion vector file.  For a given input colorFile name, e.g.
    "xxx.iff", the output blurred image will be "xxx_blur.iff" in the
    same directory as the input colorFile.  There is currently no control
    over the name of the output blurred image.
    Args:
        colorFile (str?): Name of the input color image to be blurred.  
                Properties: create
        length (float?): Scale applied on the motion vector. Ranges from 0 to infinity.  
                Properties: create
        memCapSize (float?): Size of the memory cap, in bytes  
                Properties: create
        sharpness (float?): Determines  the shape of the blur filter. The higher the value,  
                the narrower the filter, the sharper the blur. The lower the value,  
                the wider the filter, the more spread out the blur.  
                Ranges from 0 to infinity.  
                Properties: create
        smooth (float?): Filter size to smooth the blurred image. The higher the value,  
                the more anti-aliased the alpha channel. Ranges from 1.0 to 5.0.  
                Properties: create
        smoothColor (bool?): Whether to smooth the color or not.  
                Properties: create
        vectorFile (str?): Name of the input motion vector file.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def dockControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowedArea: Queryable[Multiuse[str]] = ..., annotation: Queryable[str] = ..., area: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., closeCommand: Callable[..., Any] = ..., content: Queryable[str] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dockStation: str = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enablePopupOption: bool = ..., exists: bool = ..., fixedHeight: bool = ..., fixedWidth: bool = ..., floatChangeCommand: Callable[..., Any] = ..., floating: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., moveable: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., r: bool = ..., retain: bool = ..., sizeable: bool = ..., splitLayout: str = ..., state: Queryable[str] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Multiuse[str], Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a dockable control, also known as tool palette or utility window.
    Dock controls are secondary windows placed in the dock area around the central control in a main window.
    Dock windows can be moved inside their current area, moved into new areas and floated (e.g. undocked).
    Dock control consists of a title bar and the content area. The titlebar displays the dock control window title, a float button and a close button.
    Depending on the state of the dock control, the float and close buttons may be either disabled or not shown at all.
    Args:
        allowedArea (Queryable[Multiuse[str]]?): Areas where the dock control may be placed. Valid values are "top", "left", "bottom", "right" and "all".  The default is "all".  
                Properties: create, query, edit, multiuse
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        area (Queryable[str]?): The initial dock area for this dock control. This is a required flag.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        closeCommand (Callable[..., Any]?): Script executed after the dock control is closed.  
                Properties: create, edit
        content (Queryable[str]?): The name of the control that is the content of this dock control.  This is a required flag.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dockStation (str?): The name of the control the window can be docked into.  
                If this is not set it is assumed to be the main window.  
                Properties: create
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enablePopupOption (bool?): Whether or not the menu option for the dock control in the UI Elements popup menu is enabled.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fixedHeight (bool?): Whether or not the dockControl height may be interactively resized.  
                Properties: create, query, edit
        fixedWidth (bool?): Whether or not the dockControl width may be interactively resized.  
                Properties: create, query, edit
        floatChangeCommand (Callable[..., Any]?): The script executed when the floating state of the dock widget changes.  
                Properties: create, edit
        floating (bool?): Whether the dock widget is floating.  
                A floating dock widget is presented to the user as an independent window "on top" of main window, instead of being docked in the main window.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text.  The default label is the name of the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        moveable (bool?): Control over whether or not the dockControl may be undocked/redocked.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        r (bool?): Whether the dock widget is visible and either floating or at the top of its dock widget area.  
                Properties: query, edit
        retain (bool?): Control over whether or not the window and its contents are deleted when closed.  
                The default is true.  The window and its contents are retained when closed unless this is set to false.  
                Properties: create, query, edit
        sizeable (bool?): Whether or not the dockControl width may be interactively resized.  
                Deprecated!!  Use the fixedWidth flag instead.  
                Properties: create, query, edit
        splitLayout (str?): When two windows are added to a single docking area they are by default tabbed together.  
                Setting a value for splitLayout will allow it to be placed next to another control in the same area.  
                The flag's argument controls the orientation of the split.  
                Valid values are "horizontal" or "vertical".  
                Properties: create
        state (Queryable[str]?): When queried this flag will return a string holding the dock control state information.  
                This string is a hexadecimal representation of a binary string and is not meant to be humanly readable,  
                but can be saved and loaded using the optionVar command to restore a dock control's state across sessions of Maya.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def dolly(arg0: str = ..., /, *, absolute: bool = ..., distance: float = ..., dollyTowardsCenter: bool = ..., orthoScale: float = ..., relative: bool = ...) -> bool:
    """The dolly command moves a camera along the viewing direction in
    the world space. The viewing-direction and up-direction of the
    camera are not altered. There are two modes of operation:Relative mode: for a perspective camera, the camera is moved along
    its viewing direction, and the distance of travel is computed with
    respect to the current position of the camera in the world
    space. In relative mode, when the camera is moved, its COI is
    moved along with it, and is kept at the same distance, in front of
    the camera, as before applying the dolly operation. For
    orthographic camera, the viewing width of the camera is changed by
    scaling its ortho width by the new value specified on the command
    line.Absolute mode: for a perspective camera, the camera is moved along
    its viewing direction, to the distance that is computed with
    respect to the current position of the world center of interest
    (COI) of the camera. In the absolute mode, when the camera is
    moved, the COI of the camera is not moved with the camera, but it
    is fixed at its current location in space. For orthographic
    camera, the viewing width of the camera is changed by replacing
    its ortho width with the new value specified on the command
    line. This command may be applied to more than one cameras;
    objects that are not cameras are ignored. When no camera name
    supplied on the command line, this command is applied to all
    currently active cameras.The dolly command can be applied to either a perspective or an
    orthographic camera.
    Args:
        absolute (bool?): This flag modifies the behavior of the distance and orthoScale  
                flags. When used in conjunction with the distance flag, the distance  
                argument specifies how far the camera's eye point should be set from  
                the camera's center of interest. When used with the orthoScale flag,  
                the orthoScale argument specifies the camera's new ortho width.  
                Properties: create
        distance (float?): Unit distance to dolly a perspective camera.  
                Properties: create
        dollyTowardsCenter (bool?): This flag controls whether the dolly is performed towards the  
                center of the view (if true), or towards the point where the user  
                clicks (if false). By default, dollyTowardsCenter is on.  
                Properties: create
        orthoScale (float?): Scale to change the ortho width of an orthographic camera.  
                Properties: create
        relative (bool?): This flag modifies the behavior of the distance and orthoScale  
                flags. When used in conjunction with the distance flag, the camera  
                eye and center of interest are both moved by the amount specified  
                by the distance flag's argument. When used with the orthoScale flag,  
                the orthoScale argument is used multiply the camera's ortho width.By  
                default the relative flag is always on.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def dollyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., boxDollyType: Queryable[str] = ..., centerOfInterestDolly: bool = ..., dollyTowardsCenter: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., localDolly: bool = ..., name: str = ..., orthoZoom: bool = ..., scale: Queryable[float] = ..., toolName: Queryable[str] = ...) -> Union[str, bool, float]:
    """This command can be used to create, edit, or query a dolly
    context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        boxDollyType (Queryable[str]?): Set the behavior of where the camera's center of interest is  
                set to after the box dolly. In surface mode, the center  
                of interest will be snapped to the surface point at the center  
                of the marquee. In bbox mode, the closest bounding box  
                to the camera will be used. Bounding box mode will use the  
                selection mask to determine which objects to include into the  
                calculation.  
                Properties: create, query, edit
        centerOfInterestDolly (bool?): Set the translate the camera's center of interest. Left and  
                right drag movements with the mouse will translate the center  
                of interest towards or away respectively from the camera. The  
                center of interest can be snapped to objects by using the left  
                mouse button for selection. The default select mask will be  
                used.  
                Properties: create, query, edit
        dollyTowardsCenter (bool?): Dolly towards center (if true), else dolly towards point where  
                user clicks in the view.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        localDolly (bool?): Dolly with respect to the camera's center of interest. The  
                camera will not pass through the center of interest. Local  
                dolly only applies to perspective cameras.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        orthoZoom (bool?): Zoom orthographic view (if true), else dolly orthographic camera.  
                Default value is true.  
                Properties: create, query, edit
        scale (Queryable[float]?): The sensitivity for dollying the camera.  
                Properties: create, query, edit
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query

    Returns:
        str: The name of the context

    Example:
    """

def dopeSheetEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., autoFit: Queryable[str] = ..., autoFitTime: Queryable[str] = ..., control: bool = ..., defineTemplate: str = ..., displayActiveKeyTangents: str = ..., displayActiveKeys: str = ..., displayInfinities: str = ..., displayKeys: str = ..., displayTangents: str = ..., displayValues: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., hierarchyBelow: bool = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., lookAt: str = ..., mainListConnection: Queryable[str] = ..., outliner: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., selectionWindow: Queryable[Tuple[float, float, float, float]] = ..., showScene: bool = ..., showSummary: bool = ..., showTicks: bool = ..., snapTime: Queryable[str] = ..., snapValue: Queryable[str] = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool, Tuple[float, float, float, float]]:
    """Edit a characteristic of a dope sheet editor
    Args:
        autoFit (Queryable[str]?): on | off | tgl  
                Auto fit-to-view.  
                Properties: query, edit
        autoFitTime (Queryable[str]?): on | off | tgl  
                Auto fit-to-view along the time axis, as well.  
                Properties: query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayActiveKeyTangents (str?): on | off | tgl  
                Display active key tangents in the editor.  
                Properties: edit
        displayActiveKeys (str?): on | off | tgl  
                Display active keys in the editor.  
                Properties: edit
        displayInfinities (str?): on | off | tgl  
                Display infinities in the editor.  
                Properties: edit
        displayKeys (str?): on | off | tgl  
                Display keyframes in the editor.  
                Properties: edit
        displayTangents (str?): on | off | tgl  
                Display tangents in the editor.  
                Properties: edit
        displayValues (str?): on | off | tgl  
                Display active keys and tangents values in the editor.  
                Properties: edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        hierarchyBelow (bool?): display animation for objects hierarchically  
                Properties: query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lookAt (str?): all | selected | currentTime  
                FitView helpers.  
                Properties: edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        outliner (Queryable[str]?): the name of the outliner which is associated with the dope sheet  
                Properties: query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        selectionWindow (Queryable[Tuple[float, float, float, float]]?): The selection area specified as left, right, bottom, top respectively.  
                Properties: query, edit
        showScene (bool?): display the scene summary object  
                Properties: query, edit
        showSummary (bool?): display the summary object  
                Properties: query, edit
        showTicks (bool?): display per animation tick divider in channel  
                Properties: query, edit
        snapTime (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in time.  
                Properties: query, edit
        snapValue (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in values.  
                Properties: query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Editor name

    Example:
    """

def doubleProfileBirailSurface(arg0: str = ..., arg1: str = ..., arg2: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., blendFactor: Queryable[float] = ..., caching: bool = ..., nodeState: Queryable[int] = ..., tangentContinuityProfile1: bool = ..., tangentContinuityProfile2: bool = ..., transformMode: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], float, bool, int]:
    """The arguments are 4 cuves called "profile1" "profile2" "rail1" "rail2".This command builds a railed surface by sweeping profile "profile1"
    along the two given rail curves "rail1", "rail2" until "profile2" is
    reached. By using the -blend control, the railed surface creation
    could be biased more towards one of the two profile curves. The curves
    ( both profiles and rails ) could also be surface curves ( isoparams,
    curve on surfaces ). If the profile curves are surface curves the
    surface constructed could be made tangent continuous to the surfaces
    underlying the profiles using the flags -tp1, -tp2 respectively.
    Current Limitation: Its necessary that the two profile curves
    intersect the rail curves for successful surface creation.
    Args:
        blendFactor (Queryable[float]?): A blend factor applied in between the two profiles.  
                The amount of influence 'inputProfile1' has in the surface creation.  
                Default: 0.5  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tangentContinuityProfile1 (bool?): Need tangent continuity across the input profile at inputProfile1.  
                Default: false  
                Properties: create, query, edit
        tangentContinuityProfile2 (bool?): Need tangent continuity across the input curve at inputProfile2.  
                Default: false  
                Properties: create, query, edit
        transformMode (Queryable[int]?): transform mode ( Non proportional, proportional ). Non proportional is default value.  
                Default: 0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def dpBirailCtx(*args: Any, **kwargs: Any) -> None: ...
def drag(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., useDirection: bool = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    Drag exerts a friction, or braking force proportional to the speed of
    a moving object. If direction is not enabled, the drag acts opposite
    to the current velocity of the object. If direction is enabled, it acts
    opposite to the component of the velocity in the specified direction.
    The force is independent of the position of the affected object.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        directionX (Queryable[float]?): X-component of direction.  
                Properties: query, edit
        directionY (Queryable[float]?): Y-component of direction.  
                Properties: query, edit
        directionZ (Queryable[float]?): Z-component of direction  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        useDirection (bool?): Enable/disable direction. Drag will use -dx/-dy/-dz arguments if  
                and only if this flag is set true.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def dragAttrContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., connectTo: Queryable[Multiuse[str]] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., reset: bool = ...) -> Union[str, Multiuse[str]]:
    """The dragAttrContext allows a user to manipulate the attributes of an object by using
    a virtual slider within the viewport.  The virtual slider is used by dragging in a
    viewport with the middle mouse button.  The speed at which the attributes are changed
    can be controlled by holding down the Ctrl key to slow it down and the Shift key to
    speed it up.
    Args:
        connectTo (Queryable[Multiuse[str]]?): Specifies an attribute to which to connect the context. This is a multi-use  
                flag, but all attributes used must be from one object.  
                Properties: create, query, edit, multiuse
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        reset (bool?): Resets the list of attributes to which the context is connected.  
                Properties: create, edit

    Returns:
        str: The name of the context created

    Example:
    """

def draggerContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., anchorPoint: Queryable[Tuple[float, float, float]] = ..., button: Queryable[int] = ..., currentStep: Queryable[int] = ..., cursor: Queryable[str] = ..., dragCommand: Queryable[Callable[..., Any]] = ..., dragPoint: Queryable[Tuple[float, float, float]] = ..., drawString: str = ..., exists: bool = ..., finalize: Queryable[Callable[..., Any]] = ..., helpString: Queryable[str] = ..., history: bool = ..., holdCommand: Queryable[Callable[..., Any]] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., initialize: Queryable[Callable[..., Any]] = ..., modifier: Queryable[str] = ..., name: str = ..., plane: Tuple[float, float, float] = ..., prePressCommand: Queryable[Callable[..., Any]] = ..., pressCommand: Queryable[Callable[..., Any]] = ..., projection: Queryable[str] = ..., releaseCommand: Queryable[Callable[..., Any]] = ..., snapping: bool = ..., space: Queryable[str] = ..., stepsCount: Queryable[int] = ..., undoMode: Queryable[str] = ...) -> Union[str, Tuple[float, float, float], int, Callable[..., Any], bool]:
    """The draggerContext allows the user to program the behavior of the mouse
    or an equivalent dragging device in MEL.
    Args:
        anchorPoint (Queryable[Tuple[float, float, float]]?): Anchor point (double array) where dragger was initially pressed.  
                Properties: query
        button (Queryable[int]?): Returns the current mouse button (1,2,3).  
                Properties: query
        currentStep (Queryable[int]?): Current step (press-drag-release sequence) for dragger context.  
                When queried before first press event happened, returns 0.  
                Properties: query
        cursor (Queryable[str]?): Cursor displayed while context is active.  Valid values are:  
                "default", "hand", "crossHair", "dolly", "track", and "tumble".  
                Properties: create, query, edit
        dragCommand (Queryable[Callable[..., Any]]?): Command called when mouse dragger is dragged.  
                Properties: create, query, edit
        dragPoint (Queryable[Tuple[float, float, float]]?): Drag point (double array) current position of dragger during drag.  
                Properties: query
        drawString (str?): A string to be drawn at the current position of the pointer.  
                Properties: create, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        finalize (Queryable[Callable[..., Any]]?): Command called when the tool is exited.  
                Properties: create, query, edit
        helpString (Queryable[str]?): Help string for context  
                Properties: query
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        holdCommand (Queryable[Callable[..., Any]]?): Command called when mouse dragger is held.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        initialize (Queryable[Callable[..., Any]]?): Command called when the tool is entered.  
                Properties: create, query, edit
        modifier (Queryable[str]?): Returns the current modifier type:  ctrl, alt or none.  
                Properties: query
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        plane (Tuple[float, float, float]?): Provide normal of projection plane (see -projection flag for details).  
                Properties: create, edit
        prePressCommand (Queryable[Callable[..., Any]]?): Command called when mouse dragger is pressed. It is called before  
                pressCommand, so it can be used for initialization of context.  
                Properties: create, query, edit
        pressCommand (Queryable[Callable[..., Any]]?): Command called when mouse dragger is pressed.  
                Properties: create, query, edit
        projection (Queryable[str]?): Sets current projection of drag point. Valid types are:  
              
              
                viewPlane  
                project to view plane  
              
              
                objectViewPlane  
                project to object plane (parallel to view plane)  
              
              
                objectPlane  
                project to specified plane defined by object location and normal (default) 0,1,0  
              
              
                plane  
                project to specified plane defined by origin and normal (default) 0,1,0  
              
              
                sketchPlane  
                project to sketch plane  
              
              
                xAxis  
                project to closest point on X axis  
              
              
                yAxis  
                project to closest point on Y axis  
              
              
                zAxis  
                project to closest point on Z axis  
              
              
                boundingSphere  
                project to closest point on object sphere bounds  
              
              
                boundingBox  
                project to closest point on object bounding box  
                Properties: create, query, edit
        releaseCommand (Queryable[Callable[..., Any]]?): Command called when mouse dragger is released.  
                Properties: create, query, edit
        snapping (bool?): Enable/disable snapping for dragger context.  
                Properties: create, query, edit
        space (Queryable[str]?): Sets current space that coordinates are reported in. Types are:  
              
              
                world  
                world space (global)  
              
              
                object  
                object space (local)  
              
              
                screen  
                screen space  
                Properties: create, query, edit
        stepsCount (Queryable[int]?): Number of steps (press-drag-release sequences) for dragger context.  
                When combined with undoMode flag, several steps might be recorded as  
                single undo action.  
                Properties: create, query, edit
        undoMode (Queryable[str]?): Undo queue mode for the context actions.  
                Acceptable values are:  
              
                "all" default behaviour when every action that happens during  
                dragger context activity is recorded as an individual undo chunk.  
                "step" - all the actions that happen between each press and  
                release are combined into one undo chunk.  
                "sequence" - all the actions that happen between very first press  
                and very last release are combined into single undo chunk. This works  
                exactly the same as "step" for a single step dragger context.  
                Properties: create, query, edit

    Returns:
        str: The name of the context.

    Example:
    """

def drawExtrudeFacetCtx(*args: Any, **kwargs: Any) -> None: ...
def dropoffLocator(arg0: float = ..., arg1: float = ..., arg2: str = ..., /, *args: str) -> List[str]:
    """This command adds one or more dropoff locators to a wire curve, one for
    each selected curve point. The dropoff locators can be used to provide
    localized tuning of the wire deformation about the curve point.The arguments are two floats, the envelope and percentage, followed by
    the wire node name and then by the curve point(s).
    Returns:
        List[str]: Locator name(s)

    Example:
    """

def duplicate(*args: str, fullPath: bool = ..., inputConnections: bool = ..., instanceLeaf: bool = ..., name: str = ..., parentOnly: bool = ..., renameChildren: bool = ..., returnRootsOnly: bool = ..., smartTransform: bool = ..., transformsOnly: bool = ..., upstreamNodes: bool = ...) -> List[str]:
    """This command duplicates the given objects. If no objects are
    given, then the selected list is duplicated.The smart transform feature allows duplicate to transform
    newly duplicated objects based on previous transformations
    between duplications.Example: Duplicate an object and move it to a new
    location. Duplicate it again with the smart duplicate
    flag. It should have moved once again the distance you had
    previously moved it.Note: changing the selected list between smart duplications
    will cause the transform information to be deletedThe upstream Nodes option forces duplication of all
    upstream nodes leading upto the selected objects.. Upstream nodes
    are defined as all nodes feeding into selected nodes. During traversal
    of Dependency graph, if another dagObject is encountered, then that
    node and all it's parent transforms are also duplicated.The inputConnections option forces the duplication of input connections
    to the nodes that are to be duplicated. This is very useful especially
    in cases where two nodes that are connected to each other are
    specified as nodes to be duplicated. In that situation, the connection
    between the nodes is also duplicated.instance
    Args:
        fullPath (bool?): ADDED 2023  
                Return full pathnames instead of object names.  
                Properties: create
        inputConnections (bool?): Input connections to the node to be duplicated, are  
                also duplicated. This would result in a fan-out  
                scenario as the nodes at the input side are not  
                duplicated (unlike the -un option).  
                Properties: create
        instanceLeaf (bool?): instead of duplicating leaf DAG nodes, instance them.  
                Properties: create
        name (str?): name to give duplicated object(s)  
                Properties: create
        parentOnly (bool?): Duplicate only the specified DAG node and not any of its  
                children.  
                Properties: create
        renameChildren (bool?): rename the child nodes of the hierarchy, to make them  
                unique.  
                Properties: create
        returnRootsOnly (bool?): return only the root nodes of the new hierarchy.  
                When used with upstreamNodes flag, the upstream nodes  
                will be omitted in the result.  This flag controls only  
                what is returned in the output string[], and it does  
                NOT change the behaviour of the duplicate command.  
                Properties: create
        smartTransform (bool?): remembers last transformation and applies  
                it to duplicated object(s)  
                Properties: create
        transformsOnly (bool?): Duplicate only transform nodes and not any shapes.  
                Properties: create
        upstreamNodes (bool?): the upstream nodes leading upto the selected nodes  
                (along with their connections) are also duplicated.  
                Properties: create

    Returns:
        List[str]: : names of the objects created

    Example:
    """

def duplicateCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., local: bool = ..., maxValue: Queryable[float] = ..., mergeItems: bool = ..., minValue: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., range: bool = ..., relative: bool = ...) -> Union[List[str], bool, float, int]:
    """The duplicateCurve command takes a curve on a surface and
    and returns the 3D curve. The curve on a surface could be
    isoparam component, trimmed edge or curve on surface object.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        local (bool?): Copy the transform of the surface and connect to the local  
                space version instead.  
                Properties: create
        maxValue (Queryable[float]?): Maximum parameter value for the curve segment.  Must be greater  
                than or equal to the minValue attribute.  
                If relative is true, then this attribute has maximum value of 1.0.  
                Default: -1.0  
                Properties: create, query, edit
        mergeItems (bool?): Merge component results where possible. For example, instead of returning a[1] and a[2], return a[1. 2].  
                Properties: create
        minValue (Queryable[float]?): Minimum parameter value for the curve segment  
                If relative is true, then this attribute has minimum value of 0.0.  
                Default: 1.0  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        relative (bool?): True means use a relative parameter range, from 0.0 to 1.0.  
                Otherwise, the parameter values are absolute values.  
                Default: false  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name

    Example:
    """

def duplicateSurface(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., faceCountU: Queryable[int] = ..., faceCountV: Queryable[int] = ..., firstFaceU: Queryable[int] = ..., firstFaceV: Queryable[int] = ..., local: bool = ..., mergeItems: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[List[str], bool, int]:
    """The duplicateSurface command takes a surface patch (face) and
    and returns the 3D surface. Connected patches are returned
    as a single surface.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        faceCountU (Queryable[int]?): Number of faces in U direction  
                Default: 1  
                Properties: create, query, edit
        faceCountV (Queryable[int]?): Number of faces in V direction  
                Default: 1  
                Properties: create, query, edit
        firstFaceU (Queryable[int]?): First face (U direction index)  
                Default: 0  
                Properties: create, query, edit
        firstFaceV (Queryable[int]?): First face (V direction index)  
                Default: 0  
                Properties: create, query, edit
        local (bool?): Copy the transform of the surface and connect to the local  
                space version instead.  
                Properties: create
        mergeItems (bool?): Merge component results where possible. For example, instead of returning a[1] and a[2], return a[1. 2].  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name

    Example:
    """

def dynCache() -> bool:
    """Cache the current state of all particle shapes at the current time.
    Returns:
        bool:

    Example:
    """

def dynControl() -> None:
    """This command is obsolete.  Do not use it.
    The Dynamics documentation explains how to set particle and
    rigid body node attributes to accomplish the same tasks.
    """

def dynExport(*args: str, allObjects: bool = ..., attribute: Multiuse[str] = ..., format: str = ..., maxFrame: int = ..., minFrame: int = ..., onlyUpdateParticles: bool = ..., overSampling: int = ..., path: str = ...) -> str:
    """Export particle data to disk files.For cache export (-format cache), dynExport also sets three attributes
    of the current dynGlobals node.  It sets the useParticleRenderCache
    attribute to true, and the min/maxFrameOfLastParticleRenderCache
    attributes to correspond to the min and max frames.Exported .pda or .pdb files are assigned a name of form, whereis "pda" or "pdb."The naming convention for .pdc files is similar but does not use frame
    numbers, it uses a more precise representation of the time instead.By default, the pda and pdb formats export all per-particle
    attributes, and all integer or float type attributes except those
    which are hidden or not storable. (Exception: level of detail is not
    exported, by default) The pdc format exports all attributes which the
    particle object needs for its state cache.To specify only selected attributes, use the -atr flag (which is
    multi-use).  In general, it is recommended not to use this flag with
    pdc type, since you need all the attributes in order for the cache to
    be useful.dynExport exports data for the current frame, or for a range of frames
    specified with -mnf and -mxf. If you are not already at the start
    frame, dynExport will run up the scene for you.If you use dynExport in -prompt mode, it does NOT
    automatically force evaluation of your objects.  You must do this
    yourself from your script.  The easiest way is to request each
    particle object's "count" attribute each frame.  You must request the
    count attribute for each object you want to export, because their
    solvers run independently of one another.  In interactive mode,
    objects WILL get evaluated automatically and you don't have to worry
    about any of this.When exporting a particle object whose particles are created from
    collisions involving particles in another particle object(s), you must
    make sure you simultaneously export all the particle objects involved
    in the dependency chain otherwise you will get an empty cache file.For non-per-particle attributes, pda and pdb formats write the
    identical value once for each particle.  The following types of
    non-per-particle attributes can be exported: float, double,
    doubleLinear, doubleAngle, byte, short, long, enum.  The first four
    are exported as "Real" (in PDB parlance), and the last four as
    "Integer."In the pda and pdb formats, "particleId" and "particleId0" are
    exported as Integer, and are exported under the names "id" and "id0"
    respectively.  All other attributes are exported under their long
    names.
    Args:
        allObjects (bool?): Ignore the selection list and export all particle objects.  
                If you also specify an object name, the -all flag will be ignored.  
                Properties: create
        attribute (Multiuse[str]?): Name of attribute to be exported. If any specified object  
                does not have one of the specified attributes, dynExport will issue  
                an error and not do the export.  
                Properties: create, multiuse
        format (str?): Desired format: "binary" ("pdb"), "ascii" ("pda"), or "cache" ("pdc").  
                The pdc format is for use by the Maya particle system to  
                cache particle data.  The pda and pdb format options  
                are intended for pipelines involving other software (for example,  
                sending the data to some program written in-house);  
                Maya cannot read pda or pdb files.  
                There is no formal description of the PDB format, but the  
                ExploreMe/particles/readpdb directory contains the source  
                and Makefile for a small, simple C program called "readpdb"  
                which reads it. Note that you must compile and run readpdb on the  
                platform which you exported the files on.  
                Properties: create
        maxFrame (int?): Ending frame to be exported.  
                Properties: create
        minFrame (int?): Starting frame to be exported. The export operation will play the  
                scene through from min frame to max frame as it exports.  
                Properties: create
        onlyUpdateParticles (bool?): Specify to only update the particles before exporting.  
                Properties: create
        overSampling (int?): OverSampling to be used during export.  
                Properties: create
        path (str?): This option allows you to specify a subdirectory of the workspace  
                "particles" directory where you want the exported files to be stored.  
                By default, files are stored in the workspace particles directory,  
                i.e., -path is relative to that directory.  
                ( Please Read This:  This is a change from previous versions of Maya  
                in which the path was relative to the workspace root directory.)  
                You can set the "particles" directory anywhere you want using the  
                project window or workspace -fr command. (In this way, you can use  
                an absolute path for export).  
                The -path flag cannot handle strings which include "/" or "\\",  
                in other words, it lets you go down only one level in the directory hierarchy.  
                If you specify a path which doesn't exist, the action will create it  
                if possible; if it can't create the path it will warn you and fail.  
                If you are using a project for which a particle data directory is  
                not defined, dynExport will create a default one called "particles"  
                and add it to your workspace.  
                Properties: create

    Returns:
        str: Path to the exported files

    Example:
    """

def dynExpression(*args: str, edit: bool = ..., query: bool = ..., creation: bool = ..., runtime: bool = ..., runtimeAfterDynamics: bool = ..., runtimeBeforeDynamics: bool = ..., string: str = ...) -> Union[str, bool]:
    """This command describes an expression that belongs to the specified
    particle shape.  The expression is a block of code of unlimited length
    with a C-like syntax that can perform conversions, mathematical
    operations, and logical decision making on any numeric attribute(s) or
    per-particle attribute(s) in the scene.  One expression can read and
    alter any number of these attributes.  Every particle shape in your
    scene has three expressions, one for the runtimeBeforeDynamics, one
    for the runtimeAfterDynamics and one for creation time.  The create
    expression gets executed for every particle in the object whose age is
    0.0.  The runtime expression gets executed for each particle with an
    age greater then 0.0.  Unlike expressions created with thecommand, particle expressions always exist and are a
    part of the owning particle object's shape.  They default to empty
    strings, but they are always there.  Because of this, there is no need
    to use the '-e' flag.  Every call to the dynExpression command is
    considered an edit by default.  Per-particle attributes are those
    attributes of a particle shape that have a potentially different value
    for each particle in the object.  Examples of these includeandIf this command is being sent by the command line or in a script, then
    the user should be sure to embed escaped newlines (\\n), tabs (\\t) for
    clarity when reading them in the expression editor.  Also, quotes in
    an expression must be escaped (\\") so that they are not confused by
    the system as the end of your string.  When using the expression
    editor, these characters are escaped for you unless they are already
    within quotes.This type of expression is executed during the evaluation of the
    dynamics.  If an output of the expression is requested before that,
    then the dynamics will be force to compute at that time.  If dynamics
    is disabled, then these expressions will have no effect.
    Args:
        creation (bool?): Tells the command that the string passed will be a  
                creation expression for the particle shape.  This means that  
                this expression will be executed when a particle is emitted  
                or at the beginning of the scene for existing particles.  
                Properties: create, query, edit
        runtime (bool?): Tells the command that the string passed will be a  
                runtime expression for the particle shape.  This expression  
                will be executed at the beginning of runtime.  
                Properties: create, query, edit
        runtimeAfterDynamics (bool?): Tells the command that the string passed will be a  
                runtime expression for the particle shape.  This expression  
                will be executed after dynamics whenever a particle's age  
                is greater then zero (0).  
                Properties: create, query, edit
        runtimeBeforeDynamics (bool?): Tells the command that the string passed will be a  
                runtime expression for the particle shape.  This expression  
                will be executed before dynamics whenever a particle's age  
                is greater then zero (0).  
                Properties: create, query, edit
        string (str?): Set the expression string. This is queriable with the -q/query flag and the -rbd/runtimeBeforeDynamics,  
                the -rab/runtimeAfterDynamics or the -c/creation flag.  
                Properties: create, edit

    Returns:
        str: The particle shape which this expression belongs to

    Example:
    """

def dynGlobals(*args: str, edit: bool = ..., query: bool = ..., active: bool = ..., listAll: bool = ..., overSampling: Queryable[int] = ...) -> Union[str, int, bool]:
    """This node edits and queries the attributes of the active dynGlobals
    node in the scene. There can be only one active node of this type.
    The active dynGlobals node is the first one that was created, either
    with a "createNode" command or by accessing/editing any of the
    attributes on the node through this command.
    Args:
        active (bool?): This flag returns the name of the active dynGlobals node in the  
                the scene.  Only one dynGlobals node is active. It is the first on  
                created.  Any additional dynGlobals nodes will be ignored.  
                Properties: query
        listAll (bool?): This flag will list all of the dynGlobals nodes in the scene.  
                Properties: query
        overSampling (Queryable[int]?): This flag will set the current overSampling value for all of  
                the particle in the scene.  
                Properties: query, edit

    Returns:
        str: For edit commands
        int: or string
            For query commands, depending on the flag queried.

    Example:
    """

def dynPaintCtx(*args: Any, **kwargs: Any) -> None: ...
def dynPaintEditor(*args: Any, edit: bool = ..., query: bool = ..., activeOnly: bool = ..., autoSave: bool = ..., camera: Queryable[str] = ..., canvasMode: bool = ..., canvasUndo: bool = ..., changeCommand: Queryable[Tuple[str, str, str, str]] = ..., clear: Tuple[float, float, float] = ..., control: bool = ..., currentCanvasSize: bool = ..., defineTemplate: str = ..., displayAppearance: Queryable[str] = ..., displayFog: bool = ..., displayImage: Queryable[int] = ..., displayLights: Queryable[str] = ..., displayStyle: Queryable[str] = ..., displayTextures: bool = ..., docTag: Queryable[str] = ..., doubleBuffer: bool = ..., drawAxis: bool = ..., drawContext: bool = ..., exists: bool = ..., fastUpdate: int = ..., fileName: Queryable[str] = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., iconGrab: bool = ..., loadImage: str = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., menu: str = ..., nbImages: bool = ..., newImage: Queryable[Tuple[int, int, float, float, float]] = ..., paintAll: float = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., redrawLast: bool = ..., refresh: bool = ..., refreshMode: Queryable[int] = ..., removeAllImages: bool = ..., removeImage: bool = ..., rollImage: Tuple[float, float] = ..., saveAlpha: bool = ..., saveBumpmap: Queryable[str] = ..., saveImage: bool = ..., scaleBlue: Queryable[float] = ..., scaleGreen: Queryable[float] = ..., scaleRed: Queryable[float] = ..., selectionConnection: Queryable[str] = ..., singleBuffer: bool = ..., snapShot: bool = ..., stateString: bool = ..., swap: int = ..., tileSize: int = ..., unParent: bool = ..., undoCache: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., wrap: Queryable[Tuple[bool, bool]] = ..., writeImage: str = ..., zoom: Queryable[float] = ...) -> Union[str, bool, Tuple[str, str, str, str], int, Tuple[int, int, float, float, float], float, Tuple[bool, bool]]:
    """Create a editor window that can be painted into
    Args:
        activeOnly (bool?): For Scene mode, this determines if only the active strokes will  
                be refreshed.  
                Properties: query, edit
        autoSave (bool?): For Canvas mode, this determines if the buffer will be saved  
                to a disk file after every stroke. Good for painting textures and  
                viewing the results in shaded display in the model view.  
                Properties: query, edit
        camera (Queryable[str]?): Sets the name of the camera which the Paint Effects panel  
                looks through.  
                Properties: query, edit
        canvasMode (bool?): Sets the Paint Effects panel into Canvas mode if true.  
                Properties: query, edit
        canvasUndo (bool?): Does a fast undo in Canvas mode. This is a special undo because  
                we are not using any history when we paint in Canvas mode so we  
                provide a single level undo for the Canvas.  
                Properties: edit
        changeCommand (Queryable[Tuple[str, str, str, str]]?): Parameters:  
              
                First string: command  
                Second string: editorName  
                Third string: editorCmd  
                Fourth string: updateFunc  
              
              
                Call the command when something changes in the editor The command  
                should have this prototype :  
              
                command(string $editor, string $editorCmd, string $updateFunc, int $reason)  
              
                The possible reasons could be :  
              
                0. no particular reason  
                1. scale color  
                2. buffer (single/double)  
                3. axis   
                4. image displayed  
                5. image saved in memory  
                Properties: create, query, edit
        clear (Tuple[float, float, float]?): Clears the buffer (if in Canvas mode) to the floating point  
                values (R,G,B).  
                Properties: edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        currentCanvasSize (bool?): In Query mode, this returns the (X,Y) resolution of the  
                current canvas.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayAppearance (Queryable[str]?): Sets the display appearance of the model panel.  Possible  
                values are "wireframe", "points", "boundingBox", "smoothShaded",  
                "flatShaded".  This flag may be used with the -interactive  
                and -default flags.  Note that only "wireframe", "points", and  
                "boundingBox" are valid for the interactive mode.  
                Properties: query, edit
        displayFog (bool?): For Scene mode, this determines if fog will be displayed in  
                the Paint Effects panel when refreshing the scene. If fog is on,  
                but this is off, fog will only be drawn on the strokes, not the  
                rest of the scene.  
                Properties: query, edit
        displayImage (Queryable[int]?): Set a particular image in the Editor Image Stack as the current Editor Image.  
                Images are added to the Editor Image Stack using the "si/saveImage" flag.  
                Properties: query, edit
        displayLights (Queryable[str]?): Sets the lighting for shaded mode.  Possible values are "selected",  
                "active", "all", "default".  
                Properties: query, edit
        displayStyle (Queryable[str]?): Set the mode to display the image. Valid values are:  
              
                "color" to display the basic RGB image  
                "mask" to display the mask channel  
                "lum" to display the luminance of the image  
                Properties: create, query, edit
        displayTextures (bool?): Turns on or off display of textures in shaded mode  
                Properties: query, edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        doubleBuffer (bool?): Set the display in double buffer mode  
                Properties: create, query, edit
        drawAxis (bool?): Set or query whether the axis will be drawn.  
                Properties: create, query, edit
        drawContext (bool?): Returns the name of the context.  
                Properties: query
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fastUpdate (int?): Obsolete - do not use
        fileName (Queryable[str]?): This sets the file to which the canvas will be saved.  
                Properties: query, edit
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        iconGrab (bool?): This puts the Paint Effects panel into Grab Icon mode where the  
                user is expected to drag out a section of the screen to be made into  
                an icon.  
                Properties: edit
        loadImage (str?): load an image from disk and set it as the current Editor Image  
                Properties: edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        menu (str?): Sets the name of the script used to build a menu in the editor. The script  
                takes the editor name as an argument.  
                Properties: create
        nbImages (bool?): returns the number of images  
                Properties: query
        newImage (Queryable[Tuple[int, int, float, float, float]]?): Starts a new image in edit mode, setting the resolution to  
                the integer values (X,Y) and clearing the buffer to the floating point  
                values (R,G,B). In Query mode, this returns the (X,Y) resolution of the  
                current Image.  
                Properties: query, edit
        paintAll (float?): Redraws the buffer in current refresh mode.  
                Properties: edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        redrawLast (bool?): Redraws the last stroke again. Useful when it's brush has just  
                changed. This feature does a fast undo and redraws the stroke again.  
                Properties: edit
        refresh (bool?): requests a refresh of the current Editor Image.  
                Properties: edit
        refreshMode (Queryable[int]?): Sets the refresh mode to the specified value. 0. Do not draw  
                strokes on refresh, 1. Redraw strokes in wireframe mode, 2. Redraw strokes in final rendered mode.  
                Properties: query, edit
        removeAllImages (bool?): remove all the Editor Images from the Editor Image Stack  
                Properties: edit
        removeImage (bool?): remove the current Editor Image from the Editor Image Stack  
                Properties: edit
        rollImage (Tuple[float, float]?): In Canvas mode, this rolls the image by the floating point  
                values (X,Y). X and Y are between 0 (no roll) and 1 (full roll). A  
                value of .5 rolls the image 50% (ie. the border moves to the center of the screen.  
                Properties: edit
        saveAlpha (bool?): For Canvas mode, this determines if the alpha will be saved when  
                storing the canvas to a disk file.  
                Properties: query, edit
        saveBumpmap (Queryable[str]?): Saves the current buffer as a bump map to the specified file.  
                Properties: query, edit
        saveImage (bool?): save the current Editor Image to memory. Saved Editor Images are  
                stored in an Editor Image Stack. The most recently saved image is stored in  
                position 0, the second most recently saved image in position 1,  
                and so on... To set the current Editor Image to a previously saved  
                image use the "di/displayImage" flag.  
                Properties: edit
        scaleBlue (Queryable[float]?): Define the scaling factor for the blue component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        scaleGreen (Queryable[float]?): Define the scaling factor for the green component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        scaleRed (Queryable[float]?): Define the scaling factor for the red component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        singleBuffer (bool?): Set the display in single buffer mode  
                Properties: create, query, edit
        snapShot (bool?): Takes a snapshot of the current camera view.  
                Properties: edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        swap (int?): Obsolete - do not use
        tileSize (int?): Sets the size of the tile for the hardware texture redraw of the display buffer.  
                Properties: edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        undoCache (bool?): By default the last image is cached for undo. If this is set false, then  
                undoing will be disabled in canvas mode and undo in scene mode will force a full  
                refresh. Less memory will be used if this is set false before the first clear or  
                refresh of the current scene.  
                Properties: edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        wrap (Queryable[Tuple[bool, bool]]?): For Canvas mode, should the buffer wrap in U, and V  
                (respectively) when painting.  
                Properties: query, edit
        writeImage (str?): write the current Editor Image to disk  
                Properties: edit
        zoom (Queryable[float]?): Zooms the Canvas image by the specified value.  
                Properties: query, edit

    Returns:
        str: Editor name

    Example:
    """

def dynParticleCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., conserve: Queryable[float] = ..., cursorPlacement: bool = ..., exists: bool = ..., grid: bool = ..., gridSpacing: Queryable[float] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., jitterRadius: Queryable[float] = ..., lowerLeftX: Queryable[float] = ..., lowerLeftY: Queryable[float] = ..., lowerLeftZ: Queryable[float] = ..., name: str = ..., nucleus: bool = ..., numJitters: Queryable[int] = ..., particleName: Queryable[str] = ..., sketch: bool = ..., sketchInterval: Queryable[int] = ..., textPlacement: bool = ..., upperRightX: Queryable[float] = ..., upperRightY: Queryable[float] = ..., upperZ: Queryable[float] = ...) -> Union[bool, float, str, int]:
    """The particle context command creates a particle context. The particle
    context provides an interactive means to create particle
    objects. The particle context command also provides an interactive
    means to set the option values, through the Tool Property Sheet, for
    the "particle" command that the context will issue.
    Args:
        conserve (Queryable[float]?): Conservation of momentum control (between 0 and 1). For smaller  
                values, the field will tend to erase any existing velocity the object  
                has (in other words, will not conserve momentum from frame to frame).  
                A value of 1 (the default) corresponds to the true physical law  
                of conservation of momentum.  
                Properties: query, edit
        cursorPlacement (bool?): Use the cursor to place the lower left and upper right of the grid.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        grid (bool?): Create a particle grid.  
                Properties: query, edit
        gridSpacing (Queryable[float]?): Spacing between particles in the grid.  
                Properties: query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        jitterRadius (Queryable[float]?): Max radius from the center to place the particle instances.  
                Properties: query, edit
        lowerLeftX (Queryable[float]?): Lower left X position of the particle grid.  
                Properties: query, edit
        lowerLeftY (Queryable[float]?): Lower left Y position of the particle grid.  
                Properties: query, edit
        lowerLeftZ (Queryable[float]?): Lower left Z position of the particle grid.  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        nucleus (bool?): If set true then an nParticle is generated with a nucleus node connection.  
                Otherwise a standard particle is created.  
                Properties: query, edit
        numJitters (Queryable[int]?): Number of jitters (instances) per particle.  
                Properties: query, edit
        particleName (Queryable[str]?): Particle name.  
                Properties: query, edit
        sketch (bool?): Create particles in sketch mode.  
                Properties: query, edit
        sketchInterval (Queryable[int]?): Interval between particles, when in sketch mode.  
                Properties: query, edit
        textPlacement (bool?): Use the textfields to specify the lower left and upper right of/  
                the grid.  
                Properties: query, edit
        upperRightX (Queryable[float]?): Upper right X position of the particle grid.  
                Properties: query, edit
        upperRightY (Queryable[float]?): Upper right Y position of the particle grid.  
                Properties: query, edit
        upperZ (Queryable[float]?): Upper right Z position of the particle grid.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def dynPref(*, query: bool = ..., autoCreate: bool = ..., echoCollision: bool = ..., runupFrom: Queryable[int] = ..., runupToCurrentTime: bool = ..., saveOnQuit: bool = ..., saveRuntimeState: bool = ...) -> Union[bool, int]:
    """This action modifies and queries the current state of "autoCreate
    rigid bodies", "run up to current time", and  "run up from"
    (previous time or start time).
    Args:
        autoCreate (bool?): If on, autoCreate rigid bodies.  
                Properties: create, query
        echoCollision (bool?): If on, will cause particle systems to echo to the Script Editor the  
                command that they are running for each particle collision event.  
                If off, only the output of the command will be echoed.  
                Properties: create, query
        runupFrom (Queryable[int]?): If on, run up from previous time; if 2, run up from start time  
                Properties: create, query
        runupToCurrentTime (bool?): If on, run up the scene to current time  
                Properties: create, query
        saveOnQuit (bool?): If on, save the current values of preferences to userPrefs file.  
                Properties: create, query
        saveRuntimeState (bool?): If on, runtime state as well as initial state of all particle objects  
                will be saved to file. If off, only initial state will be saved.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def dynSelectCtx(*args: Any, **kwargs: Any) -> None: ...
def dynTestData(*, arrayAttrs: bool = ..., verbose: bool = ...) -> None: ...
def dynWireCtx(*args: Any, **kwargs: Any) -> None: ...
def dynamicConstraintRemove() -> None: ...
def dynamicLoad(*args: str) -> bool:
    """Dynamically load the DLL passed as argument.
    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def editDisplayLayerGlobals(*, query: bool = ..., baseId: Queryable[int] = ..., currentDisplayLayer: Queryable[str] = ..., mergeType: Queryable[int] = ..., useCurrent: bool = ...) -> Union[bool, str, int]:
    """Edit the parameter values common to all display layers.  Some of these
    paremeters, eg. baseId and mergeType, are stored as preferences and
    some, eg. currentDisplayLayer, are stored in the file.displayLayer, display, layer, globals, current, merge
    Args:
        baseId (Queryable[int]?): Set base layer ID.  This is the number at which new layers start searching  
                for a unique ID.  
                Properties: create, query
        currentDisplayLayer (Queryable[str]?): Set current display layer; ie. the one that all new objects are added to.  
                Properties: create, query
        mergeType (Queryable[int]?): Set file import merge type.  Valid values are 0, none, 1, by number, and  
                2, by name.  
                Properties: create, query
        useCurrent (bool?): Set whether or not to enable usage of the current display layer as the  
                destination for all new nodes.  
                Properties: create, query

    Returns:
        bool: Command success
        str: Current display layer name, when querying
        int: Merge type, when querying
        int: Base ID, when querying

    Example:
    """

def editDisplayLayerMembers(*args: str, query: bool = ..., clear: bool = ..., fullNames: bool = ..., noRecurse: bool = ..., ufeObjects: bool = ...) -> Union[int, List[str], bool]:
    """This command is used to query and edit membership of display layers.  No
    equivalent 'remove' command is necessary since all objects must be in exactly
    one display layer.  Removing an object from a layer can be accomplished by
    adding it to a different layer.displayLayer, display, layer, member, relationship
    Args:
        clear (bool?): Remove all the objects contained in the layer by moving them to the default layer.  
                Properties: create
        fullNames (bool?): (Query only.) If set then return the full DAG paths of the objects in the  
                layer.  Otherwise return just the name of the object.  
                Properties: query
        noRecurse (bool?): If set then only add selected objects to the display layer.  Otherwise all  
                descendants of the selected objects will also be added.  
                Properties: create, query
        ufeObjects (bool?): (Query only.) If set will return objects that are  
                defined through the UFE interface as well as native Maya objects.  
                Properties: query

    Returns:
        int: Number of objects added to the layer
        List[str]: Query: List of objects in layer

    Example:
    """

def editImportedStatus() -> None: ...
def editMetadata(*args: str, memberName: str = ..., remove: bool = ..., stringValue: Multiuse[str] = ..., value: Multiuse[float] = ..., channelName: Queryable[str] = ..., channelType: Queryable[str] = ..., endIndex: str = ..., index: Queryable[Multiuse[str]] = ..., indexType: Queryable[str] = ..., scene: bool = ..., startIndex: str = ..., streamName: Queryable[str] = ...) -> Union[str, Multiuse[str], bool]:
    """This command is used to set metadata elements onto or remove metadata
    elements from an object. Before using this command you must first attach
    a metadata stream type to the object using thecommand
    or an API equivalent. The command has four basic variations:The difference between theandvariations
    (1,3 vs. 2,4) is thatrequires both a member name to be set
    and a new value to be set. (The reason removal doesn't use a member
    name is that you can only remove an entire metadata structural element,
    you cannot remove only a single member from it.)When metadata values are set or removed the action is performed on
    every selected component or index. This provides an easy method to
    set or remove a bunch of metadata en masse.The general usage (variations 3, 4) lets you select specific pieces
    of metadata through theandflags. Note that sinceis a multi-use flag you
    can select many different elements from the same Channel and set or
    remove the metadata on all of them in one command.Metadata on meshes is special in that the Channel types "vertex",
    "edge", "face", and "vertexFace" are directly connected to the
    components of the same name. To make setting these metadata
    Channels easier you can simply select or specify on the command
    line the corresponding components rather than using theandflags. For example the selection "myMesh.vtx[8:10]"
    corresponds toand(as a multi-use flag).Note that the metadata is assigned to an object and except in the special
    case of mesh geometry does not flow through the dependency graph. In
    meshes the metadata will move from node to node wherever the geometry
    is connected, although it will not adjust itself automatically for changes
    in topology. Internal data is arranged to minimize the amount of copying
    no matter how many other nodes are connected to it.Only a single node or scene, component type, channel type, and value type
    are allowed in a single command. This keeps the data simple at the possible
    cost of requiring multiple calls to the command to set more than one
    structure member's value.Certain nodes have metadata supplied by input attributes. If you edit one
    of those with an incoming connection on such an attribute then the metadata
    edit will not be applied directly it will be put into an 'editMetadata' node
    for application during DG evaluation. Since the details of the metadata are
    not known until the evaluation happens less rigorous compatibility checking
    is performed. The editMetadata node has its own facilities for verifying and
    reporting illegal metadata edits. Successive edits to the same metadata in
    this way appends each edit to the same editMetadata node.metadata, component, stream, channel, association
    Args:
        memberName (str?): Name of the Structure member being edited. The names of the members are  
                set up in the Structure definition, either through the description passed  
                in through the "dataStructure" command or via the API used to create that  
                Structure.  
                Properties: create
        remove (bool?): If the remove flag is set then the metadata will be removed rather  
                than have values set. In this mode the "memberName", "value", and  
                "stringValue" flags are ignored. "memberName" is ignored because when  
                deleting metadata all members of a structure must be removed as a group.  
                The others are ignored since when deleting you don't need a value to be set.  
                Properties: create
        stringValue (Multiuse[str]?): String value to be set into the specified metadata locations. This flag  
                can only be used when the data member is a numeric type. If the member has  
                N dimensions (e.g. string[2]) then this flag must appear N times (e.g. 2 times)  
                The same values are applied to the specified metadata member on all affected  
                components or metadata indices.  
                Only one of the value, and stringValue flags can be specified at once and the  
                type must match the type of the structure member named by the "member" flag.  
                Properties: create, multiuse
        value (Multiuse[float]?): Numeric value to be set into the specified metadata locations. This flag  
                can only be used when the data member is a numeric type. If the member has  
                N dimensions (e.g. float[3]) then this flag must appear N times (e.g. 3 times)  
                The same values are applied to the specified metadata member on all affected  
                components or metadata indices. All numeric member types should use this type  
                of value specification, i.e. everything except string and matrix types.  
                Only one of the value, and stringValue flags can be specified at once and the  
                type must match the type of the structure member named by the "member" flag.  
                Properties: create, multiuse
        channelName (Queryable[str]?): Filter the metadata selection to only recognize metadata belonging to  
                the specified named Channel (e.g. "vertex"). This flag is ignored if the  
                components on the selection list are being used to specify the metadata  
                of interest.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        channelType (Queryable[str]?): Obsolete - use the 'channelName' flag instead.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        endIndex (str?): The metadata is stored in a Stream, which is an indexed list. If you have  
                mesh components selected then the metadata indices are implicit in the list  
                of selected components. If you select only the node or scene then this flag  
                may be used in conjunction with the startIndex flag to specify a range  
                of indices from which to retrieve the metadata. It is an error to have the  
                value of startIndex be greater than that of endIndex.  
              
              
                See also the index flag for an alternate way to specify multiple  
                indices. This flag can only be used on index types that support a range  
                (e.g. integer values - it makes no sense to request a range between two  
                strings)  
              
                			In query mode, this flag can accept a value.  
                Properties: create
        index (Queryable[Multiuse[str]]?): In the typical case metadata is indexed using a simple integer value.  
                Certain types of data may use other index types. e.g. a "vertexFace"  
                component will use a "pair" index type, which is two integer values; one  
                for the face ID of the component and the second for the vertex ID.  
              
              
                The index flag takes a string, formatted in the way the  
                specified indexType requires. All uses of the  
                index flag have the same indexType. If the type was  
                not specified it is assumed to be a simple integer value.  
              
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        indexType (Queryable[str]?): Name of the index type the new Channel should be using. If not specified this  
                defaults to a simple integer index. Of the native types only a mesh  
                "vertexFace" channel is different, using a "pair" index type.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        scene (bool?): Use this flag when you want to add metadata to the scene as a whole rather than to  
                any individual nodes. If you use this flag and have nodes selected the nodes will  
                be ignored and a warning will be displayed.  
                Properties: create, query
        startIndex (str?): The metadata is stored in a Stream, which is an indexed list. If you have  
                mesh components selected then the metadata indices are implicit in the list  
                of selected components. If you select only the node or scene then this flag  
                may be used in conjunction with the endIndex flag to specify a range of  
                indices from which to retrieve the metadata. It is an error to have the value  
                of startIndex be greater than that of endIndex.  
              
              
                See also the index flag for an alternate way to specify multiple  
                indices. This flag can only be used on index types that support a range  
                (e.g. integer values - it makes no sense to request a range between two  
                strings)  
              
                			In query mode, this flag can accept a value.  
                Properties: create
        streamName (Queryable[str]?): Name of the metadata Stream. Depending on context it could be the name of a  
                Stream to be created, or the name of the Stream to pass through the filter.  
                			In query mode, this flag can accept a value.  
                Properties: create, query

    Returns:
        str: Name of the node where the new edits reside, empty string if edits failed. It will be an editMetadata node if construction history was present.

    Example:
    """

def editRenderLayerAdjustment(*args: str, query: bool = ..., attributeLog: bool = ..., layer: Queryable[str] = ..., nodeLog: bool = ..., remove: bool = ...) -> Union[int, List[str], bool, str]:
    """This command is used to create, edit, and query adjustments to render
    layers. An adjustment allows different attribute values or connections
    to be used depending on the active render layer.renderLayer
    Args:
        attributeLog (bool?): Output all adjustments for the specified layer sorted by attribute name.  
                Properties: query
        layer (Queryable[str]?): Specified layer in which the adjustments will be modified. If not specified  
                the active render layer will be used.  
                Properties: create, query
        nodeLog (bool?): Output all adjustments for the specified layer sorted by node name.  
                Properties: query
        remove (bool?): Remove the specified adjustments from the render layer. If an adjustment  
                is removed from the current layer, the specified plug will revert back to  
                it's master value determined by the default render layer.  
                Properties: create

    Returns:
        int: Number of adjustments applied
        List[str]: Query: List of plugs adjustments to layer

    Example:
    """

def editRenderLayerGlobals(*, query: bool = ..., baseId: Queryable[int] = ..., currentRenderLayer: Queryable[str] = ..., enableAutoAdjustments: bool = ..., mergeType: Queryable[int] = ..., useCurrent: bool = ...) -> Union[bool, str, int]:
    """Edit the parameter values common to all render layers.  Some of these
    paremeters, eg. baseId and mergeType, are stored as preferences and
    some, eg. currentRenderLayer, are stored in the file.renderLayer, render, layer, globals, current, merge
    Args:
        baseId (Queryable[int]?): Set base layer ID.  This is the number at which new layers start searching  
                for a unique ID.  
                Properties: create, query
        currentRenderLayer (Queryable[str]?): Set current render layer. This will will update the renderLayerManger and  
                all DAG objects to identify them as members of the render layer. This  
                flag may also be used in conjunction with "useCurrent" to automatically  
                add new DAG objects to the active layer. The "isCurrentRenderLayerChanging"  
                condition can be used to determine when the current layer is being changed  
                and adjustments are being applied to the scene.  
                Properties: create, query
        enableAutoAdjustments (bool?): Set whether or not to enable automatic creation of adjustments when  
                certain attributes (ie. surface render stats, shading group assignment,  
                or render settings) are changed.  
                Properties: create, query
        mergeType (Queryable[int]?): Set file import merge type.  Valid values are 0, none, 1, by number, and  
                2, by name.  
                Properties: create, query
        useCurrent (bool?): Set whether or not to enable usage of the current render layer as the  
                destination for all new nodes.  
                Properties: create, query

    Returns:
        bool: Command success
        str: Current render layer name, when querying
        int: Merge type, when querying
        int: Base ID, when querying

    Example:
    """

def editRenderLayerMembers(*args: str, query: bool = ..., fullNames: bool = ..., noRecurse: bool = ..., remove: bool = ...) -> Union[int, List[str], bool]:
    """This command is used to query and edit memberships to render layers. Only
    transform and geometry nodes may be members. At render time, all
    descendants of the members of a render layer will also be included in the
    render layer.renderLayer, render, layer, member, relationship
    Args:
        fullNames (bool?): (Query only.) If set then return the full DAG paths of the objects in the  
                layer.  Otherwise return just the name of the object.  
                Properties: query
        noRecurse (bool?): If set then only add selected objects to the render layer.  Otherwise all  
                descendants of the selected objects will also be added. This flag may be  
                applied to adding or removing objects from the layer.  
                Properties: create
        remove (bool?): Remove the specified objects from the render layer.  
                Properties: create

    Returns:
        int: Number of objects added to the layer
        List[str]: Query: List of objects in layer

    Example:
    """

def editor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool]:
    """Edit the characteristic of an editor
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Name of the editor

    Example:
    """

def editorTemplate(*args: str, addAdskAssetControls: bool = ..., addComponents: bool = ..., addControl: Tuple[str, Callable[..., Any]] = ..., addDynamicControl: Tuple[str, Callable[..., Any]] = ..., addExtraControls: bool = ..., addSeparator: bool = ..., annotateFieldOnly: bool = ..., annotation: str = ..., beginLayout: str = ..., beginNoOptimize: bool = ..., beginScrollLayout: bool = ..., callCustom: Tuple[Callable[..., Any], Callable[..., Any]] = ..., collapse: bool = ..., debugMode: bool = ..., dimControl: Tuple[str, str, bool] = ..., endLayout: bool = ..., endNoOptimize: bool = ..., endScrollLayout: bool = ..., extraControlsLabel: str = ..., forceRebuild: bool = ..., interruptOptimize: bool = ..., label: str = ..., listExtraAttributes: str = ..., preventOverride: bool = ..., queryControl: Tuple[str, str] = ..., queryLabel: Tuple[str, str] = ..., queryName: Tuple[str, str] = ..., suppress: str = ...) -> str:
    """The editorTemplate command allows the user to specify the
    conceptual layout of an attribute editor and leave the details
    of exactly which UI elements are used in the final result to the
    automatic dialog generation mechanism.
    Args:
        addAdskAssetControls (bool?): Adds controls for dynamic attributes of adskMaterial nodes  
                and organizes them in a layout according to the XML ui  
                description specified in the asset library.  
                Properties: create
        addComponents (bool?): This flag will add a frameLayout with a channel box  
                which will display any selected components for the  
                object.  
                Properties: create
        addControl (Tuple[str, Callable[..., Any]]?): The first argument is the name of the attribute for which  
                you wish to add a control. You can assume that when the editor  
                is created from the template, an appropriate type of control  
                will be used.  
                The second string argument is optional, and can be used  
                to specify a command (or script) to be executed when the  
                attribute is changed.  
                Properties: create
        addDynamicControl (Tuple[str, Callable[..., Any]]?): As -addControl with the exception that the attribute  
                for which the control is to be created/attached is dynamic.  
                [Note: -addControl will also work for dynamic attributes,  
                but will not preserve their order in the attribute editor].  
                Properties: create
        addExtraControls (bool?): By default, if there are attributes of a node which you do  
                not -addControl or -suppress, then controls will be created  
                automatically and appended to the end of editor created from the  
                template. This flag allows you to specify a particular place  
                in the template for such controls to be automatically inserted.  
                If dynamic attributes have not already been addressed  
                with -addControl, they will also be placed here.  A frameLayout  
                will automatically be generated for you when you use this flag.  
                Properties: create
        addSeparator (bool?): Adds a separator to the template.  
                Properties: create
        annotateFieldOnly (bool?): This flag can only be used with the -annotation flag.  By  
                default, for any Attribute Editor controlGroups created by  
                the -addControl flag, the -annotation flag displays its  
                annotation string when the mouse hovers over any control  
                that is part (the label, the value field, etc.) of the  
                group.  Use this flag to limit display of the annotation to  
                only the value field of the controlGroup.  This flag is  
                ignored if the controlGroup has no value field (e.g., checkBoxGrp)  
                Properties: create
        annotation (str?): This flag can only be used with the -addControl or  
                the -addDynamicControl flags. The string will be used as  
                an annotation on the controls created in the attribute editor.  
                Properties: create
        beginLayout (str?): Begins a layout in the template with the title specified  
                by the string argument.  
                Items between this flag and    its corresponding -endLayout flag  
                will be contained within the layout. You can assume that when  
                the editor is created from the template, an appropriate type of  
                layout will be used. (frameLayout).  
                Properties: create
        beginNoOptimize (bool?): Specifies that the layout of items between this flag and its  
                corresponding -endNoOptimize flag is not to be optimized to  
                minimize space.  
                Properties: create
        beginScrollLayout (bool?): Begins a scrollLayout.  Items between this flag and its  
                corresponding -endScrollLayout flag will be contained within  
                the layout.  
                Properties: create
        callCustom (Tuple[Callable[..., Any], Callable[..., Any]]?): Specifies that at this point in the template when building the  
                dialog, the procedure specified by the first argument is to be  
                called to create some UI objects when a new node type is edited.  
                The procedure specified by the second argument is to be called if  
                an attribute editor already exists and another node of the same  
                type is now to be edited. The replacing procedure should connect  
                any controls created by the creating procedure to the equivalent  
                attributes in the new node. A list of zero or more attributes  
                specifies the attributes which the two procedures will involve.  
                The procedures should have the signature:  
              
                proc AEcustomNew(string attributeName1, string attributeName2)  
              
                The number of attributes specified in the call should correspond  
                to the number of attributes in the procedure signature.  
                Properties: create
        collapse (bool?): This flag is only valid when used in conjunction with  
                a -bl/beginLayout flag.  It is used to specify the initial  
                expand/collapse state of the layout.  A true value will cause the  
                layout to be collapsed upon creation, while a false value will  
                expand the layout.  The default is true (ie. collapsed).  
                Properties: create
        debugMode (bool?): Set debugging mode for the template  
                Properties: create
        dimControl (Tuple[str, str, bool]?): This flag is only useful AFTER a control has already been  
                created (using the -addControl flag).  The first argument  
                is the node name and the second is the attribute  
                whose control you wish to affect.  The third argument is a  
                boolean which specifies whether to dim (true) or undim (false)  
                the associated control.  
                Properties: create
        endLayout (bool?): Ends a layout in the template started by -beginLayout.  
                Properties: create
        endNoOptimize (bool?): Ends a set of non-optimized items.  
                Properties: create
        endScrollLayout (bool?): Ends a scrollLayout.  
                Properties: create
        extraControlsLabel (str?): By default the label is "Extra Attributes". Specify an  
                alternate label or an empty string to hide the label. This flag  
                must be used in conjuction with the -aec/addExtraControls flag.  
                Properties: create
        forceRebuild (bool?): Force a template to always destroy/create itself rather  
                than use the replace feature.  Both the default replace  
                behavior and force rebuild preserve the collapse/expand  
                status of all the layout sections.  
                Properties: create
        interruptOptimize (bool?): Enforces a division between two sets of items whose layouts  
                may be optimized.  
                Properties: create
        label (str?): This flag can only be used with the -addControl or  
                the -addDynamicControl flags.  And it must be specified FIRST.  
                The string will override the name of the attribute that  
                will be displayed in the attribute editor.  
                Properties: create
        listExtraAttributes (str?): List extra attributes.This flag is only useful AFTER a control  
                has already been created (using the -addControl flag). The  
                first argument is the node name.  
                Properties: create
        preventOverride (bool?): If true, this flag disallows overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create
        queryControl (Tuple[str, str]?): This flag is only useful AFTER a control has already been  
                created (using the -addControl flag).  The first argument is  
                the node name and the second is the attribute whose control  
                you wish to query.  Note that in most cases, using this  
                flag is identical to issuing a getAttr command, however, in  
                the case of textFields (e.g. for message attributes), the text  
                value currently being displayed will be returned, NOT the actual  
                attribute value.  
                Properties: create
        queryLabel (Tuple[str, str]?): This flag is only useful AFTER a control has already been  
                created (using the -addControl flag).  The first argument is  
                the node name and the second is the attribute whose control  
                label you wish to query.  In most cases this flag  
                returns the same value as the attribute's nice name,  
                but when a -label flag was present on the -addControl command that  
                created the control, -queryLabel will return that value instead  
                Properties: create
        queryName (Tuple[str, str]?): This flag is only useful AFTER a control has already been  
                created (using the -addControl flag).  The first argument is  
                the node name and the second is the attribute whose control name  
                you wish to query.  
                Properties: create
        suppress (str?): Prevent a control for the attribute specified by the  
                string argument from appearing in the editor created from the  
                template.  
                Properties: create

    Returns:
        str: For queryControl, the appropriate attribute type will be
            returned.
            string array
            For listExtraAttributes, extra attributes will be returned.

    Example:
    """

def effector(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., hide: bool = ..., name: Queryable[str] = ...) -> Union[str, bool]:
    """The effector command is used to set the name or hidden
    flag for the effector.  The standard edit (-e) and query (-q) flags are
    used for edit and query functions.
    Args:
        hide (bool?): Specifies whether to hide drawing of effector  
                if attached to a handle.  
                Properties: create, query, edit
        name (Queryable[str]?): Specifies the name of the effector.  
                Properties: create, query, edit

    Returns:
        str: Command result

    Example:
    """

def emit(*, attribute: Multiuse[str] = ..., floatValue: Multiuse[float] = ..., object: str = ..., position: Multiuse[Tuple[float, float, float]] = ..., vectorValue: Multiuse[Tuple[float, float, float]] = ...) -> List[int]:
    """Theaction allows users to add particles to an existing particle
    object without the use of an emitter.  At the same time, it allows them to
    set any per-particle attribute for the particles that are created with the
    action.The particles created do not become a part of the initial state
    for the particle object, and will disappear when the scene is rewound unless
    they are saved into the initial state by the user explicitly.  In addition,
    a particle object will accept particles from an emit action ONLY at frames
    greater than or equal to its start frame.  For example, if you want to use the
    emit action to create particles at frame -5, you must set startFrame for that
    particle shape to -5 or less.Unlike many commands or actions, the emit action uses the order of its flags
    as important information as to how it works.  Theandflags can appear anywhere in the argument list.  Theand the
    value flags are interpreted based on their order.  Any value flags after an
    -attribute flag and before the next -attribute flag will set the values for
    the attribute specified by the closest -attribute flag before them in the
    argument list.  See thesection below for more detail on
    how these flags work.Currently, no creation expression is executed for the new particles
    unless they are created from within a particle expression defined with
    thecommand or the Expression Editor.  If you
    want any particular values put into the particles at the time they are
    created, then those values should be set using the, andflags.
    Args:
        attribute (Multiuse[str]?): Specifies the attribute on the particle object that any  
                value flags following it and before the next -attribute flag  
                will be associated with.  The same attribute can be specified  
                later in the command to pick up where the first one left off.  
                The attributes used must be per-particle attributes.  This  
                will accept both long and short names for the attributes.  
                Note the per-particle attribute must already exist on the  
                particle object prior to being specified via this command flag.  
                Properties: create, multiuse
        floatValue (Multiuse[float]?): Sets the float value to be used for the "current" attribute of  
                the "current" particle.  By current attribute, it is meant the  
                attribute specified by the most recent -attribute flag.  By  
                current particle, it is meant the particle in the list of -position  
                flags that corresponds to the number of values that  have  
                been set for the "current" attribute.  If the current attribute  
                is a vector-per-particle attribute, then the float value  
                specified will be used for all three components of the vector.  
                Properties: create, multiuse
        object (str?): This flag takes the name of a particleShape or the transform  
                directly above it in the DAG as its parent.  It specifies  
                which object to add the particles to.  This flag must  
                be passed, as the selection list is ignored for this action.  
                Properties: create
        position (Multiuse[Tuple[float, float, float]]?): Specifies the positions in the particle object's space  
                (usually world space) where the particles are to be created.  
                One particle is created for each occurence of this flag.  
                Properties: create, multiuse
        vectorValue (Multiuse[Tuple[float, float, float]]?): Sets the vector value to be used for the "current" attribute of  
                the "current" particle.  By current attribute, it is meant the  
                attribute specified by the most recent -attribute flag.  By  
                current particle, it is meant the particle in the list of -position  
                flags that corresponds to the number of values that have  
                been set for the "current" attribute.  If the current attribute  
                is a float-per-particle attribute, then the length of the  
                vector described by this flag will be used.  The length is  
                described as SQR( xVal2 + yVal2 + zVal2 ).  
                Properties: create, multiuse

    Returns:
        List[int]: Integer array containing the list of the particleId attribute values
            for the created particles in the same order that the position flags
            were passed.

    Example:
    """

def emitter(*args: str, edit: bool = ..., query: bool = ..., alongAxis: Queryable[float] = ..., aroundAxis: Queryable[float] = ..., awayFromAxis: Queryable[float] = ..., awayFromCenter: Queryable[float] = ..., cycleEmission: Queryable[str] = ..., cycleInterval: Queryable[int] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., directionalSpeed: Queryable[float] = ..., maxDistance: Queryable[float] = ..., minDistance: Queryable[float] = ..., name: Queryable[str] = ..., needParentUV: bool = ..., normalSpeed: Queryable[float] = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., randomDirection: Queryable[float] = ..., rate: Queryable[float] = ..., scaleRateByObjectSize: bool = ..., scaleSpeedBySize: bool = ..., speed: Queryable[float] = ..., speedRandom: Queryable[float] = ..., spread: Queryable[float] = ..., tangentSpeed: Queryable[float] = ..., torusSectionRadius: Queryable[float] = ..., type: Queryable[str] = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, int, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """Creates, edits or queries an auxiliary dynamics object
    (for example, a field or emitter).
    Creates an emitter object. If object names are provided or if objects are
    selected, applies the emitter to the named/selected object(s)in the
    scene.  Particles will then be emitted from each. If no objects are
    named or selected, or if the -pos option is specified, creates a
    positional emitter.If an emitter was created, the command returns the name of the object
    owning the emitter, and the name of emitter shape. If an emitter was
    queried, the command returns the results of the query.Keyframeable attributes of the emitter node: rate, directionX,
    directionY, directionZ, minDistance, maxDistance, spread.
    Args:
        alongAxis (Queryable[float]?): Initial velocity multiplier in the direction along  
                the central axis of the volume.  See the diagrams in  
                the documentation.  Applies only to volume emitters.  
                Properties: query, edit
        aroundAxis (Queryable[float]?): Initial velocity multiplier in the direction around  
                the central axis of the volume.  See the diagrams  
                in the documentation.  Applies only to volume emitters.  
                Properties: query, edit
        awayFromAxis (Queryable[float]?): Initial velocity multiplier in the direction away  
                from the central axis of the volume.  See the diagrams  
                in the documentation.  Used only with the cylinder, cone,  
                and torus volume emitters.  
                Properties: query, edit
        awayFromCenter (Queryable[float]?): Initial velocity multiplier in the direction away from  
                the center point of a cube or sphere volume emitter. Used only with  
                the cube and sphere volume emitters.  
                Properties: query, edit
        cycleEmission (Queryable[str]?): Possible values are "none" and "frame."  
                Cycling emission restarts the random number stream after  
                a specified interval.  This can either be a number of frames  
                or a number of emitted particles.  In each case the number  
                is specified by the cycleInterval attribute. Setting cycleEmission to  
                "frame" and cycleInterval to 1 will then re-start the random stream every  
                frame. Setting cycleInterval to values greater than 1 can be used  
                to generate cycles for games work.  
                Properties: query, edit
        cycleInterval (Queryable[int]?): Specifies the number of frames or particles between restarts of  
                the random number stream.  See cycleEmission.  Has no effect if  
                cycleEmission is set to None.  
                Properties: query, edit
        directionX (Queryable[float]?): x-component of emission direction.  
                Used for directional emitters, and for volume emitters with  
                directionalSpeed.  
                Properties: query, edit
        directionY (Queryable[float]?): y-component of emission direction.  
                Used for directional emitters, and for volume emitters with  
                directionalSpeed.  
                Properties: query, edit
        directionZ (Queryable[float]?): z-component of emission direction.  
                Used for directional emitters, and for volume emitters with  
                directionalSpeed.  
                Properties: query, edit
        directionalSpeed (Queryable[float]?): For volume emitters only, adds a component of speed in the  
                direction specified by the directionX, Y, and Z attributes.  
                Applies only to volume emitters. Does not apply to other types  
                of emitters.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which emission ends.  
                Properties: query, edit
        minDistance (Queryable[float]?): Minimum distance at which emission starts.  
                Properties: query, edit
        name (Queryable[str]?): Object name  
                Properties: create, query, edit
        needParentUV (bool?): If aNeedParentUV is true, compute parentUV value from  
                each triangle or each line segment, then send out to the  
                target particle object. You also need to add parentU and  
                parentV attributes to the particle object to store these values.  
                Properties: query, edit
        normalSpeed (Queryable[float]?): Normal speed multiple for point emission. For each emitted  
                particle, multiplies the component of the velocity normal  
                to the surface or curve by this amount. Surface and curve  
                emitters only.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): world-space position  
                Properties: create, query, edit, multiuse
        randomDirection (Queryable[float]?): Magnitude of a random component of the speed  
                from volume emission.  
                Properties: query, edit
        rate (Queryable[float]?): Rate at which particles emitted (can be non-integer).  
                For point emission this is rate per point per unit time.  
                For surface emission it is rate per square unit of area per unit time.  
                Properties: query, edit
        scaleRateByObjectSize (bool?): Applies to curve and surface emitters, only.  
                If true, number of particles is determined by object size  
                (area or length) times rate value.  If false, object size  
                is ignored and the rate value is used without modification.  
                The former is the way Maya behaved prior to version 3.0.  
                Properties: query, edit
        scaleSpeedBySize (bool?): Indicates whether the scale of a volume emitter  
                affects its velocity.  
                Properties: query, edit
        speed (Queryable[float]?): Speed multiple.  Multiplies the velocity of the  
                emitted particles by this amount. Does not apply to volume  
                emitters.  For that emitter type, use directionalSpeed.  
                Properties: query, edit
        speedRandom (Queryable[float]?): Identifies a range of random variation for the speed of  
                each generated particle.  If set to a non-zero value, speed  
                becomes the mean value of the generated particles, whose speeds  
                vary by a random amount up to plus or minus speedRandom/2.  
                For example, speed 5 and speedRandom 2 will make the speeds  
                vary between 4 and 6.  
                Properties: query, edit
        spread (Queryable[float]?): Random spread (0. 1), as a fraction of 90 degrees,  
                along specified direction.   Directional emitters only.  
                Properties: query, edit
        tangentSpeed (Queryable[float]?): Tangent speed multiple for point emission.  
                For each emitted particle, multiplies the component of the velocity  
                tangent to the surface  or curve by this amount.  
                Surface and curve emitters only.  
                Properties: query, edit
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        type (Queryable[str]?): Type of emitter. The choices are omni | dir | direction | surf |  
                surface | curve | curv. The default is omni.  
                The full definition of these types are: omnidirectional point emitter,  
                directional point emitter, surface emitter, or curve emitter.  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the emitter.  Volume offset translates  
                the emission volume by the specified amount from the actual  
                emitter location.  This is in the emitter's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the emitter.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which  
                particles are generated.  
                Values are: "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the emitter.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def enableDevice(*args: Any, query: bool = ..., apply: bool = ..., device: Queryable[str] = ..., enable: bool = ..., monitor: bool = ..., record: bool = ...) -> Union[bool, str]:
    """Sets (or queries) the device enable state for actions involving the device.Disabling a channel for applyTake cause applyTake to ignore
    the enable state of all "child" channels -- treating them as disabled.
    Args:
        apply (bool?): enable/disable "applyTake" for the specified channel(s)  
                Properties: create, query
        device (Queryable[str]?): specifies the device to change  
                Properties: create, query
        enable (bool?): enable (or disable) monitor/record/apply  
                Properties: create, query
        monitor (bool?): enables/disables visible update for the device (default)  
                Properties: create, query
        record (bool?): enable/disable "recordDevice" device recording  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def encodeString(*args: str) -> str:
    """This action will take a string and encode any character that
    would need to be escaped before being sent to some other
    command. Such characters include:
    Returns:
        str: Command result

    Example:
    """

def error(*args: str, noContext: bool = ..., showLineNumber: bool = ...) -> bool:
    """The error command is provided so that the user can issue
    error messages from his/her scripts and
    control execution in the event of runtime errors.The string argument is displayed in the command window
    (or stdout if running in batch mode) after
    being prefixed with an error message heading and
    surrounded by //.The error command also causes execution to terminate with an error.
    Using error is like raising an exception because the error will
    propagate up through the call chain. You can use catch to
    handle the error from the caller side. If you don't want
    execution to end, then you probably want to use the warning
    command instead.debug, information, echo
    Args:
        noContext (bool?): Do not include the context information with the error message.  
                Properties: create
        showLineNumber (bool?): Obsolete. Will be deleted in the next version of Maya. Use the checkbox in the  
                script editor that enables line number display instead.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def eval(arg0: str = ..., /) -> Any:
    """This function takes a string which contains MEL code and evaluates it
    using the MEL interpreter. The result is converted into a Python data type
    and is returned. If an error occurs during the execution of the MEL
    script, a Python exception is raised with the appropriate error message.
    Returns:
        Any: depending on input.

    Example:
    """

def evalContinue(arg0: str = ..., /) -> None: ...
def evalDeferred(arg0: Callable[..., Any] = ..., /, *, evaluateNext: bool = ..., list: bool = ..., lowPriority: bool = ..., lowestPriority: bool = ...) -> List[str]:
    """This command takes the string it is given and evaluates it
    during the next available idle time.  It is useful for attaching
    commands to controls that can change or delete the control.
    Args:
        evaluateNext (bool?): Specified that the command to be executed should be ran with the  
                highest priority, ideally queued up next.  
                Properties: create
        list (bool?): Return a list of the command strings that are currently pending on  
                the idle queue. By default, it will return the list of commands for all  
                priorities. The -lowestPriority and -lowPriority can be used to  
                restrict the list of commands to a given priority level.  
                Properties: create
        lowPriority (bool?): Specified that the command to be executed should be deferred with the  
                low priority. That is, it will be executed whenever Maya is idle.  
                Properties: create
        lowestPriority (bool?): Specified that the command to be executed should be deferred with the  
                lowest priority. That is, it will be executed when no other idle  
                events are scheduled.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def evalEcho() -> None: ...
def evalNoSelectNotify() -> None: ...
def evaluationManager(*args: str, query: bool = ..., cycleCluster: Queryable[str] = ..., disableInfo: Queryable[str] = ..., empty: bool = ..., enabled: bool = ..., fallbackTriggered: bool = ..., idleAction: Queryable[int] = ..., idleBuild: bool = ..., invalidate: bool = ..., manipulation: bool = ..., manipulationPrevalidation: bool = ..., manipulationReady: bool = ..., mode: Queryable[str] = ..., downstreamFrom: str = ..., nodeTypeGloballySerialize: bool = ..., nodeTypeParallel: bool = ..., nodeTypeSerialize: bool = ..., nodeTypeUntrusted: bool = ..., upstreamFrom: str = ..., reduceGraphRebuild: bool = ..., safeMode: bool = ...) -> Union[List[str], bool, int, List[bool], str]:
    """Handles turning on and off the evaluation manager method of evaluating the DG.
    Query the 'mode' flag to see all available evaluation modes. The special mode
    'off' disables the evaluation manager.
    The scheduling override flags 'nodeTypeXXX' force certain node types to use
    specific scheduling types, even though the node descriptions might indicate
    otherwise. Use with caution; certain nodes may not react well to
    alternative scheduling types.
    Only one scheduling type override will be in force at a time, the most
    restrictive one. In order, they are untrusted, globally serialized, locally
    serialized, and parallel. The node types will however remember all overrides.
    For example, if you set a node type override to be untrusted, then to be
    parallel it will continue to use the untrusted override. If you then turn off
    the untrusted override, the scheduling will advance to the parallel one.
    The actual node scheduling type is always superceded by the overrides. For example, a
    serial node will still be considered as parallel if the node type has the
    parallel override set, even though 'serial' is a more restrictive scheduling type.
    See the 'dbpeek' command 'graph' operation with arguments 'evaluationGraph' and
    'scheduling' to see what scheduling type any particular node will end up using
    after the hierarchy of overrides and native scheduling types is applied.evaluation, manager, DG, runtime
    Args:
        cycleCluster (Queryable[str]?): Returns a list of nodes that are stored together with the given one in  
                a cycle cluster. The list will be empty when the evaluation mode is not  
                active or the node is not in a cycle.  
                Properties: create, query
        disableInfo (Queryable[str]?): Returns a list of strings that contain the reasons that the evaluation manager has  
                been disabled (as distinct from it being deliberately turned off, e.g. because an  
                unsupported node type or attribute value was encountered).  
                If the list is empty then the evaluation manager is operating normally.  
                Properties: query
        empty (bool?): Valid in query mode only. Checks to see if the evaluation graph has any nodes in it.  
                This is independent of the current mode.  
                Properties: query
        enabled (bool?): Valid in query mode only. Checks to see if the evaluation manager is currently enabled.  
                This is independent of the current mode.  
                Properties: query
        fallbackTriggered (bool?): Valid in query mode only. Checks to see if fallback serial evaluation has been triggered.  
                Will be true if errors during parallel execution have forced a fallback to serial mode.  
                Will reset to false if the mode is changed again after the fallback was triggered.  
                Properties: query
        idleAction (Queryable[int]?): This flag sets the actions EM will perform on idle. It accepts the following values:  
              
                0. No action  
                1. Graph Rebuild  
                2. EM Manipulation Preparation  
                3. Graph Rebuild and EM Manipulation Preparation  
              
              
                Where:  
              
                Graph Rebuild will rebuild the evaluation graph on an idle event as soon  
                as it is able to do so.  
                EM ManipulationPreparation will get the evaluation manager to perform all  
                the steps necessary for EM manipulation to be available after the next idle event.  
              
              
                Note: These idle actions only apply to the graph attached to the normal context.  
                All other graphs will be built according to their own rules.  
              
                The disadvantage of enabling idle actions is that for some workflows that are  
                changing the graph frequently, or very large graphs, the graph build and  
                manipulation preparation time may impact the workflow. If workflows are impacted  
                it is suggested to turn idle actions off by passing this flag a value of 0.  
                Properties: create, query
        idleBuild (bool?): This flag is obsolete. Please use the -idleAction flag with a value of 1  
                in order to activate evaluation graph rebuild on idle.  
                Properties: create, query
        invalidate (bool?): This flag invalidates the graph. Value is used to control auto rebuilding on idle (false) or forced (true).  
                This command should be used as a last resort.  
                In query mode it checks to see if the graph is valid.  
                Properties: create, query
        manipulation (bool?): This flag is used to activate evaluation manager manipulation support.  
                Properties: create, query
        manipulationPrevalidation (bool?): This flag is used to activate evaluation manager manipulation prevalidation.  
                Prevalidation checks for known patterns in manipulation.  In case of a  
                successful prevalidation, there is no need to use dirty propagation in the  
                first frame of manipulation to validate that EM manipulation can safely be used,  
                and fast manipulation can start right away.  
                Properties: create, query
        manipulationReady (bool?): Valid in query mode only. Checks to see if the evaluation manager manipulation is currently ready/allowed.  
                This is independent of the current mode.  
                Properties: query
        mode (Queryable[str]?): Changes the current evaluation mode in the evaluation manager. Supported values are  
                "off", "serial" and "parallel".  
                Properties: create, query
        downstreamFrom (str?): Find the DG nodes that are immediately downstream of the named one in  
                the evaluation graph. Note that the connectivity is via evaluation mode  
                connections, not DG connections.  
                In query mode the graph is walked and any nodes downstream of the named  
                one are returned. The return type is alternating pairs of values that  
                represent the graph level and the node name, e.g. if you walk downstream  
                from A in the graph A -> B -> C then the return will be the array of  
                strings ("0","A","1","B","2","C"). Scripts can deconstruct this  
                information into something more visually recognizable. Note that cycles  
                are likely to be present so any such scripts would have to handle them.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        nodeTypeGloballySerialize (bool?): This flag is used only when the evaluation manager is in "parallel" mode  
                but can be set at anytime. It activates or deactivates the override to force  
                global serial scheduling for the class name argument(s) in the evaluation manager.  
                Legal object values are class type names: e.g. "transform", "skinCluster", "mesh".  
                When queried without specified nodes, it returns the list of nodes with the  
                global serial scheduling override active.  
                Scheduling overrides take precedence over all of the node and node type  
                scheduling rules. Use with caution; certain nodes may not react well to  
                alternative scheduling types.  
                Properties: create, query
        nodeTypeParallel (bool?): This flag is used only when the evaluation manager is in "parallel" mode  
                but can be set at anytime. It activates or deactivates the override to force  
                parallel scheduling for the class name argument(s) in the evaluation manager.  
                Legal object values are class type names: e.g. "transform", "skinCluster", "mesh".  
                When queried without specified nodes, it returns the list of nodes with the  
                parallel scheduling override active.  
                Scheduling overrides take precedence over all of the node and node type  
                scheduling rules. Use with caution; certain nodes may not react well to  
                alternative scheduling types.  
                Properties: create, query
        nodeTypeSerialize (bool?): This flag is used only when the evaluation manager is in "parallel" mode  
                but can be set at anytime. It activates or deactivates the override to force  
                local serial scheduling for the class name argument(s) in the evaluation manager.  
                Legal object values are class type names: e.g. "transform", "skinCluster", "mesh".  
                When queried without specified nodes, it returns the list of nodes with the  
                local serial scheduling override active.  
                Scheduling overrides take precedence over all of the node and node type  
                scheduling rules. Use with caution; certain nodes may not react well to  
                alternative scheduling types.  
                Properties: create, query
        nodeTypeUntrusted (bool?): This flag is used only when the evaluation manager is in "parallel" mode  
                but can be set at anytime. It activates or deactivates the override to force  
                untrusted scheduling for the class name argument(s) in the evaluation manager.  
                Legal object values are class type names: e.g. "transform", "skinCluster", "mesh".  
                When queried without specified nodes, it returns the list of nodes with the  
                untrusted scheduling override active.  
                Scheduling overrides take precedence over all of the node and node type  
                scheduling rules. Use with caution; certain nodes may not react well to  
                alternative scheduling types.  
                Untrusted scheduling will allow nodes to be evaluated in a critical section,  
                separately from any other node evaluation. It should be used only as a last resort  
                since the lost parallelism caused by untrusted nodes can greatly reduce performance.  
                Properties: create, query
        upstreamFrom (str?): Find the DG nodes that are immediately upstream of the named one in  
                the evaluation graph. Note that the connectivity is via evaluation mode  
                connections, not DG connections.  
                In query mode the graph is walked and any nodes upstream of the named  
                one are returned. The return type is alternating pairs of values that  
                represent the graph level and the node name, e.g. if you walk upstream  
                from C in the graph A -> B -> C then the return will be the array of  
                strings ("0","C","1","B","2","A"). Scripts can deconstruct this  
                information into something more visually recognizable. Note that cycles  
                are likely to be present so any such scripts would have to handle them.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        reduceGraphRebuild (bool?): This flag is used to activate evaluation manager mode to minimize rebuild when animated node are connected to EM prepopulated plug.  
                Properties: create, query
        safeMode (bool?): This flag activates/deactivates parallel evaluation safe mode. When  
                enabled, parallel execution will fall back to serial when evaluation  
                graph is missing dependencies. Detection is happening on scheduling  
                of parallel evaluation, which means potential fallback will happen at  
                the next evaluation.  
                WARNING: This mode should be disabled with extreme caution. It will  
                prevent parallel mode from falling back to serial mode when an invalid  
                evaluation is detected. Sometimes the evaluation will still work  
                correctly in those situations and use of this flag will keep the peak  
                parallel performance running. However since the safe mode is used to  
                catch invalid evaluation disabling it may also cause problems with  
                evaluation, anything from invalid values, missing evaluation, or even  
                crashes.  
                Properties: create, query

    Returns:
        List[str]: The names of all evaluation manager modes (querying without flags)
        List[str]: The names of all nodes involved in a cycle cluster with the selected one.
        bool: The success of activating of deactivating manipulation (with the 'manipulation' flag)
        bool: The manipulation active or inactive state (querying the 'manipulation' flag)
        bool: The manipulation prevalidation active or inactive state (querying the 'manipulationPrevalidation' flag)
        bool: The manipulation allowed or disallowed state (querying the 'manipulationReady' flag)
        bool: The success of setting the evaluation manager mode (with the 'mode' flag)
        bool: The success of setting the evaluation manager idle action (with the 'idleAction' flag)
        bool: False if there are any nodes in the evaluation graph (with the 'empty' flag)
        int: The Evaluation Manager idle action (querying with the 'idleAction' flag)
        bool: Is the evaluation graph currently valid? (querying with the 'invalidate' flag)
        bool: The success of setting the node type parallel scheduling mode (with the 'nodeTypeParallel' flag)
        List[bool]: The parallel scheduling states of specified node types (querying the 'nodeTypeParallel' flag with object(s))
        List[str]: The names of all node types in parallel scheduling mode (querying the 'nodeTypeParallel' flag alone)
        bool: The success of setting the node type serialized mode (with the 'nodeTypeSerialize' flag)
        List[bool]: The serialized states of specified node types (querying the 'nodeTypeSerialize' flag with object(s))
        List[str]: The names of all node types in serial scheduling mode (querying the 'nodeTypeSerialize' flag alone)
        bool: The success of setting the node type globally serialized mode (with the 'nodeTypeGloballySerialize' flag)
        List[bool]: The globally serialized states of specified node types (querying the 'nodeTypeGloballySerialize' flag with object(s))
        List[str]: The names of all node types in globally serialized scheduling mode (querying the 'nodeTypeGloballySerialize' flag alone)
        bool: The success of setting the node type untrusted mode (with the 'nodeTypeUntrusted' flag)
        List[bool]: The untrusted of specified node types (querying the 'nodeTypeUntrusted' flag with object(s))
        List[str]: The names of all node types in untrusted scheduling mode (querying the 'nodeTypeUntrusted' flag alone)
        str: The evaluation manager mode (querying with the 'mode' flag)
        List[str]: The names of all nodes immediately downstream/upstream of the named one(s) (with the 'upstreamFrom' or 'downstreamFrom' flags)
        List[str]: The list of reasons the evaluation manager has been disabled (querying the 'disableInfo' flag)
        bool: The state of fallback serial evaluation (querying the 'fallbackTriggered' flag)
        bool: The state of reduceGraphRebuild Support (querying the 'reduceGraphRebuild ' flag)

    Example:
    """

def evaluationManagerInternal(*args: str, query: bool = ..., dataSharing: bool = ..., dataTypeShare: bool = ...) -> None: ...
def evaluator(*args: str, query: bool = ..., clusters: bool = ..., configuration: Queryable[Multiuse[str]] = ..., enable: bool = ..., info: bool = ..., name: Queryable[str] = ..., nodeType: Queryable[Multiuse[str]] = ..., nodeTypeChildren: bool = ..., priority: Queryable[int] = ..., valueName: Queryable[str] = ...) -> Union[List[str], bool, str, int, Multiuse[str]]:
    """Handles turning on and off custom evaluation overrides used by the evaluation
    manager.
    Query no flag to see all available custom evaluators.
    Query the 'enable' flag to check if an evaluator is currently enabled.
    If the 'name' flag isn't used then return all modes and their current
    active state.evaluation, manager, DG, runtime
    Args:
        clusters (bool?): This flag queries the list of clusters currently assigned to the named custom evaluator.  
                The return value will be an array of strings where the array consists of a  
                set of (number, string[]) groups. e.g. If an evaluator has 2 clusters with  
                2 and 3 nodes in them respectively the output would be something like:  
                (2, 'transform2', 'transform3', 3, 'joint1', 'joint2', 'joint3')  
                Properties: query
        configuration (Queryable[Multiuse[str]]?): Sends configuration information to a custom evaluator. It's up to the evaluator  
                to understand what they mean.  
                Multiple configuration messages can be sent in a single command.  
                Query this flag for a given evaluator to find out what configuration  
                messages it accepts.  
                Properties: create, query, multiuse
        enable (bool?): Enables or disables a specific graph evaluation runtime, depending on the  
                state of the flag.  In order to use this flag you must also specify the  
                name in the 'name' argument.  
                When the 'enable' flag is used in conjunction with the 'nodeType' flag then  
                it is used to selectively turn on or off the ability of the given evaluator  
                to handle nodes of the given type (i.e. it no longer toggles the evaluator  
                enabled state).  
                When the 'enable' flag is used in conjunction with the 'configuration' flag then  
                it is passed along with the configuration message interpreted by the custom  
                evaluator.  
                Properties: create, query
        info (bool?): Queries the evaluator information. Only valid in query mode since the  
                information is generated by the evaluator's internal state and cannot be  
                changed.  
                In order to use this flag, the 'name' argument must also be specified.  
                Properties: query
        name (Queryable[str]?): Names a particular DG evaluation override evaluator. Evaluators are registered  
                automatically by name. Query this flag to get a list of available runtimes.  
                When a runtime is registered it is enabled by default. Use the 'enable'  
                flag to change its enabled state.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        nodeType (Queryable[Multiuse[str]]?): Names a particular node type to be passed to the evaluator request.  
                Evaluators can either use or ignore the node type information as passed.  
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        nodeTypeChildren (bool?): If enabled when using the 'nodeType' flag then handle all of the node types  
                derived from the given one as well. Default is to only handle the named  
                node type.  
                Properties: create, query
        priority (Queryable[int]?): Query or set the evaluator priority. Custom evaluator with highest priority  
                order will get the chance to claim the nodes first.  Evaluators must have  
                unique priority values.  
                In order to use this flag you must also specify the name in the 'name' argument.  
                Properties: create, query
        valueName (Queryable[str]?): Queries a value from a given evaluator.  Evaluators can define a set of  
                values for which they answer.  
                			In query mode, this flag can accept a value.  
                Properties: query

    Returns:
        List[str]: the list of available evaluators (querying with no evaluator flag or invalid evaluator name)
        bool: the previous active state of the named evaluator (with 'name' and 'enable' flags)
        bool: the active state of the named evaluator (query with 'name' and 'enable' flags)
        List[str]: the list of evaluators in the requested active state (query 'enable' flag alone)
        List[str]: the list of nodes for which the evaluator was activated or deactivated (with 'nodeType' or 'nodeTypeChildren' flags)
        str: the queried value for the evaluator (with 'name' and 'valueName' flags)
        bool: true if the configuration request was accepted by the evaluator (with 'name' flag and 'configuration' flag)
        List[str]: the list of configuration parameters accepted by the evaluator (query mode with 'name' flag and 'configuration' flag)
        List[str]: the list of clusters currently assigned to the evaluator with intervening sublist sizes (query mode with 'name' flag and 'clusters' flag)
        str: the help information supplied by the evaluator (query mode with 'name' flag and 'info' flag)
        int: the priority value of the evaluator (query mode with 'name' flag and 'priority' flag)

    Example:
    """

def evaluatorInternal(*args: str, query: bool = ..., name: str = ..., ready: bool = ...) -> None: ...
def event(*args: str, edit: bool = ..., query: bool = ..., count: Queryable[int] = ..., delete: bool = ..., dieAtCollision: bool = ..., emit: Queryable[int] = ..., list: bool = ..., name: Queryable[str] = ..., proc: Queryable[Callable[..., Any]] = ..., random: bool = ..., rename: Queryable[str] = ..., select: bool = ..., split: Queryable[int] = ..., spread: Queryable[float] = ..., target: Queryable[str] = ...) -> Union[str, int, bool, Callable[..., Any], float]:
    """The event command assigns collision events to a particle object.
    Collision events are stored in multi-attributes in the particle shape.
    The event command returns the event name.
    Args:
        count (Queryable[int]?): Collision number (for each particle) to which this event  
                applies. Zero (the default) indicates that it applies to all  
                collisions.  
                Properties: query, edit
        delete (bool?): Delete the specified event.  
                Properties: create
        dieAtCollision (bool?): Particle dies at the collision specified by "count."  
                If no count value is given, die at first collision.  
                Properties: query, edit
        emit (Queryable[int]?): Emit n additional particles into the assigned target object.  
                The original (colliding) particle survives as well, and remains  
                in its original object.  The new particles have age zero and mass  
                equal to the emitting particle. They use the velocity inheritance  
                parameter of the target object.  
                Properties: query, edit
        list (bool?): List all events for the chosen shape, like this:  
                event1Name event2Name ...  
                If no shape identified, list all events for all shapes, like this:  
                shape1Name event1Name shape2Name event2Name...  
                Returns a string array.  
                Properties: create
        name (Queryable[str]?): Assign a name to an event you are creating, or identify an  
                event you wish to edit, query, or delete. See examples.  
                Properties: create, query, edit
        proc (Queryable[Callable[..., Any]]?): Specify a MEL proc to be called each time the event occurs.  
                This must be a global proc with arguments as follows:  
                global proc procName( string obj, int id, string objHit );  
                Arguments passed in are the name of the particle object, the  
                id of the particle which collided, and the name of the object  
                collided with.  You can use particle -id -q to get values of  
                the particle's attributes.  
                Properties: create, query, edit
        random (bool?): Used with -split and -emit flags.  If -random is set true  
                and -split or -emit is set to n, then a random number of particles  
                uniformly distributed between 1 and n will be created at the event.  
                Properties: query, edit
        rename (Queryable[str]?): Assign a new name to an event you are editing. See examples.  
                Properties: query
        select (bool?): This flag is obsolete.  See the -name flag.
        split (Queryable[int]?): Colliding particle splits into specified number of  
                new particles. These new particles become part of the assigned  
                target object. If no target has been assigned, they become part of  
                the same object.  The new particles inherit the current age of  
                the particle that split.  They use the velocity inheritance  
                parameter of the target object.  If you set both emit and split,  
                the event will do both: first emit new particles, then split  
                the original one. This is a change from earlier versions where emit  
                and split were mutually exclusive.  
                Properties: query, edit
        spread (Queryable[float]?): Particles created at collision will spread out a random amount  
                from the rebound direction of the colliding particle.  The spread is  
                specified as a fraction (0. 1) of 90 degrees.  If spread is set at 0  
                (the default) all the new particles created may coincide.  
                Properties: query, edit
        target (Queryable[str]?): Target object for emitting or split particles. New particles  
                created through the -emit or -split flags join this object.  
                Properties: query, edit

    Returns:
        str: for creation; string array for list.

    Example:
    """

def exactWorldBoundingBox(*args: str, calculateExactly: bool = ..., ignoreInvisible: bool = ...) -> List[float]:
    """This command figures out an exact-fit bounding box for the
    specified objects (or selected objects if none are specified)
    This bounding box is always in world space.
    Args:
        calculateExactly (bool?): Should the bounding box calculation be exact?  
                Properties: create
        ignoreInvisible (bool?): Should the bounding box calculation include or exclude  
                invisible objects?  
                Properties: create

    Returns:
        List[float]: xmin, ymin, zmin, xmax, ymax, zmax.

    Example:
    """

def excludeObjectDisplayPreset() -> str:
    """This commands creates named presets of objects that can be used
    with the modelEditor command to exclude objects from beind displayed
    in a viewport.
    Returns:
        str: array

    Example:
    """

def exclusiveLightCheckBox(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: str = ..., light: str = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a checkBox that controls a light's exclusive
    non-exclusive status.  An exclusive light is one that is not
    hooked up to the default-light-list, thus it does not illuminate all
    objects be default.  However an exclusive light can be linked to
    an object.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (str?): Value of the checkbox label  
                Properties: create, edit
        light (str?): The light that is to be made exclusive/non-exclusive.  
                Properties: create
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full name to the control

    Example:
    """

def expandedSelection(*args: str, depth: int = ..., expansionType: str = ...) -> Union[str, List[str]]:
    """Examines the current selection list and returns that list, expanded to meet certain
    criteria. See the command flags for the exact criteria that will be used.select
    Args:
        depth (int?): Number of steps away from current selection to expand to.  
                A value of 0 will not expand the selection at all.  
                Properties: create
        expansionType (str?): The type of graph along which to expand the selection. Legal values are:  
                DG : Use the normal DG connections  
                EG : Use the evaluation graph connections  
                SG : Use the scheduling graph connections within the evaluation graph  
              
                If the actual selected node is not included in the graph being expanded on, e.g.  
                there is no evaluation node when using the EG type, then the selected node will not  
                appear in the output.  
                If this flag is not specified then the type defaults to DG.  
                Properties: create

    Returns:
        str: List of objects in the requested selection list expansion
        List[str]: List of nodes visited in the DG expansion
        List[str]: (Python only) List of single nodes and tuples visited in the EG or SG expansion, where tuples represent the DG nodes in a cluster

    Example:
    """

def exportEdits(*args: str, query: bool = ..., excludeHierarchy: bool = ..., excludeNode: Queryable[Multiuse[str]] = ..., exportSelected: bool = ..., force: bool = ..., includeAnimation: bool = ..., includeConstraints: bool = ..., includeDeformers: bool = ..., includeNetwork: bool = ..., includeNode: Queryable[Multiuse[str]] = ..., includeSetAttrs: bool = ..., includeSetDrivenKeys: bool = ..., includeShaders: bool = ..., selected: bool = ..., type: Queryable[str] = ..., editCommand: Queryable[Multiuse[str]] = ..., onReferenceNode: Queryable[Multiuse[str]] = ...) -> Union[List[str], bool, Multiuse[str], str]:
    """Use this command to export edits made in the scene to a file.
    The exported file can be subsequently imported to another scene.
    Edits may include: nodes, connections and reference edits such as value changes.
    The nodes that are included in the exported file will be based on the
    options used.
    At least one option flag that describes the set of target nodes to include in the
    exported file must be specified (e.g. 'selected', 'onReferenceNode').
    Use the inclusion flags ('includeAnimation', 'includeShaders', 'includeNetwork') to
    specify which additional related nodes will be added to the export list.
    In export mode, when the command completes successfully, the name of the exported file will
    be returned.
    In query mode, this command will return information about the contents of the exported
    file.
    The query mode will return the list of nodes that will be considered for
    inclusion in the exported file based on the specified flags.reference, export, node, import
    Args:
        excludeHierarchy (bool?): By default, all DAG parents and DAG history are written to the export file.  
                To prevent any DAG relations not otherwise connected to the target nodes to be  
                included, specify the -excludeHierarchy flag.  
                Properties: create, query
        excludeNode (Queryable[Multiuse[str]]?): Prevent the node from being included in the list of nodes being  
                exported. This flag is useful to exclude specific scene nodes that might  
                otherwise be exported. In the case where more than one Maya node has the  
                same name, the DAG path can be specified to uniquely identify the node.  
                Properties: create, query, multiuse
        exportSelected (bool?): The selected nodes and their connections to each other will be exported. Additionally,  
                any dangling connections to non-exported nodes will be exported.  
                Default nodes are ignored and never exported.  
                Note that when using the exportSelected flag, only selected nodes are exported, and  
                -include/-exclude flags such as -includeHierarchy are ignored.  
                Properties: create, query
        force (bool?): Force the export action to take place. This flag is required to overwrite an existing file.  
                Properties: create, query
        includeAnimation (bool?): Additionally include animation nodes and animation helper nodes associated with  
                the target nodes being exported.  
                Properties: create, query
        includeConstraints (bool?): Additionally include constraint-related nodes associated with the target nodes being exported.  
                Properties: create, query
        includeDeformers (bool?): Additionally include deformer networks associated with the target nodes being exported.  
                Properties: create, query
        includeNetwork (bool?): Additionally include the network of nodes connected to the target nodes being exported.  
                Properties: create, query
        includeNode (Queryable[Multiuse[str]]?): Additionally include the named node in the list of nodes being  
                exported. In the case where more than one Maya node has the  
                same name, the DAG path can be specified to uniquely identify the node.  
                Properties: create, query, multiuse
        includeSetAttrs (bool?): When using the -selected/-sel flag, if any of the selected nodes are referenced,  
                also include/exclude any setAttr edits on those nodes. If used with the -onReferenceNode/-orn  
                flag, include/exclude any setAttr edits on the reference.  
                Properties: create, query
        includeSetDrivenKeys (bool?): Additionally include setDrivenKey-related nodes associated with the target nodes being exported.  
                Properties: create, query
        includeShaders (bool?): Additionally include shaders associated with the target nodes being exported.  
                Properties: create, query
        selected (bool?): Export will operate on the list of nodes currently selected. This flag differs from the  
                exportSelected flag in that the selected nodes are not exported, only the edits on  
                them, and any nodes found via the include flags that are used (such as includeAnimation,  
                includeNetwork and so on).  
                Properties: create, query
        type (Queryable[str]?): Set the type of the exported file.  
                Valid values are "editMA" or "editMB".  
                Note that this command respects the global "defaultExtensions" setting  
                for file naming that is controlled with the file command defaultExtensions  
                option.  See the file command for more information.  
                Properties: create, query
        editCommand (Queryable[Multiuse[str]]?): This is a secondary flag used to indicate which type of reference edits should  
                be considered by the command.  
                If this flag is not specified all edit types will be included.  
                This flag requires a string parameter. Valid values are: "addAttr",  
                "connectAttr", "deleteAttr", "disconnectAttr", "parent", "setAttr",  
                "lock" and "unlock". In some contexts, this flag may be specified  
                more than once to specify multiple edit types to consider.  
                Properties: create, query, multiuse
        onReferenceNode (Queryable[Multiuse[str]]?): This is a secondary flag used to indicate that only those edits which are stored  
                on the indicated reference node should be considered. This flag only supports  
                multiple uses when specified with the "exportEdits" command.  
                Properties: create, query, multiuse

    Returns:
        List[str]: For query execution.

    Example:
    """

def expression(*args: str, edit: bool = ..., query: bool = ..., alwaysEvaluate: Queryable[int] = ..., animated: Queryable[int] = ..., attribute: Queryable[str] = ..., name: Queryable[str] = ..., object: Queryable[str] = ..., safe: bool = ..., shortNames: bool = ..., string: Queryable[str] = ..., timeDependent: bool = ..., unitConversion: Queryable[str] = ...) -> Union[str, int, bool]:
    """This command describes an expression that belongs to the current scene.
    The expression is a block of code of unlimited length with a C-like syntax that can perform
    conversions, mathematical operations, and logical decision making on
    any numeric attribute(s) in the scene.  One expression can read and
    alter any number of numeric attributes.  Theoretically, every expression
    in a scene can be combined into one long expression, but it is
    recommended that they are separated for ease of use and editing, as well
    as efficiency.If this command is being sent by the command line or in a script, then
    the user should be sure to embed escaped newlines (\\n), tabs (\\t) for
    clarity when reading them in the expression editor.  Also, quotes in an
    expression must be escaped (\\") so that they are not confused by the system
    as the end of your string.  When using the expression editor, these
    characters are escaped for you unless they are already within quotes.Note, expressions that alter or use per-particle attributes of a particle
    shape should use the '' command.
    Args:
        alwaysEvaluate (Queryable[int]?): If this is TRUE (the default), then the expression will be evaluated  
                whenever time changes regardless of whether the other inputs have  
                changed, and an output is requested.  If it is FALSE, then the expression  
                will only be evaluated if one or more of the inputs changes and an output is requested.  Note, if  
                'time' or 'frame' are inputs, then the expression will act as if this  
                was set to TRUE.  
                Properties: create, query, edit
        animated (Queryable[int]?): Sets the animation mode on the expression node:  
                0 = Not Animated,  
                1 = Animated,  
                2 = Animated with No Callback.  
                Properties: create, query, edit
        attribute (Queryable[str]?): Sets the name of the attribute to use for the expression  
                Properties: create, query, edit
        name (Queryable[str]?): Sets the name of the dependency graph node to use for the expression  
                Properties: create, query, edit
        object (Queryable[str]?): Sets the "default" object for the expression.  This allows the  
                expression writer to not type the object name for frequently-used  
                objects.  See the examples below.  
                Properties: create, query, edit
        safe (bool?): Returns true if no potential side effect can occurs running that expression.  
                Safe expression will be optimized to evaluate only when needed even if flagged alwaysEvaluate.  
                Properties: query
        shortNames (bool?): When used with the -q/query flag, tells the command to return the expression with attribute names as short as possible.  
                The default is to return the FULL attribute name, regardless of how the user entered  
                it into the expression, including the object names.  With this flag set, attribute names  
                are returned as their short versions, and any attribute that belongs to the default object,  
                if there is one specified, will not display the object's name.  
                Properties: create, query, edit
        string (Queryable[str]?): Set the expression string  
                Properties: create, query, edit
        timeDependent (bool?): Returns true if expression is evaluated when time change.  
                An expression can be time-dependent for the following reasons:  
                - The expression refers to 'time' or 'frame' keywords.  
                - The expression have side effects (unsafe).  
                - The expression node's "time" attribute is connected manually.  
                If the expression is safe and not time dependend, then they will always evaluate on depend, even if alwaysEvaluate is on.  
                Properties: query
        unitConversion (Queryable[str]?): Insert specified unit conversion nodes at creation: "all", "none,"  
                or "angularOnly." Default is "all."  For angularOnly, will insert unit  
                conversion nodes only for angular attributes (allowing degrees-to-radians  
                conversion).  This is for performance tuning.  
                If queried, returns the option used when the expression was created  
                or last edited.  
                Properties: query, edit

    Returns:
        str: The name of the expression

    Example:
    """

def expressionEditorListen(*, listenFile: str = ..., listenForAttr: str = ..., listenForExpression: str = ..., listenForName: str = ..., stopListenForAttr: str = ..., stopListenForExpression: str = ..., stopListenForName: str = ...) -> bool:
    """Listens for messages for the Expression Editor, at its request, and
    communicates them to it.  This action is for internal use only and
    should not be called by users.  This action should be called only
    by the Expression Editor.
    Args:
        listenFile (str?): Listen for changes to the file argument.  
                Properties: create
        listenForAttr (str?): Listen for changes to the attributes of the node argument.  
                Properties: create
        listenForExpression (str?): Listen for changes to the named expression  
                Properties: create
        listenForName (str?): Listen for name changes for the node argument.  
                Properties: create
        stopListenForAttr (str?): Stop listening for changes to the attributes of the  
                node argument.  
                Properties: create
        stopListenForExpression (str?): Stop listening for changes to the named expression  
                Properties: create
        stopListenForName (str?): Stop listening for name changes for the node argument.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def extendCurve(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., distance: Queryable[float] = ..., extendMethod: Queryable[int] = ..., extensionType: Queryable[int] = ..., inputPoint: Queryable[Tuple[float, float, float]] = ..., join: bool = ..., nodeState: Queryable[int] = ..., pointX: Queryable[float] = ..., pointY: Queryable[float] = ..., pointZ: Queryable[float] = ..., removeMultipleKnots: bool = ..., start: Queryable[int] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., noChanges: bool = ..., object: bool = ..., range: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, float, int, Tuple[float, float, float]]:
    """This command extends a curve or creates a new curve as an extension
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        distance (Queryable[float]?): The distance to extend  
                Used only for extendMethod is byDistance.  
                Default: 1  
                Properties: create, query, edit
        extendMethod (Queryable[int]?): The method with which to extend:  
                0. based on distance,  
                2. to a 3D point  
                Default: 0  
                Properties: create, query, edit
        extensionType (Queryable[int]?): The type of extension:  
                0. linear,  
                1. circular,  
                2. extrapolate  
                Default: 0  
                Properties: create, query, edit
        inputPoint (Queryable[Tuple[float, float, float]]?): The point to extend to (optional)  
                Properties: create, query, edit
        join (bool?): If true, join the extension to original curve  
                Default: true  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pointX (Queryable[float]?): X of the point to extend to  
                Default: 0  
                Properties: create, query, edit
        pointY (Queryable[float]?): Y of the point to extend to  
                Default: 0  
                Properties: create, query, edit
        pointZ (Queryable[float]?): Z of the point to extend to  
                Default: 0  
                Properties: create, query, edit
        removeMultipleKnots (bool?): If true remove multiple knots at join  
                Used only if join is true.  
                Default: false  
                Properties: create, query, edit
        start (Queryable[int]?): Which end of the curve to extend.  
                0. end,  
                1. start,  
                2. both  
                Default: 1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        noChanges (bool?): If set then the operation node will be automatically put into pass-through mode.  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def extendFluid(*args: str, edit: bool = ..., query: bool = ..., endD: int = ..., endH: int = ..., endW: int = ..., startD: int = ..., startH: int = ..., startW: int = ...) -> None: ...
def extendSurface(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., distance: Queryable[float] = ..., extendDirection: Queryable[int] = ..., extendMethod: Queryable[int] = ..., extendSide: Queryable[int] = ..., extensionType: Queryable[int] = ..., join: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, float, int]:
    """This command extends a surface or creates a new surface as an extension.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        distance (Queryable[float]?): The distance to extend (for by distance only)  
                Default: 1  
                Properties: create, query, edit
        extendDirection (Queryable[int]?): Which parametric direction of the surface to extend ( 0. U, 1. V, 2. both )  
                Default: 0  
                Properties: create, query, edit
        extendMethod (Queryable[int]?): The extend method (0. distance)  
                Default: 0  
                Properties: create, query, edit
        extendSide (Queryable[int]?): Which end of the surface to extend ( 0. end, 1. start, 2. both )  
                Default: 1  
                Properties: create, query, edit
        extensionType (Queryable[int]?): The type of extension (0. tangent, 2. extrapolate)  
                Default: 0  
                Properties: create, query, edit
        join (bool?): Join extension to original  
                Default: true  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def extrude(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., degreeAlongLength: Queryable[int] = ..., direction: Queryable[Tuple[float, float, float]] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., extrudeType: Queryable[int] = ..., fixedPath: bool = ..., length: Queryable[float] = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., reverseSurfaceIfPathReversed: bool = ..., rotation: Queryable[float] = ..., scale: Queryable[float] = ..., subCurveSubSurface: bool = ..., useComponentPivot: Queryable[int] = ..., useProfileNormal: bool = ..., constructionHistory: bool = ..., mergeItems: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., range: bool = ..., rebuild: bool = ...) -> Union[List[str], bool, int, Tuple[float, float, float], float]:
    """This command computes a surface given a profile curve and possibly
    a path curve. There are three ways to extrude a profile curve. The
    most basic method is called a "distance" extrude where direction and
    length are specified. No path curve is necessary in this case. The
    second method is called "flat" extrude. This method sweeps the profile
    curve down the path curve without changing the orientation of the
    profile curve. Finally, the third method is called "tube" extrude.
    This method sweeps a profile curve down a path curve while the
    profile curve rotates so that it maintains a relationship with the
    path curve.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degreeAlongLength (Queryable[int]?): Surface degree along the distance when a distance extrude is performed  
                Default: 1  
                Properties: create, query, edit
        direction (Queryable[Tuple[float, float, float]]?): The direction in which to extrude.  
                Use only for distance extrudeType and useProfileNormal off  
                Properties: create, query, edit
        directionX (Queryable[float]?): X of the direction  
                Default: 0  
                Properties: create, query, edit
        directionY (Queryable[float]?): Y of the direction  
                Default: 1  
                Properties: create, query, edit
        directionZ (Queryable[float]?): Z of the direction  
                Default: 0  
                Properties: create, query, edit
        extrudeType (Queryable[int]?): The extrude type (distance-0, flat-1, or tube-2)  
                Default: 2  
                Properties: create, query, edit
        fixedPath (bool?): If true, the resulting surface will be placed at the path curve.  
                Otherwise, the resulting surface will be placed at the profile curve.  
                Default: false  
                Properties: create, query, edit
        length (Queryable[float]?): The distance to extrude.  
                Use only for distance extrudeType  
                Default: 1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot point used for tube extrudeType  
                Properties: create, query, edit
        reverseSurfaceIfPathReversed (bool?): If true, extrude type is tube (2) and path has been internally reversed then computed surface is reversed in the direction corresponding to the path.  
                Default: false  
                Properties: create, query, edit
        rotation (Queryable[float]?): Amount to rotate the profile curve as it sweeps along the path curve.  
                Default: 0.0  
                Properties: create, query, edit
        scale (Queryable[float]?): Amount to scale the profile curve as it sweeps along the path curve.  
                Default: 1.0  
                Properties: create, query, edit
        subCurveSubSurface (bool?): If true, curve range on the path will get applied to the resulting surface instead of cut before the extrude.  
                Default: false  
                Properties: create, query, edit
        useComponentPivot (Queryable[int]?): Use closest endpoint of the path - 0, component pivot - 1 or the center of the bounding box of the profile - 2  
                Default: 0  
                Properties: create, query, edit
        useProfileNormal (bool?): If true, use the profile curve normal for the direction in which to extrude.  
                Use only for distance or tube extrudeType.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        mergeItems (bool?): Merge component results where possible. For example, instead of returning a[1] and a[2], return a[1. 2].  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        rebuild (bool?): Rebuild the input curve(s) before using them in the operation.  Use nurbsCurveRebuildPref to set the parameters for the conversion.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def falloffCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addControlVertex: str = ..., annotation: Queryable[str] = ..., asString: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., currentKey: Queryable[int] = ..., currentKeyValue: Queryable[Tuple[float, float]] = ..., customCurveWidget: bool = ..., defineTemplate: str = ..., deleteControlVertex: int = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., optionVar: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., readOnly: bool = ..., snapToGrid: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, Tuple[float, float], bool, Callable[..., Any]]:
    """This command creates a control for editing a 2D control
    curve. The control attaches to an optionVar used to store and
    retrieve the encoded control points stored in a string.
    Args:
        addControlVertex (str?): Used to add a control vertex for the curve.  
                Properties: edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        asString (Queryable[str]?): Used to query and set the value of the curve as a string of comma  
                separated values  
                Properties: query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Specifies a command to be executed whenever the value of this curve  
                is modified. This option should not be used when specifying an  
                optionVar.  
                Properties: edit
        currentKey (Queryable[int]?): Returns the index of the currently selected key.  
                Properties: create, query, edit
        currentKeyValue (Queryable[Tuple[float, float]]?): Get or set the value of the currently selected key.  
                Properties: query, edit
        customCurveWidget (bool?): Determines whether or not the curve widget is using a custom curve. When a custom curve is used, it is stored by a falloff curve in the brush tool settings, and the flag should be true.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteControlVertex (int?): Used to delete a control vertex of the curve.  
                Properties: edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        optionVar (Queryable[str]?): Specifies the name of the option var used to store and  
                retrieve the string value capturing the curve.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        readOnly (bool?): Specifies if the curve is read only or not. If true, the curve can't be edited.  
                Properties: create, query, edit
        snapToGrid (bool?): Specifies whether or not curve control points snap to grid when they are being moved.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the port created or modified

    Example:
    """

def falloffCurveAttr(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addControlVertex: str = ..., annotation: Queryable[str] = ..., asString: Queryable[str] = ..., attribute: str = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., currentKey: Queryable[int] = ..., currentKeyValue: Queryable[Tuple[float, float]] = ..., customCurveWidget: Queryable[int] = ..., defineTemplate: str = ..., deleteControlVertex: int = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., readOnly: Queryable[int] = ..., selectedPositionControl: str = ..., selectedValueControl: str = ..., snapToGrid: Queryable[int] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, Tuple[float, float], bool, Callable[..., Any]]:
    """This command creates a control for editing a 2D control
    curve. This control attaches to a curve attribute, which must be a multi attribute where each entry is a compound
    composed of:The MEL command AEaddCurveControl
    should be used to attach this control to an attribute in the attribute
    editor templates.
    Args:
        addControlVertex (str?): Used to add a control vertex for the curve.  
                Properties: edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        asString (Queryable[str]?): Used to query and set the value of the curve as a string of comma  
                separated values  
                Properties: query, edit
        attribute (str?): Specifies the name of the curve attribute to control.  
                Properties: create
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Specifies a command to be executed whenever the value of this curve  
                is modified.  
                Properties: edit
        currentKey (Queryable[int]?): Returns the index of the currently selected key.  
                Properties: create, query, edit
        currentKeyValue (Queryable[Tuple[float, float]]?): Get or set the value of the currently selected key.  
                Properties: query, edit
        customCurveWidget (Queryable[int]?): Determines whether or not the curve widget is using a custom curve. When a custom curve is used, it is stored by a falloff curve in the brush tool settings, and the flag should be non-zero.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteControlVertex (int?): Used to delete a control vertex of the curve.  
                Properties: edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        readOnly (Queryable[int]?): Specifies if the curve is read only or not. If true, the curve can't be edited.  
                Properties: create, query, edit
        selectedPositionControl (str?): Specifies the name of a float slider to edit the selected key position.  
                Properties: create, edit
        selectedValueControl (str?): Specifies the name of a float slider to edit the selected key value.  
                Properties: create, edit
        snapToGrid (Queryable[int]?): Specifies whether or not curve control points snap to grid when they are being moved.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the port created or modified

    Example:
    """

def fcheck(*args: str) -> bool:
    """Invokes the fcheck program to display images in a separate window.display, images
    Returns:
        bool:

    Example:
    """

def file(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., absoluteName: bool = ..., activate: bool = ..., activeProxy: bool = ..., add: bool = ..., anyModified: bool = ..., applyTo: str = ..., buildLoadSettings: bool = ..., channels: bool = ..., cleanReference: str = ..., command: Queryable[Tuple[str, str]] = ..., compress: bool = ..., constraints: bool = ..., constructionHistory: bool = ..., copyNumberList: bool = ..., defaultExtensions: bool = ..., defaultNamespace: bool = ..., deferReference: bool = ..., editCommand: str = ..., errorStatus: bool = ..., executeScriptNodes: bool = ..., exists: bool = ..., expandName: bool = ..., exportAll: bool = ..., exportAnim: bool = ..., exportAnimFromReference: bool = ..., exportAsReference: bool = ..., exportAsSegment: bool = ..., exportSelected: bool = ..., exportSelectedAnim: bool = ..., exportSelectedAnimFromReference: bool = ..., exportSelectedNoReference: bool = ..., exportSelectedStrict: bool = ..., exportSnapshotCallback: Tuple[Callable[..., Any], str] = ..., exportUnloadedReferences: bool = ..., expressions: bool = ..., fileMetaData: bool = ..., flushReference: str = ..., force: bool = ..., groupLocator: bool = ..., groupName: str = ..., groupReference: bool = ..., ignoreVersion: bool = ..., i: bool = ..., importFrameRate: bool = ..., importReference: bool = ..., importTimeRange: str = ..., lastFileOption: bool = ..., lastTempFile: bool = ..., list: bool = ..., loadAllDeferred: bool = ..., loadAllReferences: bool = ..., loadNoReferences: bool = ..., loadReference: Queryable[str] = ..., loadReferenceDepth: str = ..., loadReferencePreview: str = ..., loadSettings: str = ..., location: bool = ..., lockContainerUnpublished: bool = ..., lockFile: bool = ..., lockReference: bool = ..., mapPlaceHolderNamespace: Queryable[Multiuse[Tuple[str, str]]] = ..., mergeBaseAnimLayer: bool = ..., mergeNamespaceWithParent: bool = ..., mergeNamespaceWithRoot: bool = ..., mergeNamespacesOnClash: bool = ..., modified: bool = ..., moveSelected: bool = ..., namespace: str = ..., newFile: bool = ..., open: bool = ..., options: Queryable[str] = ..., parentNamespace: bool = ..., postSaveScript: str = ..., preSaveScript: str = ..., preserveName: bool = ..., preserveReferences: bool = ..., preview: bool = ..., prompt: bool = ..., proxyManager: str = ..., proxyTag: str = ..., reference: bool = ..., referenceDepthInfo: int = ..., referenceNode: Queryable[str] = ..., relativeNamespace: str = ..., removeDuplicateNetworks: bool = ..., removeReference: bool = ..., rename: str = ..., renameAll: bool = ..., renameToSave: bool = ..., renamingPrefix: Queryable[str] = ..., renamingPrefixList: bool = ..., replaceName: Queryable[Multiuse[Tuple[str, str]]] = ..., reserveNamespaces: bool = ..., resetError: bool = ..., returnNewNodes: bool = ..., save: bool = ..., saveDiskCache: Queryable[str] = ..., saveReference: bool = ..., saveReferencesUnloaded: bool = ..., saveTextures: Queryable[str] = ..., sceneName: bool = ..., segment: str = ..., selectAll: bool = ..., shader: bool = ..., sharedNodes: Multiuse[str] = ..., sharedReferenceFile: bool = ..., shortName: bool = ..., strict: bool = ..., swapNamespace: Multiuse[Tuple[str, str]] = ..., type: Queryable[str] = ..., uiConfiguration: bool = ..., uiLoadConfiguration: bool = ..., unloadReference: str = ..., unresolvedName: bool = ..., usingNamespaces: bool = ..., withoutCopyNumber: bool = ..., writable: bool = ...) -> Union[str, bool, Tuple[str, str], Multiuse[Tuple[str, str]]]:
    """This command needs a single main flag that specifies the action to take.
    Some of the main flags also take optional secondary flags to modify
    that action.This command needs a single main query flag that specifies the query to take
    and then optional secondary flags to modify that query.When querying a file name there are a number of ways to format the result:When a file is loaded into Maya (e.g., by opening or referencing it),
    the file path provided may not be complete. It could, for example, be
    a relative path (ex: "scenes/myScene.ma"), it could contain environment
    variables (ex: "$PRODUCTION_DIR/myScene.ma"), and it could even be a path
    which simply doesn't exist on the local disk. In each of these cases Maya
    goes through a number of steps to resolve the path and find the file on disk.
    By default the 'file' command will return the resolved file name (i.e., the
    location from which Maya is actually reading the file), but if theflag is used, the unresolved file (e.g., the one that
    was originally specified) will be returned. When providing a file path with
    an environment variable; for example, when using the -rename flag, the
    environment variable should be set to a relative path ( such as "/scenes/scenesSetA"; ).
    Providing a path using an environment variable that is set to an absolute path
    ( for example, "C:/scenes/" ) is not supported.By default the 'file' command will return the full
    path to a file, but if theflag is used just the
    file name will be returned.When the same file is loaded into Maya more
    than once (for example by referencing the same file twice), Maya
    distinguishes between the various copies by appending a copy number to the
    end of the file name. The first time the file is loaded, no copy number is
    appended. The second time the file is loaded a "{1}" is appended, the third
    time a "{2}" is used, and so on. By default the 'file' command will return
    the file name with the copy number appended, but if theflag is used the file name will be returned
    without the copy number.
    Args:
        absoluteName (bool?): This is a general flag which can be used to specify the desired format for  
                the namespace(s) returned by the command.  
                The absolute name of the namespace is a full namespace path, starting from the root namespace ":"  
                and including all parent namespaces.  For example ":ns:ball" is an absolute namespace  
                name while "ns:ball" is not.  
                Properties: create, query
        activate (bool?): This flag is obsolete.
        activeProxy (bool?): This flag is intended for internal use by Maya during file referencing.  
                It specifes which file is the active proxy when the file is loaded when  
                used with the reference flag. It is also used to specify which file is  
                the active proxy in the file referencing preload information when used  
                with the referenceDepthInfo flag.  
                Properties: create
        add (bool?): When used with selectAll it indicates that the specified items should be  
                added to the active list without removing existing  
                items from the active list.  
                Properties: create
        anyModified (bool?): This flag is obsolete. Please use file -q -modified instead.  
                Properties: query
        applyTo (str?): When importing or referencing an offline edit file, apply it to  
                to the given reference (i.e., determine what <main> gets mapped to).  
                Specify the reference node name as argument. To apply the edits to nodes in  
                the main scene (i.e., the root namespace), pass in ":".  
                To collapse <main> (i.e., map it to "None"), pass in "".  
                May only be used with the file -i/import or -r/reference flags.  
                Properties: create
        buildLoadSettings (bool?): When used with the "o/open" flag it indicates that the specified  
                file should be read for reference hierarchy information only.  
                This information will be stored in temporary load settings under  
                the name "implicitLoadSettings". When this flag is used the  
                specified scene file will not be loaded: no objects/nodes will be  
                created or modified.  
                Note: most users will not need to use this flag or the  
                "implicitLoadSettings" it builds. They can access the same  
                functionality by setting the "Selective Load" option in the  
                File > Open Option Box.  
                Properties: create
        channels (bool?): For use with exportSelected to specify whether attached channels should be included in the export.  
                Properties: create, query
        cleanReference (str?): Remove edits from the passed in reference node.  
                The reference must be in an unloaded state. To remove a particular  
                type of edit, use the editCommand flag. If no flag is specified,  
                all edits will be removed.  
                Properties: create
        command (Queryable[Tuple[str, str]]?): Specifies the callback to execute before any file operation.  
                This is an internal flag used only in the file format.  
                Properties: create, query
        compress (bool?): When used with save, it will compress (gzip) the file on output.  
                Properties: create
        constraints (bool?): For use with exportSelected to specify whether attached constraints should be included in the export.  
                Properties: create, query
        constructionHistory (bool?): For use with exportSelected to specify whether attached construction history should be included in the export.  
                Properties: create, query
        copyNumberList (bool?): When queried, this flag returns a string array containing  
                a number that uniquely identifies each instance the file  
                is used.  
                Properties: query
        defaultExtensions (bool?): Use the default extensions to rename the files. This defaults to true, but  
                is a persistent setting within a given session of Maya, meaning that if  
                you set it to true or false, that value will  
                continue to be used in subsequent file commands until a new value is set.  
                Properties: create, query
        defaultNamespace (bool?): Use the default name space for import and referencing.  This is  
                an advanced option.  If set, then on import or reference, Maya will  
                attempt to place all nodes from the imported or referenced file  
                directly into the root (default) name space, without invoking any  
                name clash resolution algorithms.  If the names of any of the new  
                objects    already exist in the root namespace, then errors will result.  
                The user of this flag is responsible for creating a name clash  
                resolution mechanism outside of Maya to avoid such errors.  
                Note: This flag    is intended only for use with custom file  
                translators written through    the API. Use at your own risk.  
                Properties: create
        deferReference (bool?): When used in conjunction with the -reference flag, this  
                flag determines if the reference is loaded, or if loading is  
                deferred.  
                C: The default is false.  
                Q: When queried, this flag returns true if the reference is deferred,  
                or false if the reference is not deferred. If this is used  
                with -rfn/referenceNode, the -rfn flag must come before -q.  
                Properties: create, query
        editCommand (str?): For use with cleanReference. Remove only this type of edit.  
                Supported edits are: setAttr addAttr deleteAttr connectAttr  
                disconnectAttr and parent  
                Properties: create
        errorStatus (bool?): Query the error status of the last file read. Returns true if and error occurred during the last file read.  
                Properties: query
        executeScriptNodes (bool?): If true, allow the appropriate script nodes to execute. If false,  
                do not allow any script node scripts to run.  
                For more information, see the documentation for script nodes.  
                Default: true.  
                Properties: create
        exists (bool?): Query if the file exists. Returns true if the file exists.  
                Properties: query
        expandName (bool?): This is a query only flag that can be used to query for the  
                file path name of the file.  
                Properties: query
        exportAll (bool?): Export everything into a single file.  
                Returns the name of the exported file.  
                Properties: create
        exportAnim (bool?): Export all animation nodes and animation helper nodes from all objects in the  
                scene.  
                The resulting animation export file will contain connections to objects that are  
                not included in the animation file. As a result, importing/referencing this file  
                back in will require objects of the same name to be present, else errors will occur.  
                The -sns/swapNamespace flag is available for swapping the namespaces of given objects  
                to another namespace. This use of namespaces can be used to re-purpose the animation  
                file to multiple targets using a consistent naming scheme.  
              
                The exportAnim flag will not export animation layers. For generalized file export of  
                animLayers and other types of nodes,  
                refer to the exportEdits command. Or  
                use the Export Layers functionality.  
                Properties: create
        exportAnimFromReference (bool?): Export the main scene animation nodes and animation helper nodes from all referenced  
                objects. This flag, when used in conjunction with the -rfn/referenceNode flag,  
                can be constrained to only export animation nodes from the specified reference  
                file. See -ean/exportAnim flag description for details on usage of animation files.  
                Properties: create
        exportAsReference (bool?): Export the selected objects into a reference file with the given  
                name. The file is saved on disk during the process.  
                Returns the name of the reference created.  
                Properties: create
        exportAsSegment (bool?): This flag is obsolete.
        exportSelected (bool?): Export the selected items into the specified file.  
                Returns the name of the exported file.  
                Properties: create
        exportSelectedAnim (bool?): Export all animation nodes and animation helper nodes from the selected objects  
                in the scene. See -ean/exportAnim flag description for details on usage of animation  
                files.  
                Properties: create
        exportSelectedAnimFromReference (bool?): Export the main scene animation nodes and animation helper nodes from the selected  
                referenced objects. This flag, when used in conjunction with the -rfn/referenceNode  
                flag, can be constrained to only export animation nodes from the selected nodes  
                of a specified reference file. See -ean/exportAnim flag description for details on  
                usage of animation files.  
                Properties: create
        exportSelectedNoReference (bool?): This flag is obsolete.
        exportSelectedStrict (bool?): Export the selected items into the specified file. This flag differs from exportSelected  
                in that it will only export the nodes that are explicitly on the selection list. Related  
                nodes (both history and DAG related) are not automatically exported unless those nodes  
                are also on the selection list. Node relationships are only preserved if both nodes in the  
                relationship (parent/child, source/destination) are exported.  
                It is important to note that there is potential for scene data loss in the exported  
                scene since not all related nodes are not exported by default. The user is responsible for  
                selecting all relevant nodes before exporting.  
                Returns the name of the exported file.  
                Properties: create
        exportSnapshotCallback (Tuple[Callable[..., Any], str]?): When specified alongside -ea/exportAll, es/exportSelected and -ess/exportSelectedStrict,  
                this flag enables Maya to temporarily duplicate the export targets into a specified  
                namespace and invoke a callback to interact with the duplicate export targets before  
                writing the duplicate export targets to disk. Once written to disk, the duplicate  
                export targets, new nodes created by the callback and temporary namespace are removed  
                from the scene. Implicitly created nodes (eg. persp, top, etc.) are not duplicated.  
              
                For the duration of the callback:  
                1. The specified namespace will be made current.  
                2. All nodes added by the callback are tracked as a temporary export target.  
                3. Although the intent of the callback is to only operate on the duplicate export  
                targets, there is nothing limiting the callback from modifying the main scene.  
                Thus, the callback should be written with care.  
              
                This flag accepts two arguments:  
                a. [string] Callback to invoke prior to write to disk.  
                b. [string] Temporary namespace to store duplicate export targets.  
              
                This flag can only be used in conjunction with -ea/exportAll, -es/exportSelected and  
                -ess/exportSelectedStrict.  
              
                Note that the -pv/preview flag still only previews the contents of the export targets  
                _prior_ to the snapshot duplication. It does not preview the final output after the  
                callback.  
              
                Referenced nodes are duplicated in the same manner as duplicating those nodes  
                manually in the scene. Similarly, scene assembly nodes will duplicate as they would  
                if manually duplicated, however scene assembly nodes have special duplication  
                behavior, so the callback should be aware of these differences when anticipating  
                the duplicate export targets.  
                Properties: create
        exportUnloadedReferences (bool?): Only effective when preserveReferences is used.  
                When used with the exportAll flag, tells the exporter to  
                include all unloaded references in the export.  
                When used with the exportSelected flag, tells the exporter to  
                include all unloaded proxy references that are related to  
                any node in the selection.  
                Properties: create
        expressions (bool?): For use with exportSelected to specify whether attached expressions should be included in the export.  
                Properties: create, query
        fileMetaData (bool?): This is a query only flag to get the file metadata for audio files. It returns the referenceTime. This field is only extracted from BWAVE files,  
                for other files it returns 0  
                Properties: query
        flushReference (str?): This flag will unload the reference file associated with the  
                passed reference node, retaining all associated reference nodes  
                and scene files. ** This option only works when using namespaces **.  
                More Details: This flag is primarily intended to be  
                used as part of a custom asset management system. It can be used to  
                defer loading of a reference which contains child references without  
                losing information about those child references. Prior to reloading a  
                flushed    reference which contains child references, the  
                'createNode reference' lines should be manually removed from the  
                children's Maya ASCII files. If this is not done, extra reference  
                nodes will be created.  
                Properties: create
        force (bool?): Force an action to take place.  
                (new, open, save, remove reference, unload reference)  
                Used with removeReference to force remove reference namespace even if it has contents.  
                Cannot be used with removeReference if the reference resides in the root namespace.  
                Used with unloadReference to force unload reference even if the reference node is locked,  
                without prompting a dialog that warns user about the lost of edits.  
                Properties: create
        groupLocator (bool?): Used only with the -r and the -gr flag.  
                Used to group the output of groupReference under a locator  
                Properties: create
        groupName (str?): Used only with the -gr flag.  
                Optionally used to set the name of the transform node that the imported/referenced  
                items will be grouped under.  
                Properties: create
        groupReference (bool?): Used only with the -r or the -i flag.  
                Used to group all the imported/referenced items under a single transform.  
                Properties: create
        ignoreVersion (bool?): Used to open files with versions other than those officially supported.  
                Success is not guaranteed. Data loss, data corruption or failure to open are all possible outcomes.  
                Can only be used with the -o and -i flags.  
                Properties: create
        i (bool?): Import the specified file.  
                Returns the name of the imported file.  
                Properties: create
        importFrameRate (bool?): Used only with the -i flag.  
                Used to import the frame rate and set it as Maya's frame rate.  
                Properties: create
        importReference (bool?): Remove the encapsulation of the reference around the data within  
                the specified file.    This makes the contents of the specified file  
                part of the current scene and all references to the original file  
                are lost.  
                Returns the name of the reference that was imported.  
                Properties: create
        importTimeRange (str?): Used only with the -i flag.  
                Used to import the time range and apply it to Maya's playback range in one  
                of three different ways as specified by the string.  The valid strings are  
                "keep", which keeps Maya's playback range untouched, "override", which overrides  
                Maya's playback range with the imported range, and "combine", which extends Maya's  
                playback range to encompass the imported range.  
                Properties: create
        lastFileOption (bool?): On query, returns the last option string used by the file command.  
                Properties: query
        lastTempFile (bool?): When queried, this flag returns the temp file name used during  
                file save. The temp file will be left in the same directory  
                as the intended file name if the save fails.  
                Properties: query
        list (bool?): List all files.  
                Returns a string array of the names of all segment/reference files.  
                Duplicates will be removed. So if a file is referenced more than  
                once, and the -withoutCopyNumber flag is set, it will only be listed once.  
                in the scene.  
                Properties: query
        loadAllDeferred (bool?): This flag is obsolete, and has been replaced by  
                the loadReferenceDepth flag. When used with the -open flag, determines  
                if the -deferReference flag is respected when reading in the file. If  
                true is passed, all of the references are loaded. If false is passed,  
                the -deferReference flag is respected.  
                Properties: create
        loadAllReferences (bool?): This flag is obsolete and has been replaced with the  
                loadReferenceDepth flag. When used with the -open flag,  
                this will cause all references to be loaded.  
                Properties: create
        loadNoReferences (bool?): This flag is obsolete and has been replaced witht the  
                loadReferenceDepth flag. When used with the -open flag,  
                no references will be loaded. When used with -i/import,  
                -r/reference or -lr/loadReference flags, will load the  
                top-most reference only.  
                Properties: create
        loadReference (Queryable[str]?): This flag loads a file and associates it with the passed reference  
                node. If the reference node does not exist, the command will fail. If  
                the file is already loaded, then this flag will reload the same file.  
                If a file is not given, the command will load (or reload) the last used  
                reference file.  
                Properties: create, query
        loadReferenceDepth (str?): Used to specify which references should be loaded. Valid types are  
                "all", "none" and "topOnly", which will load all references,  
                no references and top-level references only, respectively. May only be used  
                with the -o/open, -i/import, -r/reference or -lr/loadReference flags.  
                When "none"  
                is used with -lr/loadReference, only path validation is performed. This  
                can be used to replace a reference without triggering reload. Not using  
                loadReferenceDepth will load references in the same loaded or  
                unloaded state that they were in when the file was saved.  
                Additionally, the -lr/loadReference flag supports a fourth type, "asPrefs".  
                This will force any nested references to be loaded according to the  
                state (if any) stored in the current scene file, rather than according to the  
                state saved in the reference file itself.  
                Properties: create
        loadReferencePreview (str?): This flag will perform a special preview-only load of a reference file.  
                A preview-only reference file is not completely loaded, but instead is  
                partially loaded so that certain information, such as nested references  
                it contains, can be determined.  
                Nested references that are previewed remain in a special preview-only state.  
                Properties: create
        loadSettings (str?): When used with the "o/open" flag this flag specifies which reference  
                load settings should be used. Reference load settings specify which  
                references should be brought in loaded and which unloaded. Those  
                reference files that are brought in unloaded will usually not need  
                to be read and interpreted by Maya. This can potentially reduce the  
                time it takes Maya to load the whole scene.  
                If no "ls/loadSettings" flag is specified, or the empty string ("") is  
                used as the flag argument, the default load settings are used. The  
                default load settings represent the state of all references when the file  
                was last saved. The load settings "implicitLoadSettings" refer to the  
                temporary load settings generated by the "bls/buildLoadSettings" flag and  
                edited with the "loadSettings" command.  
                Currently on the default and implicit load settings are supported.  
                Properties: create
        location (bool?): Query the location of the given file name.  
                Properties: query
        lockContainerUnpublished (bool?): Set the unpublised lock state for all containers in this file. This will not lock  
                the attributes in the main scene directly, but any file that references this scene  
                will have all its containers come in as unpublished locked.  
                Properties: create
        lockFile (bool?): Lock or unlock the main scene. Any file referencing this scene will  
                automatically lock all attributes and nodes. Also prevents reference  
                edits from being saved to it from a parent file.  
                Properties: create
        lockReference (bool?): Locks attributes and nodes from the referenced file.  
                Properties: create
        mapPlaceHolderNamespace (Queryable[Multiuse[Tuple[str, str]]]?): Map a placeHolderNamespace to the given reference. Must be  
                used with the file -i/import, -r/reference flags in create mode.  
                The first string is the place holder namespace, including the angle  
                brackets (ex: "<foo>"). The second string is the reference node  
                whose namespace it should be mapped to (ex: "refRN"). If the namespace  
                should be mapped to the root namespace, use ":".  
                To collapse the namespace (i.e., map it to "None"), use "".  
                When queried, namespaces that are mapped to "None" will return "(None)" for clarity.  
                Properties: create, query, edit, multiuse
        mergeBaseAnimLayer (bool?): When set, Maya will merge the base animation layer imported from the file with  
                the base layer already existing in the scene.  
                Properties: create
        mergeNamespaceWithParent (bool?): Used with the removeReference flag.  
                When removing a file reference and its namespace, move the rest of the namespace  
                content to parent namespace.  
                Cannot be used if the reference resides in the root namespace.  
                Properties: create
        mergeNamespaceWithRoot (bool?): Used with the removeReference flag.  
                When removing a file reference and its namespace, move the rest of the namespace  
                content to root namespace.  
                Cannot be used if the reference resides in the root namespace.  
                Properties: create
        mergeNamespacesOnClash (bool?): Used with the import, reference or edit flags, this option will prevent new namespaces  
                from being created when namespaces of the same name already exist within Maya.  
                The default value is false.  
                For example, if an object "pSphere1", which is being imported, refers to the  
                namespace "ref" and there is already a namespace called "ref" defined in Maya.  
                If mergeNamespacesOnClash is true, the existing "ref" namespace will be reused  
                and pSphere1 will be moved into the existing namespace; and if the namespace has  
                another object which is also named "pSphere1", then the imported one will be  
                renamed with an incremental number("pSphere2"). On the other hand, if  
                mergeNamespacesOnClash is false, a new namespace will be created with an incremental  
                number (in first case is "ref1") and pSphere1 will be moved into the "ref1" namespace.  
                This flag also support nested namespace, for example, if an object "pSphere1" which is  
                imported and refers to namespace "ref:foo" and mergeNamespacesOnClash  
                is true this time, then the existing "ref:foo" will be reused and the object will be  
                moved into "ref:foo". Also if mergeNamespacesOnClash is false, then a new namespace  
                "ref:foo1" will be created and "pSphere1" will be moved into that new namespace.  
                Properties: create
        modified (bool?): Set the modified state of the entire scene. If the scene is modified  
                it will need to be saved before a new file is opened or created.  
                Normally there is no need to edit this flag as the state of the file  
                is updated automatically whenever an object is created or modified.  
                If editing of the state is desired, it is done without use of  
                the edit flag as covered in the example section below.  
                In query mode, if the scene has been modified 1 is returned. Otherwise 0  
                is returned.  
                Properties: create, query
        moveSelected (bool?): This flag is obsolete.  
                Properties: edit
        namespace (str?): The namespace name to use that will group all objects during  
                importing and referencing.  
                Change the namespace used to group all the objects from  
                the specified referenced file. The reference must have been created  
                with the "Using Namespaces" option, and must be loaded. Non-referenced  
                nodes contained in the existing namespace will also be moved to the new  
                namespace. The new namespace will be created by this command and can  
                not already exist. The old namespace will be removed.  
                Properties: edit
        newFile (bool?): Initialize the scene.  
                Returns untitled scene with default location.  
                Properties: create
        open (bool?): Open the specified file.  
                Returns the name of the opened file.  
                Properties: create
        options (Queryable[str]?): Set/query the currently set file options.  
                file options are used while saving a maya file.  
                Two file option flags supported in current file command are v and p.  
              
                v(verbose) indicates whether long or short attribute names and command flags names are used  
                when saving the file. Used by both maya ascii and maya binary file formats.  
                It only can be 0 or 1.  
                Setting v=1 indicates that long attribute names and command flag names will be used.  
                By default, or by setting v=0, short attribute names will be used.  
              
              
                p(precision) defines the maya file IO's precision when saving the file. Only used by maya ascii file format.  
                It is an integer value. The default value is 17.  
              
                The option format is "flag1=XXX;flag2=XXX".Maya uses the last v and p as the final result.  
                Note:  
                1. Use a semicolon(";") to separate several flags.  
                2. No blank space(" ") in option string.  
                Properties: create, query
        parentNamespace (bool?): Returns the name(s) of a referenced file's parent namespaces.  
                Properties: query
        postSaveScript (str?): When used with the save flag, the specified script will be executed  
                after the file is saved.  
                Properties: create
        preSaveScript (str?): When used with the save flag, the specified script will be executed  
                before the file is saved.  
                Properties: create
        preserveName (bool?): When used with compress, it will retain the regular extension rather than appending .gz.  
                Properties: create
        preserveReferences (bool?): Modifies the various import/export flags such that  
                references are imported/exported as actual references  
                rather than copies of those references.  
                Properties: create
        preview (bool?): Used in conjunction with any of the -exportXXX flags, causes Maya  
                to return a list of the nodes that would be exported, without  
                actually writing the exported file to disk.  
                Properties: create
        prompt (bool?): This flag controls the display of file prompting dialogs.  
                Some examples of file prompting dialogs include error  
                messages that require user confirmation and missing file  
                reference dialogs. Once this flag is used, every instance  
                of the file command will use the last set value of this flag.  
                Some interactive file operations may post dialogs even when  
                the flag is set to false, but every scripted file command  
                will not display any dialogs when this flag is set to  
                false.  The default value is true.  
                Properties: create, query
        proxyManager (str?): When a one or more proxy references are added to an existing file reference,  
                the proxy manage node is used to define the proxies associated with that  
                reference. This flag is used in conjunction with the activeProxy and proxyTag  
                flag to specify the proxyManager of interest. This flag is also used to  
                specify the proxyManager for a proxy reference in the file referencing  
                preload information, when used in conjunction with the referenceDepthInfo flag.  
                Properties: create
        proxyTag (str?): This flag is intended for internal use only during file load or preload.  
                Proxy tags are names you assign to proxy references to more easily  
                manage the proxy references from the reference editor. Proxy tags are  
                unique within a given proxy set.  
                This flag must be  used in conjunction with the proxyManager flag.  
                Properties: create
        reference (bool?): Create a reference to the specified file. Returns the  
                name of the file referenced.  
                Query all file references from the specified file.  
                Properties: query
        referenceDepthInfo (int?): This flag is used to store reference loading preferences  
                associated with a Maya ascii file (.ma). This flag is only useful  
                during file I/O so users should not have any need to use this flag.  
                Properties: create
        referenceNode (Queryable[str]?): This flag is only used during queries. In MEL, if it appears before -query  
                then it must be followed by the name of one of the scene's reference  
                nodes. That will determine the reference to be queried by whatever flags  
                appear after -query. If the named reference node does not exist within  
                the scene the command will fail with an error.  
              
                In Python the equivalent behavior is obtained by passing the name of the  
                reference node as the flag's value.  
              
                In MEL, if this flag appears after -query then it takes no argument and will  
                cause the command to return the name of the reference node associated with the  
                file given as the command's argument. If the file is not a reference or  
                for some reason does not have a reference node (e.g., the user deleted it)  
                then an empty string will be returned. If the file is not part of the  
                current scene then the command will fail with an error.  
              
                In Python the equivalent behavior is obtained by passing True as the flag's  
                value.  
                      In query mode, this flag can accept a value.  
                Properties: query
        relativeNamespace (str?): This flag can be used with the exportSelected, exportSelectedStrict and exportAll operations to specify  
                that the nodes in the exported file are to be written out relative to a specified  
                namespace. This provides the ability to remove undesired levels of namespacing from  
                the node names as they are exported. The relativeNamespace value specifies the  
                namespace to use as the relative root for the exported nodes, and must be specified  
                as an absolute namespace. Nodes in the exported file not residing within the specified  
                relative namespace will be written out using absolute namespace names.  
                Note: this flag cannot be used in conjunction with the preserveReferences flag.  
                Properties: create
        removeDuplicateNetworks (bool?): When set, Maya will remove imported networks if the same network is also  
                detected in the current scene. You can explicitly specify that certain types of  
                networks be exempted from removal by this flag. For example, if you set to the  
                optionVar removeDuplicateShadingNetworksOnImport to 0 (or disable the option  
                Remove Duplicate Shading Networks from the File > Import options), then shading  
                networks will be exempted from removal by this flag.This flag can only be used  
                in conjunction with the -i/import flag.  
                Properties: create
        removeReference (bool?): Remove the given file reference from its parent. This will also  
                Remove everything this file references.  
                Returns the name of the file removed.  
                If the reference is alone in its namespace, remove the namespace.  
                If there are objects remaining in the namespace after the file reference is removed,  
                by default, keep the remaining objects in the namespace.  
                To merge the objects remaining in the namespace to the parent or root  
                namespace, use flags mergeNamespaceWithParent  
                or mergeNamespaceWithRoot. The empty file reference namespace is then removed.  
                To forcibly delete all objects, use flag force. The empty file reference namespace is then removed.  
                Properties: create
        rename (str?): Rename the scene.  
                Used mostly during save to set the saveAs name.  
                Returns the new name of the scene.  
                Properties: create
        renameAll (bool?): If true, rename all newly-created  
                nodes, not just those whose names clash with existing nodes.  
                Only available with -i/import.  
                Properties: create
        renameToSave (bool?): If true, the scene will need to be renamed before it can be  
                saved. When queried this flag returns true if the scene must be  
                renamed before it can be saved.   
                The default is false.  
                Properties: create, query
        renamingPrefix (Queryable[str]?): The string to use as a prefix for all objects from this file.  
                This flag has been replaced by -ns/namespace.  
                Properties: create, query
        renamingPrefixList (bool?): This flag returns a list of all of the renaming prefixes used  
                by the file.  
                Properties: query
        replaceName (Queryable[Multiuse[Tuple[str, str]]]?): Define a search and replace string. Will apply search and replace to  
                leaf node names. The search string can include namespaces and wild-cards,  
                but will only apply to leaf nodes in a dag hierarchy. Intended for use  
                with offline edits files. May only be used with file -i/import  
                or -r/reference. If a nested reference also defines a substitution, it  
                will become the active substitution table while loading the nested reference.  
                Note: if used with the -e/edit flag, the replacement will only be applied  
                the next time the reference is loaded  
                Examples: -replace "*pCube1" "prop" will change "foo:pCube1" to  
                "foo:prop" and "|A:pCube1|B:pCube1" to "|A:pCube1|prop".  
                Properties: create, query, edit, multiuse
        reserveNamespaces (bool?): When this flag is enabled namespaces for unloaded references will be  
                created after loading the file to reduce the chances of unexpected  
                namespace collisions when loading or adding references later on.  
                Properties: create
        resetError (bool?): Turn off any pre-existing global file errors.  
                Properties: create
        returnNewNodes (bool?): Used to control the return value in open, import, loadReference,  
                and reference operations. It will force the file command to return  
                a list of new nodes added to the current scene.  
                Properties: create
        save (bool?): Save the specified file.  
                Returns the name of the saved file.  
                Properties: create
        saveDiskCache (Queryable[str]?): This flag sets the saveAs option for Jiggle disk caches.  
                The valid inputs are "always" - always copy a file texture to a  
                new location, "never" - do not copy at all.   
                C: The default is "always".   
                Q: When queried it returns a string ("always", "never").  
                Properties: create, query
        saveReference (bool?): Save reference node edits and connections to reference file.  
                This includes newly added history and animation, provided that  
                these do not apply to any objects outside the reference being saved.  
                Properties: create
        saveReferencesUnloaded (bool?): This flag can only be used in conjunction with the save flag. It specifies  
                that the saved file will be saved with all references unloaded.  
                Properties: create
        saveTextures (Queryable[str]?): This flag sets the saveAs option for 3d Paint file textures.  
                The valid inputs are "always" - always copy a file texture to a  
                new location, "unlessRef" - copy only if this is not a referenced  
                file texture, "never" - do not copy at all.   
                C: The default is "unlessRef".   
                Q: When queried it returns a string ("always", unlessRef", "never").  
                Properties: create, query
        sceneName (bool?): return the name of the current scene.  
                Properties: query
        segment (str?): This flag is obsolete.
        selectAll (bool?): Select all the components of this file as well as its child  
                files.  Note that the file specified must be one that is  
                already opened in this Maya session.  
                The default behavior is to replace the existing selection.  
                Use with the "add" flag to keep the active selection list.  
                Properties: create
        shader (bool?): For use with exportSelected to specify whether attached shaders should be included in the export.  
                Properties: create, query
        sharedNodes (Multiuse[str]?): This flag modifies the '-r/reference' flag to indicate that  
                certain    types of nodes within that reference should be treated as  
                shared nodes. All shared nodes will be placed in the default  
                namespace. New copies of those nodes will not be created if a copy  
                already exists in the default namespace, instead the shared node  
                will be merged with the    existing node. The specifics of what  
                happens when two nodes are merged depends on the node type. In  
                general attribute values will not be merged, meaning the values set  
                on any existing shared nodes will be retained, and the values of  
                the nodes being merged in will be ignored.  
                The valid options are "displayLayers", "shadingNetworks",  
                "renderLayersByName", and "renderLayersById". This flag is  
                multi-use; it may be specified multiple times to for  
                example, share both display layers and shading networks.  
                Two shading networks will only be merged if    they are identical:  
                the network    of nodes feeding into the shading group must be  
                arranged identically with equivalent nodes have the same name and  
                node type. Additionally if a network is animated or contains a DAG  
                object or expression it will not be mergeable.  
                This flag cannot be used in conjunction with -srf/sharedReferenceFile.  
                Properties: create, multiuse
        sharedReferenceFile (bool?): Can only be used in conjunction with the -r/reference flag and  
                the -ns/namespace flag (there is no prefix support). This flag modifies  
                the '-r/reference' flag to indicate that all nodes within that  
                reference should be treated as shared nodes. New copies    of  
                those nodes will not be created if a copy already exists. Instead,  
                the shared node will be merged with the existing node. The specifics of  
                what happens when two nodes are merged depends on the node type.  
                This flag cannot be used in conjunction with -shd/sharedNodes.  
                Properties: create
        shortName (bool?): When used with a main query flag it indicates that the file name  
                returned will be the short name (i.e., just a file name without  
                any directory paths). If this flag is not present, the full name  
                and directory path will be returned.  
                Properties: query
        strict (bool?): Set strict file path resolution. If true, all paths will be matched  
                exactly, both relative and absolute. Relative paths will be considered  
                relative to the project root directory. May only be used with the -o/open,  
                -i/import, -ir/importReference or -r/reference flags.  
                Properties: create
        swapNamespace (Multiuse[Tuple[str, str]]?): Can only be used in conjunction with the -r/reference or -i/import  
                flags. This flag will replace any occurrences of a given namespace to  
                an alternate specified namespace. This namespace "swap" will occur  
                as the file is referenced in. It takes in two string arguments. The  
                first argument specifies the namespace to replace. The second argument  
                specifies the replacement namespace. Use of this flag, implicitly  
                enables the use of namespaces and cannot be used with deferReference.  
                Properties: create, multiuse
        type (Queryable[str]?): Set the type of this file.  By default this can be any one of:  
                "mayaAscii", "mayaBinary", "mel",  "OBJ", "directory", "plug-in", "audio", "move", "EPS", "Adobe(R) Illustrator(R)", "image"  
                plug-ins may define their own types as well.  
                Return a string array of file types that match this file.  
                Properties: create, query
        uiConfiguration (bool?): Save the ui configuration with the scene in a uiConfiguration  
                script node. (eg. panes, etc.)  
                The current default is on and is set in initialStartup.mel.  
                Properties: create, query
        uiLoadConfiguration (bool?): Load the scene's ui configuration. (eg. panes, etc.)  
                The current default is on and is set in initialStartup.mel.  
                Properties: create, query
        unloadReference (str?): This flag will unload the reference file associated with the  
                passed reference node.  
                Properties: create
        unresolvedName (bool?): When used with a main query flag it indicates that the file name  
                returned will be unresolved (i.e., it will be the path originally  
                specified when the file was loaded into Maya; this path may  
                contain environment variables and may not exist on disk). If this  
                flag is not present, the resolved name will be returned.  
                Properties: query
        usingNamespaces (bool?): Returns boolean.  
                Queries whether the specified reference file uses namespaces  
                or renaming prefixes.  
                Properties: query
        withoutCopyNumber (bool?): When used with a main query flag it indicates that the file name  
                returned will not have a copy number appended to the end. If this  
                flag is not present, the file name returned may have a copy number  
                appended to the end.  
                Properties: query
        writable (bool?): Query whether the given file is writable in the current scene. For  
                main scene files this indicates writable to the file system by the  
                current user. Files referenced by the main scene file are always not  
                writable (referenced files are by nature read only). Files not present  
                in the current scene always return false.  
                Properties: query

    Returns:
        str: The name of the specified file for most actions. When the returnNewNodes flag is used, an array of strings will be returned indicating the names of the nodes that were read.

    Example:
    """

def fileBrowserDialog(*, actionName: str = ..., dialogStyle: int = ..., fileCommand: Callable[..., Any] = ..., fileType: str = ..., filterList: Multiuse[str] = ..., includeName: str = ..., mode: int = ..., operationMode: str = ..., tipMessage: str = ..., windowTitle: str = ...) -> str:
    """The fileBrowserDialog and fileDialog commands have now been deprecated.
    Both commands are still callable, but it is recommended that the fileDialog2 command
    be used instead.  To maintain some backwards compatibility, both fileBrowserDialog and
    fileDialog will convert the flags/values passed to them into the appropriate flags/values
    that the fileDialog2 command uses and will call that command internally.  It is not
    guaranteed that this compatibility will be able to be maintained in future versions so
    any new scripts that are written should use fileDialog2.See below for an example of how to change a script to use fileDialog2.
    Args:
        actionName (str?): Script to be called when the file is validated.  
                Properties: create
        dialogStyle (int?): 0 for old style dialog  
                1 for Windows 2000 style Explorer style  
                2 for Explorer style with "Shortcut" tip at bottom  
                Properties: create
        fileCommand (Callable[..., Any]?): The script to run on command action  
                Properties: create
        fileType (str?): Set the type of file to filter.  By default this can be any one of:  
                "mayaAscii", "mayaBinary", "mel", "OBJ", "directory", "plug-in", "audio", "move", "EPS", "Illustrator", "image".  
                plug-ins may define their own types as well.  
                Properties: create
        filterList (Multiuse[str]?): Specify file filters. Used with dialog style  
                1 and 2. Each string should be a description followed by a  
                comma followed by a semi-colon separated list of file  
                extensions with wildcard.  
                Properties: create, multiuse
        includeName (str?): Include the given string after the actionName in parentheses.  
                If the name is too long, it will be shortened to fit on the  
                dialog (for example, /usr/alias/commands/scripts/fileBrowser.mel  
                might be shortened to /usr/...pts/fileBrowser.mel)  
                Properties: create
        mode (int?): Defines the mode in which to run the file brower:  
              
                0 for read  
                1 for write  
                2 for write without paths (segmented files)  
                4 for directories have meaning when used with the action  
              
                +100 for returning short names  
                Properties: create
        operationMode (str?): Enables the option dialog. Valid strings are:  
              
                "Import"  
                "Reference"  
                "SaveAs"  
                "ExportAll"  
                "ExportActive"  
                Properties: create
        tipMessage (str?): Message to be displayed at the bottom of the style 2 dialog box.  
                Properties: create
        windowTitle (str?): Set the window title of a style 1 or 2 dialog box  
                Properties: create

    Returns:
        str: Dialog name

    Example:
    """

def fileDialog(*, application: bool = ..., defaultFileName: str = ..., directoryMask: str = ..., mode: int = ..., title: str = ...) -> str:
    """The fileBrowserDialog and fileDialog commands have now been deprecated.
    Both commands are still callable, but it is recommended that the fileDialog2 command
    be used instead.  To maintain some backwards compatibility, both fileBrowserDialog and
    fileDialog will convert the flags/values passed to them into the appropriate flags/values
    that the fileDialog2 command uses and will call that command internally.  It is not
    guaranteed that this compatibility will be able to be maintained in future versions so
    any new scripts that are written should use fileDialog2.See below for an example of how to change a script to use fileDialog2.
    Args:
        application (bool?): This is a "Mac" only flag. This brings up the dialog which  
                selects only the application bundle.  
                Properties: create
        defaultFileName (str?): Set default file name. This flag is available under "write" mode  
                Properties: create
        directoryMask (str?): This can be used to specify what directory and file names  
                will be displayed in the dialog.  If not specified, the  
                current directory will be used, with all files displayed.  
                The string may contain a path name, and must contain a  
                wild-carded file specifier. (eg "*.cc" or "/usr/u/*") If  
                just a path is specified, then the last directory in the  
                path is taken to be a file specifier, and this will not  
                produce the desired results.  
                Properties: create
        mode (int?): Defines the mode in which to run the file dialog:  
              
                0 for read  
                1 for write  
              
                Write mode can not be used in conjunction with the -application flag.  
                Properties: create
        title (str?): Set title text. The default value under "write" mode is "Save As". The default value under "read" mode is "Open".  
                Properties: create

    Returns:
        str: Name of dialog

    Example:
    """

def fileDialog2(*, buttonBoxOrientation: int = ..., cancelCaption: str = ..., caption: str = ..., dialogStyle: int = ..., fileFilter: str = ..., fileMode: int = ..., fileTypeChanged: Callable[..., Any] = ..., hideNameEdit: bool = ..., okCaption: str = ..., optionsUICancel: Callable[..., Any] = ..., optionsUICommit: Callable[..., Any] = ..., optionsUICommit2: Callable[..., Any] = ..., optionsUICreate: Callable[..., Any] = ..., optionsUIInit: Callable[..., Any] = ..., optionsUITitle: str = ..., returnFilter: bool = ..., selectFileFilter: str = ..., selectionChanged: Callable[..., Any] = ..., setProjectBtnEnabled: bool = ..., startingDirectory: str = ...) -> str:
    """This command provides a dialog that allows users to select files or directories.
    Args:
        buttonBoxOrientation (int?): 1 Vertical button box layout. Cancel button is below the accept button.   
                2 Horizontal button box layout. Cancel button is to the right of the accept button.  
                Properties: create
        cancelCaption (str?): If the dialogStyle flag is set to 2 then this provides a caption for the  
                Cancel button within the dialog.  
                Properties: create
        caption (str?): Provide a title for the dialog.  
                Properties: create
        dialogStyle (int?): 1 On Windows or Mac OS X will use a native style file dialog.  
                2 Use a custom file dialog with a style that is consistent across platforms.  
                Properties: create
        fileFilter (str?): Provide a list of file type filters to the dialog.  Multiple filters should be  
                separated by double semi-colons.  See the examples section.  
                Properties: create
        fileMode (int?): Indicate what the dialog is to return.  
              
                0 Any file, whether it exists or not.  
                1 A single existing file.  
                2 The name of a directory.  Both directories and files are displayed in the dialog.  
                3 The name of a directory.  Only directories are displayed in the dialog.  
                4 The names of one or more existing files.  
                Properties: create
        fileTypeChanged (Callable[..., Any]?): MEL only.  The string is interpreted as a MEL callback, to be called  
                when the user-selected file type changes.  The callback is of the form:  
              
                global proc MyCustomFileTypeChanged(string $parent, string $newType)  
              
                The parent argument is the parent layout into which controls have been  
                added using the optionsUICreate flag.  The newType argument is the new  
                file type.  
                Properties: create
        hideNameEdit (bool?): Hide name editing input field.  
                Properties: create
        okCaption (str?): If the dialogStyle flag is set to 2 then this provides a caption for the  
                OK, or Accept, button within the dialog.  
                Properties: create
        optionsUICancel (Callable[..., Any]?): MEL only.  The string is interpreted as a MEL callback, to be called  
                when the dialog is cancelled (with Cancel button or close button to close window).  
                The callback is of the form:  
              
                global proc MyCustomOptionsUICancel()  
                Properties: create
        optionsUICommit (Callable[..., Any]?): MEL only.  The string is interpreted as a MEL callback, to be called  
                when the dialog is successfully dismissed.  It will not be called if  
                the user cancels the dialog, or closes the window using window title  
                bar controls or other window system means.  The callback is of the form:  
              
                global proc MyCustomOptionsUICommit(string $parent)  
              
                The parent argument is the parent layout into which controls have been  
                added using the optionsUICreate flag.  
                Properties: create
        optionsUICommit2 (Callable[..., Any]?): MEL only.  As optionsUICommit, the given string is interpreted as a MEL  
                callback, to be called when the dialog is successfully dismissed. The  
                difference is that this callback takes one additional argument which is  
                the file name selected by the user before the dialog validation.  
                It will not be called if the user cancels the dialog, or closes the window using  
                window title bar controls or other window system means.  The callback is of the form:  
              
                global proc MyCustomOptionsUICommit(string $parent, string $selectedFile)  
              
                The parent argument is the parent layout into which controls have been  
                added using the optionsUICreate flag.  
                Properties: create
        optionsUICreate (Callable[..., Any]?): MEL only.  The string is interpreted as a MEL callback, to be called  
                on creation of the file dialog.  The callback is of the form:  
              
                global proc MyCustomOptionsUISetup(string $parent)  
              
                The parent argument is the parent layout into which controls can be  
                added.  This parent is the right-hand pane of the file dialog.  
                Properties: create
        optionsUIInit (Callable[..., Any]?): MEL only.  The string is interpreted as a MEL callback, to be called  
                just after file dialog creation, to initialize controls.  The callback is of  
                the form:  
              
                global proc MyCustomOptionsUIInitValues(string $parent, string $filterType)  
              
                The parent argument is the parent layout into which controls have been  
                added using the optionsUICreate flag.  The filterType argument is the  
                initial file filter.  
                Properties: create
        optionsUITitle (str?): MEL only. If optionsUICreate is set, user can set a custom title  
                to their option window using this flag. If no title is desired, an  
                empty string i.e. "" can be used.  
                Properties: create
        returnFilter (bool?): If true, the selected filter will be returned as the last item in the string array along  
                with the selected files.  
                Properties: create
        selectFileFilter (str?): Specify the initial file filter to select.  Specify just the begining text and not the full wildcard spec.  
                Properties: create
        selectionChanged (Callable[..., Any]?): MEL only.  The string is interpreted as a MEL callback, to be called  
                when the user changes the file selection in the file dialog.  The  
                callback is of the form:  
              
                global proc MyCustomSelectionChanged(string $parent, string $selection)  
              
                The parent argument is the parent layout into which controls have been  
                added using the optionsUICreate flag.  The selection argument is the  
                full path to the newly-selected file.  
                Properties: create
        setProjectBtnEnabled (bool?): Define whether the project button should be enabled  
                Properties: create
        startingDirectory (str?): Provide the starting directory for the dialog.  
                Properties: create

    Returns:
        str: array

    Example:
    """

def fileInfo(arg0: str = ..., arg1: str = ..., /, *, query: bool = ..., referenceNode: str = ..., remove: Queryable[str] = ...) -> Union[List[str], str]:
    """fileInfo provides a mechanism for keeping information related
    to a Maya scene file.
    Each invocation of the command consists of a keyword/value pair,
    where both the keyword and the associated value are strings.
    The command may be invoked multiple times with different keywords.
    Maya emits this command several times into each file it creates,
    primarily to provide details such as
    which productization or packaging of the program was used
    (e.g "Complete", "Unlimited"), the specific version and build identification
    that was run, and the operating system on which it was run.
    Maya may make use of this information when present in files it reads.
    All keyword/value pairs defined by use of the fileInfo command are
    preserved when Maya saves the scene, whether to an ASCII or binary file.file, version
    Args:
        referenceNode (str?): Specify the name of a referenceNode to indicate the scene file to query.  
                This flag is only valid during query.  
                			In query mode, this flag needs a value.  
                Properties: query
        remove (Queryable[str]?): If the remove flag is specified, the string following it is a keyword to  
                remove from the list of fileInfo to be saved with the scene file.  
                Properties: create, query

    Returns:
        List[str]: Command result

    Example:
    """

def filePathEditor(*args: str, query: bool = ..., attributeOnly: bool = ..., attributeType: Queryable[str] = ..., byType: str = ..., copyAndRepath: Tuple[str, str] = ..., deregisterType: str = ..., force: bool = ..., listDirectories: str = ..., listFiles: str = ..., listRegisteredTypes: bool = ..., preview: bool = ..., recursive: bool = ..., refresh: bool = ..., registerType: str = ..., relativeNames: bool = ..., repath: str = ..., replaceAll: bool = ..., replaceField: str = ..., replaceString: Tuple[str, str] = ..., status: bool = ..., temporary: bool = ..., typeLabel: str = ..., unresolved: bool = ..., withAttribute: bool = ...) -> Union[bool, str]:
    """Maya can reference and use external files, such as textures or other Maya
    scenes. This command is used to get the information about those file paths and
    modify them in bulk.
    By default, only the most frequently used types of files are presented to the
    user:For the command to manage more file types, those must be explicitly requested by
    the caller using the "registerType" flag. This flag tells the command about
    attributes or nodes that are to reveal their paths when the command is used.Currently, the attributes specified through this flag must have the
    "usedAsFileName" property. Supported nodes are "reference" and plug-in nodes.
    For example: "brush.flowerImage" or "reference" can be used as value for this
    flag.Conversely, the "deregisterType" flag can be used to tell the command to stop
    handling certain attributes or nodes.Once the set of attributes and nodes to be searched for external files is
    selected, the command can be used to obtain a list of plugs that contain file
    names. Additional information can be obtained, such as each file's name,
    directory, and report whether the file exists. Additional information about the
    associated node or plug can also be obtained, such as its name, type and label.Finally, the command can be used to perform various manipulations such as
    editing the paths, remapping the files or verifying the presence of
    identically-named files in target directories. See the "repath",
    "copyAndRepath" and "replaceField" flags for more information.The results of these manipulations can be previewed before they are applied
    using the "preview" flag.filepath, editor, repath
    Args:
        attributeOnly (bool?): Used with "listFiles" to return the node and attribute name that  
                are using the files.  
                Properties: query
        attributeType (Queryable[str]?): Query the attribute type for the specified plug.  
                Properties: query
        byType (str?): Used with "listFiles" to query files that are  
                used by the specified node type or attribute type.  
                			In query mode, this flag needs a value.  
                Properties: query
        copyAndRepath (Tuple[str, str]?): Copy a source file to the destination path and repath the plug data to the new  
                file.  
                The source file must have the same name as the one in the plug.  
                The command will look for the file at the specified location first. If not  
                found, the command will try to use the original file in the plug.  
                If the file is still not found, nothing is done.  
                Properties: create
        deregisterType (str?): Deregister a file type from the list of registered types so the command stops  
                handling it.  
                Unless the "temporary" flag is used, the type will be removed from the  
                preferences will not reappear on application restart. When the "temporary" flag  
                is specified, the deregistration is only effective for the current session.  
                The deregistration will be rejected if the type has already been unregistered.  
                However, it is valid to deregister permanently (without the "temporary" flag)  
                a type after it has been temporarily deregistered.  
                Properties: create
        force (bool?): Used with flag "repath" to repath all files to the new location, including  
                the resolved files. Otherwise, "repath" will only deal with the missing files.  
                Used with flag "copyAndRepath" to overwrite any colliding file at the  
                destination. Otherwise, "copyAndRepath" will use the existing file at the  
                destination instead of overwriting it.  
                The default value is off.  
                Properties: create
        listDirectories (str?): List all sub directories of the specified directory.  Only directories  
                containing at least one file whose type is registered (see "registerType") will  
                be listed.  
                If no directory is provided, all directories applicable to the scene will be  
                returned.  
                			In query mode, this flag needs a value.  
                Properties: query
        listFiles (str?): List files in the specified directory. No recursion in subdirectories will be  
                performed.  
                			In query mode, this flag needs a value.  
                Properties: query
        listRegisteredTypes (bool?): Query the list of registered attribute types. The registered types include  
                the auto-loaded types from the preference file and the types explicitly  
                registered by the user, both with and without the "temporary" flag.  
                Properties: query
        preview (bool?): Used with "repath", "replaceString" or "copyAndRepath" to preview the result of  
                the operation instead of excuting it.  
                When it is used with "repath" or "replaceString", the command returns the new  
                file path and a status flag indicating whether the new file exists (1) or not  
                (0).  
                The path name and the file status are listed in pairs.  
                When it is used with "copyAndRepath", the command returns the files that need  
                copying.  
                Properties: create
        recursive (bool?): Used with flag "repath" to search the files in the target directory and its  
                subdirectories recursively. If the flag is on, the command will repath the plug  
                to a file that has the same name in the target directory or sub directories.  
                If the flag is off, the command will apply the directory change without  
                verifying that the resulting file exists.  
                Properties: create
        refresh (bool?): Clear and re-collect the file information in the scene.  
                The command does not automatically track file path modifications in the scene.  
                So it is the users responsibility to cause refreshes in order to get up-to-date  
                information.  
                Properties: create
        registerType (str?): Register a new file type that the command will handle and recognize from now on.  
                Unless the "temporary" flag is used, the registered type is saved in the  
                preferences and reappears on application restart.  
                The new type will be rejected if it collides with an existing type or label.  
                One exception to this is when registering a type without the "temporary" flag  
                after the type has been registered with it. This is considered as modifying  
                the persistent/temporary property of the existing type, rather than registering  
                a new type.  
                Properties: create
        relativeNames (bool?): Used with "listDirectories" or "listFiles" to return the relative path  
                of each directory or file.  Paths are relative to the current project  
                folder.  
                If a file or the directory is not under the current project folder,  
                the returned path will still be a full path.  
                Properties: query
        repath (str?): Replace the directory part of a file path with a specified location.  
                The file name will be preserved.  
                Properties: create
        replaceAll (bool?): Used with flag "replaceString", specifies how many times the matched string will  
                be replaced. When the flag is false, only the first matched string will be  
                replaced. Otherwise, all matched strings will be replaced.  
                The default value is false.  
                Properties: create
        replaceField (str?): Used with the "replaceString" flag to control the scope of the replacement.  
                Possible values are:  
                "pathOnly" - only replace strings in the directory part.  
                "nameOnly" - only replace strings in the file name, without the directory.  
                "fullPath" - replace strings anywhere in the full name.  
                The default argument is "fullPath".  
                Properties: create
        replaceString (Tuple[str, str]?): Replace the target string with the new string in the file paths.  
                The flag needs two arguments: the first one is the target string and the second  
                one is the new string.  
                See the "replaceField" and "replaceAll" flags to control how the replacement is  
                performed.  
                Properties: create
        status (bool?): Used with "listFiles", this will cause the returned list of files to include  
                one status flag per file: 0 if it cannot be resolved and 1 if it can.  
                Used with "listDirectories", this will cause the returned list of directories to  
                include one status flag per directory: 0 if it cannot be resolved, 1 if it can  
                and 2 if the resolution is partial.  
                The status will be interleaved with the file/directory names, with the name  
                appearing first. See the example for "listFiles".  See the "withAttribute" flag  
                for another way of getting per-file information.  When multiple per-entry items  
                appear in the list (e.g.: plug name), the status is always last.  
                Properties: query
        temporary (bool?): Make the effect of the "register"/"deregister" flag only applicable in the  
                current session.  
                Normally, a type registration/deregistration is permanent and is made persistent  
                via a preference file. When the "temporary" flag is specified, the changes will  
                not be saved to the preference file. When the application restarts, any type  
                that has been previously temporarily registered will not appear and any type  
                that was temporarily deregistered will re-appear.  
                Properties: create
        typeLabel (str?): Used with "registerType" to set the label name for the new file type.  
                Used with "query" to return the type label for the specified attribute type.  
                For default types, the type label is the localized string.  
                For other types, the type label is supplied by user.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        unresolved (bool?): Used with "listFiles" to query the unresolved files  
                that are being used in the scene.  
                Properties: query
        withAttribute (bool?): Used with "listFiles" to return the name of the plug using a given file.  
                For example, if "file.jpg" is used by the plug "node1.fileTextureName",  
                then the returned string will become the pair  
                "file.jpg node1.fileTextureName".  See the "status" flag for another  
                way to get per-file information.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def filletCurve(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., bias: Queryable[float] = ..., blendControl: bool = ..., caching: bool = ..., circular: bool = ..., curveParameter1: Queryable[float] = ..., curveParameter2: Queryable[float] = ..., depth: Queryable[float] = ..., freeformBlend: bool = ..., nodeState: Queryable[int] = ..., radius: Queryable[float] = ..., constructionHistory: bool = ..., join: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ..., trim: bool = ...) -> Union[List[str], float, bool, int]:
    """The curve fillet command creates a fillet curve between two curves.
    If no objects are specified in the command line, then the first two
    active curves are used. The fillet created can be circular (with
    a radius) or freeform (with a type of tangent or blend).
    Args:
        bias (Queryable[float]?): Adjusting the bias value causes the fillet curve to be skewed to one of the input curves. Available only if blendControl is true.  
                Default: 0.0  
                Properties: create, query, edit
        blendControl (bool?): If true then depth and bias can be controlled. Otherwise, depth and bias are not available options.  
                Default: false  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        circular (bool?): Curve fillet will be created as circular if true or freeform if false.  
                Default: true  
                Properties: create, query, edit
        curveParameter1 (Queryable[float]?): Parameter where fillet curve will contact the primary input curve.  
                Default: 0.0  
                Properties: create, query, edit
        curveParameter2 (Queryable[float]?): Parameter where fillet curve will contact the secondary input curve.  
                Default: 0.0  
                Properties: create, query, edit
        depth (Queryable[float]?): Adjusts the depth of the fillet curve. Available only if blendControl is true.  
                Default: 0.5  
                Properties: create, query, edit
        freeformBlend (bool?): The freeform type is blend if true or tangent if false. Available if the fillet type is freeform.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        radius (Queryable[float]?): The radius if creating a circular fillet.  
                Default: 1.0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        join (bool?): Should the fillet be joined?  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create
        trim (bool?): Should the fillet be trimmed?  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def filter(*args: Any, edit: bool = ..., query: bool = ..., name: Queryable[str] = ..., type: Queryable[str] = ...) -> str:
    """Creates or modifies a filter node.  Filter nodes are used by applyTake
    to modify recorded device data before assigning it to the param curves
    for the attached attributes.
    Args:
        name (Queryable[str]?): Name for created filter  
                Properties: create, query, edit
        type (Queryable[str]?): Filter type to create, One of:  
              
                filterEuler            Euler angle "demangler"  
                filterResample          
                Resamples input data at fixed output rate with several filtering options  
                filterSimplify          
                Combines groups of data points that are almost linear into lines segments  
                filterClosestSample      
                Resamples input data a fixed output rate using the closest sample point  
                Properties: create, query, edit

    Returns:
        str: filter name

    Example:
    """

def filterButterworthCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., apply: bool = ..., cutoffFrequency: Queryable[float] = ..., endTime: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., keepKeysOnFrame: bool = ..., name: str = ..., samplingRate: Queryable[float] = ..., selectedKeys: bool = ..., startTime: Queryable[int] = ...) -> Union[str, float, int, bool]:
    """Creates/edits a Butterworth filter context. This context can be used
    to interactively preview/edit the Butterworth filter on a set of
    animation curves.
    Args:
        apply (bool?): When specified, finalizes the current context state  
                and records the command for the operation. This is equivalent  
                to completing the tool action without exiting the current  
                tool context.  
                Properties: edit
        cutoffFrequency (Queryable[float]?): Specifies the cutoff frequency setting of the Butterworth filter.  
                Default is 7.0.  
                Properties: query, edit
        endTime (Queryable[int]?): Specifies the end time portion of the time range for this filter.  
                This time range is used when selectedKeys is false.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        keepKeysOnFrame (bool?): When true, the Butterworth filter will reposition output keys to  
                whole frames for the specified sampling rate.  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        samplingRate (Queryable[float]?): Specifies the sampling rate setting of the Butterworth filter.  
                Default is 30.0.  
                Properties: query, edit
        selectedKeys (bool?): If true, sets the filter to apply to the selected keys. Otherwise,  
                the filter applies to the specified time range. Default is on.  
                Properties: query, edit
        startTime (Queryable[int]?): Specifies the start time portion of the time range for this filter.  
                This time range is used when selectedKeys is false.  
                Properties: query, edit

    Returns:
        str: Context name

    Example:
    """

def filterCurve(*args: str, cutoffFrequency: float = ..., endTime: int = ..., filter: str = ..., keepKeysOnFrame: bool = ..., kernel: str = ..., keySync: bool = ..., maxTimeStep: float = ..., minTimeStep: float = ..., period: float = ..., precision: float = ..., precisionMode: int = ..., preserveKeyTangent: Multiuse[str] = ..., sampleCount: int = ..., samplingRate: float = ..., selectedKeys: bool = ..., startTime: int = ..., timeTolerance: float = ..., tolerance: float = ..., useQuaternion: bool = ..., width: int = ...) -> int:
    """The filterCurve command takes a list of anim curve and filters
            them using a specified filter. The following filters are supported:filter
    Args:
        cutoffFrequency (float?): Defines the cutoff frequency (in Hz) for the Butterworth filter.  
                Properties: create
        endTime (int?): Specify the end time of the section to filter. If not specified, the last  
                key of the animation curve is used to define the end time.  
                Properties: create
        filter (str?): Specifies the filter type to use. The avalible filters are:  
                butterworth  
                euler (default)  
                gaussian  
                keyReducer  
                peakRemover  
                keySync  
                resample  
                simplify  
                Properties: create
        keepKeysOnFrame (bool?): When specified, a secondary filter pass is applied to position keys on whole  
                frames. This flag is only supported by the Butterworth filter.  
                Properties: create
        kernel (str?): The resample kernel is a decimation resampling filter used to resample  
                dense data. It works on the keyframes and may not produce the desired results  
                when used with sparse data.  
              
                The resample filter converts from either uniform or non-uniform  
                timestep input data samples to the specified uniform timeStep. Various  
                time domain filters are available and are specified with the kernel  
                flag which selects the resampling kernel applied to the keyframes  
                on the animation curves.  
              
              
                Kernel Values  
                closest  
                 Closest sample to output timestamp  
                lirp  
                 Linear interpolation between closest samples  
                box  
                 Box filter: moving average  
                triangle  
                 Triangle filter: (1. |x|)  weighted moving average  
                gaussian2  
                 Gaussian2 Filter: (2^(-2x*x))  weighted moving average  
                gaussian4  
                 Gaussian4 Filter: (2^(-4x*x))  weighted moving average  
              
              
                This filter is only targeted at decimation resampling  
                -- interpolation resampling is basically unsupported.  If your  
                output framerate is much higher than your input frame rate  
                (approximate, as the input timestep is not assumed to be regular)  
                the lirp and triangle will interpolate (usually) and the rest will  
                either average, or use the closest sample (depending on the  
                phase and frequency of the input).  However this mode of operation  
                may not give the expected result.  
                Properties: create
        keySync (bool?): When specified, a secondary filter pass is applied that adds a key to sibling  
                curves (X,Y,Z) for each key that is encountered. This flag is only supported by the  
                Key Reducer filter.  
                Properties: create
        maxTimeStep (float?): Simplify filter.  
                Properties: create
        minTimeStep (float?): Simplify filter.  
                Properties: create
        period (float?): Resample filter  
                Properties: create
        precision (float?): Defines the precision parameter.  
                For the Key Reducer filter, this parameter specifies the error limit between the  
                source and output curves. Greater values reduce precision. Lower values increase  
                precision.  
                Properties: create
        precisionMode (int?): Defines whether the precision value should be treated as:  
                0. An absolute value  
                1. A percentage.  
                Properties: create
        preserveKeyTangent (Multiuse[str]?): When specified, keys whose in or out tangent type match the  
                specified type are preserved.  
                Supported tangent types:  
                fixed  
                linear  
                flat  
                smooth  
                step  
                clamped  
                plateau  
                stepnext  
                auto  
                This flag is only supported by the Key Reducer filter.  
                Properties: create, multiuse
        sampleCount (int?): Defines the Gaussian filter kernel dimension.  
                Properties: create
        samplingRate (float?): Defines the rate at which keys are added to the Butterworth filtered curve in  
                frames per second (FPS).  
                Properties: create
        selectedKeys (bool?): When specified, the filter is only applied to selected keys. This flag  
                supercedes the startTime/endTime specification.  
                Properties: create
        startTime (int?): Specify the start time to filter. If not specified, then the first key in the  
                animation curve is used to get the start time.  
                Properties: create
        timeTolerance (float?): Simplify filter.  
                Properties: create
        tolerance (float?): Simplify filter.  
                Properties: create
        useQuaternion (bool?): Enable to use quaternion instead of euler.  
                Properties: create
        width (int?): Defines the width of the Gaussian filter.  
                Properties: create

    Returns:
        int: The number of filtered curves

    Example:
    """

def filterExpand(*args: str, expand: bool = ..., fullPath: bool = ..., selectionMask: Multiuse[int] = ..., symActive: bool = ..., symNegative: bool = ..., symPositive: bool = ..., symSeam: bool = ...) -> List[str]:
    """Based on selected components (or components specified on the command line),
    the command filters and/or expands the list given
    the options.
    Returns a string array containing all matching selection items.
    Selection masks are as follows:
    Args:
        expand (bool?): Each item is a single entity if this is true.  Default is true.  
                Properties: create
        fullPath (bool?): If this is true and the selection item is a DAG object, return its  
                full selection path, instead of the name of the object only when  
                this value is false.  Default is false.  
                Properties: create
        selectionMask (Multiuse[int]?): Specify the selection mask  
                Properties: create, multiuse
        symActive (bool?): If symmetry is enabled only return the components on the active symmetry  
                side of the object. This flag has no effect if symmetry is not active.  
                Properties: create
        symNegative (bool?): If symmetry is enabled only return the components on the negative  
                side of the object relative to the current symmetry plane. This flag has  
                no effect if symmetry is not active.  
                Properties: create
        symPositive (bool?): If symmetry is enabled only return the components on the positive  
                side of the object relative to the current symmetry plane. This flag has  
                no effect if symmetry is not active.  
                Properties: create
        symSeam (bool?): If symmetry is enabled only return the components that lie equally on both sides  
                of the object relative to the current symmetry plane. This flag has  
                no effect if symmetry is not active.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def filterGaussianCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., apply: bool = ..., endTime: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., sampleCount: Queryable[int] = ..., selectedKeys: bool = ..., startTime: Queryable[int] = ..., useQuaternion: bool = ..., width: Queryable[int] = ...) -> Union[str, int, bool]:
    """Creates a smooth (gaussian) filter context. This context can ben used
    to interactively preview/edit the smooth (gaussian) filter on a set of
    animation curves.
    Args:
        apply (bool?): When specified, finalizes the current context state  
                and records the command for the operation. This is equivalent  
                to completing the tool action without exiting the current  
                tool context.  
                Properties: edit
        endTime (Queryable[int]?): Specifies the end time portion of the time range for this filter.  
                This time range is used when selectedKeys is false.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        sampleCount (Queryable[int]?): This parameter specifies the number of neighbor will be sampled.  
                Properties: query, edit
        selectedKeys (bool?): If true, sets the filter to apply to the selected keys. Otherwise,  
                the filter applies to the specified time range. Default is on.  
                Properties: query, edit
        startTime (Queryable[int]?): Specifies the start time portion of the time range for this filter.  
                This time range is used when selectedKeys is false.  
                Properties: query, edit
        useQuaternion (bool?): When this is enabled, the filter will first convert the curves  
                (rotation channel curves, 3 sibling requires at the same time)  
                from Euler space to quaternions. Then apply the gaussian filter  
                on it. Convert it back from Quaternions back to Euler space eventually.  
                Properties: query, edit
        width (Queryable[int]?): This parameter specifies the width of the gaussian kernel shape.  
                Wider width will  
                Properties: query, edit

    Returns:
        str: Context name

    Example:
    """

def filterInstances(*args: str, query: bool = ..., shapes: bool = ...) -> List[str]:
    """This command filters the selection list to remove duplicate instances
    that refer to the same object/components. If any such instances are
    found they will be merged with the first selected instance.Returns a string array containing all matching selection items or
    true/false if the query flag is used.
    Args:
        shapes (bool?): If this is true then the command will check for an instanced shapes  
                below the selected transform(s) and use them to decide whether the  
                parent transforms should be considered instances. Default is false.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def filterKeyReducerCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., apply: bool = ..., endTime: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., keySync: bool = ..., name: str = ..., precision: Queryable[float] = ..., precisionMode: Queryable[int] = ..., preserveKeyTangent: Queryable[Multiuse[str]] = ..., selectedKeys: bool = ..., startTime: Queryable[int] = ...) -> Union[str, int, bool, float, Multiuse[str]]:
    """Creates/edits a KeyReducer filter context. This context can be used
    to interactively preview/edit the KeyReducer filter on a set of
    animation curves.
    Args:
        apply (bool?): When specified, finalizes the current context state  
                and records the command for the operation. This is equivalent  
                to completing the tool action without exiting the current  
                tool context.  
                Properties: edit
        endTime (Queryable[int]?): Specifies the end time portion of the time range for this filter.  
                This time range is used when selectedKeys is false.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        keySync (bool?): When true, a secondary filter pass is applied that adds a key to sibling  
                curves (X,Y,Z) for each key that is encountered.  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        precision (Queryable[float]?): Defines the precision parameter.  
              
                For the Key Reducer filter, this parameter specifies the error limit between the  
                source and output curves. Greater values reduce precision. Lower values increase  
                precision.  
                Properties: query, edit
        precisionMode (Queryable[int]?): Specifies the precision mode for the Key Reducer filter. Avaiable  
                modes are:  
              
                0. Absolute value.  
                1. Percentage  
              
                Default is 1 (percentage mode).  
                Properties: query, edit
        preserveKeyTangent (Queryable[Multiuse[str]]?): When specified, keys whose in or out tangent type match the  
                specified type are preserved.  
              
                Supported tangent types:  
              
                fixed  
                linear  
                flat  
                smooth  
                step  
                clamped  
                plateau  
                stepnext  
                auto  
                Properties: query, edit, multiuse
        selectedKeys (bool?): If true, sets the filter to apply to the selected keys. Otherwise,  
                the filter applies to the specified time range. Default is on.  
                Properties: query, edit
        startTime (Queryable[int]?): Specifies the start time portion of the time range for this filter.  
                This time range is used when selectedKeys is false.  
                Properties: query, edit

    Returns:
        str: Context name

    Example:
    """

def filterPeakRemoverCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., apply: bool = ..., history: bool = ..., endTime: int = ..., exists: bool = ..., image1: str = ..., image2: str = ..., image3: str = ..., name: str = ..., startTime: int = ..., selectedKeys: bool = ...) -> None: ...
def findDeformers(*args: str) -> bool:
    """This command finds all deformers for the specified shape(s).If no shapes are specified on the command then the curently selected
    shapes are used.
    Returns:
        bool:

    Example:
    """

def findKeyframe(*args: str, animation: str = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., curve: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ..., timeSlider: bool = ..., which: str = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command will return the time (in current units) of the requested
    key. For the relative direction methods (next, previous) if
    -time is NOT specified they will use current time.
    If the specified object is not animated the command will return
    the current time.
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        curve (bool?): Return a list of the existing curves driving the selected object  
                or attributes. The which, index, floatRange, timeRange, and  
                includeUpperBound flags are ignored when this flag is used.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        timeSlider (bool?): Get the next key time from the ticks displayed in the  
                time slider. If this flag is set, then the -an/animation flag  
                is ignored.  
                Properties: create
        which (str?): next | previous | first | last  
                How to find the key  
                Properties: create

    Returns:
        int: Command result

    Example:
    """

def findType(*args: str, deep: bool = ..., exact: bool = ..., forward: bool = ..., type: str = ...) -> List[str]:
    """Thecommand is used to search through a dependency
    subgraph on a certain node to find all nodes of the given type.
    The search can go either upstream (input connections) or downstream (output
    connections). The plug/attribute dependencies are not taken into account
    when searching for matching nodes, only the connections.debug, node, type, search
    Args:
        deep (bool?): Find all nodes of the given type instead of just the first.  
                Properties: create
        exact (bool?): Match node types exactly instead of any in a node hierarchy.  
                Properties: create
        forward (bool?): Look forwards (downstream) through the graph rather than backwards  
                (upstream) for matching nodes.  
                Properties: create
        type (str?): Type of node to look for (e.g. "transform"). This flag is mandatory.  
                Properties: create

    Returns:
        List[str]: The list of node(s) of the requested type connected to the given node(s)

    Example:
    """

def fitBspline(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, int, float]:
    """The fitBspline command fits the CVs from an input curve
    and and returns a 3D curve.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance for the fit.  The resulting curve will be kept  
                within tolerance of the given points.  
                Default: 0.1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def flagTest(arg0: str = ..., arg1: float = ..., arg2: int = ..., arg3: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., floatRange: Multiuse[Range[float]] = ..., int64: int = ..., indexRange: Multiuse[int] = ..., multiUse: Multiuse[Tuple[float, int, str]] = ..., noReport: bool = ..., optionalQueryArgsFlag: Tuple[float, int, str] = ..., pythonOptionalQueryArgsFlag: Tuple[float, int, str] = ..., pythonQueryArgsFlag: Tuple[float, int, str] = ..., queryArgsFlag: Tuple[float, int, str] = ..., simpleFlag: bool = ..., stringArrayFlag: List[str] = ..., stringFlag: str = ..., tripleFloat: Tuple[float, float, float] = ..., timeRange: Multiuse[NullableRange[float]] = ...) -> None: ...
def flexor(*args: str, edit: bool = ..., query: bool = ..., atBones: bool = ..., atJoints: bool = ..., deformerCommand: str = ..., list: bool = ..., name: str = ..., noScale: bool = ..., toSkeleton: bool = ..., type: str = ...) -> Union[List[str], bool]:
    """This command creates a flexor. A flexor a deformer plus a set of
    driving    attributes. For example, a flexor might be a sculpt object
    that is driven by a joint's x rotation and a cube's y position.
    Args:
        atBones (bool?): Add a flexor at bones. Flexor will be added at each of the  
                selected bones, or at all bones in the selected skeleton if  
                the -ts flag is also specified.  
                Properties: create
        atJoints (bool?): Add a flexor at joints. Flexor will be added at each of the  
                selected joints, or at all joints in the selected skeleton if  
                the -ts flag is specified.  
                Properties: create
        deformerCommand (str?): String representing underlying deformer command string.  
                Properties: create
        list (bool?): List all possible types of flexors. Query mode only.  
                Properties: query
        name (str?): This flag is obsolete.  
                Properties: create
        noScale (bool?): Do not auto-scale the flexor to the size of the nearby geometry.  
                Properties: create
        toSkeleton (bool?): Specifies that flexors will be added to the entire skeleton  
                rather than just to the selected joints/bones.  
                This flag is used in conjunction with the -ab and -aj flags.  
                Properties: create
        type (str?): Specifies which type of flexor. To see list of valid types,  
                use the "flexor -query -list" command.  
                Properties: create

    Returns:
        List[str]: (the names of the new flexor nodes)

    Example:
    """

def floatField(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enterCommand: Callable[..., Any] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: Queryable[int] = ..., preventOverride: bool = ..., receiveFocusCommand: Callable[..., Any] = ..., showTrailingZeros: bool = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., value: Queryable[float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Callable[..., Any]]:
    """Create a field control that accepts only float values and is bound by
    a minimum and maximum value.  An invisible slider is attached to the
    field and accessed by holding down the Ctrl modifier key while pressing
    one of the mouse buttons.  Dragging the invisible slider to the right
    with the middle mouse button increases the field value by the amount
    specified with theflag, while dragging to the left
    decreases the value by the same amount.  The left and right mouse
    buttons apply a factor of 0.1 and 10 to the step value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the field changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when dragging in the field.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is set  
                to true and the field value may be changed by typing into it.  If  
                false then the field can not be changed interactively.  However,  
                you can change the field text with the -v/value flag  
                regardless of the state of the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enterCommand (Callable[..., Any]?): Command executed when the keypad 'Enter' key is pressed.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Upper limit of the field.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Lower limit of the field.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (Queryable[int]?): Number of digits to the right of the decimal place.  
                Properties: create, query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        receiveFocusCommand (Callable[..., Any]?): Command executed when the field receives focus.  
                Properties: create, edit
        showTrailingZeros (bool?): Show trailing zeros or not  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Increment for the invisible slider.   The field value  
                will change by this amount when the invisible slider is dragged.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[float]?): Value of the field.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def floatFieldGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enable1: bool = ..., enable2: bool = ..., enable3: bool = ..., enable4: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfFields: int = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: int = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., showTrailingZeros: bool = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., value: Queryable[Tuple[float, float, float, float]] = ..., value1: Queryable[float] = ..., value2: Queryable[float] = ..., value3: Queryable[float] = ..., value4: Queryable[float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Tuple[float, float, float, float], Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text and
    editable float fields.  The label text is optional and one to four
    float fields can be created.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when the value of any of the  
                fields changes.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed when dragging the invisible slider  
                in any of the fields.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enable1 (bool?):   
                Properties: create, query, edit
        enable2 (bool?):   
                Properties: create, query, edit
        enable3 (bool?):   
                Properties: create, query, edit
        enable4 (bool?): Enable state for the respective field.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label in the group.  Sets the string to be label text to  
                the right of fields.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): If present on creation this specifies that there will be  
                a label to the left of the fields.  Sets the string to be the label  
                text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfFields (int?): Set the number of fields on creation. One to four fields are  
                available.  The default is one field.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (int?): Set the number of digits to the right of the decimal.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        showTrailingZeros (bool?): Show trailing zeros or not  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Set the delta of invisioSlider delta , the invisioSlider  
                step is delta/10.0 in LMB , delta in MMB,delta*10.0 in RMB.  
                Default is 10.0  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[Tuple[float, float, float, float]]?): Values for all fields.  
                Properties: create, query, edit
        value1 (Queryable[float]?):   
                Properties: create, query, edit
        value2 (Queryable[float]?):   
                Properties: create, query, edit
        value3 (Queryable[float]?):   
                Properties: create, query, edit
        value4 (Queryable[float]?): Value for the respective field.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def floatScrollBar(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., largeStep: Queryable[float] = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., value: Queryable[float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Callable[..., Any]]:
    """Create a scroll bar control that accepts only float values and is bound
    by a minimum and maximum value.  The scroll bar displays a marker
    indicating the current value of the scroll bar relative to its minimum
    and maximum values.  Click and drag the marker or on the scroll bar
    itself to change the current value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when the value changes by dragging the  
                scroll bar's value marker.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the slider.  This flag is true by default,  
                which corresponds to a horizontally oriented slider.  
                Properties: create, query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        largeStep (Queryable[float]?): Larger increment for the scroll bar, ie. the increment  
                used when the press is between the arrow button and the thumb.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Upper limit of the scroll bar.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Lower limit of the scroll bar.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Smaller increment for the scroll bar, ie. the increment  
                used when the arrow buttons are pressed.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[float]?): Value of the scroll bar.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def floatSlider(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., value: Queryable[float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Callable[..., Any]]:
    """Create a slider control that accepts only float values and is bound
    by a minimum and maximum value.  The slider displays a marker
    indicating the current value of the slider relative to its minimum
    and maximum values.  Click and drag the marker, or on the slider itself
    to change the current value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when the value changes by dragging the  
                slider's value marker.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the slider.  This flag is true by default,  
                which corresponds to a horizontally oriented slider.  
                Properties: create, query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Upper limit of the slider.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Lower limit of the slider.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): The step value represents the amount the  
                value will increase or decrease when you click either side of the  
                slider.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[float]?): Value of the slider.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def floatSlider2(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand1: str = ..., changeCommand2: str = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., maximum: Queryable[float] = ..., minimum: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., polarity: Queryable[int] = ..., popupMenuArray: bool = ..., positionControl1: str = ..., positionControl2: str = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., value1: Queryable[float] = ..., value2: Queryable[float] = ..., values: Tuple[float, float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Callable[..., Any]]:
    """This command creates a float slider containing two handles.
    The two handles are arranged such that they cannot pass one
    another, thus handle 1 will always have a value less than
    or or equal to handle 2 when you adjust the values.
    Each handle may have a MEL command associated with it which is
    issued when the handle moves and thus can be used to update the
    values of plugs such as via a setAttr command. Each handle can
    also be associated with a float textfield to display the current
    value of the handle.Note: the floatSlider2 widget currently only supports vertical
    (columnLayout) orientation.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand1 (str?): Command to be associated with handle 1 and issued  
                whenever the value of the handle is changed (except when values  
                are changed via the -hv/handleValue flag). An example command might be  
                "setAttr nurbsSphere1.tx" and if handle 1 were to move to  
                value 0.23 the slider would issue the command  
                "setAttr nurbsSphere1.tx 0.23;".  
                Properties: create, edit
        changeCommand2 (str?): Command to be associated with handle 2 and issued  
                whenever the value of the handle is changed (except when values  
                are changed via the -hv/handleValue flag). An example command might be  
                "setAttr nurbsSphere1.tx" and if handle 2 were to move to  
                value 0.23 the slider would issue the command  
                "setAttr nurbsSphere1.tx 0.23;".  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maximum (Queryable[float]?): Maximum limit of the slider. The default value is 10.0.  
                The maximum value occurs at the top(right) end of the slider  
                unless -polarity was specified. Note: you cannot set the  
                maximum value greater than or equal to the current minimum.  
                Properties: create, query, edit
        minimum (Queryable[float]?): Minimum limit of the slider. The default value is 0.0.  
                The minimum value occurs at the bottom end of the slider  
                unless -polarity was specified. Note: you cannot set the  
                minimum value greater than or equal to the current maximum.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        polarity (Queryable[int]?): Specifies the polarity of the slider. If 0 (the default), the minimum  
                value (specified by the -minimum flag) occurs at the bottom end of  
                the slider and maximum at the top(right), with values increasing as the slider  
                handles are moved towards the upper end of the slider. If the polarity  
                is specified as 1, the reverse behaviour occurs, with the maximum  
                occurring at the bottom end, the mimimum occuring at the top(right) end  
                and values decreasing as the handles are moved towards the upper end.  
                Properties: create, query, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        positionControl1 (str?): Set the name of the control (if any) which is associated with  
                handle 1 of this slider. The control must be a "floatField". The  
                control always displays the value of the handle, and is updated as  
                the handle moves.  
                Properties: create, edit
        positionControl2 (str?): Set the name of the control (if any) which is associated with  
                handle 2 of this slider. The control must be a "floatField". The  
                control always displays the value of the handle, and is updated as  
                the handle moves.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value1 (Queryable[float]?): Value of handle 1. To ensure that handle 1 stays at  
                or below handle 2, an error will occur if the value specified  
                is too large. If you wish to set both handles simultaneously,  
                use the -values flag.  
                Properties: create, query, edit
        value2 (Queryable[float]?): Value of handle 2. To ensure that handle 2 stays at  
                or above handle 2, an error will occur if the value specified  
                is too large. If you wish to set both handles simultaneously,  
                use the -values flag.  
                Properties: create, query, edit
        values (Tuple[float, float]?): Sets the value for handles 1 and 2 simulteneously. The  
                first argument is applied to handle 1 and must be less than  
                or equal to the second (handle 2) argument or an error will  
                be issued.  
                Properties: create, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the port created or modified

    Example:
    """

def floatSliderButtonGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., buttonCommand: Callable[..., Any] = ..., buttonLabel: Queryable[str] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., field: bool = ..., fieldMaxValue: Queryable[float] = ..., fieldMinValue: Queryable[float] = ..., fieldStep: Queryable[float] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: int = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., sliderStep: Queryable[float] = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., symbolButtonCommand: Callable[..., Any] = ..., symbolButtonDisplay: bool = ..., useTemplate: str = ..., value: Queryable[float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, float, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a float slider component with optional button
    and symbol buttons.TelfFloatSliderGrpCmd.cpp
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        buttonCommand (Callable[..., Any]?): Command string to be executed when the button is pressed.  
                Properties: create, edit
        buttonLabel (Queryable[str]?): The button text.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when the value of the  
                slider changes.  It will be executed only once after a drag  
                of the slider.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed repeatedly during a drag  
                of the slider.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label appearing after the slider.  Sets the string to be  
                the text for the extra label.  
                Properties: create, query, edit
        field (bool?): Indicates whether the group will have an editable float field  
                present that reflects the value of the slider.  
                Properties: create
        fieldMaxValue (Queryable[float]?): Maximum value that may be entered in the field.  This  
                value may be set to any value greater than  
                the -max/maxValue flag.  By default, it is equal to  
                the -max/maxValue flag.  
                Properties: create, query, edit
        fieldMinValue (Queryable[float]?): Minimum value that may be entered in the field.  This  
                value may be set to any value less than  
                the -min/minValue flag.  By default, it is equal to  
                the -min/minValue flag.  
                Properties: create, query, edit
        fieldStep (Queryable[float]?): Increment for the field.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): Image displayed on the symbol button.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): If present on creation the group will have static text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Maximum value for both the slider and the field.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Minimum value for both the slider and the field.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (int?): Number of digits to the right of the decimal.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        sliderStep (Queryable[float]?): The slider step value represents the  
                amount the value will increase or decrease when you click either  
                side of the slider.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Increment for both the slider and field.  
                Properties: create, query, edit
        symbolButtonCommand (Callable[..., Any]?): Command string executed when the symbol button is pressed.  
                Properties: create, edit
        symbolButtonDisplay (bool?): Visibility of the symbol button.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[float]?): Value of the group.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def floatSliderGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., field: bool = ..., fieldMaxValue: Queryable[float] = ..., fieldMinValue: Queryable[float] = ..., fieldStep: Queryable[float] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: int = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., sliderStep: Queryable[float] = ..., statusBarMessage: str = ..., step: Queryable[float] = ..., useTemplate: str = ..., value: Queryable[float] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, float, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of controls containing a
    label text, an float field and a float slider. The text and field
    controls are optional.  Editing or querying the field range values has
    no effect if theflag was not specified when the group was
    created.This group also allows you to enter values into the field outside of the
    slider range which is limited by theandflags.  To do this, use
    theandflags to
    specify a greater range of values.Note that the command will not allow you to specify
    agreater than thevalue nor
    aless than thevalue.If you do supply a larger field range with theandflags then you will notice that entering a
    value in the field that is outside of the slider range will result in
    extending the slider range as well.  For example, if you create a slider
    group with the following command:Then you will be able to use the slider to select any value from -10 to 10.
    At the same time you will be able to enter into the field any value
    from -100 to 100.  If you enter a value, say 20, then the new slider
    range will grow such that this value is now accessible through the slider
    as well.  In fact, the new slider limit will become double of that what you
    entered.  Note that the slider limits will never grow beyond the field
    limits, in other words if you entered the value 80 then the slider will be
    clipped to the field limit of 100 and not doubled to 160.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when the value of the  
                slider changes.  It will be executed only once after a drag  
                of the slider.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed repeatedly during a drag  
                of the slider.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label appearing after the slider.  Sets the string to be  
                the text for the extra label.  
                Properties: create, query, edit
        field (bool?): Indicates whether the group will have an editable float field  
                present that reflects the value of the slider.  
                Properties: create
        fieldMaxValue (Queryable[float]?): Maximum value that may be entered in the field.  This  
                value may be set to any value greater than  
                the -max/maxValue flag.  By default, it is equal to  
                the -max/maxValue flag.  
                Properties: create, query, edit
        fieldMinValue (Queryable[float]?): Minimum value that may be entered in the field.  This  
                value may be set to any value less than  
                the -min/minValue flag.  By default, it is equal to  
                the -min/minValue flag.  
                Properties: create, query, edit
        fieldStep (Queryable[float]?): Increment for the field.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): If present on creation the group will have static text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Maximum value for both the slider and the field.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Minimum value for both the slider and the field.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (int?): Number of digits to the right of the decimal.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        sliderStep (Queryable[float]?): The slider step value represents the  
                amount the value will increase or decrease when you click either  
                side of the slider.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[float]?): Increment for both the slider and field.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[float]?): Value of the group.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name of the control.

    Example:
    """

def flow(*args: str, edit: bool = ..., query: bool = ..., divisions: Queryable[Tuple[int, int, int]] = ..., localCompute: bool = ..., localDivisions: Queryable[Tuple[int, int, int]] = ..., objectCentered: bool = ...) -> Union[List[str], Tuple[int, int, int], bool]:
    """The flow command creates a deformation lattice to `bend' the object
    that is animated along a curve of a motion path animation.
    The motion path animation has to have the follow option set to be on.
    Args:
        divisions (Queryable[Tuple[int, int, int]]?): This flag specifies the number of lattice slices  
                in x,y,z.  
                The default values are 2 5 2.  
                When queried, it returns the uint32_t uint32_t uint32_t  
                Properties: query
        localCompute (bool?): This flag specifies whether or not to have local  
                control over the object deformation.  
                Default value:  
                is on when the lattice is around the curve, and  
                is off when the lattice is around the object.   
                When queried, it returns a boolean  
                Properties: query
        localDivisions (Queryable[Tuple[int, int, int]]?): This flag specifies the extent of the region of effect.  
                Default values are 2 2 2.  
                When queried, it returns the uint32_t uint32_t uint32_t  
                Properties: query
        objectCentered (bool?): This flag specifies whether to create the lattice around  
                the selected object at its center, or to create the lattice  
                around the curve.  
                Default value is true.  
                When queried, it returns a boolean  
                Properties: query

    Returns:
        List[str]: The names of the created flow node and associated
            lattice nodes.

    Example:
    """

def flowLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., columnSpacing: Queryable[int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., vertical: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., wrap: bool = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a layout that arranges its children along a single line
    (either horizontal or vertical). Depending on the value of the -wrap boolean flag
    (default is false), if the layout's parent cannot fit all the children on one line, the
    children will either wrap onto the next line(s) or be truncated.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        columnSpacing (Queryable[int]?): Sets the space between children.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the layout. This flag is true by default, which corresponds to a horizontally laid out control.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        vertical (bool?): This flag is obsolete. Please use the -hr/-horizontal flag instead.  
                Properties: create, query
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        wrap (bool?): When set to true, if the layout's parent cannot fit all the children in a single  
                line, the children will wrap onto the next line(s). Default setting is false.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def fluidAppend() -> None: ...
def fluidAppendOpt() -> None: ...
def fluidCacheInfo(*args: str, edit: bool = ..., query: bool = ..., attribute: Queryable[str] = ..., cacheTime: Queryable[int] = ..., endFrame: bool = ..., hasCache: bool = ..., hasData: bool = ..., initialConditions: bool = ..., playback: bool = ..., resolution: bool = ..., startFrame: bool = ...) -> Union[bool, str, int]:
    """A command to get information about the fluids cache.
    Get the startFrame and resolution for InitialConditions.
    Get the endFrame as well for a playback cache.
    Note that for the playback cache, it will look at the current time
    (or last frame if the current time is past end of cache)fluid
    Args:
        attribute (Queryable[str]?): Modifier to the "hasData" flag, used to query whether a  
                cache has data (at the current time)  
                for a specific fluid attribute.  Valid attribute  
                values are "density", "velocity", "temperature", "fuel", "color",  
                "coordinates" (for texture coordinates), "falloff".  
                Properties: create, query, edit
        cacheTime (Queryable[int]?): Only valid with the -hasData flag.  The time the -hasData flag  
                uses when it queries the cache to see if there is data.  
                Properties: create, query, edit
        endFrame (bool?): Returns end time of cache as float.  
                Properties: create, query, edit
        hasCache (bool?): Returns true if fluid has specified cache, false if not.  
                Properties: create, query, edit
        hasData (bool?): Queries whether a given cache has data in it at the time specified  
                by the -time flag.  (If not -time flag is present, -hasData assumes  
                the current time.)  
                When used with  
                the "attribute" flag, indicates if data for the specified attribute  
                exists in the cache.  When used without the "attribute" flag, "hasData"  
                indicates whether there is data in the cache for any of the valid  
                fluid attributes.  
                Properties: create, query, edit
        initialConditions (bool?): Specifies the cache to be queried is the "Initial Conditions" cache.  
                Properties: create, query, edit
        playback (bool?): Specifies the cache to be queried is the "Playback" cache.  
                Properties: create, query, edit
        resolution (bool?): Returns cache resolution as float[].  
                Properties: create, query, edit
        startFrame (bool?): Returns start time for cache as float.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def fluidDeleteCache() -> None: ...
def fluidDeleteCacheFrames() -> None: ...
def fluidDeleteCacheFramesOpt() -> None: ...
def fluidDeleteCacheOpt() -> None: ...
def fluidEmitter(*args: str, edit: bool = ..., query: bool = ..., cycleEmission: Queryable[str] = ..., cycleInterval: Queryable[int] = ..., densityEmissionRate: Queryable[float] = ..., fluidDropoff: Queryable[float] = ..., fuelEmissionRate: Queryable[float] = ..., heatEmissionRate: Queryable[float] = ..., maxDistance: Queryable[float] = ..., minDistance: Queryable[float] = ..., name: Queryable[str] = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., rate: Queryable[float] = ..., torusSectionRadius: Queryable[float] = ..., type: Queryable[str] = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, int, float, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """Creates, edits or queries an auxiliary dynamics object
    (for example, a field or emitter).
    Creates an emitter object. If object names are provided or if objects are
    selected, applies the emitter to the named/selected object(s)in the
    scene.  Fluid will then be emitted from each. If no objects are
    named or selected, or if the -pos option is specified, creates a
    positional emitter.If an emitter was created, the command returns the name of the object
    owning the emitter, and the name of emitter shape. If an emitter was
    queried, the command returns the results of the query.
    Args:
        cycleEmission (Queryable[str]?): Possible values are "none" and "frame."  
                Cycling emission restarts the random number stream after  
                a specified interval.  This can either be a number of frames  
                or a number of emitted particles.  In each case the number  
                is specified by the cycleInterval attribute. Setting cycleEmission to  
                "frame" and cycleInterval to 1 will then re-start the random stream every  
                frame. Setting cycleInterval to values greater than 1 can be used  
                to generate cycles for games work.  
                Properties: query, edit
        cycleInterval (Queryable[int]?): Specifies the number of frames or particles between restarts of  
                the random number stream.  See cycleEmission.  Has no effect if  
                cycleEmission is set to None.  
                Properties: query, edit
        densityEmissionRate (Queryable[float]?): Rate at which density is emitted.  
                Properties: query, edit
        fluidDropoff (Queryable[float]?): Fluid Emission Dropoff in volume  
                Properties: query, edit
        fuelEmissionRate (Queryable[float]?): Rate at which  is emitted.  
                Properties: query, edit
        heatEmissionRate (Queryable[float]?): Rate at which density is emitted.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which emission ends.  
                Properties: query, edit
        minDistance (Queryable[float]?): Minimum distance at which emission starts.  
                Properties: query, edit
        name (Queryable[str]?): Object name  
                Properties: create, query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): world-space position  
                Properties: create, query, edit, multiuse
        rate (Queryable[float]?): Rate at which particles emitted (can be non-integer).  
                For point emission this is rate per point per unit time.  
                For surface emission it is rate per square unit of area per unit time.  
                Properties: query, edit
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        type (Queryable[str]?): Type of emitter. The choices are omni | dir | direction | surf |  
                surface | curve | curv. The default is omni.  
                The full definition of these types are: omnidirectional point emitter,  
                directional point emitter, surface emitter, or curve emitter.  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the emitter.  Volume offset translates  
                the emission volume by the specified amount from the actual  
                emitter location.  This is in the emitter's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the emitter.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which  
                particles are generated.  
                Values are: "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the emitter.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def fluidMergeCache() -> None: ...
def fluidMergeCacheOpt() -> None: ...
def fluidReplaceCache() -> None: ...
def fluidReplaceCacheOpt() -> None: ...
def fluidReplaceFrames() -> None: ...
def fluidReplaceFramesOpt() -> None: ...
def fluidVoxelInfo(*args: str, checkBounds: bool = ..., inBounds: Tuple[int, int, int] = ..., objectSpace: bool = ..., radius: float = ..., voxel: Tuple[float, float, float] = ..., voxelCenter: bool = ..., xIndex: int = ..., yIndex: int = ..., zIndex: int = ...) -> bool:
    """Provides basic information about the mapping of a fluid voxel grid into world- or object space of the fluid.  Use this command to determine the center point of a voxel, or to find the voxel containing a given point, among other things.fluid
    Args:
        checkBounds (bool?): If this flag is on, and the voxel index of a point that is out of bounds is requested,  
                then we return nothing.  
                Properties: create
        inBounds (Tuple[int, int, int]?): Are the three ints representing the x, y, z indices of a voxel within the bounds of the fluid's voxel grid?  True if yes, false if not.  (For 2D fluids, pass in z=0 for the third argument.  See examples.)  
                Properties: create
        objectSpace (bool?): Whether the queried value should be returned in object space (TRUE),  
                or world space (FALSE, the default).  
                Properties: create
        radius (float?): Modifier for the -voxel flag.  Returns a list of  
                index triples identifying voxels that fall within  
                the given radius of the point specified by the  
                -voxel flag.  
                Properties: create
        voxel (Tuple[float, float, float]?): Returns array of three ints representing the x, y, z indices of the voxel within which the given point position is contained.  
                If the checkBounds flag is on, and the point is out of bounds, we return nothing. Otherwise, even if the point is out of bounds, index values are returned.  
                When combined with the -radius flag, returns an array of index triples  
                representing a list of voxels within a given radius of the given point position.  
                Properties: create
        voxelCenter (bool?): The center position of the specified voxels.  Returns an array of floats (three for each of the indices in the query).  (Valid only with the -xIndex, -yIndex, and -zIndex flags.)  
                Properties: create
        xIndex (int?): Only return values for cells with this X index  
                Properties: create
        yIndex (int?): Only return values for cells with this Y index  
                Properties: create
        zIndex (int?): Only return values for cells with this Z index  
                Properties: create

    Returns:
        bool:

    Example:
    """

def flushIdleQueue(*, resume: bool = ...) -> None: ...
def flushThumbnailCache(*args: Any, **kwargs: Any) -> None: ...
def flushUndo() -> bool:
    """Removes everything from the undo queue, freeing up memory.
    Returns:
        bool:

    Example:
    """

def fontDialog(*, FontList: bool = ..., scalable: bool = ...) -> str:
    """Displays a dialog of available fonts for the user to select from. The
    name of the selected font is returned, or an empty string if no font was selected.When theflag is used, no dialog is displayed. Instead
    the command returns an array of the available fonts.
    Args:
        FontList (bool?): Returns an array of all available font names. No dialog is displayed.  
                Properties: create
        scalable (bool?): Limits the fonts returned or displayed to just those that are scalable.  
                Properties: create

    Returns:
        str: Dialog name

    Example:
    """

def formLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., attachControl: Multiuse[Tuple[str, str, int, str]] = ..., attachForm: Multiuse[Tuple[str, str, int]] = ..., attachNone: Multiuse[Tuple[str, str]] = ..., attachOppositeControl: Multiuse[Tuple[str, str, int, str]] = ..., attachOppositeForm: Multiuse[Tuple[str, str, int]] = ..., attachPosition: Multiuse[Tuple[str, str, int, int]] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfDivisions: Queryable[int] = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a form layout control. A form layout allows
    absolute and relative positioning of the controls that are
    its immediate children.Controls have four edges: top, left, bottom and right.
    There are only two directions that children can be positioned in,
    right-left and up-down. The attach flags take the direction of
    an attachment from the argument that names the edge to attach
    (the second argument). Any or all edges of a child may be
    attached. There are six ways to attach them:Each edge attachment may have an offset that acts to separate
    controls visually.There is no default positioning relationship so to have children
    appear in the form they must have at least one edge attached in
    each direction.In the flag definitions the arguments follow these
    rules:These are multi-use flags so any number of attachments
    may be made in a single command.Avoid making control attachments that form a loop in
    control dependencies. For example:$btn2 is attached to $btn1, $btn3 is attached to $btn2, and $btn1 is
    attached to $btn3. Thus, the placement of $btn1 is dependent on the
    placement of $btn3, which is dependent on the placement of $btn2, which
    is dependent on the placement of $btn1. The last control attachment will
    have created a loop in the dependencies.To prevent runtime errors, Maya will ignore this attachment and instead
    issue a warning that a cyclical control attachment has been detected in
    the script.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attachControl (Multiuse[Tuple[str, str, int, str]]?): Arguments are: control, edge, offset, control  
                Valid edge values are: "top" | "bottom" | "left" | "right".  
                Attach a control to another control.  
                Properties: create, edit, multiuse
        attachForm (Multiuse[Tuple[str, str, int]]?): Arguments are: control, edge, offset.  
                Valid edge values are: "top" | "bottom" | "left" | "right".  
                Attach the specified control to the form, offset by the specified  
                amount.  
                Properties: create, edit, multiuse
        attachNone (Multiuse[Tuple[str, str]]?): Arguments are: control, edge  
                Valid edge values are: "top" | "bottom" | "left" | "right".  
                Attach a control to nothing.  
                Properties: create, edit, multiuse
        attachOppositeControl (Multiuse[Tuple[str, str, int, str]]?): Arguments are: control, edge, offset, control  
                Valid edge values are: "top" | "bottom" | "left" | "right".  
                Attach a control to the opposite side of another control.  
                Properties: create, edit, multiuse
        attachOppositeForm (Multiuse[Tuple[str, str, int]]?): Arguments are: control, edge, offset.  
                Valid edge values are: "top" | "bottom" | "left" | "right".  
                Attach a control to the opposite side of the form.  
                Properties: create, edit, multiuse
        attachPosition (Multiuse[Tuple[str, str, int, int]]?): Arguments are: control, edge, offset, position  
                Valid edge values are: "top" | "bottom" | "left" | "right".  
                Attach a control to a position in the form.  
                Properties: create, edit, multiuse
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfDivisions (Queryable[int]?): Specify the number of horizontal and vertical divisions  
                across the form. Value must be greater than 0.  
                Properties: create, query, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the control.

    Example:
    """

def format(arg0: str = ..., /, *, stringArg: Multiuse[str] = ...) -> str:
    """This command takes a format string, where the format string contains
    format specifiers.  The format specifiers have a number associated
    with them relating to which parameter they represent to allow for
    alternate ordering of the passed-in values for other
    languages by merely changing the format stringformat, string
    Args:
        stringArg (Multiuse[str]?): Specify the arguments for the format string.  
                Properties: create, multiuse

    Returns:
        str: Command result

    Example:
    """

def frameBufferName(*, autoTruncate: bool = ..., camera: str = ..., renderLayer: str = ..., renderPass: str = ...) -> str:
    """Returns the frame buffer name for a given renderPass renderLayer and
    camera combination. Optionally, this command can apply a name truncation
    algorithm so that the frameBuffer name will respect the maximum length
    imposed by the destination file format, if applicable.render, pass
    Args:
        autoTruncate (bool?): use this flag to apply a name truncation algorithm so that the frameBuffer  
                name will respect the maximum length imposed by the destination file format,  
                if applicable.  
                Properties: create
        camera (str?): Specify a camera  
                Properties: create
        renderLayer (str?): Specify a renderer layer  
                Properties: create
        renderPass (str?): Specify a renderer pass  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def frameLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., backgroundShade: bool = ..., borderStyle: Queryable[str] = ..., borderVisible: bool = ..., childArray: bool = ..., collapsable: bool = ..., collapse: bool = ..., collapseCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., expandCommand: Callable[..., Any] = ..., font: Queryable[str] = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelAlign: Queryable[str] = ..., labelIndent: Queryable[int] = ..., labelVisible: bool = ..., labelWidth: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preCollapseCommand: Callable[..., Any] = ..., preExpandCommand: Callable[..., Any] = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates frame layout control. A frame layout may draw a
    border around its child controls as well as a display a title. Frame
    layouts may also be collapsable. Collapsing a frame layout will make
    the child of the frame layout invisible and shrink the frame layout
    size. The frame layout may then be expanded to make its child visible.
    Note that the frame layout may have only one child control.  If you
    wish to have more than one child inside a frame layout then you must
    use some other control layout as the immediate child of the frame
    layout.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        backgroundShade (bool?): Controls whether the background of the frame layout draws with a shaded effect. It is turned off by default.  
                Properties: create, query, edit
        borderStyle (Queryable[str]?): This flag is obsolete. The border style is no longer supported.  
                Using this flag will return a warning.  
                Properties: create, query, edit
        borderVisible (bool?): Visibility of the border.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        collapsable (bool?): Collapsibility of the frame layout.  
                Properties: create, query, edit
        collapse (bool?): Collapse state of the frame layout.  
                Properties: create, query, edit
        collapseCommand (Callable[..., Any]?): Command executed after the frame is collapsed.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        expandCommand (Callable[..., Any]?): Command executed after the frame is expanded.  
                Properties: create, edit
        font (Queryable[str]?): The font for the frame label.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label string for the frame layout.  
                Properties: create, query, edit
        labelAlign (Queryable[str]?): How to align the label. Default is "top".  
                Properties: create, query, edit
        labelIndent (Queryable[int]?): Indentation for the frame label.  
                Properties: create, query, edit
        labelVisible (bool?): Visibility of the frame label.  
                Properties: create, query, edit
        labelWidth (Queryable[int]?): Width of the label.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): Vertical distance between the frame and its children.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): Horizontal distance between the frame and its children.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preCollapseCommand (Callable[..., Any]?): Command executed just before the frame is collapsed.  
                Properties: create, edit
        preExpandCommand (Callable[..., Any]?): Command executed just before the frame is expanded.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def framelessDialog(*, button: Multiuse[str] = ..., message: str = ..., parent: str = ..., path: str = ..., primary: Multiuse[str] = ..., title: str = ...) -> str:
    """The framelessDialog command creates a modal dialog with a message to the
    user and a variable number of buttons to dismiss the dialog.  The
    dialog is dismissed when the user presses any button or chooses the
    close item from the window menu.  In the case where a button is
    pressed then the name of the button selected is returned.
    Args:
        button (Multiuse[str]?): Create a button with the given string as it's text.  
                Properties: create, multiuse
        message (str?): The message text appearing in the dialog.  
                Properties: create
        parent (str?): Specify the parent window for the dialog.  The dialog will  
                be centered on this window and raise and lower with it's parent.  
                By default, the dialog is not parented to a particular window and  
                is simply centered on the screen.  
                Properties: create
        path (str?): An optional path appearing after the message.  
                Properties: create
        primary (Multiuse[str]?): Set given buttons as primary.  
                Properties: create, multiuse
        title (str?): The dialog title.  
                Properties: create

    Returns:
        str: Indicates how the dialog was dismissed. If a button is
            pressed then the label of the button is returned.

    Example:
    """

def freeFormFillet(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., bias: Queryable[float] = ..., caching: bool = ..., depth: Queryable[float] = ..., nodeState: Queryable[int] = ..., positionTolerance: Queryable[float] = ..., tangentTolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., range: bool = ...) -> Union[List[str], float, bool, int]:
    """This command creates a free form surface fillet across two surface
    trim edges or isoparms or curve on surface. The fillet surface
    creation has blend controls in the form of bias and depth. The bias
    value scales the tangents at the two ends across the two selected
    curves. The depth values controls the curvature of the fillet across
    the two selected curves. The default values of depth, bias are 0.5
    and 0.5 respectively.
    Args:
        bias (Queryable[float]?): Bias value for fillet  
                Default: 0.5  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        depth (Queryable[float]?): Depth value for fillet  
                Default: 0.5  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        positionTolerance (Queryable[float]?): C(0) Tolerance For Filleted Surface creation  
                Default: 0.1  
                Properties: create, query, edit
        tangentTolerance (Queryable[float]?): G(1) continuity Tolerance For Filleted Surface creation  
                Default: 0.1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def freezeOptions(*, query: bool = ..., displayLayers: bool = ..., downstream: Queryable[str] = ..., explicitPropagation: bool = ..., invisible: bool = ..., referencedNodes: bool = ..., runtimePropagation: bool = ..., upstream: Queryable[str] = ...) -> Union[str, bool]:
    """This command provides access to the options used by the evaluation manager to
    handle propagation and recognition of when a node is in a frozen state.
    See the individual flags for the different options available.
    These values are all stored as user preferences and persist across sessions.evaluation, manager, DG, runtime, freeze
    Args:
        displayLayers (bool?): If this option is enabled then any nodes that are in an enabled, invisible display  
                layer will be considered to be frozen, and the frozen state will propagate accordingly.  
                Properties: create, query
        downstream (Queryable[str]?): Controls how frozen state is propagated downstream from currently frozen nodes.  
                Valid values are "none" for no propagation, "safe" for propagation downstream  
                only when all upstream nodes are frozen, and "force" for propagation downstream  
                when any upstream node is frozen.  
                Properties: create, query
        explicitPropagation (bool?): When turned on this will perform an extra pass when the evaluation graph is  
                constructed to perform intelligent propagation of the frozen state to related  
                nodes as specified by the currently enabled options of the evaluation graph.  
                See also "runtimePropagation".  
                This option performs more thorough propagation of the frozen state, but requires  
                extra time for recalculating the evaluation graph.  
                Properties: create, query
        invisible (bool?): If this option is enabled then any nodes that are invisible, either directly or  
                via an invisible parent node, will be considered to be frozen, and the frozen state  
                will propagate accordingly.  
                Properties: create, query
        referencedNodes (bool?): If this option is enabled then any nodes that are referenced in from a frozen referenced node  
                will also be considered to be frozen, and the frozen state will propagate accordingly.  
                Properties: create, query
        runtimePropagation (bool?): When turned on this will allow the frozen state to propagate during execution  
                of the evaluation graph. See also "explicitPropagation".  
                This option allows frozen nodes to be scheduled for evaluation, but once it  
                discovers a node that is frozen it will prune the evaluation based on the  
                current set of enabled options. It only works in the downstream direction.  
                Properties: create, query
        upstream (Queryable[str]?): Controls how frozen state is propagated upstream from currently frozen nodes.  
                Valid values are "none" for no propagation, "safe" for propagation upstream  
                only when all downstream nodes are frozen, and "force" for propagation upstream  
                when any downstream node is frozen.  
                Properties: create, query

    Returns:
        str: Current value of the option if querying the downstream or upstream flags
        bool: Current value of the option if querying the displayLayers, invisible, referencedNodes, explicitPropagation, or runtimePropagaton flags
        bool: In creation mode returns true if all options were successfully set

    Example:
    """

def geomBind(*args: str, edit: bool = ..., query: bool = ..., bindMethod: int = ..., falloff: Queryable[float] = ..., geodesicVoxelParams: Queryable[Tuple[int, bool]] = ..., maxInfluences: Queryable[int] = ...) -> Union[bool, float, Tuple[int, bool], int]:
    """This command is used to compute weights using geodesic voxel binding algorithm.
    It works by setting the right weights values on an already-existing skinCluster
    node.
    Since this command uses GPU acceleration, it is not supported on headless
    versions of Maya, i.e. batch mode.skinCluster
    Args:
        bindMethod (int?): Specifies which bind algorithm to use. By default, Geodesic Voxel will be used.  
                Available algorithms are:  
                3. Geodesic Voxel  
                Properties: create
        falloff (Queryable[float]?): Falloff controlling the bind stiffness. Valid values range from [0..1].  
                Properties: create, query, edit
        geodesicVoxelParams (Queryable[Tuple[int, bool]]?): Specifies the geodesic voxel binding parameters. This flag is composed of three  
                parameters:  
                0. Maximum voxel grid resolution which must be a power of two. (ie. 64, 128, 256, etc. )  
                1. Performs a post voxel state validation when enabled.  
                Default values are 256 true.  
                Properties: create, query, edit
        maxInfluences (Queryable[int]?): Specifies the maximum influences a vertex can have. By default, all influences  
                are used (-1).  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def geomToBBox(*args: str, bakeAnimation: bool = ..., combineMesh: bool = ..., endTime: int = ..., keepOriginal: bool = ..., name: str = ..., nameSuffix: str = ..., sampleBy: int = ..., shaderColor: Tuple[float, float, float] = ..., single: bool = ..., startTime: int = ...) -> bool:
    """Create polygonal mesh bounding boxes for geometry.
    Can also create a single bounding box per hierarchy.bounding, box
    Args:
        bakeAnimation (bool?): Bake the animation. Can be used with startTime, endTime and sampleBy flags.  
                If used alone, the time slider will be used to specify the startTime and endTime.  
                Properties: create
        combineMesh (bool?): Combine resulting bounding boxes.  
                Mutually exclusive with -s/single option.  
                Properties: create
        endTime (int?): Used with bakeAnimation flag. Specifies the end time of the baking process.  
                Properties: create
        keepOriginal (bool?): Do not remove the selected nodes used to create the bounding boxes.  
                Properties: create
        name (str?): Specifies the bounding box name.  
                Properties: create
        nameSuffix (str?): Specifies the bounding box name suffix.  
                Properties: create
        sampleBy (int?): Used with bakeAnimation flag. Specifies the animation evaluation time increment.  
                Properties: create
        shaderColor (Tuple[float, float, float]?): Set the color attribute of the Lambert material associate with the bounding box.  
                The RGB values should be defined between 0 to 1.0.  
                Default value is 0.5 0.5 0.5.  
                Properties: create
        single (bool?): Create a single bounding box per hierarchy selected.  
                Properties: create
        startTime (int?): Used with bakeAnimation flag. Specifies the start time of the baking process.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def geometryAppendCache() -> None: ...
def geometryAppendCacheOpt() -> None: ...
def geometryAttrInfo(*args: str, boundingBox: bool = ..., castToEdges: bool = ..., castToFaces: bool = ..., castToVerts: bool = ..., componentTagCategory: bool = ..., componentTagExpression: str = ..., componentTagHash: bool = ..., componentTagHistory: bool = ..., componentTagHistoryHash: bool = ..., componentTagNames: bool = ..., components: bool = ..., deformerChain: bool = ..., elementCount: bool = ..., groupId: int = ..., matrix: bool = ..., nodeChain: bool = ..., originalGeometry: bool = ..., outputPlugChain: bool = ..., plugChain: bool = ..., pointCount: bool = ..., pointIndices: bool = ..., points: bool = ..., subsetState: bool = ...) -> Any:
    """This command provides information about the geometry in an attribute. This
    command therefore only works on attributes that contain geometry.
    A variety of types of information can be requested, like the number of verts,
    the boundingbox, which componentTags exist, etc.The requests can be made on a subset of the geometry, either limited by a
    specific groupId or by a componentTag expression. For example, when a componentTag
    expression is used, the requested indices will be the indices that match the
    subset as defined by that expression.
    Args:
        boundingBox (bool?): Returns the bounding box of the geometry  
                Properties: create
        castToEdges (bool?): Ensures the componentTag expression will be resolved to edge components  
                Properties: create
        castToFaces (bool?): Ensures the componentTag expression will be resolved to face components  
                Properties: create
        castToVerts (bool?): Ensures the componentTag expression will be resolved to vert components  
                Properties: create
        componentTagCategory (bool?): This flag will return the component tag category of the resulting components.  
                Verts are "v", edges are "e", faces are "f". In case the the category can not  
                be determined "unknown" is returned  
                Properties: create
        componentTagExpression (str?): Specifies the componentTagExpression we want to query. When specified all answers to  
                the information requests will be limited to the subset of the geometry as is  
                contained in the combination of these componentTags  
                Properties: create
        componentTagHash (bool?): This flag will return a unique hash value for the state of all the componentTags  
                contained in the geometry. If a hash is different from before it means that  
                something has changed, either tags have been added/removed/renamed and/or their  
                component contents have been altered.  
                Properties: create
        componentTagHistory (bool?): This flag will return a description of the componentTags and the nodes in the chain  
                where they were added to the geometry.  
                Properties: create
        componentTagHistoryHash (bool?): This flag will return a unique hash value for the componentTag history of the  
                geometry in the plug. If a hash is different from before it means that  
                something has changed, either different nodes have created the tags or the  
                contents of the tags have been altered.  
                Properties: create
        componentTagNames (bool?): Returns the names of the componentTags on the geometry  
                Properties: create
        components (bool?): Returns the components of the geometry  
                Properties: create
        deformerChain (bool?): This flag will return the list of deformer nodes through which the geometry passes to the specified plug  
                Properties: create
        elementCount (bool?): Returns the element count of the components  
                Properties: create
        groupId (int?): Specifies the groupId we want to query. When specified all answers to the  
                information requests will be limited to the subset of the geometry as is  
                contained in this groupId  
                Properties: create
        matrix (bool?): Returns the matrix associated with the geometry  
                Properties: create
        nodeChain (bool?): This flag will return the list of nodes through which the geometry passes to the specified plug  
                Properties: create
        originalGeometry (bool?): This flag will return the name of a plug on a node upstream (likely at the front end)  
                that is the best candidate to be used as the originalGeometry. This can return an  
                empty plug when none exists.  
                Properties: create
        outputPlugChain (bool?): This flag will return the chain of plugs upstream of the specified plug (including only output plugs)  
                Properties: create
        plugChain (bool?): This flag will return the chain of plugs upstream of the specified plug (including both input and output plugs)  
                Properties: create
        pointCount (bool?): Returns the point count of the geometry  
                Properties: create
        pointIndices (bool?): Returns the indices of the geometry  
                Properties: create
        points (bool?): Returns a list of points of the geometry  
                Properties: create
        subsetState (bool?): Returns the state of the specified subset  
                -1 means the subset was invalid  
                0 means the subset contains none of the points of the geometry  
                1 means the subset contains some (but not all) of the points of the geometry  
                2 means the subset contains all the points of the geometry  
                Properties: create

    Returns:
        Any: Information about the geometry in the attribute. The number and type
            of values returned depends on the information request.

    Example:
    """

def geometryCache() -> None: ...
def geometryCacheOpt() -> None: ...
def geometryConstraint(*args: str, edit: bool = ..., query: bool = ..., layer: str = ..., name: Queryable[str] = ..., remove: bool = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[List[str], str, bool, float]:
    """Constrain an object's position based on the shape of the target
    surface(s) at the closest point(s) to the object.A geometryConstraint takes as input one or more surface shapes (the
    targets) and a DAG transform node (the object).  The
    geometryConstraint position constrained object such object lies on
    the surface of the target with the greatest weight value.  If two
    targets have the same weight value then the one with the lowest index
    is chosen.
    Args:
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def geometryDeleteCacheFrames() -> None: ...
def geometryDeleteCacheFramesOpt() -> None: ...
def geometryDeleteCacheOpt() -> None: ...
def geometryExportCache() -> None: ...
def geometryExportCacheOpt() -> None: ...
def geometryMergeCache() -> None: ...
def geometryMergeCacheOpt() -> None: ...
def geometryReplaceCache() -> None: ...
def geometryReplaceCacheFrames() -> None: ...
def geometryReplaceCacheFramesOpt() -> None: ...
def geometryReplaceCacheOpt() -> None: ...
def getAttr(*args: str, asString: bool = ..., caching: bool = ..., channelBox: bool = ..., expandEnvironmentVariables: bool = ..., keyable: bool = ..., lock: bool = ..., multiIndices: bool = ..., settable: bool = ..., silent: bool = ..., size: bool = ..., time: int = ..., type: bool = ...) -> Any:
    """This command returns the value of the named object's attribute.For Ufe attributes, the input attribute string should be
    "<ufe_path_string>.<ufe_attribute_name>".UI units are used where applicable.Currently, the types of attributes that can be displayed are:Other data types cannot be retrieved. No result is returned if the
    attribute contains no data.
    Args:
        asString (bool?): This flag is only valid for enum attributes. It allows you to  
                get the attribute values as strings instead of integer values.  
                Note that the returned string value is dependent on the  
                UI language Maya is running in (about -uiLanguage).  
                Not supported for Ufe attributes.  
                Properties: create
        caching (bool?): Returns whether the attribute is set to be cached internally  
                Not supported for Ufe attributes.  
                Properties: create
        channelBox (bool?): Returns whether the attribute is set to show in the Channel Box.  
                Keyable attributes also show in the Channel Box.  
                Not supported for Ufe attributes. The display of Ufe attributes in  
                the Channel Box is controlled using the channelBox command flag  
                -ual/ufeFixedAttrList.  
                Properties: create
        expandEnvironmentVariables (bool?): Expand any environment variable and (tilde characters on UNIX)  
                found in string attributes which are returned.  
                Not supported for Ufe attributes.  
                Properties: create
        keyable (bool?): Returns the keyable state of the attribute.  
                Not supported for Ufe attributes.  
                Properties: create
        lock (bool?): Returns the lock state of the attribute.  
                Properties: create
        multiIndices (bool?): If the attribute is a multi, this will return a list containing  
                all of the valid indices for the attribute.  
                Not supported for Ufe attributes.  
                Properties: create
        settable (bool?): Returns 1 if this attribute is currently settable by setAttr,  
                0 otherwise. An attribute is settable if it's not locked  
                and either not connected, or has only keyframed animation.  
                For Ufe attributes an attribute is settable if it's not locked.  
                Properties: create
        silent (bool?): When evaluating an attribute that is not a numeric or string  
                value, suppress the error message saying that the data cannot be  
                displayed. The attribute will be evaluated even though its data  
                cannot be displayed. This flag does not suppress all error messages,  
                only those that are benign.  
                Not supported for Ufe attributes.  
                Properties: create
        size (bool?): Returns the size of a multi-attribute array.  Returns 1 if non-multi.  
                Not supported for Ufe attributes.  
                Properties: create
        time (int?): Evaluate the attribute at the given time instead of the current time.  
                Not supported for Ufe attributes.  
                Properties: create
        type (bool?): Returns the type of data currently in the attribute.  
              
                Attributes of simple types such as strings and numerics always contain  
                data, but attributes of complex types (arrays, meshes, etc) may contain no data  
                if none has ever been assigned to them. When this happens the command will  
                return with no result: not an empty string, but no result at all.  
                Attempting to directly compare this non-result to another value or use it  
                in an expression will result in an error, but you can assign it to a  
                variable in which case the variable will be set to the default value for  
                its type (e.g. an empty string for a string variable, zero for an integer  
                variable, an empty array for an array variable). So to be safe when using this  
                flag, always assign its result to a string variable, never try to use it  
                directly.  
                Properties: create

    Returns:
        Any: Value or state of the attribute. The number and type
            of values returned is dependent on the attribute type.

    Example:
    """

def getClassification(arg0: str = ..., /, *, satisfies: str = ...) -> List[str]:
    """Returns the classification string for a given node type.Classification strings look like file pathnames ("shader/reflective" or "texture/2D", for
    example).  Multiple classifications can be combined into a single compound
    classification string by joining the individual classifications with ':'.
    For example, the classification string "shader/reflective:texture/2D" means
    that the node is both a reflective shader and a 2D texture.The classification string is used to determine how rendering nodes
    are categorized in various UI, such as the Create Render Node and HyperShade
    windows:The classification string is also used to determine how Viewport 2.0
    will interpret the node.
    Args:
        satisfies (str?): Returns true if the given node type's classification satisfies the classification  
                string which is passed with the flag.  
              
                A non-compound classification string A is said to satisfy a non-compound  
                classification string B if A is a subclassification of B (for example,  
                "shaders/reflective" satisfies "shaders").  
              
                A compound classification string A satisfies a compound classification  
                string B iff:  
              
              
                every component of A satisfies at least one component of B and   
                every component of B is satisfied by at least one component of A  
              
              
                Hence, "shader/reflective/phong:texture" satisfies "shader:texture", but  
                "shader/reflective/phong" does not satisfy "shader:texture".  
                Properties: create

    Returns:
        List[str]: Returns the classification strings for the given node type, or
            an empty array if the node type is not classified.

    Example:
    """

def getDefaultBrush() -> str:
    """The command returns the name of the default Paint Effects brush.
    Returns:
        str: Name of the default brush node

    Example:
    """

def getFileList(*, filespec: str = ..., folder: str = ...) -> List[str]:
    """Returns a list of files matching an optional wildcard pattern.
    Note that this command works directly on raw system files and does not go through standard Maya file path resolution.
    Args:
        filespec (str?): wildcard specifier for search.  
                Properties: create
        folder (str?): return a directory listing  
                Properties: create

    Returns:
        List[str]: an array of file names

    Example:
    """

def getFluidAttr(*args: str, attribute: str = ..., lowerFace: bool = ..., xIndex: int = ..., xvalue: bool = ..., yIndex: int = ..., yvalue: bool = ..., zIndex: int = ..., zvalue: bool = ...) -> bool:
    """Returns values of built-in fluid attributes such as density,
    velocity, etc., for individual grid cells or for all cells in the grid.fluid
    Args:
        attribute (str?): Specifies the fluid attribute for which to display values.  Valid  
                attributes are "force", "velocity", "density", "falloff",  
                "fuel", "color", and "temperature".  (Note that getting force values is an  
                alternate way of getting velocity values at one time step.)  
                Properties: create
        lowerFace (bool?): Only valid with "-at velocity".  Since velocity values are stored on the edges  
                of each voxel and not at the center, using voxel based indices to set velocity  
                necessarily affects neighboring voxels.  Use this flag to only set velocity  
                components on the lower left three faces of a voxel, rather than all six.  
                Properties: create
        xIndex (int?): Only return values for cells with this X index  
                Properties: create
        xvalue (bool?): Only get the first component of the vector-valued attribute specified by  
                the "-at/attribute" flag.
        yIndex (int?): Only return values for cells with this Y index  
                Properties: create
        yvalue (bool?): Only get the second component of the vector-valued attribute specified by  
                the "-at/attribute" flag.
        zIndex (int?): Only return values for cells with this Z index  
                Properties: create
        zvalue (bool?): Only get the third component of the vector-valued attribute specified by  
                the "-at/attribute" flag.

    Returns:
        bool:

    Example:
    """

def getInputDeviceRange(*args: Any, maxValue: bool = ..., minValue: bool = ...) -> List[float]:
    """This command lists the minimum and maximum values the device
    axis can return.  This value is the raw device values before
    any mapping is applied.  If you don't specify an axis the
    values for all axes of the device are returned.
    Args:
        maxValue (bool?): list only the maximum value of the axis  
                Properties: create
        minValue (bool?): list only the minimum value of the axis  
                Properties: create

    Returns:
        List[float]: Command result

    Example:
    """

def getLastError() -> None: ...
def getMetadata(*args: str, dataType: bool = ..., listChannelNames: bool = ..., listMemberNames: bool = ..., listStreamNames: bool = ..., memberName: str = ..., channelName: Queryable[str] = ..., channelType: Queryable[str] = ..., endIndex: str = ..., index: Queryable[Multiuse[str]] = ..., indexType: Queryable[str] = ..., scene: bool = ..., startIndex: str = ..., streamName: Queryable[str] = ...) -> Union[List[int], List[float], List[str], str, Multiuse[str], bool]:
    """This command is used to retrieve the values of metadata elements from a node or scene.
    It is restricted to returning a single structure member at a time. For convenience
    the detail required is only enough to find a single Member of a single Structure
    on a single metadata Channel.In the simplest case if there is a single Stream on one metadata Channel
    which uses a Structure with only one Member then all that is required is the
    name of the object containing the metadata. In the most complex case the
    'channelName', 'streamName', and 'memberName' are all required to narrow down
    the metadata to a single unique Member.In general for scripting it's a good idea to use all flags anyway since there
    could be metadata added anywhere. The shortcuts are mainly for quick entry when
    entering commands directly in the script editor or command line.When an Index is specified where data is not present the command fails with a
    message telling you which Index or Indices didn't have values. Use thecommand first to determine where metadata exists if you
    need to know in advance where to find valid metadata.Metadata on meshes is special in that the Channel types "vertex",
    "edge", "face", and "vertexFace" are directly connected to the
    components of the same name. To make getting these metadata
    Channels easier you can simply select or specify on the command
    line the corresponding components rather than using theandflags. For
    example the selection "myMesh.vtx[8:10]" corresponds toand eitheras a multi-use flag orOnly a single node or scene and unique metadata Structure Member are
    allowed in a single command. This keeps the data simple at the possible
    cost of requiring multiple calls to the command to get more than one
    Structure Member's value.When the data is returned it will be in Index order with an entire Member
    appearing together. For example if you were retrieving float[3] metadata on
    three components you would get the nine values back in the order:
    index[0]-float[0], index[0]-float[1], index[0]-float[2],
    index[1]-float[0], index[1]-float[1], index[1]-float[2],
    index[2]-float[0], index[2]-float[1], index[2]-float[2]. In the Python
    implementation the float[3] values will be an array each so you would
    get back three float[3] arrays.metadata, component, stream, channel, association
    Args:
        dataType (bool?): Used with the flag 'streamName' and 'memberName' to query the dataType  
                of the specfied member.  
                Properties: create
        listChannelNames (bool?): Query the channel names on the shape.  
                This flag can be used with some flags to filter the results.  
                It can be used with the flag 'streamName' to get the channel  
                with the specfied stream and the flag 'memberName' to get the channel  
                in which the stream contains the specified member.  
                It cannot be used with the flag 'channelName'.  
                Properties: create
        listMemberNames (bool?): Query the member names on the shape.  
                This flag can be used with some flags to filter the results. It can be used with  
                'streamName' to get the member which is in the specified stream and the flag  
                'channelName' to get the member which is used in the specfied channel.  
                It cannot be used with the flag 'memberName'.  
                Properties: create
        listStreamNames (bool?): Query the stream names on the shape.  
                This flag can be used with some flags to filter the results. It can be  
                used with the flag 'channelName' to get the stream names on the specified channel  
                and the flag 'memberName' to get the stream names which has the specified member.  
                It cannot be used with the flag 'streamName'.  
                Properties: create
        memberName (str?): Name of the Structure member being retrieved. The names of the members are  
                set up in the Structure definition, either through the description passed  
                in through the "dataStructure" command or via the API used to create that  
                Structure. This flag is only necessary when selected Structures have more  
                than one member.  
                Properties: create
        channelName (Queryable[str]?): Filter the metadata selection to only recognize metadata belonging to  
                the specified named Channel (e.g. "vertex"). This flag is ignored if the  
                components on the selection list are being used to specify the metadata  
                of interest.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        channelType (Queryable[str]?): Obsolete - use the 'channelName' flag instead.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        endIndex (str?): The metadata is stored in a Stream, which is an indexed list. If you have  
                mesh components selected then the metadata indices are implicit in the list  
                of selected components. If you select only the node or scene then this flag  
                may be used in conjunction with the startIndex flag to specify a range  
                of indices from which to retrieve the metadata. It is an error to have the  
                value of startIndex be greater than that of endIndex.  
              
              
                See also the index flag for an alternate way to specify multiple  
                indices. This flag can only be used on index types that support a range  
                (e.g. integer values - it makes no sense to request a range between two  
                strings)  
              
                			In query mode, this flag can accept a value.  
                Properties: create
        index (Queryable[Multiuse[str]]?): In the typical case metadata is indexed using a simple integer value.  
                Certain types of data may use other index types. e.g. a "vertexFace"  
                component will use a "pair" index type, which is two integer values; one  
                for the face ID of the component and the second for the vertex ID.  
              
              
                The index flag takes a string, formatted in the way the  
                specified indexType requires. All uses of the  
                index flag have the same indexType. If the type was  
                not specified it is assumed to be a simple integer value.  
              
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        indexType (Queryable[str]?): Name of the index type the new Channel should be using. If not specified this  
                defaults to a simple integer index. Of the native types only a mesh  
                "vertexFace" channel is different, using a "pair" index type.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        scene (bool?): Use this flag when you want to add metadata to the scene as a whole rather than to  
                any individual nodes. If you use this flag and have nodes selected the nodes will  
                be ignored and a warning will be displayed.  
                Properties: create, query
        startIndex (str?): The metadata is stored in a Stream, which is an indexed list. If you have  
                mesh components selected then the metadata indices are implicit in the list  
                of selected components. If you select only the node or scene then this flag  
                may be used in conjunction with the endIndex flag to specify a range of  
                indices from which to retrieve the metadata. It is an error to have the value  
                of startIndex be greater than that of endIndex.  
              
              
                See also the index flag for an alternate way to specify multiple  
                indices. This flag can only be used on index types that support a range  
                (e.g. integer values - it makes no sense to request a range between two  
                strings)  
              
                			In query mode, this flag can accept a value.  
                Properties: create
        streamName (Queryable[str]?): Name of the metadata Stream. Depending on context it could be the name of a  
                Stream to be created, or the name of the Stream to pass through the filter.  
                			In query mode, this flag can accept a value.  
                Properties: create, query

    Returns:
        List[int]: List of integer values from the metadata member
        List[float]: List of real values from the metadata member
        List[str]: List of string values from the metadata member

    Example:
    """

def getModifiers() -> int:
    """This command returns the current state of the modifier keys. The state
    of each modifier can be obtained by testing for the modifier's
    corresponding bit value in the return value. Shift is bit 1,
    Ctrl is bit 3, Alt is bit 4, and bit 5 is the 'Windows' key on Windows keyboards
    and the Command key on Mac keyboards.  See the provided
    example for more details on testing for each modifier's bit value.
    Returns:
        int: indicating which modifier keys are pressed.

    Example:
    """

def getModulePath(*, moduleName: str = ...) -> str:
    """Returns the module path for a given module name.module
    Args:
        moduleName (str?): The name of the module whose path you want to retrieve.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def getPanel(*, allConfigs: bool = ..., allPanels: bool = ..., allScriptedTypes: bool = ..., allTypes: bool = ..., atPosition: Tuple[int, int] = ..., configWithLabel: str = ..., containing: str = ..., invisiblePanels: bool = ..., scriptType: str = ..., type: str = ..., typeOf: str = ..., underPointer: bool = ..., visiblePanels: bool = ..., withFocus: bool = ..., withLabel: str = ...) -> List[str]:
    """This command returns panel and panel configuration information.
    Args:
        allConfigs (bool?): Return the names of the all panel configuration in a string array.  
                Properties: create
        allPanels (bool?): Return the names of all the panels in a string array.  
                Properties: create
        allScriptedTypes (bool?): Return the names of all types of scripted panels in a string array.  
                Properties: create
        allTypes (bool?): Return the names of all types of panels, except scripted types in  
                a string array.  
                Properties: create
        atPosition (Tuple[int, int]?): Return the name of the panel which contains the specified screen coordinates.  
                An empty string is returned if there is no panel at those coordinates.  
                Properties: create
        configWithLabel (str?): Return the name of the panel configuration with the specified label text.  
                Properties: create
        containing (str?): Return the name of the panel containing the specified control.  
                An empty string is returned if the specified control is not in  
                any panel.  
                Properties: create
        invisiblePanels (bool?): Return the names of all the invisible panels in a string array.  
                Properties: create
        scriptType (str?): Return the names of all scripted panels of the specified type in a  
                string array.  
                Properties: create
        type (str?): Return the names of all panels of the specified type in a string array.  
                Properties: create
        typeOf (str?): Return the type of the specified panel.  
                Properties: create
        underPointer (bool?): Return the name of the panel that the pointer is currently over.  
                An empty string is returned if the pointer is not over any panel.  
                Properties: create
        visiblePanels (bool?): Return the names of all the visible panels in a string array.  
                Properties: create
        withFocus (bool?): Return the name of the panel that currently has focus.  If no  
                panel has focus then the last panel that had focus is returned.  
                Properties: create
        withLabel (str?): Return the name of the panel with the specified label text.  
                Properties: create

    Returns:
        List[str]: An array of panel names

    Example:
    """

def getParticleAttr(*args: str, array: bool = ..., attribute: str = ..., object: str = ...) -> List[float]:
    """This action will return either an array of values, or the average
    value and maximum offset, for a specied per-particle attribute of a
    particle object or component.  If a particle component is specified on
    the command line, values are returned for that component only.  If an
    object name is given instead, values are returned for all particles in
    that object.  If no object name is passed, but a particle object or
    component is selected, values are returned for the selection.If you list components, they must all be from the same particle
    object; the action ignores all objects after the first.  Likewise if
    you list more than one object, the actiion will return values only for
    the first one.
    Args:
        array (bool?): Tells the action whether you want a full array of data. If set true,  
                the action returns an array of floats containing the values for all  
                the specified particles.  If set false (the default), the action  
                returns the average value and the maximum offset from the average over  
                the component.  If the attribute is a vector attribute, the action  
                returns six values: Average X, Average Y, Average Z, Maximum offset in X, Y, and Z of component.  
                Properties: create
        attribute (str?): Tells the action which attribute you want the value of.  
                Must be a per-particle attribute.  
                Properties: create
        object (str?): This flag is obsolete.  Instead of using it, please pass the  
                name of the object and/or components you want on the command line.  
                See the examples.  
                Properties: create

    Returns:
        List[float]: Command result

    Example:
    """

def getProcArguments(arg0: str = ..., /) -> None: ...
def getRenderDependencies(arg0: str = ..., /) -> str:
    """Command to return dependencies of an image source.  Image sources (such
    as render targets) can depend on other upstream image sources that result
    from renderings of 3D scene, or renderings of 2D compositing graphs.
    This command returns these dependencies, so that they can be analyzed and
    rendered.image, source, dependencies
    Returns:
        str: Dependencies for argument image source

    Example:
    """

def getRenderTasks(arg0: str = ..., /, *, camera: str = ..., renderLayer: str = ...) -> List[str]:
    """Command to return render tasks to render an image source.  Image
    source can depend on upstream image sources that result from
    renderings of 3D scene, or 2D renderings (e.g. render targets).
    This command obtains the graph of image source render dependencies,
    and creates render tasks according to these dependencies.  A render
    task has context, which can be camera, render layer, and resolution,
    or other, renderer-specific context.  Because of image source
    overrides, the render task context depends on the path through the
    render dependency graph, with the most upstream override for a context
    item applied.  As there can be multiple paths through a render
    dependency graph to a render dependency, there can be multiple render
    tasks for a given render dependency.imageSource, render, task
    Args:
        camera (str?): Camera node to use in the render context for the image source render task.  
                Properties: create
        renderLayer (str?): Render layer to use in the render context for the image source render task.  
                Properties: create

    Returns:
        List[str]: Render tasks (one per string) for argument render target.

    Example:
    """

def ghosting(*args: str, edit: bool = ..., query: bool = ..., action: str = ..., allGhostedObjects: bool = ..., allInRange: bool = ..., customFrames: Queryable[Multiuse[int]] = ..., enable: bool = ..., farOpacity: Queryable[float] = ..., frames: bool = ..., geometryFilter: bool = ..., ghostedObjects: bool = ..., ghostsStep: Queryable[int] = ..., hierarchy: bool = ..., jointFilter: bool = ..., locatorFilter: bool = ..., mode: Queryable[str] = ..., nearOpacity: Queryable[float] = ..., postColor: Queryable[Tuple[float, float, float]] = ..., postFrames: Queryable[int] = ..., preColor: Queryable[Tuple[float, float, float]] = ..., preFrames: Queryable[int] = ..., preset: Queryable[str] = ..., resetAll: bool = ..., useDriver: bool = ...) -> Union[bool, List[str], List[float], float, str, List[int], Multiuse[int], int, Tuple[float, float, float]]:
    """Provides an aggregated interface to all of the node-base ghosting parameters, as well
    as the global preferences used by this command for ghosting actions.
    Query the 'enable' flag to check if ghost drawing is currently enabled.
    If you run in create mode with no 'action' set then you will be modifying the current values of the ghosting parameters.
    If you have 'action=ghost' set then you will be modifying the current values of the ghosting parameters and then applying them to selected objects.OGS, ghosting
    Args:
        action (str?): Define the actions to be performed by the command. Legal values are  
                "ghost", "unghost", and "unghostAll".  
                The "ghost" will try to enable ghosting on all _visible_ DAG objects in the selection list.  
                Imtermediate transform nodes will only be ghosted if axis display are active.  
                Properties: create
        allGhostedObjects (bool?): Only works in edit mode, specifying that the edits are to be applied to all ghosted objects instead of just the selected ones.  
                Properties: edit
        allInRange (bool?): In create mode, define the default value for whether keyframe mode should use every keyframe in the playback range or use the specified values.  
                In edit mode, modify the all-in-range value for all ghosts.  
                In create mode with the "ghost" action, also set the custom ghost all-in-range value for the selected objects.  
                Properties: create, query, edit
        customFrames (Queryable[Multiuse[int]]?): In create mode, define the default value for the list of custom ghost frames.  
                In edit mode, modify the custom ghost frames for all ghosts. The special frame number "-9999999" is used  
                to remove all custom frames, circumventing a quirk in the command engine that does not allow passing an empty list.  
                In create mode with the "ghost" action, also set the custom ghost frames for the selected objects.  
                Properties: create, query, edit, multiuse
        enable (bool?): Enables or disables ghost visibility on the entire scene. This does not modify  
                any of the node ghosting attributes, it only globally enables or disables the  
                drawing of any ghosts that have been defined on nodes.  
                This is a preference-based flag so its value will persist between sessions,  
                even if you load a new file with different ghost attribute settings.  
                Properties: create, query
        farOpacity (Queryable[float]?): In create mode, define the default value for the opacity value for ghosts farthest away from the current time.  
                In edit mode, modify the opacity value of ghosts farthest away from the current time for all ghosts.  
                In create mode with the "ghost" action, also set the opacity value of ghosts farthest away from the current time for the selected objects.  
                Properties: create, query, edit
        frames (bool?): Queries the current set of ghost frames on the selected objects based on the ghosting  
                mode, parameters set on the object, and the current time when relevant. Ignores the state  
                of the ghosting enabled flag.  
                Properties: query
        geometryFilter (bool?): In create mode, enable or disable the default ghost geometry filter.  
                In create mode with the "ghost" action set, also filter the selection to omit geometry nodes if this flag is false.  
                Properties: create, query, edit
        ghostedObjects (bool?): Only works in query mode to find the names of all currently ghosted DAG nodes.  
                Properties: query
        ghostsStep (Queryable[int]?): In create mode, define the default value for the number of steps (keyframes or frames) between ghosts.  
                In edit mode, modify the number of steps (keyframes or frames) between ghosts.  
                In create mode with the "ghost" action, also set the default number of steps (keyframes or frames) between ghosts for the selected objects.  
                Properties: create, query, edit
        hierarchy (bool?): Enables or disables the ghost hierarchy default value. When no ghosting action is set it does  
                not modify any of the node ghosting attributes, it only sets the preference for how  
                future commands will filter the list of affected nodes.  
                When used in conjunction with a ghosting action it will fist set the preference value and  
                then use that new value as a filter on the ghosting action. If a ghosting action is specified  
                without this flag then the current value of the preference is used in its place.  
                This is a preference-based flag so its value will persist between sessions,  
                even if you load a new file with different ghost attribute settings.  
                Properties: create, query, edit
        jointFilter (bool?): In create mode, enable or disable the default ghost joint filter.  
                In create mode with the "ghost" action set, also filter the selection to omit joint nodes if this flag is false.  
                Properties: create, query, edit
        locatorFilter (bool?): In create mode, enable or disable the default ghost locator filter.  
                In create mode with the "ghost" action set, also filter the selection to omit locator nodes if this flag is false.  
                Properties: create, query, edit
        mode (Queryable[str]?): Define the default mode for ghosting actions. Legal values are "preAndPost",  
                "pre", "post", "custom", and "keyframes".  
                Properties: create, query, edit
        nearOpacity (Queryable[float]?): In create mode, define the default value for the opacity value for ghosts nearest to the current time.  
                In edit mode, modify the opacity value of ghosts nearest to the current time for all ghosts.  
                In create mode with the "ghost" action, also set the opacity value of ghosts nearest to the current time for the selected objects.  
                Properties: create, query, edit
        postColor (Queryable[Tuple[float, float, float]]?): In create mode, define the default value for the color of ghosts after the current time.  
                In edit mode, modify the color of ghosts after the current time for all ghosts.  
                In create mode with the "ghost" action, also set the color of ghosts after the current time for the selected objects.  
                Properties: create, query, edit
        postFrames (Queryable[int]?): In create mode, define the default value for the number of ghosted frames after the current time.  
                In edit mode, modify the number of ghosted frames after the current time for all ghosts.  
                In create mode with the "ghost" action, also set the default number of ghosted frames after the current time for the selected objects.  
                Properties: create, query, edit
        preColor (Queryable[Tuple[float, float, float]]?): In create mode, define the default value for the color of ghosts before the current time.  
                In edit mode, modify the color of ghosts before the current time for all ghosts.  
                In create mode with the "ghost" action, also set the color of ghosts before the current time for the selected objects.  
                Properties: create, query, edit
        preFrames (Queryable[int]?): In create mode, define the default value for the number of ghosted frames before the current time.  
                In edit mode, modify the number of ghosted frames before the current time for all ghosts.  
                In create mode with the "ghost" action, also set the default number of ghosted frames before the current time for the selected objects.  
                Properties: create, query, edit
        preset (Queryable[str]?): Define the default mode for ghosting presets. Legal values are "1s", "2s", "4s", "5s", "10s", and "Custom".  
                Setting anything other than "Custom" fixes ghosts at 3 pre frames, 3 post frames, with a step value of the preset  
                (e.g. "2s" means show ghosts at every second frame or keyframe)  
                Properties: create, query, edit
        resetAll (bool?): Reset all ghosting options to their default values. Use with caution!  
                Properties: create, edit
        useDriver (bool?): In create mode, enable or disable the default ghost use driver value.  
                In edit mode, modify the use driver value of all existing ghosts.  
                In create mode with the "ghost" action, also set the use driver value for the selected objects.  
                Properties: create, query, edit

    Returns:
        bool: the previous global state of ghost visibility (after setting 'enable' flag)
        bool: the global state of ghost visibility (query 'enabled' flag)
        bool: the global state of the default ghost all-in-range value (query 'allInRange' flag)
        bool: the global state of the default ghost hierarchy (query 'hierarchy' flag)
        bool: the global state of the default ghost geometry filter (query 'geometryFilter' flag)
        bool: the global state of the default ghost joint filter (query 'jointFilter' flag)
        bool: the global state of the default ghost locator filter (query 'locatorFilter' flag)
        bool: the global state of the default post frame count (query 'postFrames' flag)
        bool: the global state of the default pre frame count (query 'preFrames' flag)
        bool: the global state of the default ghost frames step count (query 'ghostsStep' flag)
        List[str]: List of all objects for which ghosting was enabled ('action="ghost"' in create mode)
        List[str]: List of all objects for which ghosting was disabled ('action="unghost"' or 'action="unghostAll"' in create mode)
        List[str]: List of all objects for which ghosting is currently enabled (query 'ghostedObjects' flag)
        List[str]: List of affected objects (any flag in edit mode)
        List[float]: List of (frame1, frame2, ...) that is the union of ghosted frames on all selected objects (query 'frames' flag)
        float: Current opacity value for ghosts farthest from the current time (query 'farOpacity' flag)
        float: Current opacity value for ghosts closest to the current time (query 'nearOpacity' flag)
        float: The previous opacity value for ghosts farthest from the current time (set 'farOpacity' flag)
        float: The previous opacity value for ghosts closest to the current time (set 'nearOpacity' flag)
        str: Current ghosting mode (query 'mode' flag)
        str: The previous ghosting mode (set 'mode' flag)
        List[float]: Color as [red, green, blue] used for ghosts after the current time (query 'postColor' flag)
        List[float]: Previous color as [red, green, blue] used for ghosts after the current time (set 'postColor' flag)
        List[float]: Color as [red, green, blue] used for ghosts before the current time (query 'preColor' flag)
        List[float]: Previous color as [red, green, blue] used for ghosts before the current time (set 'preColor' flag)
        List[int]: Custom frame list for the 'frames' mode (query 'customFrames' flag)
        List[int]: Previous custom frame list (set 'customFrames' flag)

    Example:
    """

def glRender(*, edit: bool = ..., query: bool = ..., accumBufferPasses: Queryable[int] = ..., alphaSource: Queryable[str] = ..., antiAliasMethod: Queryable[str] = ..., cameraIcons: bool = ..., clearClr: Queryable[Tuple[float, float, float]] = ..., collisionIcons: bool = ..., crossingEffect: bool = ..., currentFrame: bool = ..., drawStyle: Queryable[str] = ..., edgeSmoothness: Queryable[float] = ..., emitterIcons: bool = ..., fieldIcons: bool = ..., flipbookCallback: Queryable[str] = ..., frameEnd: Queryable[int] = ..., frameIncrement: Queryable[int] = ..., frameStart: Queryable[int] = ..., fullResolution: bool = ..., grid: bool = ..., imageDirectory: Queryable[str] = ..., imageName: Queryable[str] = ..., imageSize: Queryable[Tuple[int, int, float]] = ..., lightIcons: bool = ..., lightingMode: Queryable[str] = ..., lineSmoothing: bool = ..., offScreen: bool = ..., renderFrame: Queryable[str] = ..., renderSequence: Queryable[str] = ..., sharpness: Queryable[float] = ..., shutterAngle: Queryable[float] = ..., textureDisplay: bool = ..., transformIcons: bool = ..., useAccumBuffer: bool = ..., viewport: Queryable[Tuple[int, int, float]] = ..., writeDepthMap: bool = ...) -> Union[bool, int, str, Tuple[float, float, float], float, Tuple[int, int, float]]:
    """This command provides access to the Hardware Render Manager (HRM). There
    is one-and-only-one HRM in maya. The HRM controls the rendering performed
    in the hardware render buffer window. This command allows shell scripts,
    to modify the render state, and to initiate a render request.
    Args:
        accumBufferPasses (Queryable[int]?): Set the number of accum buffer render passes.  
                Properties: query, edit
        alphaSource (Queryable[str]?): Control the alpha source when writing image files. Valid values  
                include: off, alpha, red, green, blue, luminance, clamp, invClamp.  
                Properties: query, edit
        antiAliasMethod (Queryable[str]?): Set the method used for anti-aliasing polygons: off,  
                uniform, gaussian.  
                Properties: query, edit
        cameraIcons (bool?): Set display status of camera icons.  
                Properties: query, edit
        clearClr (Queryable[Tuple[float, float, float]]?): Set the viewport clear color (0. 1).  
                Properties: query, edit
        collisionIcons (bool?): Set display status of collison model icons.  
                Properties: query, edit
        crossingEffect (bool?): Enable/disable image filtering with a convolution filter.  
                Properties: query, edit
        currentFrame (bool?): Returns the current frame being rendered.  
                Properties: query
        drawStyle (Queryable[str]?): Set the object drawing style: boundingBox, points, wireframe,  
                flatShaded, smoothShaded.  
                Properties: query, edit
        edgeSmoothness (Queryable[float]?): Controls the amount of edge smoothing. A value of 0.0 gives no  
                smoothing, 1.0 gives default smoothing, and any other value scales  
                the amount of default smoothing. Must enable the accumulation buffer.  
                Properties: query, edit
        emitterIcons (bool?): Set display status of emitter icons.  
                Properties: query, edit
        fieldIcons (bool?): Set display status of field icons.  
                Properties: query, edit
        flipbookCallback (Queryable[str]?): Register a procedure to be called after the render sequence has  
                completed. Used to build the flipbook pulldown menu. See the  
                example section for more details about how to build this procedure.  
                Properties: query, edit
        frameEnd (Queryable[int]?): Set the last frame to be rendered.  
                Properties: query, edit
        frameIncrement (Queryable[int]?): Set the frame increment during rendering.  
                Properties: query, edit
        frameStart (Queryable[int]?): Set the first frame to be rendered.  
                Properties: query, edit
        fullResolution (bool?): Enable/disable rendering to full image output resolution.  
                Must set a valid image output resolution (-is).  
                Properties: query, edit
        grid (bool?): Set display status of the grid.  
                Properties: query, edit
        imageDirectory (Queryable[str]?): Set the directory for the image files.  
                Properties: query, edit
        imageName (Queryable[str]?): Set the base name of the image files.  
                Properties: query, edit
        imageSize (Queryable[Tuple[int, int, float]]?): Set the image output size. Takes width, height and aspect ratio.  
                Pass 0,0,0 to use current port size. The image size must be equal to  
                or greater then the viewport size. Large images will be tiled if full  
                resolution rendering has been enabled (-fr/fullResolution).  
                Properties: query, edit
        lightIcons (bool?): Set display status of light icons.  
                Properties: query, edit
        lightingMode (Queryable[str]?): Set the lighting mode used for rendering: all, selected, default.  
                Properties: query, edit
        lineSmoothing (bool?): Enable/disable anti-aliased lines.  
                Properties: query, edit
        offScreen (bool?): When set, this toggle allow HRM to use an offscreen buffer  
                to render the view. This allows HRM to work when the application  
                is iconified, or obscured  
                Properties: query, edit
        renderFrame (Queryable[str]?): Render the current frame. Requires the name of the view in  
                which to render.  
                Properties: query, edit
        renderSequence (Queryable[str]?): Render the current frame sequence. Requires the name of the  
                view in which to render.  
                Properties: query, edit
        sharpness (Queryable[float]?): Control the sharpness level of the convolution filter.  
                Properties: query, edit
        shutterAngle (Queryable[float]?): Set the shutter angle used for motion blur (0. 1). A value  
                of 0.0 gives no blurring, 0.5 gives correct blurring, and 1.0  
                gives continuous blurring. Must enable the accumulation buffer.  
                Properties: query, edit
        textureDisplay (bool?): Enable/disable texture map display.  
                Properties: query, edit
        transformIcons (bool?): Set display status of transform icons.  
                Properties: query, edit
        useAccumBuffer (bool?): Enable/disable the accumulation buffer.  
                Properties: query, edit
        viewport (Queryable[Tuple[int, int, float]]?): Set the viewport size. Pass in the width, height and aspect ratio.  
                This size will be used for all test rendering and image output size  
                unless full resolution (-fr) has been set and a valid image output  
                size (-is) has been set.  
                Properties: query, edit
        writeDepthMap (bool?): Enable/disable writing of zdepth to image files.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def glRenderEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., lookThru: Queryable[str] = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., viewCameraName: bool = ...) -> Union[bool, str]:
    """Create a glRender view. This is a special view used for hardware
    rendering. This command is used to create and reparent the view
    as needed to support panels. See the glRender command for controlling
    the specific behavior of the hardware rendering.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lookThru (Queryable[str]?): Specify which camera the glRender view should be using.  
                Properties: create, query, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        viewCameraName (bool?): Returns the name of the current camera used by the glRenderPanel. This  
                is a query only flag.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def globalStitch(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., lockSurface: Queryable[Multiuse[bool]] = ..., maxSeparation: Queryable[float] = ..., modificationResistance: Queryable[float] = ..., nodeState: Queryable[int] = ..., sampling: Queryable[int] = ..., stitchCorners: Queryable[int] = ..., stitchEdges: Queryable[int] = ..., stitchPartialEdges: bool = ..., stitchSmoothness: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, Multiuse[bool], float, int]:
    """This command computes a globalStitch of NURBS surfaces. There
    should be at least one  NURBS surface. The
    NURBS surface(s) should be untrimmed.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        lockSurface (Queryable[Multiuse[bool]]?): Keep the NURBS surface at the specified multi index unchanged by the fitting.  
                Default: false  
                Properties: create, query, edit, multiuse
        maxSeparation (Queryable[float]?): Maximum separation that will still be stitched.  
                Default: 0.1  
                Properties: create, query, edit
        modificationResistance (Queryable[float]?): Modification resistance weight for surface CVs.  
                Default: 1e-1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        sampling (Queryable[int]?): Sampling when stitching edges.  
                Default: 1  
                Properties: create, query, edit
        stitchCorners (Queryable[int]?): Stitch corners of surfaces.  
                0. off  
                1. closest point  
                2. closest knot  
                Default: 1  
                Properties: create, query, edit
        stitchEdges (Queryable[int]?): Stitch edges of surfaces.  
                0. off  
                1. closest point  
                2. matching params  
                Default: 1  
                Properties: create, query, edit
        stitchPartialEdges (bool?): Toggle on (off) partial edge stitching.  
                Default: false  
                Properties: create, query, edit
        stitchSmoothness (Queryable[int]?): Set type of smoothness of edge join.  
                0. off  
                1. tangent  
                2. normal  
                Default: 0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def goal(*args: str, query: bool = ..., goal: Queryable[Multiuse[str]] = ..., index: bool = ..., useTransformAsGoal: bool = ..., weight: float = ...) -> Union[str, Multiuse[str], bool]:
    """Specifies the given objects as being goals for the given particle
    object.  If the goal objects are geometry, each particle in the particle
    object will each try to follow or match its position to that of a certain
    vertex/CV/lattice point of the goal.  If the goal object is another
    particle object, each particle will try to follow a paricle of the goal.
    In any other case, all the particles will try to follow the current location
    of the goal object's transform.  You can get this latter behavior for
    a geometry or particle object too by using -utr true.The goal weight can be keyframed.  It lives on the particle object to
    which the goal was added and is a multi-attribute.
    Args:
        goal (Queryable[Multiuse[str]]?): This flag specifies string to be a goal of the particle object on  
                the command line or the currently selected particle object.  This flag  
                can be used multiple times to specify multiple goals for a particle  
                object.  Query is for use by the attribute editor.  
                Properties: create, query, multiuse
        index (bool?): Returns array of multi-attribute indices for the goals.  
                Intended for use by the Attribute Editor.  
                Properties: query
        useTransformAsGoal (bool?): Use transform of specified object instead of the shape.  
                Meaningful only for particle and geometry objects.  Can only be  
                passed once, applies to all objects passed with -g.  
                Properties: create
        weight (float?): This specifies the goal weight as a value from 0 to 1.  A value of 0  
                means that the goal's position will have no effect on the particle  
                object, while a weight of 1 will make the particle object try to follow  
                the goal object exactly.  This flag can only be passed once and sets  
                the weight for every goal passed with the -g/-goal flag.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def grabColor(*, alpha: bool = ..., hsvValue: bool = ..., rgbValue: bool = ...) -> float:
    """This command changes the cursor and enters a modal state which will be
    exited by pressing a mouse button.  The color component values of the
    pixel below the cursor at the time of the button press are returned.
    Args:
        alpha (bool?): Appends the alpha value to the results  
                Properties: create
        hsvValue (bool?): The 3 returned float values will specify the hue, saturation and  
                value color components.  
                Properties: create
        rgbValue (bool?): Default : the 3 returned float values will specify the red, green and blue  
                color components.  
                Properties: create

    Returns:
        float: []
            
            Three float values representing the color components of the pixel below
            the cursor.  If no flags are specified then the default is to return
            the red, green and blue color components.

    Example:
    """

def gradientControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adaptiveScaling: bool = ..., annotation: Queryable[str] = ..., attribute: str = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clearAttribute: bool = ..., defineTemplate: str = ..., displayKeyInfo: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightMode: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfControls: Queryable[int] = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., readOnly: bool = ..., refreshOnRelease: Queryable[int] = ..., selectedColorControl: str = ..., selectedInterpControl: str = ..., selectedPositionControl: str = ..., staticNumberOfControls: bool = ..., staticPositions: bool = ..., statusBarMessage: str = ..., upperLimitControl: Queryable[str] = ..., useTemplate: str = ..., verticalLayout: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Callable[..., Any]]:
    """This command creates a control that displays
    the gradient attribute specified. The gradient attribute must be
    of the correct form and naming. It should be a multi attribute
    with each entry a compound composed of:Currently the routines to get the value of a ramp structure
    (with interpolation) are not available through MEL, which limits
    the use of this control by end users. The MEL command AEaddRampControl
    should be used to attach this control to an attribute from attribute
    editor templates.
    Args:
        adaptiveScaling (bool?): Allow the ramp widget display to scale vertically to  
                accommodate values greater than 1.0. True if adaptive scaling is  
                enabled, false (the default) if not.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attribute (str?): Specifies the name of the gradient attribute to control.  
                Properties: create, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clearAttribute (bool?): Removes the gradient attribute that controls the widget.  
                A new attribute can be set again using the attribute flag  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayKeyInfo (bool?): Specifies if key position should be displayed in a tooltip when the user  
                hovers over or drags a control point.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlightMode (Queryable[str]?): Specifies when the ramp should be highlighted. Only applies to curves.  
                Possible values are "off", "hover" and "always". Default is "off".  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfControls (Queryable[int]?): Returns the number of controls in the ramp widget  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        readOnly (bool?): Specifies if the ramp is read only or not. If true, the ramp  
                can't be edited and control points will be hidden.  
                Properties: create, query, edit
        refreshOnRelease (Queryable[int]?): Define how updates are dispatched during interactive  
                editing of the ramp widget. True causes updates to only dispatch  
                after releasing the mouse button after editing. False (the default)  
                causes updates to dispatch interactively during editing (e.g. while  
                moving ramp curve points). Note that the global update mode, if  
                set to "on release" can disable the effect of this option.  
                Properties: create, query, edit
        selectedColorControl (str?): Specifies the name of a color control to edit the selected color.  
                Properties: create, edit
        selectedInterpControl (str?): Specifies the name of an enum control to edit the selected  
                interpolation.  
                Properties: create, edit
        selectedPositionControl (str?): Specifies the name of a float slider to edit the selected  
                position.  
                Properties: create, edit
        staticNumberOfControls (bool?): When 'true', this flag disables the creation/deletion of  
                ramp entries (control points) via ramp widget interaction. Default  
                is false.  
                Properties: create, query, edit
        staticPositions (bool?): When 'true', this flag disables the interactive modification  
                of ramp entry positions. Default is false.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        upperLimitControl (Queryable[str]?): Specify the name of a text control which is updated with the  
                current upper display limit for the ramp. This option is only  
                effective when adaptiveScaling is specified.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalLayout (bool?): When 'true', this makes the control orient vertically rather than  
                horizontally. The default is `false` or horizontal.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the port created or modified

    Example:
    """

def gradientControlNoAttr(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., asString: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., currentKey: Queryable[int] = ..., currentKeyChanged: Callable[..., Any] = ..., currentKeyColorValue: Queryable[Tuple[float, float, float]] = ..., currentKeyCurveValue: bool = ..., currentKeyInterpValue: Queryable[int] = ..., defineTemplate: str = ..., displayKeyInfo: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightMode: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., optionVar: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rampAsColor: bool = ..., readOnly: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., valueAtPoint: float = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, bool, Callable[..., Any]]:
    """This command creates a control for editing a ramp (2D control
    curve). The control attaches to an optionVar used to store and
    retrieve the encoded gradient control points stored in a string.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        asString (Queryable[str]?): Used to query and set the value of the ramp as a string of comma  
                separated values  
                Properties: query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Specifies a command to be executed whenever the value of this ramp  
                is modified. This option should not be used when specifying an  
                optionVar.  
                Properties: edit
        currentKey (Queryable[int]?): Returns the index of the currently selected key.  
                Properties: create, query, edit
        currentKeyChanged (Callable[..., Any]?): Specifies a command to be executed whenever the selected key  
                changes.  
                Properties: edit
        currentKeyColorValue (Queryable[Tuple[float, float, float]]?): Get or set the color of the currently selected key.  
                Only useful if the ramp is set to be a color ramp.  
                Properties: query, edit
        currentKeyCurveValue (bool?): Get or set the value of the currently selected key.  
                Only useful if the ramp is set to be a curve ramp.  
                Properties: query, edit
        currentKeyInterpValue (Queryable[int]?): Get or set the interpolation value for the current key.  
                Properties: query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayKeyInfo (bool?): Specifies if key position should be displayed in a tooltip when the user  
                hovers over or drags a control point.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Specifies a command to be executed while the ramp is being modified.  
                Properties: edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlightMode (Queryable[str]?): Specifies when the ramp should be highlighted. Only applies to curves.  
                Possible values are "off", "hover" and "always". Default is "off".  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        optionVar (Queryable[str]?): Specifies the name of the option var used to store and  
                retrieve the string value capturing the curve.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rampAsColor (bool?): Sets whether the ramp should be viewed as a colour ramp or as  
                a curve.  Default is as a curve.  
                Properties: create, query, edit
        readOnly (bool?): Specifies if the ramp is read only or not. If true, the ramp  
                can't be edited and control points will be hidden.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        valueAtPoint (float?): Used during query to specify the point at which to query the curve.  
                      In query mode, this flag needs a value.  
                Properties: query
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the port created or modified

    Example:
    """

def graphDollyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command can be used to create a dolly context
    for the graph editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def graphSelectContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """This command can be used to create a selection context for the
    hypergraph editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: Command result

    Example:
    """

def graphTrackCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command can be used to create a track context
    for the graph editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def gravity(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A gravity field simulates the Earth's gravitational force.   It pulls
    objects in a fixed direction (generally downward) entirely
    independent of their position or mass.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.The default for -dx -dy -dz is always the opposite of the current up
    direction. For example, if the current up direction is (0,1,0)
    (a standard Maya configuration), then the gravity default is
    -dx 0 -dy -1 -dz 0.  The default for -a is 9.8.  9.8 meters per second
    squared happens to be standard Earth gravity, but in fact Maya interprets
    this value as centimeters per second squared.  If we were to use it as
    meters per second squared then with default Maya units, your particles
    would vanish almost in the wink of an eye. If you want a different value,
    set it in the gravity option box.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        directionX (Queryable[float]?): X-component of direction.  
                Properties: query, edit
        directionY (Queryable[float]?): Y-component of direction.  
                Properties: query, edit
        directionZ (Queryable[float]?): Z-component of direction  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def grid(*args: str, query: bool = ..., default: bool = ..., displayAxes: bool = ..., displayAxesBold: bool = ..., displayDivisionLines: bool = ..., displayGridLines: bool = ..., displayOrthographicLabels: bool = ..., displayPerspectiveLabels: bool = ..., divisions: Queryable[int] = ..., orthographicLabelPosition: Queryable[str] = ..., perspectiveLabelPosition: Queryable[str] = ..., reset: bool = ..., size: Queryable[float] = ..., spacing: Queryable[float] = ..., style: Queryable[int] = ..., toggle: bool = ...) -> Union[bool, int, str, float]:
    """This command changes the size and spacing of lines on the ground
    plane displayed in the perspective and orthographic views.This command lets you reset the ground plane, change its size
    and grid line spacing, grid subdivisions and display options.
    Args:
        default (bool?): Used to specify/query default values.  
                Properties: query
        displayAxes (bool?): Specify true to display the grid axes.  
                Properties: query
        displayAxesBold (bool?): Specify true to accent the grid axes by drawing them with a  
                thicker line.  
                Properties: query
        displayDivisionLines (bool?): Specify true to display the subdivision lines between  
                grid lines.  
                Properties: query
        displayGridLines (bool?): Specify true to display the grid lines.  
                Properties: query
        displayOrthographicLabels (bool?): Specify true to display the grid line numeric labels in  
                the orthographic views.  
                Properties: query
        displayPerspectiveLabels (bool?): Specify true to display the grid line numeric labels in  
                the perspective view.  
                Properties: query
        divisions (Queryable[int]?): Sets the number of subdivisions between major grid lines.  
                The default is 10. If the spacing is 10 units, setting  
                divisions to 10 will cause division lines to appear 1 unit  
                apart.  
                Properties: query
        orthographicLabelPosition (Queryable[str]?): The position of the grid's numeric labels in orthographic  
                views. Valid values are    "axis" and "edge".  
                Properties: query
        perspectiveLabelPosition (Queryable[str]?): The position of the grid's numeric labels in perspective  
                views. Valid values are    "axis" and "edge".  
                Properties: query
        reset (bool?): Resets the ground plane to its default values
        size (Queryable[float]?): Sets the size of the grid in linear units.  The default is  
                12 units.  
                Properties: query
        spacing (Queryable[float]?): Sets the spacing between major grid lines in linear units.  
                The default is 10 units.  
                Properties: query
        style (Queryable[int]?): This flag is obsolete and should not be used.  
                Properties: query
        toggle (bool?): Turns the ground plane display off in all windows, including  
                orthographic windows.  Default is true.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def gridLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowEmptyCells: bool = ..., annotation: Queryable[str] = ..., autoGrow: bool = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., cellHeight: Queryable[int] = ..., cellWidth: Queryable[int] = ..., cellWidthHeight: Tuple[int, int] = ..., childArray: bool = ..., columnsResizable: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., gridOrder: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfColumns: Queryable[int] = ..., numberOfPopupMenus: bool = ..., numberOfRows: Queryable[int] = ..., numberOfRowsColumns: Tuple[int, int] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., position: Multiuse[Tuple[str, int]] = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Callable[..., Any]]:
    """This layout arranges children in a grid fashion where every
    cell in the grid is the same size.  You may specify the number
    of rows and columns as well as the width and height of the grid
    cells.
    Args:
        allowEmptyCells (bool?): Specify true if you want free positioning of the children  
                in the layout and potentially leaving empty cells between children.  
                Set to false if you want the children to always be packed together.  
                The default is true.  
                Properties: create, query
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        autoGrow (bool?): Specify true if you want the grid layout size to grow as  
                children are added.  For example, if the grid layout has 2 columns  
                and 2 rows then adding a fifth child will cause the grid to expand  
                to 3 rows if this flag is true, otherwise the grid will remain the  
                same size and the new child will be hidden from view until you  
                expand the size of the grid using the appropriate flags.  The  
                default is true.  
                Properties: create, query
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        cellHeight (Queryable[int]?): A positive non-zero integer value indicating the height  
                of cells in the grid layout.  
                Properties: create, query, edit
        cellWidth (Queryable[int]?): A positive non-zero integer value indicating the width  
                of cells in the grid layout.  
                Properties: create, query, edit
        cellWidthHeight (Tuple[int, int]?): Two positive non-zero integer values for indicating the  
                width and height, respectively, of the cells in the grid layout.  
                Properties: create, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        columnsResizable (bool?): Specify true if you want the number of columns to adjust  
                according to the width of the layout.  Set to false if you want  
                the number of columns to remain fixed when the width of the  
                layout is changed.  The default is false.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        gridOrder (bool?): As opposed to the childArray flag, the gridOrder flag  
                returns the children of the grid Layout in the order they  
                are diplayed in the window.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfColumns (Queryable[int]?): A positive non-zero integer value indicating the number  
                of columns in the grid layout.  
                Properties: create, query, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfRows (Queryable[int]?): A positive non-zero integer value indicating the number  
                of rows in the grid layout.  
                Properties: create, query, edit
        numberOfRowsColumns (Tuple[int, int]?): Two positive non-zero integer values for the number  
                of rows and columns, respectively, in the grid layout.  
                Properties: create, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        position (Multiuse[Tuple[str, int]]?): Specify the name of a child control in the grid layout along  
                with a 1. based integer value indicating the desired  
                position of the child.  Positions increase from left to right  
                within a row and then wrap around to the next row increasing from  
                top to bottom.  For example, a grid layout with 3 columns and 2  
                rows has 6 visible positions where 1, 2 and 3 occupy the first row  
                and 4, 5 and 6 occupy the second.  
                Properties: create, edit, multiuse
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def group(*args: str, absolute: bool = ..., empty: bool = ..., name: str = ..., parent: str = ..., relative: bool = ..., useAsGroup: str = ..., world: bool = ...) -> str:
    """This command groups the specified objects under a new group
    and returns the name of the new group.If the -em flag is specified, then an empty group (with no
    objects) is created.If the -w flag is specified then the new group is placed under the
    world, otherwise if -p is specified it is placed under the
    specified node. If neither -w or -p is specified the new group is
    placed under the lowest common group they have in common. (or the
    world if no such group exists)If an object is grouped with another object that has the same name
    then one of the objects will be renamed by this command.
    Args:
        absolute (bool?): preserve existing world object transformations  
                (overall object transformation is preserved  
                by modifying the objects local transformation)  
                [default]  
                Properties: create
        empty (bool?): create an empty group (with no objects in it)  
                Properties: create
        name (str?): Assign given name to new group node.  
                Properties: create
        parent (str?): put the new group under the given parent  
                Properties: create
        relative (bool?): preserve existing local object transformations  
                (relative to the new group node)  
                Properties: create
        useAsGroup (str?): Use the specified node as the group node. The specified node must be  
                derived from the transform node and must not have any existing parents  
                or children.  
                Properties: create
        world (bool?): put the new group under the world  
                Properties: create

    Returns:
        str: - name of the group node

    Example:
    """

def groupParts() -> None: ...
def hardenPointCurve(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., multiplicity: Queryable[int] = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int]:
    """The hardenPointCurve command changes the knots of a curve given a list
    of control point indices so that the knot corresponding to that
    control point gets the specified multiplicity.  Multiplicity of -1 is
    the universal value used for multiplicity equal to the degree of
    the curve.The CV whose multiplicity is being raised needs to have its
    neighbouring CVs of multiplicity 1.  How many neighbours depends on
    the degree of the curve and the difference in CV multiplicities before
    and after this operation.  For example, if you're changing a CV of
    multiplicity 1 into a CV of multiplicity 3, you will need the 4
    neighbouring CVs (2 on each side) to be of multiplicity 1.  The CVs
    that do not satisfy that requirement will be ignored.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        multiplicity (Queryable[int]?): the required multiplicity of the curve knot  
                Default: -1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def hardware(*, brdType: bool = ..., cpuType: bool = ..., graphicsType: bool = ..., megaHertz: bool = ..., numProcessors: bool = ...) -> str:
    """Return description of the hardware available in the machine.
    Args:
        brdType (bool?): Returns IP number identifying the CPU motherboard  
                Properties: create
        cpuType (bool?): Returns type of CPU  
                Properties: create
        graphicsType (bool?): Returns string identifying graphics hardware type  
                Properties: create
        megaHertz (bool?): Returns string identifying the speed of the CPU chip  
                Properties: create
        numProcessors (bool?): Returns string identifying the number of processors  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def hardwareRenderPanel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., camera: Queryable[str] = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., glRenderEditor: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command creates, edit and queries hardware render panels which contain
    only a hardware render editor.
    Args:
        camera (Queryable[str]?): Query or edit the camera in a gl render panel.  
                Properties: query, edit
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        glRenderEditor (bool?): Query only. This flag returns the name of the  
                gl render editor contained in the panel.  
                Properties: query
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Panel name

    Example:
    """

def hasMetadata(*args: str, asList: bool = ..., ignoreDefault: bool = ..., memberName: str = ..., channelName: Queryable[str] = ..., channelType: Queryable[str] = ..., endIndex: str = ..., index: Queryable[Multiuse[str]] = ..., indexType: Queryable[str] = ..., scene: bool = ..., startIndex: str = ..., streamName: Queryable[str] = ...) -> Union[List[str], List[bool], str, Multiuse[str], bool]:
    """This command is used to query for the presence of metadata elements on a node,
    components, or scene. The command works at all levels of metadata presence, from
    the existence of any metadata at all on a node or scene right down to the presence
    of metadata values set on a particular metadata Stream index.metadata, component, stream, channel, association
    Args:
        asList (bool?): Use this flag when you want to return string values indicating where the  
                metadata lives rather than boolean values. See the command description  
                for more details on what this flag will return.  
                Properties: create
        ignoreDefault (bool?): Use this flag when you want to skip over any metadata that has only  
                default values. i.e. the metadata may exist but it hasn't had a new  
                value set yet (non-zero for numerics, non-empty strings, etc.)  
                See the command description for more details on how this flag filters  
                the search.  
                Properties: create
        memberName (str?): Name of the Structure member being checked. The names of the members are  
                set up in the Structure definition, either through the description passed  
                in through the "dataStructure" command or via the API used to create that  
                Structure. As the assignment of metadata is on a per-structure basis this  
                flag only needs to be specified when querying for non-default values. If  
                you query for non-default values and omit this flag then it checks that  
                any of the members have a non-default value.  
                Properties: create
        channelName (Queryable[str]?): Filter the metadata selection to only recognize metadata belonging to  
                the specified named Channel (e.g. "vertex"). This flag is ignored if the  
                components on the selection list are being used to specify the metadata  
                of interest.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        channelType (Queryable[str]?): Obsolete - use the 'channelName' flag instead.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        endIndex (str?): The metadata is stored in a Stream, which is an indexed list. If you have  
                mesh components selected then the metadata indices are implicit in the list  
                of selected components. If you select only the node or scene then this flag  
                may be used in conjunction with the startIndex flag to specify a range  
                of indices from which to retrieve the metadata. It is an error to have the  
                value of startIndex be greater than that of endIndex.  
              
              
                See also the index flag for an alternate way to specify multiple  
                indices. This flag can only be used on index types that support a range  
                (e.g. integer values - it makes no sense to request a range between two  
                strings)  
              
                			In query mode, this flag can accept a value.  
                Properties: create
        index (Queryable[Multiuse[str]]?): In the typical case metadata is indexed using a simple integer value.  
                Certain types of data may use other index types. e.g. a "vertexFace"  
                component will use a "pair" index type, which is two integer values; one  
                for the face ID of the component and the second for the vertex ID.  
              
              
                The index flag takes a string, formatted in the way the  
                specified indexType requires. All uses of the  
                index flag have the same indexType. If the type was  
                not specified it is assumed to be a simple integer value.  
              
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        indexType (Queryable[str]?): Name of the index type the new Channel should be using. If not specified this  
                defaults to a simple integer index. Of the native types only a mesh  
                "vertexFace" channel is different, using a "pair" index type.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        scene (bool?): Use this flag when you want to add metadata to the scene as a whole rather than to  
                any individual nodes. If you use this flag and have nodes selected the nodes will  
                be ignored and a warning will be displayed.  
                Properties: create, query
        startIndex (str?): The metadata is stored in a Stream, which is an indexed list. If you have  
                mesh components selected then the metadata indices are implicit in the list  
                of selected components. If you select only the node or scene then this flag  
                may be used in conjunction with the endIndex flag to specify a range of  
                indices from which to retrieve the metadata. It is an error to have the value  
                of startIndex be greater than that of endIndex.  
              
              
                See also the index flag for an alternate way to specify multiple  
                indices. This flag can only be used on index types that support a range  
                (e.g. integer values - it makes no sense to request a range between two  
                strings)  
              
                			In query mode, this flag can accept a value.  
                Properties: create
        streamName (Queryable[str]?): Name of the metadata Stream. Depending on context it could be the name of a  
                Stream to be created, or the name of the Stream to pass through the filter.  
                			In query mode, this flag can accept a value.  
                Properties: create, query

    Returns:
        List[str]: List of indexes in the filtered list which contain metadata
        List[bool]: List of answers to whether the specified item(s) have metadata

    Example:
    """

def headsUpDisplay(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allDescendants: bool = ..., allowOverlap: bool = ..., attachToRefresh: bool = ..., attributeChange: str = ..., block: Queryable[int] = ..., blockAlignment: Queryable[str] = ..., blockSize: Queryable[str] = ..., command: Queryable[Callable[..., Any]] = ..., conditionChange: str = ..., conditionFalse: str = ..., conditionTrue: str = ..., connectionChange: str = ..., dataAlignment: Queryable[str] = ..., dataFontSize: Queryable[str] = ..., dataWidth: Queryable[int] = ..., decimalPrecision: Queryable[int] = ..., disregardIndex: bool = ..., event: str = ..., exists: bool = ..., getOption: str = ..., gridColor: Queryable[int] = ..., label: Queryable[str] = ..., labelFontSize: Queryable[str] = ..., labelWidth: Queryable[int] = ..., lastOccupiedBlock: int = ..., layoutVisibility: bool = ..., listConditions: bool = ..., listEvents: bool = ..., listHeadsUpDisplays: bool = ..., listNodeChanges: bool = ..., listPresets: bool = ..., name: str = ..., nextFreeBlock: int = ..., nodeChanges: Queryable[Multiuse[str]] = ..., padding: Queryable[int] = ..., preset: Queryable[str] = ..., refresh: bool = ..., remove: bool = ..., removeID: int = ..., removePosition: Tuple[int, int] = ..., resetNodeChanges: Multiuse[str] = ..., scriptResult: bool = ..., section: Queryable[int] = ..., setOption: Tuple[str, str] = ..., showGrid: bool = ..., visible: bool = ...) -> Union[int, Union[str, int, Tuple[int, int]], bool, str, Callable[..., Any], Multiuse[str]]:
    """This command creates a Heads-up Display (HUD) object which is placed in a 2D
    inactive overlay plane on the 3D viewport. It is to be used to provide hands-on
    information designated by a user script. The text string displayed on the viewport
    is formatted using the various flags of this command.The only mandatory flags, on creation are the section and block flags. Note if the preset
    OR command/trigger flags are not present, only a label will be drawn on the viewport.Upon creation of a HUD object, an ID number will be assigned to it. This can be used to
    remove the HUD object (-rid/removeID [int IDNumber]), if desired. Alternatively, HUD
    objects may be removed via their position (section and block), or their unique name.hud, headsupdisplay
    Args:
        allDescendants (bool?): This flag can only be used in conjunction with the -ac/attributeChange  
                flag. If it is specified, and the HUD is attached to a compound or multi  
                attribute, then the HUD command will run due to changes to the specified  
                attribute as well as changes to its descendants.  
                Properties: create, edit
        allowOverlap (bool?): Sets the Heads-Up Display to be visible regardless of overlapping section  
                widths/limitations (see -s/section flag description for more details).  
                Properties: create, query, edit
        attachToRefresh (bool?): Attaches the command to the refresh process. The script is then run each time  
                an idle refresh is run and updates directly following it.  
                Properties: create, query, edit
        attributeChange (str?): Runs the command when the named attribute changes value. The string must  
                identify both the dependency node and the particular attribute. If the  
                dependency node is deleted, this HUD is removed (even if the deletion is  
                undoable).  
                Properties: create, edit
        block (Queryable[int]?): Denotes the individual block that the HUD will reside in, within a  
                section. Each section is composed of a single column of blocks.  
                The total number of blocks contained within each section is variable.  
              
                The number of blocks that will be visible within each section is  
                dependent on the size of blocks contained in each section and the  
                current size of the window. Blocks begin enumerating from 0 and  
                flexibly increase based on need.  
              
                The resultant output string of each HUD is formatted within each block,  
                using parameters defined by the formatting flags listed below (eg. justify,  
                padding, labelWidth and dataWidth). The layout is shown in the following  
                diagram:  
              
                 __________________________________________  
                |     |     |        |         |     |     |  
                |  P  |  J  |   LW   |   DWX   |  J  |  P  |  
                |_____|_____|________|_________|_____|_____|  
                P = Sub-block of width, padding  
                J = Justification of the entire block  
                LW = Sub-block of width, labelWidth  
                DWX = X number of sub-blocks of width, dataWidth, for X data elements.  
              
              
                Block Layout  
              
                The above diagram shows the layout of each block. The widths: padding,  
                labelWidth and dataWidth are defined by their respective flags. To  
                elaborate on the layout of the blocks, First the padding of the block is  
                calculated. Then the two main sub-blocks (LW and DWX) in the above diagram,  
                are justified and positioned together between the left and right margins  
                of the block. The widths of the main sub-blocks are not variable based on  
                it's contents. The only sub-block in the above diagram which is unique is the  
                DWX sub-block which actually represents X number of sub-blocks, where X  
                is the number of data elements returned by the command.  
              
                Block Positioning  
              
                Blocks on the top section begin from the top edge of the main  
                viewport, while the bottom section begins from the bottom edge.  
                Blocks are dynamically removed from visibility from the midpoint  
                of the viewport. So, a relatively large block number will not  
                draw to the viewport.  
              
                Lastly, there can be at most one HUD occupying a block at any time.  
                Trying to position a HUD in an occupied block will result in an error.  
                Keep this in mind when positioning the HUD.  
                Properties: create, query, edit
        blockAlignment (Queryable[str]?): Specifies the alignment of the block within its respective column. Available  
                alignments are: "center", "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        blockSize (Queryable[str]?): Sets the height of each block. Available heights are: small, medium and large.  
                In pixel measurements, each corresponds to a 20, 35 or 50 pixel height, respectively.  
                Properties: create, query, edit
        command (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run, in order to obtain the  
                desired information. This must return a value or an array of values.  
                A warning will be displayed if the command does not return a value.  
                This flag MUST always be accompanied by a trigger flag (eg. a condition flag,  
                an event flag, an attachToRefresh flag, etc.).  
                Properties: create, query, edit
        conditionChange (str?): A trigger which runs the command (to sample the data), when the  
                named condition changes. The named condition must be pre-defined or a  
                user defined boolean. To get a list of what conditions exist, use  
                the -lc/listConditions flag.  
                Properties: create, edit
        conditionFalse (str?): A trigger which runs the command (to sample the data), when the  
                named condition becomes false. The named condition must be pre-defined or  
                a user defined boolean. To get a list of what conditions exist, use  
                the -lc/listConditions flag.  
                Properties: create, edit
        conditionTrue (str?): A trigger which runs the command (to sample the data), when the  
                named condition becomes true. The named condition must be pre-defined or a  
                user defined boolean. To get a list of what conditions exist, use  
                the -lc/listConditions flag.  
                Properties: create, edit
        connectionChange (str?): Runs the command when the named attribute changes its connectivity. The  
                string must identify both the dependency node and the particular attribute.  
                If the dependency node is deleted, this HUD is removed (even if the deletion  
                is undoable).  
                Properties: create, edit
        dataAlignment (Queryable[str]?): Specifies the alignment of the data blocks and the data text, within a HUD block.  
                Available alignments are: "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        dataFontSize (Queryable[str]?): Sets the font size of the returned data. Available sizes are: small and large.  
                Properties: create, query, edit
        dataWidth (Queryable[int]?): Specifies the pixel width of the virtual "textbox" which will hold a data value.  
                For commands which return more than one value (ie. arrays), one of these "textboxes"  
                will be created for each data element, each with this specified width. If the width  
                of the data value exceeds the width of the "textbox", the data value will be  
                truncated to fit within the dimensions of the "textbox." (To see a layout of a  
                block, see the description of the -block flag.)  
                Properties: create, query, edit
        decimalPrecision (Queryable[int]?): Sets the decimal precision of any floating point value returned by the command. The valid  
                range of precision values are 1 to 8.  
                Properties: create, query, edit
        disregardIndex (bool?): This flag can only be used in conjunction with the -ac/attributeChange  
                flag. If it is specified, and the HUD is attached to a multi (indexed)  
                attribute, then the HUD command will run no matter which attribute in  
                the multi changes.  
                Properties: create, edit
        event (str?): Runs the command when the named event occurs. The named event, must be a  
                pre-defined Maya event. To get a list of what events exist, use the  
                -le/listEvents flag.  
                Properties: create, edit
        exists (bool?): This flag returns whether the given object exists in the Heads-Up Display layout.  
                An object name must be supplied with this command. This flag cannot be combined  
                with any other flag.  
                Properties: create, query
        getOption (str?): This flag will return the value of the option specified by the string.  
                See setOption for a list of options  
                			In query mode, this flag needs a value.  
                Properties: query
        gridColor (Queryable[int]?): This flag specifies a color for the grid lines using the inactive color palette. Specifying  
                an index number between 1 to 23 will select the corresponding color in the palette.  
                Properties: create, query, edit
        label (Queryable[str]?): Text string that appears to the left of the desired information.  
                Properties: create, query, edit
        labelFontSize (Queryable[str]?): Sets the font size of the label. Available sizes are: small and large.  
                Properties: create, query, edit
        labelWidth (Queryable[int]?): Specifies the pixel width of the virtual "textbox" which will hold the label. The  
                contents of this "textbox" will be left justified. If the width of the actual label  
                exceeds the width of the "textbox," the label will be truncated to fit within the  
                dimensions of the "textbox." (To see a layout of a block, see the description  
                of the -block flag.)  
                Properties: create, query, edit
        lastOccupiedBlock (int?): Returns the block number of the last occupied block in a given section.  
                Properties: create
        layoutVisibility (bool?): Sets the visibility of Heads-Up Display layout on and off. This does not  
                modify individual visibilities of heads-up displays, but turns off the layout  
                so that no heads-up displays will draw to screen. Personalized settings for  
                the visibilities of HUDs are kept safe. This flag can only be used by itself,  
                excepting edit and query.  
                Properties: create, query, edit
        listConditions (bool?): This flag will return a string array containing all names of the available  
                conditions.  
                Properties: create, query
        listEvents (bool?): This flag will return a string array containing all names of the available  
                events.  
                Properties: create, query
        listHeadsUpDisplays (bool?): This flag will return a string array containing all names of existing HUDs.  
                Properties: create, query
        listNodeChanges (bool?): This flag will return a string array containing all names of the available  
                node changes.  
                Properties: create, query
        listPresets (bool?): This flag will return a string array containing all names of the available  
                preset HUDs.  
                Properties: create, query
        name (str?): This flag only permits the EDITING of the name of the Heads-Up Display.  
                Properties: edit
        nextFreeBlock (int?): Returns the block number of the next free block in a given section.  
                Properties: create
        nodeChanges (Queryable[Multiuse[str]]?): Works only with selection based triggers (ie. "SelectionChanged" or "SomethingSelected"),  
                otherwise this flag is ignored. This flag attaches the HUD script to execute on specific  
                node changes of any selected node. This flag is used to set a nodeChange. In order to  
                reset a nodeChange, use the -rnc/resetNodeChanges flag. To view a list of all available  
                node changes, use the -lnc/listNodeChanges flag. The following is a list of available node  
                changes and their function:  
              
                attributeChange:  The script will be sensitive to any attribute changes in the currently  
                                  selected nodes.  
              
                connectionChange: The script will be sensitive to any connection changes in the currently  
                                  selected nodes.  
              
                instanceChange:   The script will be sensitive to any changes to an instance in the  
                                  currently selected nodes.  
              
              
                On query mode, this flag will return the values of all nodeChanges in pairs of values  
                (the name of the nodeChange followed by its value).  
              
                WARNING: (Performance Warning)  
                         Attaching a nodeChange trigger to a selection based trigger can cause a large  
                         performance drop, if the node change that is being watched is caused by the  
                         HUD script itself.  
              
                         With this said, an attempt should be made to keep the HUD command/script  
                                 simple and limited to retrieving data. Changing an attribute, creating or  
                                 modifying a connection or instance will all result in a performance drop.  
                Properties: create, query, edit, multiuse
        padding (Queryable[int]?): Specifies the width of both the left and right margins of a block. Default  
                value is 15 pixels.  
                Properties: create, query, edit
        preset (Queryable[str]?): This setting is used to select certain pre-defined HUDs, some of which retrieve  
                specific data, that is unobtainable through normal MEL commands or scripts. This flag  
                is mutually exclusive from the command and trigger flag combination. However, presets  
                can work with all other headsUpDisplay attribute flags (ie. block alignment, label,  
                dataFontSize, etc.), unless otherwise specified below. To obtain a list  
                of available presets, use the -lp/listPresets flag on this command.  
              
                The following is a list of available presets and a description of each:  
              
                cameraNames  
                This will return the camera name that the view is looking through, in  
                the data block, for each view that the HUD is drawing to.  
                polyVerts  
                This will return three values in the data block, regarding the number of  
                vertices that are visible by the camera.  
              
                1st Value: Represents the number of camera visible vertices, both  
                active and inactive.  
                2nd Value: Represents the number of camera visible vertices, on  
                active objects only.  
                3rd Value: Represents the number of camera visible vertices, that  
                are active.  
              
                polyEdges  
                This will return three values in the data block, regarding the number of  
                edges that are visible by the camera. The order of these three values are  
                similar to the polyVerts preset.  
                polyFaces  
                This will return three values in the data block, regarding the number of  
                faces that are visible by the camera. The order of these three values are  
                similar to the polyVerts preset.  
                polyUVs  
                This will return three values in the data block, regarding the number of  
                UVs that are visible by the camera. The order of these three values are  
                similar to the polyVerts preset.  
                polyTriangles  
                This will return three values in the data block, regarding the number of  
                triangles that are visible by the camera. The order of these three values are  
                similar to the polyVerts preset.  
                materialLoadingCount  
                This will return the material loading count.  
                It updates on each refresh.  
                textureLoadingCount  
                This will return the texture loading count.  
                It updates on each refresh.  
                frameRate  
                This will return a single string carrying both the frame rate and the "fps"  
                string in the data block. It updates on each refresh.  
                viewAxis  
                This will draw the orientation of the grid axes within the HUD. It updates  
                on each refresh. While this preset can take in all attribute flags, the  
                only one which will have an effect are block attribute related flags  
                (ie. block alignment and block size). The block dimensions of this preset  
                are: blockSize - "large" and blockWidth - "50", which results in a 50x50  
                pixel region.  
                distanceFromCamera  
                This will return in the data block the distance from the view's camera  
                to the centre of the bounding box containing the selected objects in the view.  
                Properties: create, query, edit
        refresh (bool?): This flag forces the given Heads-Up Display element to refresh, updating  
                the value displayed.  This flag cannot be combined with any other flag.  
                Properties: create
        remove (bool?): This command will remove a given HUD object, given a specified HUD name. This flag will  
                override all other flags and is mutually exclusive from the other remove flags.  
                Properties: create, edit
        removeID (int?): This command will remove a given HUD object, given a specified HUD ID number assigned  
                to it at creation time. This flag will override all other flags and is mutually exclusive  
                from the other remove flags.  
                Properties: create, edit
        removePosition (Tuple[int, int]?): This command will remove the contents of a specific block location in the HUD layout.  
                This flag will override all other flags and is mutually exclusive from the other remove  
                flags. Syntax for this flag is: -removePosition/rp [section] [block].  
                Properties: create, edit
        resetNodeChanges (Multiuse[str]?): This flag will reset a specificied nodeChange back to false. This flag only operates under  
                the edit flag. See the description for the -nc/nodeChanges flag for further details.  
                Properties: edit, multiuse
        scriptResult (bool?): This flag is only used in conjunction with the query flag. Calling a query on this flag  
                returns the most recent result of the HUD.  
                Properties: query
        section (Queryable[int]?): Defines the section the HUD will appear in. There are 10 sections  
                divided across the screen. Five columns and two rows make up the  
                ten element matrix which divide the main viewport. Here is a visual  
                layout of the sections.  
              
                 ________________________  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 0  | 1  | 2  | 3  | 4  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 5  | 6  | 7  | 8  | 9  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                Each section is denoted by a number from 0 to 9 as illustrated above.  
                For example, if the second column of the top row was desired, the  
                section would be defined as: -sec 1  
              
                To prevent HUD objects from displaying over each other and causing a  
                clutter of letters, each row has a defined visibility precedence,  
                where each section would have a visibility priority level. Depending  
                on each priority level, when the screen space begins to shrink to  
                a point where the section widths of a given row begin to collide, the  
                HUD automatically compensates for this by removing the sections of  
                least priority. These sections are made invisible and a warning is  
                issued to inform the user of the removal. This continues until only  
                the section of highest priority remains.  
              
                For each row, the priorities are defined as follows. Using the top  
                row as an example: Section 0, has the highest priority, followed  
                by Section 4, making the outermost sections of highest priority.  
                Next in the list is Section 2, and lastly Sections 1 and 3 are of  
                the equal and least priority. This priority structure can be applied  
                to the bottom row as well. The two outermost sections have the highest  
                priority, followed by the middle section, and finally the remaining  
                two sections are of lowest priority.  
              
                This means that as the viewport gradually decreases in width  
                to the point where sections in the top row begin to overlap, sections  
                1 and 3 will be removed from view first, followed by section 2, and  
                finally section 4. A similar note is provided below for the block layout.  
                Properties: create, query, edit
        setOption (Tuple[str, str]?): This flag will edit the option specified by the first string. Current options are:  
                smpPolyCount - "cage" or "smp" - in smooth mesh preview, determines the poly count display  
                Properties: edit
        showGrid (bool?): This flag will toggle the display of the grid lines of the HUD layout.  
                Properties: create, query, edit
        visible (bool?): Sets the visibility of the Heads-Up Display on and off.  
                Properties: create, query, edit

    Returns:
        int: ID number of the Heads-Up Display (HUD), for regular command execution.
        Union[str, int, Tuple[int, int]]: HUD name, HUD ID or Section and block value, for respective remove commands.

    Example:
    """

def headsUpMessage(*args: Any, horizontalOffset: int = ..., object: str = ..., selection: bool = ..., time: float = ..., uvTextureEditor: bool = ..., verticalOffset: int = ..., viewport: bool = ...) -> bool:
    """This command draws a message in the 3d view.  The message
    is automatically erased at the next screen refresh.
    Args:
        horizontalOffset (int?): If this flag is specified, the message will appear  
                the specified distance (in pixels) to the right of  
                the point.  Otherwise, a default horizontal offset of 0  
                pixels is used.  
                Properties: create
        object (str?): If an object is specified, then the message is drawn  
                just above the object's bounding-box centre point.  
                If this flag is not specified, or the object is not  
                found, then the message is centred in the current view.  
                Properties: create
        selection (bool?): If this flag is specified, the message will be  
                centred among the currently selected objects.  This  
                flag does nothing if the object flag is also specified.  
                Properties: create
        time (float?): If this flag is specified, the message will be  
                displayed for a minimum of the given amount of time  
                (in seconds).  Otherwise a default time of 1.0 seconds  
                is used.  
                Properties: create
        uvTextureEditor (bool?): Should the HUD be shown in the UV Texture Editor?  
                Properties: create
        verticalOffset (int?): If this flag is specified, the message will appear  
                the specified distance (in pixels) above the point.  
                Otherwise, a default vertical offset of 0 pixels is used.  
                Properties: create
        viewport (bool?): Should the HUD be shown in the viewport?  
                Properties: create

    Returns:
        bool:

    Example:
    """

def help(arg0: str = ..., /, *, query: bool = ..., documentation: bool = ..., language: str = ..., list: bool = ..., popupDisplayTime: Queryable[int] = ..., popupMode: bool = ..., popupPauseTime: Queryable[int] = ..., popupSimpleMode: bool = ..., rolloverMode: bool = ..., syntaxOnly: bool = ...) -> Union[bool, int]:
    """With no arguments, help tells how to use help. If a command name is
    specified, help will return the quick help for that command. Other
    flags can be used to open the online documentation, or to list
    available commands based on a pattern.Pattern follows the following syntax:
    Args:
        documentation (bool?): Use a browser to show the documentation associated with the single  
                command name given. A pattern cannot be used with this flag. If no  
                command name is specified, then this flag will go to the main  
                documentation index.  
                Properties: create
        language (str?): Show the help for this command in the specified language.  
                Valid values are "mel" and "python".  
                The default is Mel.  
                Used with the doc flag.  
                Properties: create
        list (bool?): List all the commands whose names match the regular expression. Pass the  
                regular expression as the first argument to the command specified.  
                Properties: create
        popupDisplayTime (Queryable[int]?): Set the amount of time, in seconds, that the popup help  
                will be displayed.  The default is 4 seconds.  
                This flag is mutually exclusive of the list and doc flags.  
                Properties: create, query
        popupMode (bool?): Turn on or off popup help mode.  This flag is mutually exclusive  
                of the list and doc flags.  
                Properties: create, query
        popupPauseTime (Queryable[int]?): Set the amount of time, in milliseconds, before the popup help  
                will be displayed. The default is 800 milliseconds.  
                This flag is mutually exclusive of the list and doc flags.  
                Properties: create, query
        popupSimpleMode (bool?): Turn on or off simple popup help mode. If set, ToolClips will display  
                only name and keyboard shortcut.  
                Properties: create, query
        rolloverMode (bool?): Turn on or off rollover help mode.  This flag is mutually exclusive  
                with the list and doc flags.  
                Properties: create, query
        syntaxOnly (bool?): When no other flag is specified, return only the syntax part of the  
                quick help.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def helpLine(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a help line where tool help/hints
    are shown.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name of control.

    Example:
    """

def hide(*args: str, allObjects: bool = ..., clearLastHidden: bool = ..., clearSelection: bool = ..., invertComponents: bool = ..., returnHidden: bool = ..., testVisibility: bool = ...) -> bool:
    """Thecommand is used to make objects invisible. If no flags are
    used, the objects specified, or the active objects if none are specified,
    will be made invisible.
    Args:
        allObjects (bool?): Make everything invisible (top level objects).  
                Properties: create
        clearLastHidden (bool?): Clear the last hidden list.  
                Properties: create
        clearSelection (bool?): Clear selection after the operation.  
                Properties: create
        invertComponents (bool?): Hide components that are not specified.  
                Properties: create
        returnHidden (bool?): Hide objects, but also return list of hidden objects.  
                Properties: create
        testVisibility (bool?): Do not change visibility, just test it (returns 1 is invisible, 2 if visible, 3 if partially visible).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def hikGlobals(*, edit: bool = ..., query: bool = ..., releaseAllPinning: bool = ...) -> bool:
    """Sets global HumanIK flags for the application.
    Args:
        releaseAllPinning (bool?): Sets the global release all pinning hik flag. When this flag is set,  
                all pinning states are ignored.  
                Properties: query, edit

    Returns:
        bool: Giving the state of the option

    Example:
    """

def hilite(*args: str, replace: bool = ..., toggle: bool = ..., unHilite: bool = ...) -> bool:
    """Hilites/Unhilites the specified object(s).  Hiliting an object makes
    it possible to select the components of the object.  If no objects
    are specified then the selection list is used.
    Args:
        replace (bool?): Hilite the specified objects.  Any objects previously  
                hilited will no longer be hilited.  
                Properties: create
        toggle (bool?): Toggle the hilite state of the specified objects.  
                Properties: create
        unHilite (bool?): Remove the specified objects from the hilite list.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def hitTest(arg0: str = ..., arg1: int = ..., arg2: int = ..., /) -> List[str]:
    """Thecommand hit-tests a point in the named control and returns
    a list of items underneath the point. The point is specified in pixels with
    the origin (0,0) at the top-left corner. This position is compatible
    with the coordinates provided by a drop-callback. The types of items
    that may be returned depends upon the specific control; not all
    controls currently support hit-testing.hit, hittest, drag-and-drop
    Returns:
        List[str]: items underneath the hit-point

    Example:
    """

def hotBox(*, query: bool = ..., PaneOnlyMenus: bool = ..., PaneToggleMenus: bool = ..., animationOnlyMenus: bool = ..., animationToggleMenus: bool = ..., clothOnlyMenus: bool = ..., clothToggleMenus: bool = ..., commonOnlyMenus: bool = ..., commonToggleMenus: bool = ..., customMenuSetsToggleMenus: bool = ..., displayCenterOnly: bool = ..., displayHotbox: bool = ..., displayStyle: bool = ..., displayZonesOnly: bool = ..., dynamicsOnlyMenus: bool = ..., dynamicsToggleMenus: bool = ..., liveOnlyMenus: bool = ..., liveToggleMenus: bool = ..., menuSetOnly: str = ..., menuSetToggle: Tuple[str, bool] = ..., modelingOnlyMenus: bool = ..., modelingToggleMenus: bool = ..., noClickCommand: Callable[..., Any] = ..., noClickDelay: float = ..., noClickPosition: bool = ..., noKeyPress: bool = ..., polygonsOnlyMenus: bool = ..., polygonsToggleMenus: bool = ..., position: Tuple[int, int] = ..., release: bool = ..., renderingOnlyMenus: bool = ..., renderingToggleMenus: bool = ..., riggingOnlyMenus: bool = ..., riggingToggleMenus: bool = ..., rmbPopups: bool = ..., showAllToggleMenus: bool = ..., surfacesOnlyMenus: bool = ..., surfacesToggleMenus: bool = ..., transparenyLevel: Queryable[int] = ..., updateMenus: bool = ...) -> Union[bool, int]:
    """This command controls parameters related to the hotBox menubar palette.
    When the command is invoked with no flags, the hotBox is popped up.
    Args:
        PaneOnlyMenus (bool?): Sets a row of menus to be the only visible row.  
                Properties: create
        PaneToggleMenus (bool?): Sets the visibilty of a row of menus to on or off.  
                Properties: create, query
        animationOnlyMenus (bool?):   
                Properties: create, query
        animationToggleMenus (bool?):   
                Properties: create, query
        clothOnlyMenus (bool?):   
                Properties: create, query
        clothToggleMenus (bool?):   
                Properties: create, query
        commonOnlyMenus (bool?):   
                Properties: create, query
        commonToggleMenus (bool?):   
                Properties: create, query
        customMenuSetsToggleMenus (bool?):   
                Properties: create, query
        displayCenterOnly (bool?): Three different display styles are defined for the hotBox. It can  
                be fully displayed (dh), display only the marking menu zones  
                (dzo) or no display (dco) which means that the entire  
                screen can be used to access the marking menus defined in the center zone.  
                Properties: create
        displayHotbox (bool?):   
                Properties: create, query
        displayStyle (bool?): Returns a string that identifies the flag used to set the current  
                display style. The results can be dh, dzo, or  
                dco, depending on  which style the hotBox is using at the moment.  
                Properties: query
        displayZonesOnly (bool?):   
                Properties: create, query
        dynamicsOnlyMenus (bool?):   
                Properties: create, query
        dynamicsToggleMenus (bool?):   
                Properties: create, query
        liveOnlyMenus (bool?):   
                Properties: create, query
        liveToggleMenus (bool?):   
                Properties: create, query
        menuSetOnly (str?): Show only the named menu set  
                Properties: create
        menuSetToggle (Tuple[str, bool]?): Update the given menu sets with the paired toggle value  
                Properties: create
        modelingOnlyMenus (bool?):   
                Properties: create, query
        modelingToggleMenus (bool?):   
                Properties: create, query
        noClickCommand (Callable[..., Any]?): The command to be executed if the hotBox is engaged  
                and then disengaged within noClickDelay time units.  
                Properties: create
        noClickDelay (float?): If the hotBox is engaged and then disengaged within  
                this time interval, then the noClickCommand is executed.  
                The time interval is in seconds.  The default value is 0.1.  
                Properties: create
        noClickPosition (bool?): If a -noClickCommand has been specified then this flag will cause the X and Y  
                screen coordinates of the mouse pointer to be appended as arguments to that command.  
                The coordinates used are those of the pointer at the time when the hotbox command was  
                initiated.  
                Properties: create
        noKeyPress (bool?): Normally the hotbox is popped by a pressing a keyboard key. Use the  
                nkp flag to pop the hotbox from a device other than the keyboard  
                (still use the rl flag to unpop the hotbox).  
                Properties: create, query
        polygonsOnlyMenus (bool?):   
                Properties: create, query
        polygonsToggleMenus (bool?):   
                Properties: create, query
        position (Tuple[int, int]?): Specify the screen position the hotbox should be centered at next time  
                it is displayed.  The default is the cursor position.  
                Properties: create
        release (bool?): Action to be called on the release of the key which invoked the hotbox  
                Properties: create, query
        renderingOnlyMenus (bool?):   
                Properties: create, query
        renderingToggleMenus (bool?):   
                Properties: create, query
        riggingOnlyMenus (bool?):   
                Properties: create, query
        riggingToggleMenus (bool?):   
                Properties: create, query
        rmbPopups (bool?): Enables/Disables a popup menu of the current function set.  
                This popup menu appear when the right mouse button is pressed  
                in the center zone of the hotbox.  
                Properties: create, query
        showAllToggleMenus (bool?): Sets the visibility of all menus to on or off.  
                When queried, will only return true if all menu rows are visible.  
                Properties: create, query
        surfacesOnlyMenus (bool?):   
                Properties: create, query
        surfacesToggleMenus (bool?):   
                Properties: create, query
        transparenyLevel (Queryable[int]?): The percentage of transparency, from 0 to 100.  
                Currently, only the values 0, 25, 50, 75 and 100 are  
                supported.  Any other values will be rounded off  
                to the nearest supported value.  
                Properties: create, query
        updateMenus (bool?): Reloads the hotBox menus from the main menubar.  
                This flag is used when the menus in the main menubar are modified,  
                and the hotBox menus need to be refreshed.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def hotkey(arg0: str = ..., /, *, query: bool = ..., altModifier: bool = ..., autoSave: bool = ..., commandModifier: bool = ..., ctrlModifier: bool = ..., ctxClient: Queryable[str] = ..., dragPress: bool = ..., factorySettings: bool = ..., isModifier: bool = ..., keyShortcut: str = ..., name: Queryable[str] = ..., pressCommandRepeat: bool = ..., releaseCommandRepeat: bool = ..., releaseName: Queryable[str] = ..., shiftModifier: bool = ..., sourceUserHotkeys: bool = ...) -> Union[bool, str]:
    """This command sets the single-key hotkeys for the entire application.
    Args:
        altModifier (bool?):   
                Properties: create, query
        autoSave (bool?): If set to true then the hotkeys will always be saved when  
                you quit.  If false then the hotkeys are not saved unless  
                "savePrefs -hotkeys" is used.  
                Properties: create
        commandModifier (bool?): The Command key must be pressed to get the hotkey.  
                This is only available on systems which have a separate  
                command key.  
                Note that if menu item accelerator keys are being used  
                (menuItem -ke/keyEquivalent), then the accelerator key  
                settings override the hotkey settings.  
                Properties: create
        ctrlModifier (bool?): The Ctrl key must be pressed to get the hotkey.  
                Note that if menu item accelerator keys are being used  
                (menuItem -ke/keyEquivalent), then the accelerator key  
                settings override the hotkey settings.  
                Properties: create, query
        ctxClient (Queryable[str]?): Specifies the hotkey context. It is used together with the other flags to modify or query  
                the hotkey for a certain hotkey context. If it is not specified, the global hotkey context will be taken into  
                account. Check hotkeyCtx command to see how the hotkeys work with the hotkey contexts.  
                Properties: create, query
        dragPress (bool?): Specify true and the command may be executed during  
                manipulator dragging, if the tool context also allows  
                this. This flag is false by default.  
                Properties: create
        factorySettings (bool?): Resets the hotkeys back to the initial defaults.  
                Properties: create
        isModifier (bool?): This flag is obsolete and should no longer be used.  
                Properties: create
        keyShortcut (str?): Specify what key is being set. The key must be either a single  
                ascii character (capital and lowercase can be set independently)  
                or one of the keyword  
                strings for the special keyboard characters.  
              
                The valid keywords are:  
                Up, Down, Right, Left,  
                Home, End, Page_Up, Page_Down, Insert  
                Return, Space  
                F1 to F12  
                Tab (Will only work when modifiers are specified)  
                Delete, Backspace (Will only work when modifiers are specified)  
                Properties: create
        name (Queryable[str]?): The name of the namedCommand object that will be executed when the key is pressed.  
                Properties: create, query
        pressCommandRepeat (bool?): Specify true and the command may be repeated by executing  
                the command repeatLast. This flag is false by default.  
                Properties: create
        releaseCommandRepeat (bool?): Specify true and the command may be repeated by executing  
                the command repeatLast. This flag is false by default.  
                Properties: create
        releaseName (Queryable[str]?): The name of the namedCommand object that will be executed when the key is released.  
                Properties: create, query
        shiftModifier (bool?): The Shift key must be pressed to get the hotkey.  
                Properties: create, query
        sourceUserHotkeys (bool?): This flag is obsolete. Please use import flag from hotkeySet command  
                to import the user hotkeys.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def hotkeyCheck(*, altModifier: bool = ..., commandModifier: bool = ..., ctrlModifier: bool = ..., isRepeatable: bool = ..., keyString: str = ..., keyUp: bool = ..., optionModifier: bool = ...) -> str:
    """This command checks if the given hotkey is mapped to a nameCommand
    object.  If so, the annotation of the nameCommand object is returned.
    Otherwise an empty string is returned.
    Args:
        altModifier (bool?): Specifies if the Alt key is pressed.  
                Properties: create
        commandModifier (bool?): Specifies if the command key is pressed.  
                Properties: create
        ctrlModifier (bool?): Specifies if the Ctrl key is pressed.  
                Properties: create
        isRepeatable (bool?): Specify this flag if the hotkey is repeatable.  
                Properties: create
        keyString (str?): The key to check.  
                Properties: create
        keyUp (bool?): Specifies if the hotkey is on keyup or keydown  
                (i.e. Release or Press).  
                Properties: create
        optionModifier (bool?): Specifies if the option key is pressed.  
                Properties: create

    Returns:
        str: Contains all clients name, each followed by the annotation of the corresponding nameCommand object, or
            an empty string.

    Example:
    """

def hotkeyCtx(*, query: bool = ..., addClient: Multiuse[str] = ..., clientArray: bool = ..., currentClient: Queryable[str] = ..., insertTypeAt: Tuple[str, str] = ..., removeAllClients: bool = ..., removeClient: Multiuse[str] = ..., removeType: str = ..., type: Queryable[str] = ..., typeArray: bool = ..., typeExists: str = ...) -> Union[bool, str]:
    """This command sets the hotkey context for the entire application.
    Args:
        addClient (Multiuse[str]?): Associates a client to the given hotkey context type.  
                This flag needs to be used with the flag "type" which specifies the context type.  
                Properties: create, multiuse
        clientArray (bool?): Returns an array of the all context clients associated to the hotkey context type.  
                This flag needs to be used with the flag "type" which specifies the context type.  
                Properties: query
        currentClient (Queryable[str]?): Current client for the given hotkey context type.  
                This flag needs to be used with the flag "type" which specifies the context type.  
                Properties: create, query
        insertTypeAt (Tuple[str, str]?): Inserts a new hotkey context type in the front of the given type.  
                The first argument specifies an existing type. If it's empty,  
                the new context type will be inserted before "Global" context type.  
                The second argument specifies the name of new context type.  
                Properties: create
        removeAllClients (bool?): Removes all the clients associated to the hotkey context type.  
                This flag needs to be used with the flag "type" which specifies the context type.  
                Properties: create
        removeClient (Multiuse[str]?): Removes a client associated to the hotkey context type.  
                This flag needs to be used with the flag "type" which specifies the context type.  
                Properties: create, multiuse
        removeType (str?): Removes the given hotkey context type.  
                Properties: create
        type (Queryable[str]?): Specifies the context type. It's used together with the other flags such as  
                "currentClient", "addClient", "removeClient" and so on.  
                Properties: create, query
        typeArray (bool?): Returns a string array containing the names of all hotkey context types,  
                ordered by priority.  
                Properties: query
        typeExists (str?): Returns true|false depending upon whether the specified hotkey context type  
                exists.  
                      In query mode, this flag needs a value.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def hotkeyEditor(*args: Any, **kwargs: Any) -> None: ...
def hotkeyEditorPanel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """A hotkeyEditor creates a new hotkey editor in the current layout.
    The hotkey editor lets you assign predefined commands, MEL scripts, or
    marking menus to keys and key combinations.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the editor.

    Example:
    """

def hotkeyMapSet(*args: Any, **kwargs: Any) -> None: ...
def hotkeySet(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., current: bool = ..., delete: bool = ..., exists: bool = ..., export: str = ..., hotkeySetArray: bool = ..., ip: str = ..., rename: str = ..., source: str = ...) -> Union[str, bool]:
    """Manages hotkey sets in Maya. A hotkey set holds hotkey to command mapping information.
    Default hotkey sets are hotkey sets that are shipped together with Maya. They are locked and cannot be altered.A new hotkey set is always duplicated from an existing hotkey set. In create mode, users can choose to specify
    which hotkey set to duplicate by using the -source flag. A duplicated hotkey set is independent from the source
    hotkey set.
    Args:
        current (bool?): Sets the hotkey set as the current active hotkey set. In query mode, returns the name of  
                the current hotkey set.  
                Properties: create, query, edit
        delete (bool?): Deletes the hotkey set if it exists. Other flags are ignored.  
                Returns true|false depending on the delete operation.  
                Properties: edit
        exists (bool?): Returns true|false depending upon whether the specified object  
                exists. Other flags are ignored.  
                Properties: create
        export (str?): Exports a hotkey set. The argument is used to specify a full path of the output file.  
                Properties: edit
        hotkeySetArray (bool?): Returns a string array of all existing hotkey set names.  
                Properties: query
        ip (str?): Imports a hotkey set. The argument is used to specify a full path of the hotkey set file to import.  
                Properties: edit
        rename (str?): Renames an existing hotkey set. All white spaces will be replaced with '_' during operation.  
                Properties: edit
        source (str?): Specifies the source hotkey set. If flag is not provided, the current active hotkey set is used.  
                Properties: create

    Returns:
        str: The name of the hotkey set.

    Example:
    """

def hudButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowOverlap: bool = ..., block: Queryable[int] = ..., blockAlignment: Queryable[str] = ..., blockSize: Queryable[str] = ..., buttonShape: Queryable[str] = ..., buttonWidth: Queryable[int] = ..., label: Queryable[str] = ..., labelFontSize: Queryable[str] = ..., padding: Queryable[int] = ..., pressCommand: Queryable[Callable[..., Any]] = ..., releaseCommand: Queryable[Callable[..., Any]] = ..., section: Queryable[int] = ..., visible: bool = ...) -> Union[int, Union[str, int, Tuple[int, int]], bool, str, Callable[..., Any]]:
    """This command creates a Heads-up Display (HUD) button control which is placed in
    a 2D inactive overlay plane on the 3D viewport. It is to be used to provide hands-on
    interaction designated by a user script. The HUD button is derived from
    a generic HUD object and thus inherits a similar workflow.Although this command provides much of the same functionality as the headsUpDisplay
    command, it does not provide headsUpDisplay layout controls such as layoutVisibility,
    nextFreeBlock, lastOccupiedBlock, exists, remove, etc. To access that functionality,
    please use the headsUpDisplay command. This command is focused solely around the creation
    and management of HUD button controls. Similarly, all operations performed by
    this command are limited to HUDs that are button controls.The only mandatory flags, on creation are the section and block flags.Like the headsUpDisplay command, upon creation of a HUD button, an ID number
    will be assigned to it. This can be used to remove the HUD via the headsUpDisplay
    command (-rid/removeID [int IDNumber]), if desired. Alternatively, the headsUpDisplay
    command can remove HUD objects via their position (section and block),
    or their unique name.hud, headsupdisplay, button, hudbutton
    Args:
        allowOverlap (bool?): Sets the Heads-Up Display to be visible regardless of overlapping section  
                widths/limitations (see -s/section flag description for more details).  
                Properties: create, query, edit
        block (Queryable[int]?): Denotes the individual block that the HUD will reside in, within a  
                section. Each section is composed of a single column of blocks.  
                The total number of blocks contained within each section is variable.  
              
                The number of blocks that will be visible within each section is  
                dependent on the size of blocks contained in each section and the  
                current size of the window. Blocks begin enumerating from 0 and  
                flexibly increase based on need.  
              
                For HUD buttons, the format differs from that of the standard HUD.  
                The layout using parameters defined by the formatting flags listed  
                below (eg. justify, padding, buttonWidth) is shown below:  
              
                 __________________________________  
                |     |     |          |     |     |  
                |  P  |  J  |  Button  |  J  |  P  |  
                |_____|_____|__________|_____|_____|  
                P = Sub-block of width, padding  
                J = Justification of the entire block  
                Button = Sub-block of width, buttonWidth  
              
              
                Block Positioning  
              
                Blocks on the top section begin from the top edge of the main  
                viewport, while the bottom section begins from the bottom edge.  
                Blocks are dynamically removed from visibility from the midpoint  
                of the viewport. So, a relatively large block number will not  
                draw to the viewport.  
              
                Lastly, there can be at most one HUD occupying a block at any time.  
                Trying to position a HUD in an occupied block will result in an error.  
                Keep this in mind when positioning the HUD.  
                Properties: create, query, edit
        blockAlignment (Queryable[str]?): Specifies the alignment of the block within its respective column. Available  
                alignments are: "center", "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        blockSize (Queryable[str]?): Sets the height of each block. Available heights are: small, medium and large.  
                In pixel measurements, each corresponds to a 20, 35 or 50 pixel height, respectively.  
                Properties: create, query, edit
        buttonShape (Queryable[str]?): Specifies the shape of the button. Available button shapes are:  
                "rectangle" and "roundRectangle". The first will draw a rectangular  
                button, while the latter is a rectangle with rounded edges.  
                Properties: create, query, edit
        buttonWidth (Queryable[int]?): Specifies the width of the button.  
                Properties: create, query, edit
        label (Queryable[str]?): Text label of the HUD button.  
                Properties: create, query, edit
        labelFontSize (Queryable[str]?): Sets the font size of the label. Available sizes are: small and large.  
                Properties: create, query, edit
        padding (Queryable[int]?): Specifies the width of both the left and right margins of a block. Default  
                value is 15 pixels.  
                Properties: create, query, edit
        pressCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a mouse click event.  
                Properties: create, query, edit
        releaseCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a mouse release event.  
                Properties: create, query, edit
        section (Queryable[int]?): Defines the section the HUD will appear in. There are 10 sections  
                divided across the screen. Five columns and two rows make up the  
                ten element matrix which divide the main viewport. Here is a visual  
                layout of the sections.  
              
                 ________________________  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 0  | 1  | 2  | 3  | 4  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 5  | 6  | 7  | 8  | 9  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                Each section is denoted by a number from 0 to 9 as illustrated above.  
                For example, if the second column of the top row was desired, the  
                section would be defined as: -sec 1  
              
                To prevent HUD objects from displaying over each other and causing a  
                clutter of letters, each row has a defined visibility precedence,  
                where each section would have a visibility priority level. Depending  
                on each priority level, when the screen space begins to shrink to  
                a point where the section widths of a given row begin to collide, the  
                HUD automatically compensates for this by removing the sections of  
                least priority. These sections are made invisible and a warning is  
                issued to inform the user of the removal. This continues until only  
                the section of highest priority remains.  
              
                For each row, the priorities are defined as follows. Using the top  
                row as an example: Section 0, has the highest priority, followed  
                by Section 4, making the outermost sections of highest priority.  
                Next in the list is Section 2, and lastly Sections 1 and 3 are of  
                the equal and least priority. This priority structure can be applied  
                to the bottom row as well. The two outermost sections have the highest  
                priority, followed by the middle section, and finally the remaining  
                two sections are of lowest priority.  
              
                This means that as the viewport gradually decreases in width  
                to the point where sections in the top row begin to overlap, sections  
                1 and 3 will be removed from view first, followed by section 2, and  
                finally section 4. A similar note is provided below for the block layout.  
                Properties: create, query, edit
        visible (bool?): Sets the visibility of the Heads-Up Display on and off.  
                Properties: create, query, edit

    Returns:
        int: ID number of the Heads-Up Display (HUD).
        Union[str, int, Tuple[int, int]]: HUD name, HUD ID or Section and block value, for respective remove commands.

    Example:
    """

def hudSlider(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowOverlap: bool = ..., block: Queryable[int] = ..., blockAlignment: Queryable[str] = ..., blockSize: Queryable[str] = ..., decimalPrecision: Queryable[int] = ..., dragCommand: Queryable[Callable[..., Any]] = ..., internalPadding: Queryable[int] = ..., label: Queryable[str] = ..., labelFontSize: Queryable[str] = ..., labelWidth: Queryable[int] = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., padding: Queryable[int] = ..., pressCommand: Queryable[Callable[..., Any]] = ..., releaseCommand: Queryable[Callable[..., Any]] = ..., section: Queryable[int] = ..., sliderIncrement: Queryable[float] = ..., sliderLength: Queryable[int] = ..., type: Queryable[str] = ..., value: Queryable[float] = ..., valueAlignment: Queryable[str] = ..., valueFontSize: Queryable[str] = ..., valueWidth: Queryable[int] = ..., visible: bool = ...) -> Union[int, Union[str, int, Tuple[int, int]], bool, str, Callable[..., Any], float]:
    """This command creates a Heads-up Display (HUD) slider control which is placed in a 2D
    inactive overlay plane on the 3D viewport. It is to be used to provide hands-on
    interaction designated by a user script. The HUD slider is derived from
    a generic HUD object and thus inherits a similar workflow.Although this command provides much of the same functionality as the headsUpDisplay
    command, it does not provide headsUpDisplay layout controls such as layoutVisibility,
    nextFreeBlock, lastOccupiedBlock, exists, remove, etc. To access that functionality,
    please use the headsUpDisplay command. This command is focused solely around the creation
    and management of HUD sliders. Similarly, all operations performed by this command
    are limited to HUDs that are sliders.The only mandatory flags, on creation are the section and block flags.Like the headsUpDisplay command, upon creation of a HUD slider, an ID number will be
    assigned to it. This can be used to remove the HUD slider via the headsUpDisplay
    command (-rid/removeID [int IDNumber]), if desired. Alternatively, the headsUpDisplay
    command can remove HUD objects via their position (section and block),
    or their unique name.hud, headsupdisplay, slider, hudslider
    Args:
        allowOverlap (bool?): Sets the Heads-Up Display to be visible regardless of overlapping section  
                widths/limitations (see -s/section flag description for more details).  
                Properties: create, query, edit
        block (Queryable[int]?): Denotes the individual block that the HUD will reside in, within a  
                section. Each section is composed of a single column of blocks.  
                The total number of blocks contained within each section is variable.  
              
                The number of blocks that will be visible within each section is  
                dependent on the size of blocks contained in each section and the  
                current size of the window. Blocks begin enumerating from 0 and  
                flexibly increase based on need.  
              
                For HUD sliders, the format differs from that of the standard HUD.  
                The layout using parameters defined by the formatting flags listed  
                below (eg. justify, padding, labelWidth, valueWidth) is shown below:  
              
                 __________________________________________________________________  
                |     |     |        |            |      |             |     |     |  
                |  P  |  J  |   LW   |   Slider   |  IP  | SliderValue |  J  |  P  |  
                |_____|_____|________|____________|______|_____________|_____|_____|  
                P = Sub-block of width, padding  
                J = Justification of the entire block  
                LW = Sub-block of width, labelWidth  
                Slider = Length of the slider  
                SliderValue = Sub-block of width, valueWidth  
                IP = Internal padding  
              
              
                Block Positioning  
              
                Blocks on the top section begin from the top edge of the main  
                viewport, while the bottom section begins from the bottom edge.  
                Blocks are dynamically removed from visibility from the midpoint  
                of the viewport. So, a relatively large block number will not  
                draw to the viewport.  
              
                Lastly, there can be at most one HUD occupying a block at any time.  
                Trying to position a HUD in an occupied block will result in an error.  
                Keep this in mind when positioning the HUD.  
                Properties: create, query, edit
        blockAlignment (Queryable[str]?): Specifies the alignment of the block within its respective column. Available  
                alignments are: "center", "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        blockSize (Queryable[str]?): Sets the height of each block. Available heights are: small, medium and large.  
                In pixel measurements, each corresponds to a 20, 35 or 50 pixel height, respectively.  
                Properties: create, query, edit
        decimalPrecision (Queryable[int]?): Sets the decimal precision of any floating point value returned by the command. The valid  
                range of precision values are 1 to 8.  
                Properties: create, query, edit
        dragCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a mouse drag event.  
                Properties: create, query, edit
        internalPadding (Queryable[int]?): Specifies the amount of padding between the internal elements of the HUD. For the  
                hudSlider, this represents the padding between the slider bar and the slider  
                value. The default padding is 10.  
                Properties: create, query, edit
        label (Queryable[str]?): Text label of the HUD.  
                Properties: create, query, edit
        labelFontSize (Queryable[str]?): Sets the font size of the label. Available sizes are: small and large.  
                Properties: create, query, edit
        labelWidth (Queryable[int]?): Specifies the pixel width of the virtual "textbox" which will hold the label. The  
                contents of this "textbox" will be left justified. If the width of the actual label  
                exceeds the width of the "textbox," the label will be truncated to fit within the  
                dimensions of the "textbox." (To see a layout of a block, see the description  
                of the -block flag.)  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Specify the maximum value of the slider.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Specify the minimum value of the slider.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        padding (Queryable[int]?): Specifies the width of both the left and right margins of a block. Default  
                value is 15 pixels.  
                Properties: create, query, edit
        pressCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a mouse click event.  
                Properties: create, query, edit
        releaseCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a mouse release event.  
                Properties: create, query, edit
        section (Queryable[int]?): Defines the section the HUD will appear in. There are 10 sections  
                divided across the screen. Five columns and two rows make up the  
                ten element matrix which divide the main viewport. Here is a visual  
                layout of the sections.  
              
                 ________________________  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 0  | 1  | 2  | 3  | 4  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 5  | 6  | 7  | 8  | 9  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                Each section is denoted by a number from 0 to 9 as illustrated above.  
                For example, if the second column of the top row was desired, the  
                section would be defined as: -sec 1  
              
                To prevent HUD objects from displaying over each other and causing a  
                clutter of letters, each row has a defined visibility precedence,  
                where each section would have a visibility priority level. Depending  
                on each priority level, when the screen space begins to shrink to  
                a point where the section widths of a given row begin to collide, the  
                HUD automatically compensates for this by removing the sections of  
                least priority. These sections are made invisible and a warning is  
                issued to inform the user of the removal. This continues until only  
                the section of highest priority remains.  
              
                For each row, the priorities are defined as follows. Using the top  
                row as an example: Section 0, has the highest priority, followed  
                by Section 4, making the outermost sections of highest priority.  
                Next in the list is Section 2, and lastly Sections 1 and 3 are of  
                the equal and least priority. This priority structure can be applied  
                to the bottom row as well. The two outermost sections have the highest  
                priority, followed by the middle section, and finally the remaining  
                two sections are of lowest priority.  
              
                This means that as the viewport gradually decreases in width  
                to the point where sections in the top row begin to overlap, sections  
                1 and 3 will be removed from view first, followed by section 2, and  
                finally section 4. A similar note is provided below for the block layout.  
                Properties: create, query, edit
        sliderIncrement (Queryable[float]?): Specify the number of increments along the slider. If not specified or set to 0 or less,  
                the slider will be linearly even and continuous from minValue to maxValue.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        sliderLength (Queryable[int]?): Specifies the length of the slider in pixels.  
                Properties: create, query, edit
        type (Queryable[str]?): Specify the numeric type of the HUD. Available types are:  
                "float" and "int".  
                Properties: create, query, edit
        value (Queryable[float]?): Set/Return the slider value if the HUD is a valid HUD slider.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        valueAlignment (Queryable[str]?): Specifies the alignment of the data blocks and the data text, within a HUD block.  
                Available alignments are: "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        valueFontSize (Queryable[str]?): Sets the font size of the slider value. Available sizes are: small and large.  
                Properties: create, query, edit
        valueWidth (Queryable[int]?): Specifies the pixel width of the virtual "textbox" which will hold the slider value.  
                (To see a layout of a block, see the description of the -block flag.)  
                Properties: create, query, edit
        visible (bool?): Sets the visibility of the Heads-Up Display on and off.  
                Properties: create, query, edit

    Returns:
        int: ID number of the Heads-Up Display (HUD).
        Union[str, int, Tuple[int, int]]: HUD name, HUD ID or Section and block value, for respective remove commands.

    Example:
    """

def hudSliderButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowOverlap: bool = ..., block: Queryable[int] = ..., blockAlignment: Queryable[str] = ..., blockSize: Queryable[str] = ..., buttonLabel: Queryable[str] = ..., buttonLabelFontSize: Queryable[str] = ..., buttonPressCommand: Queryable[Callable[..., Any]] = ..., buttonReleaseCommand: Queryable[Callable[..., Any]] = ..., buttonShape: Queryable[str] = ..., buttonWidth: Queryable[int] = ..., decimalPrecision: Queryable[int] = ..., internalPadding: Queryable[int] = ..., maxValue: Queryable[float] = ..., minValue: Queryable[float] = ..., padding: Queryable[int] = ..., section: Queryable[int] = ..., sliderDragCommand: Queryable[Callable[..., Any]] = ..., sliderIncrement: Queryable[float] = ..., sliderLabel: Queryable[str] = ..., sliderLabelFontSize: Queryable[str] = ..., sliderLabelWidth: Queryable[int] = ..., sliderLength: Queryable[int] = ..., sliderPressCommand: Queryable[Callable[..., Any]] = ..., sliderReleaseCommand: Queryable[Callable[..., Any]] = ..., type: Queryable[str] = ..., value: Queryable[float] = ..., valueAlignment: Queryable[str] = ..., valueFontSize: Queryable[str] = ..., valueWidth: Queryable[int] = ..., visible: bool = ...) -> Union[int, Union[str, int, Tuple[int, int]], bool, str, Callable[..., Any], float]:
    """This command creates a Heads-up Display (HUD) slider button control which is placed in
    a 2D inactive overlay plane on the 3D viewport. It is to be used to provide hands-on
    interaction designated by a user script. The HUD slider button control is derived from
    a generic HUD object and thus inherits a similar workflow.Although this command provides much of the same functionality as the headsUpDisplay
    command, it does not provide headsUpDisplay layout controls such as layoutVisibility,
    nextFreeBlock, lastOccupiedBlock, exists, remove, etc. To access that functionality,
    please use the headsUpDisplay command. This command is focused solely around the creation
    and management of HUD slider button controls. Similarly, all operations performed by
    this command are limited to HUDs that are slider button controls.The only mandatory flags, on creation are the section and block flags.Like the headsUpDisplay command, upon creation of a HUD slider button, an ID number
    will be assigned to it. This can be used to remove the HUD slider via the headsUpDisplay
    command (-rid/removeID [int IDNumber]), if desired. Alternatively, the headsUpDisplay
    command can remove HUD objects via their position (section and block),
    or their unique name.hud, headsupdisplay, slider, hudslider, hudsliderbutton, button
    Args:
        allowOverlap (bool?): Sets the Heads-Up Display to be visible regardless of overlapping section  
                widths/limitations (see -s/section flag description for more details).  
                Properties: create, query, edit
        block (Queryable[int]?): Denotes the individual block that the HUD will reside in, within a  
                section. Each section is composed of a single column of blocks.  
                The total number of blocks contained within each section is variable.  
              
                The number of blocks that will be visible within each section is  
                dependent on the size of blocks contained in each section and the  
                current size of the window. Blocks begin enumerating from 0 and  
                flexibly increase based on need.  
              
                For HUD sliders, the format differs from that of the standard HUD.  
                The layout using parameters defined by the formatting flags listed  
                below (eg. justify, padding, labelWidth, valueWidth) is shown below:  
              
                __________________________________________________________________________  
                |     |     |      |           |      |       |      |        |     |     |  
                |  P  |  J  |  LW  |  Slider   |  IP  | Value |  IP  | Button |  J  |  P  |  
                |_____|_____|______|___________|______|_______|______|________|_____|_____|  
                P = Sub-block of width, padding  
                J = Justification of the entire block  
                LW = Sub-block of width, labelWidth  
                Slider = Length of the slider  
                SliderValue = Sub-block of width, valueWidth  
                Button = Sub-block of width, buttonWidth  
                IP = Internal Padding  
              
              
                Block Positioning  
              
                Blocks on the top section begin from the top edge of the main  
                viewport, while the bottom section begins from the bottom edge.  
                Blocks are dynamically removed from visibility from the midpoint  
                of the viewport. So, a relatively large block number will not  
                draw to the viewport.  
              
                Lastly, there can be at most one HUD occupying a block at any time.  
                Trying to position a HUD in an occupied block will result in an error.  
                Keep this in mind when positioning the HUD.  
                Properties: create, query, edit
        blockAlignment (Queryable[str]?): Specifies the alignment of the block within its respective column. Available  
                alignments are: "center", "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        blockSize (Queryable[str]?): Sets the height of each block. Available heights are: small, medium and large.  
                In pixel measurements, each corresponds to a 20, 35 or 50 pixel height, respectively.  
                Properties: create, query, edit
        buttonLabel (Queryable[str]?): Text label of the HUD button.  
                Properties: create, query, edit
        buttonLabelFontSize (Queryable[str]?): Sets the font size of the button label. Available sizes are: small and large.  
                Properties: create, query, edit
        buttonPressCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a button mouse click event.  
                Properties: create, query, edit
        buttonReleaseCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a button mouse release event.  
                Properties: create, query, edit
        buttonShape (Queryable[str]?): Specifies the shape of the button. Available button shapes are:  
                "rectangle" and "roundRectangle". The first will draw a rectangular  
                button, while the latter is a rectangle with rounded edges.  
                Properties: create, query, edit
        buttonWidth (Queryable[int]?): Specifies the width of the button.  
                Properties: create, query, edit
        decimalPrecision (Queryable[int]?): Sets the decimal precision of any floating point value returned by the command. The valid  
                range of precision values are 1 to 8.  
                Properties: create, query, edit
        internalPadding (Queryable[int]?): Specifies the amount of padding between the internal elements of the HUD. For the  
                hudSlider, this represents the padding between the slider bar and the slider  
                value. The default padding is 10.  
                Properties: create, query, edit
        maxValue (Queryable[float]?): Specify the maximum value of the slider.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        minValue (Queryable[float]?): Specify the minimum value of the slider.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        padding (Queryable[int]?): Specifies the width of both the left and right margins of a block. Default  
                value is 15 pixels.  
                Properties: create, query, edit
        section (Queryable[int]?): Defines the section the HUD will appear in. There are 10 sections  
                divided across the screen. Five columns and two rows make up the  
                ten element matrix which divide the main viewport. Here is a visual  
                layout of the sections.  
              
                 ________________________  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 0  | 1  | 2  | 3  | 4  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                |    |    |    |    |    |  
                |    |    |    |    |    |  
                | 5  | 6  | 7  | 8  | 9  |  
                |    |    |    |    |    |  
                |____|____|____|____|____|  
                Each section is denoted by a number from 0 to 9 as illustrated above.  
                For example, if the second column of the top row was desired, the  
                section would be defined as: -sec 1  
              
                To prevent HUD objects from displaying over each other and causing a  
                clutter of letters, each row has a defined visibility precedence,  
                where each section would have a visibility priority level. Depending  
                on each priority level, when the screen space begins to shrink to  
                a point where the section widths of a given row begin to collide, the  
                HUD automatically compensates for this by removing the sections of  
                least priority. These sections are made invisible and a warning is  
                issued to inform the user of the removal. This continues until only  
                the section of highest priority remains.  
              
                For each row, the priorities are defined as follows. Using the top  
                row as an example: Section 0, has the highest priority, followed  
                by Section 4, making the outermost sections of highest priority.  
                Next in the list is Section 2, and lastly Sections 1 and 3 are of  
                the equal and least priority. This priority structure can be applied  
                to the bottom row as well. The two outermost sections have the highest  
                priority, followed by the middle section, and finally the remaining  
                two sections are of lowest priority.  
              
                This means that as the viewport gradually decreases in width  
                to the point where sections in the top row begin to overlap, sections  
                1 and 3 will be removed from view first, followed by section 2, and  
                finally section 4. A similar note is provided below for the block layout.  
                Properties: create, query, edit
        sliderDragCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a slider mouse drag event.  
                Properties: create, query, edit
        sliderIncrement (Queryable[float]?): Specify the number of increments along the slider. If not specified or set to 0 or less,  
                the slider will be linearly even and continuous from minValue to maxValue.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        sliderLabel (Queryable[str]?): Text label of the HUD slider.  
                Properties: create, query, edit
        sliderLabelFontSize (Queryable[str]?): Sets the font size of the slider label. Available sizes are: small and large.  
                Properties: create, query, edit
        sliderLabelWidth (Queryable[int]?): Specifies the pixel width of the virtual "textbox" which will hold the label. The  
                contents of this "textbox" will be left justified. If the width of the actual label  
                exceeds the width of the "textbox," the label will be truncated to fit within the  
                dimensions of the "textbox." (To see a layout of a block, see the description  
                of the -block flag.)  
                Properties: create, query, edit
        sliderLength (Queryable[int]?): Specifies the length of the slider in pixels.  
                Properties: create, query, edit
        sliderPressCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a slider mouse click event.  
                Properties: create, query, edit
        sliderReleaseCommand (Queryable[Callable[..., Any]]?): Specifies the procedure or script to run during a slider mouse release event.  
                Properties: create, query, edit
        type (Queryable[str]?): Specify the numeric type of the HUD. Available types are:  
                "float" and "int".  
                Properties: create, query, edit
        value (Queryable[float]?): Set/Return the slider value if the HUD is a valid HUD slider.  
                Note: Although this flag takes in a FLOAT as an argument, if the  
                HUD type is "int", the value will be automatically converted  
                internally to an integer.  
                Properties: create, query, edit
        valueAlignment (Queryable[str]?): Specifies the alignment of the data blocks and the data text, within a HUD block.  
                Available alignments are: "left" and "right". The default alignment is "left".  
                Properties: create, query, edit
        valueFontSize (Queryable[str]?): Sets the font size of the slider value. Available sizes are: small and large.  
                Properties: create, query, edit
        valueWidth (Queryable[int]?): Specifies the pixel width of the virtual "textbox" which will hold the slider value.  
                (To see a layout of a block, see the description of the -block flag.)  
                Properties: create, query, edit
        visible (bool?): Sets the visibility of the Heads-Up Display on and off.  
                Properties: create, query, edit

    Returns:
        int: ID number of the Heads-Up Display (HUD).
        Union[str, int, Tuple[int, int]]: HUD name, HUD ID or Section and block value, for respective remove commands.

    Example:
    """

def hwReflectionMap(*args: str, edit: bool = ..., query: bool = ..., backTextureName: Queryable[str] = ..., bottomTextureName: Queryable[str] = ..., cubeMap: bool = ..., decalMode: bool = ..., enable: bool = ..., frontTextureName: Queryable[str] = ..., leftTextureName: Queryable[str] = ..., rightTextureName: Queryable[str] = ..., sphereMapTextureName: Queryable[str] = ..., topTextureName: Queryable[str] = ...) -> Union[str, bool]:
    """This command creates a hwReflectionMap node for having reflection on
    textured surfaces that currently have their boolean attribute
    displayHWEnvironment set to true.
    Args:
        backTextureName (Queryable[str]?): This flag specifies the file texture name for the back side of the cube.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query
        bottomTextureName (Queryable[str]?): This flag specifies the file texture name for the bottom side of the cube.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query
        cubeMap (bool?): If on, the reflection of the textures is done using the cube mapping.  
                Default is false. The reflection is done using sphere mapping.  
                When queried, this flag returns a boolean.  
                Properties: query
        decalMode (bool?): If on, the reflection color replaces the surface shading.  
                Default is false. The reflection is multiplied to the surface shading.  
                When queried, this flag returns a boolean.  
                Properties: query
        enable (bool?): If on, enable the corresponding hwReflectionMap node.  
                Default is false.  
                When queried, this flag returns a boolean.  
                Properties: query
        frontTextureName (Queryable[str]?): This flag specifies the file texture name for the front side of the cube.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query
        leftTextureName (Queryable[str]?): This flag specifies the file texture name for the left side of the cube.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query
        rightTextureName (Queryable[str]?): This flag specifies the file texture name for the right side of the cube.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query
        sphereMapTextureName (Queryable[str]?): This flag specifies the file texture name for the sphere mapping option.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query
        topTextureName (Queryable[str]?): This flag specifies the file texture name for the top side of the cube.  
                Default is none  
                When queried, this flag returns a string.  
                Properties: query

    Returns:
        str: (name of the created hwReflectionMap node)

    Example:
    """

def hwRender(*args: str, query: bool = ..., acceleratedMultiSampleSupport: bool = ..., activeTextureCount: bool = ..., camera: Queryable[str] = ..., currentFrame: bool = ..., currentView: bool = ..., edgeAntiAliasing: Queryable[Tuple[int, int]] = ..., fixFileNameNumberPattern: bool = ..., frame: float = ..., fullRenderSupport: bool = ..., height: Queryable[int] = ..., imageFileName: bool = ..., layer: Queryable[str] = ..., limitedRenderSupport: bool = ..., lowQualityLighting: bool = ..., noRenderView: bool = ..., notWriteToFile: bool = ..., printGeometry: bool = ..., renderHardwareName: bool = ..., renderRegion: Queryable[Tuple[int, int, int, int]] = ..., renderSelected: bool = ..., textureResolution: Queryable[int] = ..., width: Queryable[int] = ..., writeAlpha: bool = ..., writeDepth: bool = ...) -> Union[bool, str, Tuple[int, int], int, Tuple[int, int, int, int]]:
    """Renders an image or a sequence using the hardware rendering enginehardware, rendering
    Args:
        acceleratedMultiSampleSupport (bool?): This flag when used with query will return whether the graphics supports  
                    hardware accelerated multi-sampling.  
                Properties: query
        activeTextureCount (bool?): This flag when used with query will return the number of textures that  
                    have been bound to the graphics by the hardware renderer.  
                Properties: query
        camera (Queryable[str]?): Specify the camera to use.  Use the first available camera if the camera  
                        given is not found.  
                Properties: create, query
        currentFrame (bool?): Render the current frame.  
                Properties: create, query
        currentView (bool?): When turned on, only the current view will be rendered.  
                Properties: create, query
        edgeAntiAliasing (Queryable[Tuple[int, int]]?): Enables multipass rendering. Controls for the number of exposures rendered  
                per frame are provided in the form of two associated flag arguments. The first  
                specifies the sampling algorithm:  
              
                0. Uniform Weighted Grid Sampling  
                1. Rotated Grid Super Sampling (RGSS)  
                2. Gaussian Weighted Sampling  
              
                 Use of a sampling method other than the others listed above, will result in  
                use of the default sample method of Uniform Weighted Grid Sampling. The second  
                argument specifies a number of samples to use. For each sampling algorithm  
                there is a fixed set of sample counts available:  
              
                0. Uniform Weighted Grid Sampling  
                1 Sample  
                3 Samples  
                4 Samples  
                5 Samples  
                7 Samples  
                9 Samples  
                16 Samples  
                25 Samples  
                36 Samples  
                1. Rotated Grid Super Sampling (RGSS)  
                1 Sample  
                4 Samples  
                5 Samples  
                2. Gaussian Weighted Sampling  
                1 Sample  
                3 Samples  
                4 Samples  
                5 Samples  
                7 Samples  
                9 Samples  
                16 Samples  
                25 Samples  
                36 Samples  
              
                 Using a sampling count other than the allowable options for the given  
                sampling method will result in using the default sample count of 5. The values  
                passed via the command will override settings stored in the  
                hardwareRenderGlobals node.  
                Properties: create, query
        fixFileNameNumberPattern (bool?): This flag allows the user to take the hardwareRenderGlobals  
                    filename as the initial filename pattern,  
                    fix the frame number pattern in the filename in a unique way,  
                    returns the new filename pattern.  This does not change the  
                    hardwareRenderGlobals's filename.  
                Properties: create, query
        frame (float?): Specify the frame to render.  
                Properties: create
        fullRenderSupport (bool?): This flag may be used in the create or query context.  
                    In the create context, it will force the renderer to abort and not  
                    render any frames if the hardware is not fully supported.  
                        In the query context, it will return whether full quality rendering  
                    is supported on the current graphics system. Please see the graphics  
                    card qualification charts for an explanation of limited support.  
                Properties: create, query
        height (Queryable[int]?): Height. If not used, the height is taken from the render globals settings.  
                Properties: create, query
        imageFileName (bool?): This flag let people query the image name for a specified frame.  
                    The frame can be specified using the "-frame" flag.  
                    When no "-frame" is used, the  
                    current frame number is used.  
                Properties: create, query
        layer (Queryable[str]?): Render the specified render layer.  
                        Only this render layer will be rendered,  
                        regardless of the renderable attribute value of the render layer.  
                        The layer name will be appended to the output image file name.  
                        The specified render layer becomes the current render layer before rendering,  
                        and remains as current render layer after the rendering.  
                Properties: create, query
        limitedRenderSupport (bool?): This flag when used with query will return whether limited rendering is supported  
                        on the current graphics system. Please see the graphics card qualification  
                        charts for the current definition of limited support.  
                Properties: query
        lowQualityLighting (bool?): Disable lighting evaluation per pixel (fragment).  
                        Note: The values passed via the command will override settings stored in  
                    the hardware render globals node.  
                Properties: create, query
        noRenderView (bool?): When turned on, the render view is not updated after image computation  
                Properties: create, query
        notWriteToFile (bool?): This flag is set to true if the user does not want to write  
                    the image to a file.  It is set to false, otherwise.  
                    The default value of the flag is "false".  
                Properties: create, query
        printGeometry (bool?): Print the geomety objects as they get translated.  
                Properties: create, query
        renderHardwareName (bool?): This flag will create a graphics context and return the name of the  
                    graphics hardware being used. The graphics hardware is determined by  
                    creating an off screen buffer and querying the GL_RENDERER string  
                    from OpenGL. If the off screen buffer cannot be created an empty  
                    string is returned.  
                Properties: query
        renderRegion (Queryable[Tuple[int, int, int, int]]?): Render region. The parameters are 4 integers, indicating  
                            left right bottom top  
                    of the region.  
                Properties: create, query
        renderSelected (bool?): Only renders the selected objects.  
                Properties: create, query
        textureResolution (Queryable[int]?): Specify the desired resolution of baked textures.  
                Properties: create, query
        width (Queryable[int]?): Width. If not used, the width is taken from the render globals settings.  
                Properties: create, query
        writeAlpha (bool?): Read the alpha channel of color buffer and return as tif file.  
                Properties: create, query
        writeDepth (bool?): Read the depth buffer and return as tif file.  
                Properties: create, query

    Returns:
        bool: Command result

    Example:
    """

def hwRenderLoad() -> bool:
    """Empty command used to force the dynamic load of HR renderhardware, rendering
    Returns:
        bool:

    Example:
    """

def hyperGraph(*args: Any, edit: bool = ..., query: bool = ..., addBookmark: bool = ..., addDependGraph: str = ..., addDependNode: str = ..., animateTransition: bool = ..., attributeEditor: str = ..., backward: bool = ..., bookmarkName: bool = ..., breakConnectionCommand: Queryable[str] = ..., clear: bool = ..., collapseContainer: bool = ..., connectionDrawStyle: str = ..., control: bool = ..., currentEdge: Queryable[str] = ..., currentNode: Queryable[str] = ..., debug: str = ..., defineTemplate: str = ..., deleteBookmark: str = ..., dependGraph: bool = ..., dependNode: str = ..., directoryPressCommand: str = ..., docTag: Queryable[str] = ..., down: bool = ..., downstream: bool = ..., dragAndDropBehaviorCommand: str = ..., dropNode: Queryable[str] = ..., dropTargetNode: Queryable[str] = ..., edgeDblClickCommand: str = ..., edgeDimmedDblClickCommand: str = ..., edgeDropCommand: str = ..., edgePressCommand: str = ..., edgeReleaseCommand: str = ..., enableAutomaticLayout: bool = ..., exists: bool = ..., expandContainer: bool = ..., feedbackGadget: Queryable[str] = ..., feedbackNode: Queryable[str] = ..., filter: Queryable[str] = ..., filterDetail: Tuple[str, bool] = ..., fitImageToHeight: bool = ..., fitImageToWidth: bool = ..., focusCommand: str = ..., fold: bool = ..., forceMainConnection: Queryable[str] = ..., forceRefresh: bool = ..., forward: bool = ..., frame: bool = ..., frameBranch: bool = ..., frameGraph: bool = ..., frameGraphNoRebuild: bool = ..., frameHierarchy: bool = ..., freeform: bool = ..., fromAttr: Queryable[str] = ..., fromNode: Queryable[str] = ..., getNodeList: bool = ..., getNodePosition: Queryable[str] = ..., graphDescription: bool = ..., graphLayoutStyle: Queryable[str] = ..., graphType: Queryable[str] = ..., heatMapDisplay: bool = ..., highlightConnection: Queryable[str] = ..., iconSize: Queryable[str] = ..., image: Queryable[str] = ..., imageEnabled: bool = ..., imageForContainer: bool = ..., imagePosition: Queryable[Tuple[float, float]] = ..., imageScale: Queryable[float] = ..., initializeScript: str = ..., isHotkeyTarget: bool = ..., layout: bool = ..., layoutSelected: str = ..., limitGraphTraversal: int = ..., lockMainConnection: bool = ..., look: Tuple[float, float] = ..., mainListConnection: Queryable[str] = ..., mergeConnections: bool = ..., navigateHome: bool = ..., navup: bool = ..., newInputConnection: str = ..., newOutputConnection: str = ..., nextView: bool = ..., nodeConnectCommand: str = ..., nodeDblClickCommand: str = ..., nodeDropCommand: str = ..., nodeMenuCommand: str = ..., nodePressCommand: str = ..., nodeReleaseCommand: str = ..., opaqueContainers: bool = ..., orientation: Queryable[str] = ..., panView: Tuple[float, float] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuScript: str = ..., previousView: bool = ..., range: Queryable[Tuple[float, float]] = ..., rebuild: bool = ..., removeNode: str = ..., rename: bool = ..., resetFreeform: bool = ..., restoreBookmark: str = ..., scrollUpDownNoZoom: bool = ..., selectionConnection: Queryable[str] = ..., setNodePosition: Tuple[str, float, float] = ..., showCachedConnections: bool = ..., showConnectionFromSelected: bool = ..., showConnectionToSelected: bool = ..., showConstraintLabels: bool = ..., showConstraints: bool = ..., showDeformers: bool = ..., showExpressions: bool = ..., showInvisible: bool = ..., showRelationships: bool = ..., showShapes: bool = ..., showUnderworld: bool = ..., stateString: bool = ..., toAttr: Queryable[str] = ..., toNode: Queryable[str] = ..., transitionFrames: Queryable[int] = ..., unParent: bool = ..., unfold: bool = ..., unfoldAll: bool = ..., unfoldAllShapes: bool = ..., unfoldHidden: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., updateNodeAdded: bool = ..., updateSelection: bool = ..., upstream: bool = ..., useDrawOverrideColor: bool = ..., useFeedbackList: bool = ..., useTemplate: str = ..., viewOption: Queryable[str] = ..., visibility: bool = ..., zoom: float = ...) -> Union[str, bool, Tuple[float, float], float, int]:
    """The following is an overview of the basic features of the hypergraph.
    A more detailed description is given in the user manuals.The hypergraph provides the user with the ability to view and edit
    the maya scene graph.  The hypergraph supports two types of graphs:
    the DAG or scene hierarchy and the dependency graph.The default view of the hypergraph editor is the DAG view.
    The user can show the dependency graph for a collection of nodes by
    first selecting the nodes and navigating to the dependency graph using one
    of the graph options.  The user can save any view by setting a
    bookmark to that view.  The user can also show previous views using
    the view options provided.The hypergraph supports a simple editing mechanism for editing hierarchy
    in the DAG view and connections in dependency graph view.
    In the DAG  view, the user can reparent or reorder nodes in the graph
    using drag-and-drop. In the dependency graph view, the user can select
    connections and delete them or make new connections by dragging and
    dropping nodes or existing connections.The hypergraph supports two layout modes in the DAG view: automatic and
    freeform.  In automatic mode, the graph nodes are automatically
    positioned according to the layout preferences.  In freeform mode, the
    user can position nodes manually.  The node position is saved in the scene.
    A background image can be placed behind DG or DAG in freeform mode.
    This can be used as a template for positioning nodes in a user-defined
    layout.Nodes in the DAG view can be expanded or collapsed.  The state is saved
    in the scene.  The performance of the graph drawing will increase
    as hierarchies are collapsed.In addition to hierachy relationships, the hypergraph can show
    expression, constraint and deformation relationships in the DAG.
    These can be enabled/disabled through the options provided.  There
    are also additional filters for showing shape nodes and invisible
    nodes.  The amount of detail show may affect the speed of the display
    of the graph.Most of the UI features of the hypergraph are addressable through the
    hypergraph command-line interface.  The available command-line
    options are described in the next section.
    Args:
        addBookmark (bool?): Create a bookmark for the current hypergraph view.  
                Properties: create, edit
        addDependGraph (str?): Add a dependency graph starting at the named node to the view  
                Properties: create, edit
        addDependNode (str?): Add a dependency node to the dependency graph view  
                Properties: create, edit
        animateTransition (bool?): Turns animate transitions off and on.  
                Properties: create, query, edit
        attributeEditor (str?): Launches attribute editor on selected node.  
                Properties: create, edit
        backward (bool?): Navigate backward one step.  
                Properties: create, edit
        bookmarkName (bool?): Returns the bookmark name for the most recently created bookmark.  
                Properties: query
        breakConnectionCommand (Queryable[str]?): Specify the command to call when a connection is broken.  
                Properties: create, query, edit
        clear (bool?): Clears the current hypergraph view and deletes the graph UI.  
                (see also -rebuild flag)  
                Properties: create, edit
        collapseContainer (bool?): Collapses containers selected in DG graph.  
                Properties: create, edit
        connectionDrawStyle (str?): Specify how connections between nodes should be drawn. Valid  
                values are "center" (draws connection lines from the center of one node  
                to the center of the other) and "side" (draws connection lines from the  
                right side of the source node to the left side of the destination  
                node). The default is "center". This flag does not apply to Hypershade  
                graphs, which are always drawn with the "side" connection draw style.  
                Properties: create, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        currentEdge (Queryable[str]?): Return the current edge name.  
                Properties: query, edit
        currentNode (Queryable[str]?): Return the current node name.  
                Properties: query, edit
        debug (str?): Run a debug method on the graph  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteBookmark (str?): Delete the bookmark with the corresponding node name.  
                Properties: create, edit
        dependGraph (bool?): Displays dependency graph iterated from specified node.  
                Properties: create, edit
        dependNode (str?): Displays dependency node in view.  
                Properties: create, edit
        directoryPressCommand (str?): Specify a command to run when a directory is pressed.  
                Properties: create, edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        down (bool?): Navigate down to the dependency graph containing the current selection.  
                Shows upstream and downstream connections.  
                Properties: create, edit
        downstream (bool?): Show downstream dependency graph of selected node(s).  
                Properties: create, edit
        dragAndDropBehaviorCommand (str?): Mel proc called when a drag and drop onto a hyperGraph  
                node has occurred. Proc signature is  
                procName (string $editor, string $sourceNode, string $destinationNode).  
                Properties: create, edit
        dropNode (Queryable[str]?): Returns the name of the source node in a drag and drop connection,  
                when called during processing of a drop.  
                Properties: query
        dropTargetNode (Queryable[str]?): Returns the name of the destination node in a drag and drop  
                connection, when called during processing of a drop.  
                Properties: query
        edgeDblClickCommand (str?): Mel proc called when an edge is double clicked.  Proc signature is  
                procName (string $editor, string $edge).  
                Properties: create, edit
        edgeDimmedDblClickCommand (str?): Mel proc called when a dimmed edge is double clicked.  Proc signature is  
                procName (string $editor, string $edge).  
                Properties: create, edit
        edgeDropCommand (str?): Command to execute when an edge drop occurs.  
                Properties: create, edit
        edgePressCommand (str?): Command to execute when an edge press occurs.  
                Properties: create, edit
        edgeReleaseCommand (str?): Command to execute when an edge release occurs.  
                Properties: create, edit
        enableAutomaticLayout (bool?): Rebuild the graph if a node is added or removed from the graph  
                via drag and drop or dg messages. Default is true.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        expandContainer (bool?): Expands containers selected in DG graph.  
                Properties: create, edit
        feedbackGadget (Queryable[str]?): Returns the name of the current gadget.  
                Properties: query
        feedbackNode (Queryable[str]?): Returns the name of the current feedback or highlight node.  
                Properties: query
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        filterDetail (Tuple[str, bool]?): This flag is obsolete. Use the showConstraints, showExpressions,  
                showDeformer, showInvisible, showShapes and showUnderworld flags  
                instead.  
                Properties: create, edit
        fitImageToHeight (bool?): Changes position and scale of background image, so its height fits current editor view.  
                Properties: create
        fitImageToWidth (bool?): Changes position and scale of background image, so its width fits current editor view.  
                Properties: create
        focusCommand (str?): Mel proc to be run when the mouse is clicked in the hyper  
                graph. Primarily of use in setting the window focus.  
                Properties: create, edit
        fold (bool?): Folds (Collapses) selected object.  
                Properties: create, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        forceRefresh (bool?): Forces the hypergraph to refresh (redraw) its contents.  
                Properties: create, edit
        forward (bool?): Navigate forward one step.  
                Properties: create, edit
        frame (bool?): Frames the selected objects  
                Properties: create, edit
        frameBranch (bool?): Frames the the branch from the selected node on downward.  
                Properties: create, edit
        frameGraph (bool?): Frames the entire graph.  
                Properties: create, edit
        frameGraphNoRebuild (bool?): Specify that on zoom out the graph should not rebuild; for efficiency.  
                Properties: create, edit
        frameHierarchy (bool?): Frames the hierarchy that contains the selected node.  
                Properties: create, edit
        freeform (bool?): Enable freeform layout mode.  
                Properties: create, query, edit
        fromAttr (Queryable[str]?): Returns the name of the source attribute in a drag and drop  
                connection, when called during processing of a drop.  
                Properties: query
        fromNode (Queryable[str]?): Returns the name of the source node in a drag and drop  
                connection, when called during processing of a drop.  
                Properties: query
        getNodeList (bool?): Returns a string array that represents a list  
                of all the nodes in the graph.  
                Properties: query
        getNodePosition (Queryable[str]?): Returns the position of a specified node in x,y graph coords.  
                This flag and its argument must be passed to the command before the  
                -q flag (see examples).  
                      In query mode, this flag can accept a value.  
                Properties: query
        graphDescription (bool?): When used, return a description of the current graph.  
                Properties: create, edit
        graphLayoutStyle (Queryable[str]?): This flag is obsolete.  The only supported graph layout style is "hierarchicalLayout".  
                Use of any other style will trigger a warning.  
                Properties: create, query, edit
        graphType (Queryable[str]?): Returns the type name of the current graph in the view  
                (either DAG or DG).  
                Properties: query
        heatMapDisplay (bool?): Specify whether the heat map should be shown or not.  
                Properties: query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        iconSize (Queryable[str]?): Set or query the icon size for this hyper graph editor.  
                The currently allowed icon sizes are "smallIcons", "mediumIcons",  
                "largeIcons" and "superIcons".  
                Properties: create, query, edit
        image (Queryable[str]?): Specify background image to be loaded from the project image directory.  
                Properties: create, query, edit
        imageEnabled (bool?): Enable display of a loaded background image (Freeform DAG view or DG view)  
                Properties: create, query, edit
        imageForContainer (bool?): Specify that the following flags work on selected containers instead of the whole image:  
                -imageScale,-imagePosition, fitImageToWidth, -fitImageToHeight, -image  
                Properties: create, query, edit
        imagePosition (Queryable[Tuple[float, float]]?): Position of the background image.  
                Properties: create, query, edit
        imageScale (Queryable[float]?): Uniform scale of the background image.  
                Properties: create, query, edit
        initializeScript (str?): Script to call when the graph is initialized.  
                Properties: create, edit
        isHotkeyTarget (bool?): For internal use.  
                Properties: query
        layout (bool?): Perform an automatic layout on the graph.  
                Properties: create, edit
        layoutSelected (str?): This flag is obsolete.  The only supported graph layout style is "hierarchicalLayout".  
                Use of any other style will trigger a warning.  
                Properties: create, edit
        limitGraphTraversal (int?): Limit the graph traversal to a certain number of levels.  
                Properties: create, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        look (Tuple[float, float]?): Look at a coordinate in the graph view  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        mergeConnections (bool?): Merge groups of connections into 'fat' connections.  
                Properties: create, query, edit
        navigateHome (bool?): Navigate to the home (DAG) view.  
                Properties: create, edit
        navup (bool?): Navigate up to the dependency graph containing the current selection.  
                Shows upstream and downstream connections.  
                Properties: create, edit
        newInputConnection (str?): Specify a new connection, input side  
                Properties: create, edit
        newOutputConnection (str?): Specify a new connection, output side  
                Properties: create, edit
        nextView (bool?): Changes the view to the next DAG view.  
                Properties: create, edit
        nodeConnectCommand (str?): Command to call when a node is connected.  
                Properties: create, edit
        nodeDblClickCommand (str?): Command to call when a node is double-clicked.  
                Properties: create, edit
        nodeDropCommand (str?): Set the command to be called when a node is dropped in the  
                hypergraph window.  
                Properties: create, edit
        nodeMenuCommand (str?): Command to call when a node menu is activated.  
                Properties: create, edit
        nodePressCommand (str?): Set the command to be called when the user presses a mouse button  
                while the cursor is over a node in the hypergraph window.  
                Properties: create, edit
        nodeReleaseCommand (str?): Set the command to be called when the user releases a mouse button  
                while the cursor is over a node in the hypergraph window.  
                Properties: create, edit
        opaqueContainers (bool?): Sets expanded container background opacity.  
                Properties: query, edit
        orientation (Queryable[str]?): Selects orientation style of graph: "horiz"|"vert"  
                Properties: create, query, edit
        panView (Tuple[float, float]?): Pan the view to a new center.  
                Properties: create, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        popupMenuScript (str?): Set the script to be called to register the popup menu with the  
                control for this hypergraph. The script will be called with a string  
                argument which gives the name of the hypergraph whose control the popup  
                menu should be parented to.  
                Properties: create, edit
        previousView (bool?): Changes the view back to the previous DAG view.  
                Properties: create, edit
        range (Queryable[Tuple[float, float]]?): Limits the display of nodes to only those within the range.  
                There are two float values expected, the first the lower threshold  
                of the range and the second the upper threshold of the range.  
                The values are absolute timing values, not percentages.  
                Properties: create, query, edit
        rebuild (bool?): Rebuilds graph  
                Properties: create, edit
        removeNode (str?): Removes the node identified by string from the graph.  
                Properties: create, edit
        rename (bool?): Pops up text field over selected object for renaming  
                Properties: create, edit
        resetFreeform (bool?): Resets freeform position on all nodes.  
                Properties: create, edit
        restoreBookmark (str?): Restore the view corresponding to the bookmark.  
                Properties: create, edit
        scrollUpDownNoZoom (bool?): Specify if we want to be in the  
                scroll along y only with no free zooming mode.  
                By default, hyper graph editor allows user to  
                pan left and right.  
                Properties: create, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        setNodePosition (Tuple[str, float, float]?): Sets the node identified by string to the (x,y) position  
                in the window specified by the two floats. If  
                the node is not in the graph than it will be added to the  
                graph and then moved to the new position.  
                Properties: create, edit
        showCachedConnections (bool?): Specify whether cached connections should be shown.  
                Properties: create, edit
        showConnectionFromSelected (bool?): Show the connects (constraints, expresions, and deformers - see showConstraints for example)  
                leaving from selected nodes. This can be combined with showConnectionToSelected to show both  
                arrive and leaving connects. If both flags are false then all the connections will be shown.  
                Properties: create, query, edit
        showConnectionToSelected (bool?): Show the connects (constraints, expresions, and deformers - see showConstraints for example)  
                arriving at selected nodes. This can be combined with  
                showConnectionFromSelected to show both arrive and leaving connects. If both flags  
                are false then all the connections will be shown.  
                Properties: create, query, edit
        showConstraintLabels (bool?): Specify whether constraint labels should be shown.  
                Properties: create, edit
        showConstraints (bool?): Show constraint relationships in the DAG.  
                Properties: create, query, edit
        showDeformers (bool?): Show deformer or geometry filter relationships in the DAG.  
                Properties: create, query, edit
        showExpressions (bool?): Show expression relationships in the DAG.  
                Properties: create, query, edit
        showInvisible (bool?): Show invisible nodes in the DAG.  
                Properties: create, query, edit
        showRelationships (bool?): Show relationship (message) connections.  
                Properties: create, query, edit
        showShapes (bool?): Show shape nodes in the DAG.  
                Properties: create, query, edit
        showUnderworld (bool?): Show underworld graphs in the DAG.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        toAttr (Queryable[str]?): Returns the name of the destination attribute in a drag and drop  
                connection, when called during processing of a drop.  
                Properties: query
        toNode (Queryable[str]?): Returns the name of the destination node in a drag and drop  
                connection, when called during processing of a drop.  
                Properties: query
        transitionFrames (Queryable[int]?): Specify te number of transition frames for animate transitions.  
                Properties: create, query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unfold (bool?): Unfolds (expands) selected object.  
                Properties: create, edit
        unfoldAll (bool?): Unfolds everything under selected object.  
                Properties: create, edit
        unfoldAllShapes (bool?): Unfolds all shapes.  
                Properties: create, edit
        unfoldHidden (bool?): Unfolds all hidden objects.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        updateNodeAdded (bool?): Update graph when a new node is added to the database  
                Properties: create, query, edit
        updateSelection (bool?): Update selection state in the graph when the selection state of  
                database changes.  
                Properties: create, query, edit
        upstream (bool?): Show upstream dependency graph of selected node(s).  
                Properties: create, edit
        useDrawOverrideColor (bool?): Specify whether or not to use draw override coloring.  
                Properties: create, edit
        useFeedbackList (bool?): Use feedback or highlight list as the target selection when  
                processing other hypergraph command-line options.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        viewOption (Queryable[str]?): Set or query the view option for this hyper graph editor.  
                The currently allowed views are "asIcons" and "asList".  
                Properties: create, query, edit
        visibility (bool?): Set the visible state of the selected node(s).  
                Properties: create, edit
        zoom (float?): Specify the zoom factor for animating transitions  
                Properties: create, edit

    Returns:
        str: the name of the panel

    Example:
    """

def hyperPanel(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., hyperEditor: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command creates, edit and queries hypergraph panels which contain only
    a hypergraph editor.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        hyperEditor (bool?): This flag returns the name of the hypergraph editor  
                contained by the panel.  
                Properties: query
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the panel

    Example:
    """

def hyperShade(*args: Any, assign: str = ..., clearWorkArea: bool = ..., collapse: str = ..., createNode: str = ..., dependGraphArea: bool = ..., downStream: bool = ..., duplicate: bool = ..., fixRenderSize: bool = ..., geometries: Multiuse[str] = ..., incremental: bool = ..., listDownstreamNodes: str = ..., listDownstreamShaderNodes: str = ..., listGeometries: str = ..., listMaterialNodes: bool = ..., listUpstreamNodes: str = ..., name: str = ..., networks: bool = ..., noSGShapes: bool = ..., noShapes: bool = ..., noTransforms: bool = ..., objects: str = ..., renderCreateAndDrop: str = ..., reset: bool = ..., resetGraph: bool = ..., resetSwatch: bool = ..., setAllowsRegraphing: bool = ..., setWorkArea: str = ..., shaderNetwork: str = ..., shaderNetworks: bool = ..., shaderNetworksSelectMaterialNodes: bool = ..., snapShot: bool = ..., uncollapse: str = ..., upStream: bool = ..., useMaterialTemplate: bool = ..., userDefinedLayout: bool = ..., workAreaAddCmd: str = ..., workAreaDeleteCmd: str = ..., workAreaSelectCmd: str = ...) -> str:
    """Commands for shader editing in the hypergraphrender, hypergraph, shader, hypershade
    Args:
        assign (str?): Assign the specified shader node to renderable objects on the active list  
                or the geometries in the -geometries option when specified.  
                The node can either be a shading group or the shader node attached to the  
                shading group.  
                Properties: create
        clearWorkArea (bool?): Push the current work area on to the stack and create a clear work area  
                Properties: create
        collapse (str?): Hide the upstream nodes from the specified node.  
                Properties: create
        createNode (str?): Create a node of the specified type.  This is called when a new rendering  
                node is created using drag and drop from the image browser or from the  
                RMB context sensitive menu on nodes in the Visor Create folders.  
                Properties: create
        dependGraphArea (bool?): When setting a work area, and the work area doesn't already exist this  
                flag inicates a new graph should be created that is either a depend graph  
                or a folder view.  
                Properties: create
        downStream (bool?): Show nodes downstream from the specified node  
                Properties: create
        duplicate (bool?): Duplicate upstream nodes.  If the node is a shader make sure duplicate  
                include the shading group if there is one  
                Properties: create
        fixRenderSize (bool?): If set to true dont rerender swatches when they change size as the user  
                zooms  
                Properties: create
        geometries (Multiuse[str]?): When used in conjunction with the -assign option the shaders will be assigned to geometries specified here.  
                When used in conjunction with the -listMaterialNodes option the material nodes used by the geometries specified here will be listed.  
                Properties: create, multiuse
        incremental (bool?): Enable or disable incremental layout when making new nodes or connections  
                Properties: create
        listDownstreamNodes (str?): List all the downstream render nodes from the specified nodes.  
                Properties: create
        listDownstreamShaderNodes (str?): List all the downstream shader nodes from the specified nodes.  
                Properties: create
        listGeometries (str?): List the geoemtries which are attached to the specified shader node.  
                The shader node can be either the shading group or the shader attached  
                to the shading group.  When this flag's argument is the empty string,  
                we will use the currently selected shader node as the input.  
                Properties: create
        listMaterialNodes (bool?): List all the materials nodes for the geometries in the -geometries option  
                or, if not specified, the currently selected objects.  
                Properties: create
        listUpstreamNodes (str?): List all the upstream render nodes from the specified nodes.  
                Properties: create
        name (str?): Name for the work area created by this command  
                Properties: create
        networks (bool?): Do an incremental layout on all of the nodes in the current selection  
                list and that are in the current work area.  
                Properties: create
        noSGShapes (bool?): Display only shapes that are connected to nodes in the  
                network other than a shading group.  
                Properties: create
        noShapes (bool?): Display no shapes when graphing networks.  
                Properties: create
        noTransforms (bool?): Display no transforms when graphing networks.  
                Properties: create
        objects (str?): Select the objects which are attached to the specified shader node.  
                The shader node can be either the shading group or the shader attached  
                to the shading group.  When this flag's argument is the empty string,  
                we will use the currently selected shder node as the input.  
                Properties: create
        renderCreateAndDrop (str?): Create a render node of the specified type and put user into drag and  
                drop mode to place or connect it.  
                Properties: create
        reset (bool?): Reset the Hypershade panel to its initial state.  In particular delete all  
                the work areas.  
                Properties: create
        resetGraph (bool?): Reset the current graph.  Typically called prior to rebuilding a folder in  
                a Hypershade view.  
                Properties: create
        resetSwatch (bool?): For all selected nodes remove user defined swatches if the node has one  
                Properties: create
        setAllowsRegraphing (bool?): For internal use only.  
                Properties: create
        setWorkArea (str?): Set the work area to the existing named work area  
                Properties: create
        shaderNetwork (str?): Show the shader network for the specified material node.  If the materials  
                shading group has a displacement or volume map these will be shown.  If not  
                then the shading group will not be shown.  
                Properties: create
        shaderNetworks (bool?): Show the shader network for all the objects on the selection list that  
                have shaders.  
                Properties: create
        shaderNetworksSelectMaterialNodes (bool?): Select the material nodes in the shader network for all the  
                objects on the selection list that have shaders.  
                Properties: create
        snapShot (bool?): Put hypergraph in snapshot mode.  This is only for testing  
                Properties: create
        uncollapse (str?): Unhide the upstream nodes from the specified node.  
                Properties: create
        upStream (bool?): Show nodes upstream from the specified node  
                Properties: create
        useMaterialTemplate (bool?): Specifies that a material will be assigned using the materialTemplate method.  
                Properties: create
        userDefinedLayout (bool?): Enable or disable remembrance of user defined layouts.  Default is disabled  
                until this functionality is better tested.  
                Properties: create
        workAreaAddCmd (str?): Set the MEL procedure called when a new work area is added to HyperShade  
                Properties: create
        workAreaDeleteCmd (str?): Set the MEL procedure called when a work area is deleted in HyperShade  
                Properties: create
        workAreaSelectCmd (str?): Set the MEL procedure called when a work area is selected in HyperShade  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def iconTextButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., command: Queryable[Callable[..., Any]] = ..., commandRepeatable: bool = ..., defineTemplate: str = ..., disabledImage: Queryable[str] = ..., docTag: Queryable[str] = ..., doubleClickCommand: Queryable[Callable[..., Any]] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., flat: bool = ..., flipX: bool = ..., flipY: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., handleNodeDropCallback: Callable[..., Any] = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightImage: Queryable[str] = ..., image: Queryable[str] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelEditingCallback: Callable[..., Any] = ..., labelOffset: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., overlayLabelBackColor: Queryable[Tuple[float, float, float, float]] = ..., overlayLabelColor: Queryable[Tuple[float, float, float]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rotation: Queryable[float] = ..., scaleIcon: bool = ..., selectionImage: Queryable[str] = ..., sourceType: Queryable[str] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useAlpha: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int, Tuple[float, float, float, float], float]:
    """This control supports up to 3 icon images and 4 different display
    styles.  The icon image displayed is the one that best fits the
    current size of the control given its current style.This command creates an iconTextButton that can be displayed with different
    icons, with or without accompanying text label. When an argument is
    passed, it is used to give a name to the iconTextButton.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center". By default, the label is aligned "center".  
                Currently only available when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        command (Queryable[Callable[..., Any]]?): Command executed when the control is pressed.  
                Properties: create, query, edit
        commandRepeatable (bool?): Set if the MEL command specified in the command flag should be repeatable  
                or not.  The "g" key, by default, is the shortcut to repeat the last executed command.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disabledImage (Queryable[str]?): Image used when the button is disabled. Image size must  
                be the same as the image specified with the i/image flag.  
                This is a Windows only flag.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Queryable[Callable[..., Any]]?): Command executed when the control is double clicked.  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        flat (bool?): Sets whether the control will be a flat button (0 false, 1 true).  
                Properties: create, query, edit
        flipX (bool?): Is the image flipped horizontally?  
                Properties: create, query, edit
        flipY (bool?): Is the image flipped vertically?  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        handleNodeDropCallback (Callable[..., Any]?): Specify a script callback which is called when a node is dropped  
                on the control.  The name of the node being dropped will be  
                passed to the function  (python callable) or appended to the end  
                (script) to form the command to be executed.  
                Properties: create, edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlightImage (Queryable[str]?): Highlight image displayed while the cursor is over the  
                control. Image size must be the same as the image specified with  
                the -i/image flag. This is a Windows only flag.  
                Properties: create, query, edit
        image (Queryable[str]?): If you are not providing images with different sizes then you may  
                use this flag for the control's image. If the "iconOnly" style is  
                set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string, up to 6 characters, representing a label that will be displayed  
                on top of the image.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The text that appears in the control.  
                Properties: create, query, edit
        labelEditingCallback (Callable[..., Any]?): Specify a callback which is called after the user  
                double clicks the label of the control to give it a new label.  
                The new label string will be passed to the callback.  
                Properties: create, edit
        labelOffset (Queryable[int]?): The label offset. Default is 0. Currently only available  
                when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): The number of pixels above and below the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): The number of pixels on either side of the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        overlayLabelBackColor (Queryable[Tuple[float, float, float, float]]?): The RGBA color of the shadow behind the label defined by  
                imageOverlayLabel. Default is 50% transparent black: 0 0 0 .5  
                Properties: create, query, edit
        overlayLabelColor (Queryable[Tuple[float, float, float]]?): The RGB color of the label defined by imageOverlayLabel. Default is a  
                light grey: .8 .8 .8  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rotation (Queryable[float]?): The rotation value of the image in radians.  
                Properties: create, query, edit
        scaleIcon (bool?): For "textOnly" and "iconOnly" style, this flag has no effect.  
                For other styles, if the flag is specified, the icon will be scaled to the size of the control.  
                Properties: create, edit
        selectionImage (Queryable[str]?): Image displayed while the control is selected. Image size  
                must be the same as the image specified with the -i/image  
                flag. This is a Windows only flag.  
                Properties: create, query, edit
        sourceType (Queryable[str]?): Sets the language type for the command script. Can only be used in  
                conjunction with the c/command or dcc/doubleClickCommand flags.  
                Valid values are "mel" (enabled by default), and "python".  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal", "iconAndTextVertical", and  
                "iconAndTextCentered". (Note: "iconAndTextCentered" is only available on Windows).  
                If the "iconOnly" style is set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        useAlpha (bool?): Is the image using alpha channel?  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the iconTextButton.

    Example:
    """

def iconTextCheckBox(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., disabledImage: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., flat: bool = ..., flipX: bool = ..., flipY: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightImage: Queryable[str] = ..., image: Queryable[str] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelOffset: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., offCommand: Queryable[Callable[..., Any]] = ..., onCommand: Queryable[Callable[..., Any]] = ..., overlayLabelBackColor: Queryable[Tuple[float, float, float, float]] = ..., overlayLabelColor: Queryable[Tuple[float, float, float]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rotation: Queryable[float] = ..., selectionHighlightImage: Queryable[str] = ..., selectionImage: Queryable[str] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useAlpha: bool = ..., useTemplate: str = ..., value: bool = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int, Tuple[float, float, float, float], float]:
    """This control supports up to 3 icon images and 4 different display
    styles.  The icon image displayed is the one that best fits the
    current size of the control given its current style.This command creates an iconTextCheckBox.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center". By default, the label is aligned "center".  
                Currently only available when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Queryable[Callable[..., Any]]?): Command executed when the control's state is changed.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of the control from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disabledImage (Queryable[str]?): Image used when the button is disabled. Image size must  
                be the same as the image specified with the i/image flag.  
                This is a Windows only flag.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        flat (bool?): Sets whether the control will be a flat button (0 false, 1 true).  
                Properties: create, query, edit
        flipX (bool?): Is the image flipped horizontally?  
                Properties: create, query, edit
        flipY (bool?): Is the image flipped vertically?  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlightImage (Queryable[str]?): Highlight image displayed while the cursor is over the  
                control. Image size must be the same as the image specified with  
                the -i/image flag. This is a Windows only flag.  
                Properties: create, query, edit
        image (Queryable[str]?): If you are not providing images with different sizes then you may  
                use this flag for the control's image. If the "iconOnly" style is  
                set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string, up to 6 characters, representing a label that will be displayed  
                on top of the image.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The text that appears in the control.  
                Properties: create, query, edit
        labelOffset (Queryable[int]?): The label offset. Default is 0. Currently only available  
                when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): The number of pixels above and below the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): The number of pixels on either side of the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Queryable[Callable[..., Any]]?): Command executed when the control is turned off.  
                Properties: create, query, edit
        onCommand (Queryable[Callable[..., Any]]?): Command executed when the control is turned on.  
                Properties: create, query, edit
        overlayLabelBackColor (Queryable[Tuple[float, float, float, float]]?): The RGBA color of the shadow behind the label defined by  
                imageOverlayLabel. Default is 50% transparent black: 0 0 0 .5  
                Properties: create, query, edit
        overlayLabelColor (Queryable[Tuple[float, float, float]]?): The RGB color of the label defined by imageOverlayLabel. Default is a  
                light grey: .8 .8 .8  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rotation (Queryable[float]?): The rotation value of the image in radians.  
                Properties: create, query, edit
        selectionHighlightImage (Queryable[str]?): Image displayed while the control is selected and the cursor  
                is over the control. Image size  
                must be the same as the image specified with the -i/image  
                flag. This is a Windows only flag.  
                Properties: create, query, edit
        selectionImage (Queryable[str]?): Image displayed while the control is selected. Image size  
                must be the same as the image specified with the -i/image  
                flag. This is a Windows only flag.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal", "iconAndTextVertical", and  
                "iconAndTextCentered". (Note: "iconAndTextCentered" is only available on Windows).  
                If the "iconOnly" style is set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        useAlpha (bool?): Is the image using alpha channel?  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (bool?): Sets or returns the state of the control.  
                Properties: create, query, edit
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def iconTextRadioButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Queryable[Callable[..., Any]] = ..., collection: str = ..., defineTemplate: str = ..., disabledImage: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., flat: bool = ..., flipX: bool = ..., flipY: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightImage: Queryable[str] = ..., image: Queryable[str] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelOffset: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., offCommand: Queryable[Callable[..., Any]] = ..., onCommand: Queryable[Callable[..., Any]] = ..., overlayLabelBackColor: Queryable[Tuple[float, float, float, float]] = ..., overlayLabelColor: Queryable[Tuple[float, float, float]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rotation: Queryable[float] = ..., select: bool = ..., selectionHighlightImage: Queryable[str] = ..., selectionImage: Queryable[str] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useAlpha: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int, Tuple[float, float, float, float], float]:
    """This control supports up to 3 icon images and 4 different display
    styles.  The icon image displayed is the one that best fits the
    current size of the control given its current style.This command creates a iconTextRadioButton that is added to the most
    recently created iconTextRadioCollection unless the -cl/cluster flag is
    used.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center". By default, the label is aligned "center".  
                Currently only available when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Queryable[Callable[..., Any]]?): Command executed when the control's state is changed.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of the control from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, query, edit
        collection (str?): To explicitly add the control to the specified collection.  
                Properties: create
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disabledImage (Queryable[str]?): Image used when the button is disabled. Image size must  
                be the same as the image specified with the i/image flag.  
                This is a Windows only flag.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        flat (bool?): Sets whether the control will be a flat button (0 false, 1 true).  
                Properties: create, query, edit
        flipX (bool?): Is the image flipped horizontally?  
                Properties: create, query, edit
        flipY (bool?): Is the image flipped vertically?  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlightImage (Queryable[str]?): Highlight image displayed while the cursor is over the  
                control. Image size must be the same as the image specified with  
                the -i/image flag. This is a Windows only flag.  
                Properties: create, query, edit
        image (Queryable[str]?): If you are not providing images with different sizes then you may  
                use this flag for the control's image. If the "iconOnly" style is  
                set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string, up to 6 characters, representing a label that will be displayed  
                on top of the image.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The text that appears in the control.  
                Properties: create, query, edit
        labelOffset (Queryable[int]?): The label offset. Default is 0. Currently only available  
                when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): The number of pixels above and below the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): The number of pixels on either side of the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Queryable[Callable[..., Any]]?): Command executed when the control is turned off.  
                Properties: create, query, edit
        onCommand (Queryable[Callable[..., Any]]?): Command executed when the control is turned on.  
                Properties: create, query, edit
        overlayLabelBackColor (Queryable[Tuple[float, float, float, float]]?): The RGBA color of the shadow behind the label defined by  
                imageOverlayLabel. Default is 50% transparent black: 0 0 0 .5  
                Properties: create, query, edit
        overlayLabelColor (Queryable[Tuple[float, float, float]]?): The RGB color of the label defined by imageOverlayLabel. Default is a  
                light grey: .8 .8 .8  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rotation (Queryable[float]?): The rotation value of the image in radians.  
                Properties: create, query, edit
        select (bool?): Will set this button as the selected one.  
                Properties: create, query, edit
        selectionHighlightImage (Queryable[str]?): Image displayed while the control is selected and the cursor  
                is over the control. Image size  
                must be the same as the image specified with the -i/image  
                flag. This is a Windows only flag.  
                Properties: create, query, edit
        selectionImage (Queryable[str]?): Image displayed while the control is selected. Image size  
                must be the same as the image specified with the -i/image  
                flag. This is a Windows only flag.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal", "iconAndTextVertical", and  
                "iconAndTextCentered". (Note: "iconAndTextCentered" is only available on Windows).  
                If the "iconOnly" style is set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        useAlpha (bool?): Is the image using alpha channel?  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the iconTextRadioButton created.

    Example:
    """

def iconTextRadioCollection(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., collectionItemArray: bool = ..., defineTemplate: str = ..., disableCommands: bool = ..., exists: bool = ..., gl: bool = ..., numberOfCollectionItems: bool = ..., parent: str = ..., select: Queryable[str] = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command creates a cluster for iconTextRadioButtons.  Clusters
    will be parented to the current default layout if no parent is
    specified with the -p/parent flag. As children of the layout they will
    be deleted when the layout is deleted. Clusters may also span more
    than one window if the -g/global flag is used. In this case the
    cluster has no parent so must be explicitly deleted with
    the 'deleteUI' command.
    Args:
        collectionItemArray (bool?): Returns a string list giving the long names of all the items  
                in this collection.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disableCommands (bool?): Allows a particular iconTextRadioButton in the collection to  
                be selected without invoking the commands attached to  
                the -cc/changeCommand, -onc/onCommand, or -ofc/offCommand flags.  
                This flag is only meaningful when used in conjuction with  
                the -edit and -select flags.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        gl (bool?): Set the collection to have no parent layout.  If the collection has  
                a parent layout then it will be deleted with that layout, otherwise  
                if it is specified to be global it must be explicitly deleted.  
                Properties: create, query
        numberOfCollectionItems (bool?): Returns the number of items that are in this collection.  
                Properties: query
        parent (str?): Set the specified layout to be the parent layout of the cluster.  
                Properties: create
        select (Queryable[str]?): Select the specified collection item.  If queried will return  
                the name of the currently selected collection item.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the iconTextRadioCollection created.

    Example:
    """

def iconTextScrollList(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowMultiSelection: bool = ..., annotation: Queryable[str] = ..., append: Multiuse[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., deselectAll: bool = ..., docTag: Queryable[str] = ..., doubleClickCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dragFeedbackVisible: bool = ..., dropCallback: Callable[..., Any] = ..., dropRectCallback: Callable[..., Any] = ..., editIndexed: int = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., itemAt: Tuple[int, int] = ..., itemTextColor: Multiuse[Tuple[int, float, float, float]] = ..., manage: bool = ..., noBackground: bool = ..., numberOfIcons: Queryable[int] = ..., numberOfPopupMenus: bool = ..., numberOfRows: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., removeAll: bool = ..., selectCommand: Callable[..., Any] = ..., selectIndexedItem: Queryable[Multiuse[int]] = ..., selectItem: Queryable[Multiuse[str]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., visualRectAt: Tuple[int, int] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Multiuse[int], Multiuse[str], Callable[..., Any]]:
    """This command creates/edits/queries a text scrolling list. The
    list can be in single select mode where only one item at at time
    is selected, or in multi-select mode where many items may be
    selected.
    Args:
        allowMultiSelection (bool?): Specify multi or single selection mode.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        append (Multiuse[str]?): Add an item to the end of the list.  
                Properties: create, edit, multiuse
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Script to run when the list changes  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deselectAll (bool?): Deselect all items.  
                Properties: create, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Callable[..., Any]?): Specify the command to be executed when an item is double clicked.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragFeedbackVisible (bool?): Should the drag feedback be shown in the scrollbar?  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        dropRectCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is hovering above the drop site.  It returns the shape of the  
                rectangle to be drawn to highlight the entry, if the control can receive  
                the dropped data. The MEL version of the callback is of the form:  
              
                global proc int[] callbackName(string $dropControl, int $x, int $y)  
              
                The return value is an array of size 4, with the parameters, in order, being  
                the left and top coordinates of the rectangle to be drawn, followed by the  
                width and height.  
                This functionality is currently only implemented in MEL.  
                Properties: edit
        editIndexed (int?): Index of the edited field  
                Properties: create, edit
        editable (bool?): Set the field to be editable or not  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        itemAt (Tuple[int, int]?): Return the name of the item, if any, located at given point  
                      In query mode, this flag needs a value.  
                Properties: query
        itemTextColor (Multiuse[Tuple[int, float, float, float]]?): Set the text color of the item at the given index. Arguments are:  
                index, red, green, and blue. Indices are 1. based. Each color  
                component ranges in value from 0.0 to 1.0.  
                Properties: create, edit, multiuse
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfIcons (Queryable[int]?): Number of icons.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfRows (bool?): Number of visible rows.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        removeAll (bool?): Remove all items.  
                Properties: create, edit
        selectCommand (Callable[..., Any]?): Specify the command to be executed when an item is selected.  
                Properties: create, edit
        selectIndexedItem (Queryable[Multiuse[int]]?): Select the indexed item. Indices are 1. based.  
                Properties: create, query, edit, multiuse
        selectItem (Queryable[Multiuse[str]]?): Select the item that contains the specified text.  
                Properties: create, query, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        visualRectAt (Tuple[int, int]?): Return the visual rectangle of the item, if any, located at given point. The  
                result is a an array of 4 integers, in local coordinates, describing the  
                rectangle, in the following order: left, top, width, height.  
                      In query mode, this flag needs a value.  
                Properties: query
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def iconTextStaticLabel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., disabledImage: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., flipX: bool = ..., flipY: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelOffset: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., overlayLabelBackColor: Queryable[Tuple[float, float, float, float]] = ..., overlayLabelColor: Queryable[Tuple[float, float, float]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rotation: Queryable[float] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useAlpha: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Tuple[float, float, float, float], float, Callable[..., Any]]:
    """This control supports up to 3 icon images and 4 different display
    styles.  The icon image displayed is the one that best fits the
    current size of the control given its current style.This command creates an iconTextStaticLabel.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center". By default, the label is aligned "center".  
                Currently only available when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disabledImage (Queryable[str]?): Image used when the button is disabled. Image size must  
                be the same as the image specified with the i/image flag.  
                This is a Windows only flag.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        flipX (bool?): Is the image flipped horizontally?  
                Properties: create, query, edit
        flipY (bool?): Is the image flipped vertically?  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): If you are not providing images with different sizes then you may  
                use this flag for the control's image. If the "iconOnly" style is  
                set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string, up to 6 characters, representing a label that will be displayed  
                on top of the image.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The text that appears in the control.  
                Properties: create, query, edit
        labelOffset (Queryable[int]?): The label offset. Default is 0. Currently only available  
                when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): The number of pixels above and below the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): The number of pixels on either side of the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        overlayLabelBackColor (Queryable[Tuple[float, float, float, float]]?): The RGBA color of the shadow behind the label defined by  
                imageOverlayLabel. Default is 50% transparent black: 0 0 0 .5  
                Properties: create, query, edit
        overlayLabelColor (Queryable[Tuple[float, float, float]]?): The RGB color of the label defined by imageOverlayLabel. Default is a  
                light grey: .8 .8 .8  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rotation (Queryable[float]?): The rotation value of the image in radians.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal", "iconAndTextVertical", and  
                "iconAndTextCentered". (Note: "iconAndTextCentered" is only available on Windows).  
                If the "iconOnly" style is set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        useAlpha (bool?): Is the image using alpha channel?  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the iconTextStaticLabel created.

    Example:
    """

def ikHandle(*args: str, edit: bool = ..., query: bool = ..., autoPriority: bool = ..., connectEffector: bool = ..., createCurve: bool = ..., createRootAxis: bool = ..., curve: Queryable[str] = ..., disableHandles: bool = ..., enableHandles: bool = ..., endEffector: Queryable[str] = ..., exists: str = ..., forceSolver: bool = ..., freezeJoints: bool = ..., jointList: bool = ..., name: Queryable[str] = ..., numSpans: int = ..., parentCurve: bool = ..., positionWeight: Queryable[float] = ..., priority: Queryable[int] = ..., rootOnCurve: bool = ..., rootTwistMode: bool = ..., setupForRPsolver: bool = ..., simplifyCurve: bool = ..., snapCurve: bool = ..., snapHandleFlagToggle: bool = ..., snapHandleToEffector: bool = ..., solver: Queryable[str] = ..., startJoint: Queryable[str] = ..., sticky: Queryable[str] = ..., twistType: Queryable[str] = ..., weight: Queryable[float] = ...) -> Union[str, bool, float, int]:
    """The handle command is used to create, edit, and query a handle
    within Maya.  The standard edit (-e) and query (-q) flags are
    used for edit and query functions.If there are 2 joints selected and neither -startJoint nor
    -endEffector flags are not specified, then the handle will be
    created from the selected joints.If a single joint is selected and neither -startJoint nor
    -endEffector flags are specified, then the handle will be
    created with the selected joint as the end-effector and the
    start joint will be the top of the joint chain containing the
    end effector.The default values of the flags are:These attributes can be specified in creation mode, edited in
    edit mode (-e) or queried in query mode (-q).
    Args:
        autoPriority (bool?): Specifies that this handle's priority is assigned  
                automatically.  The assigned priority will be based on  
                the hierarchy distance from the root of the skeletal  
                chain to the start joint of the handle.  
                Properties: edit
        connectEffector (bool?): This option is set to true as default, meaning that  
                end-effector translate is connected with the endJoint translate.  
                Properties: create, edit
        createCurve (bool?): Specifies if a curve should automatically be created for  
                the ikSplineHandle.  
                Properties: create
        createRootAxis (bool?): Specifies if a root transform should automatically  
                be created above the joints affected by the ikSplineHandle.  
                This option is used to prevent the root flipping singularity  
                on a motion path.  
                Properties: create
        curve (Queryable[str]?): Specifies the curve to be used by the ikSplineHandle. Joints  
                will be moved to align with this curve. This flag is mandatory if you use  
                the -freezeJoints option.  
                Properties: create, query, edit
        disableHandles (bool?): set given handles to full fk (ikBlend attribute = 0.0)  
                Properties: edit
        enableHandles (bool?): set given handles to full ik (ikBlend attribute = 1.0)  
                Properties: edit
        endEffector (Queryable[str]?): Specifies the end-effector of the handle's joint chain.  
                The end effector may be specified with a joint or an  
                end-effector.  If a joint is specified, an end-effector will  
                be created at the same position as the joint and this  
                new end-effector will be used as the end-effector.  
                Properties: create, query, edit
        exists (str?): Indicates if the specified handle exists or not.  
                Properties: edit
        forceSolver (bool?): Forces the solver to be used everytime.  
                It could also be known as animSticky. So, after you set  
                the first key the handle is sticky.  
                Properties: create, query, edit
        freezeJoints (bool?): Forces the curve, specfied by -curve option, to align itself along the existing joint chain.  
                When false, or unspecified, the joints will be moved to positions along the specified curve.  
                Properties: create, edit
        jointList (bool?): Returns the list of joints that the handle is manipulating.  
                Properties: edit
        name (Queryable[str]?): Specifies the name of the handle.  
                Properties: create, query, edit
        numSpans (int?): Specifies the number of spans in the  
                automatically generated curve of the ikSplineHandle.  
                Properties: create
        parentCurve (bool?): Specifies if the curve should automatically  
                be parented to the parent of the first joint affected  
                by the ikSplineHandle.  
                Properties: create
        positionWeight (Queryable[float]?): Specifies the position/orientation weight of a handle.  
                This is used to compute the "distance" between the goal  
                position and the end-effector position.  A positionWeight of  
                1.0 computes the distance as the distance between  
                positions only and ignores the orientations.  A positionWeight  
                of 0.0 computes the distance as the distance between the  
                orientations only and ignores the positions.  A positionWeight  
                of 0.5 attempts to weight the distances equally but  
                cannot actually compute this due to unit differences.  
                Because there is no way to add linear units and angular units.  
                Properties: create, query, edit
        priority (Queryable[int]?): Sets the priority of the handle.  Logically, all handles  
                with a lower number priority are solved before any  
                handles with a higher numbered priority.  (All handles  
                of priority 1 are solved before any handles of priority  
                2 and so on.)  Handle priorities must be ] 0.  
                Properties: create, query, edit
        rootOnCurve (bool?): Specifies if the root is  
                locked onto the curve of the ikSplineHandle.  
                Properties: create, query, edit
        rootTwistMode (bool?): Specifies whether the start joint is allowed to  
                twist or not. If not, then the required twist is distributed over the  
                remaining joints. This applies to all the twist types.  
                Properties: create, query, edit
        setupForRPsolver (bool?): If the flag is set and ikSolver is ikRPsolver, call  
                RPRotateSetup for the new ikHandle. It is for ikRPsolver only.  
                Properties: edit
        simplifyCurve (bool?): Specifies if the ikSplineHandle curve should be simplified.  
                Properties: create
        snapCurve (bool?): Specifies if the curve should automatically  
                snap to the first joint affected by the ikSplineHandle.  
                Properties: create
        snapHandleFlagToggle (bool?): Specifies that the handle position should be snapped to  
                the end-effector position if the end-effector is moved  
                by the user.  Setting this flag on allows you to use  
                forward kinematics to pose or adjust your skeleton and  
                then to animate it with inverse kinematics.  
                Properties: create, query, edit
        snapHandleToEffector (bool?): All handles are immediately moved so that the handle  
                position and orientation matches the end-effector  
                position and orientation.  
                Properties: edit
        solver (Queryable[str]?): Specifies the solver.  The complete list of  
                available solvers may not be known until run-time  
                because some of the solvers may be implemented as  
                plug-ins.  Currently the only valid solver are  
                ikRPsolver, ikSCsolver and ikSplineSolver.  
                Properties: create, query, edit
        startJoint (Queryable[str]?): Specifies the start joint of the handle's joint chain.  
                Properties: create, query, edit
        sticky (Queryable[str]?): Specifies that this handle is "sticky". Valid values are "off",  
                "sticky", "superSticky". Sticky handles  
                are solved when the skeleton is being manipulated  
                interactively.  If a character has sticky feet, the  
                solver will attempt to keep them in the same position as  
                the user moves the character's root.  If they were not  
                sticky, they would move along with the root.  
                Properties: create, query, edit
        twistType (Queryable[str]?): Specifies the type of interpolation to  
                be used by the ikSplineHandle.  The interpolation options are  
                "linear", "easeIn", "easeOut", and "easeInOut".  
                Properties: create, query, edit
        weight (Queryable[float]?): Specifies the handles weight in error calculations.  The  
                weight only applies when handle goals are in conflict  
                and cannot be solved simultaneously.  When this happens,  
                a solution is computed that weights the "distance" from  
                each goal to the solution by the handle's weight and  
                attempts to minimize this value.  The weight must be ]= 0.  
                Properties: create, query, edit

    Returns:
        str: Command result

    Example:
    """

def ikHandleCtx(*args: Any, edit: bool = ..., query: bool = ..., autoPriorityH: bool = ..., createCurve: bool = ..., createRootAxis: bool = ..., exists: bool = ..., forceSolverH: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., numSpans: int = ..., parentCurve: bool = ..., poWeightH: Queryable[float] = ..., priorityH: Queryable[int] = ..., rootOnCurve: bool = ..., rootTwistMode: bool = ..., simplifyCurve: bool = ..., snapCurve: bool = ..., snapHandleH: bool = ..., solverTypeH: Queryable[str] = ..., stickyH: Queryable[str] = ..., twistType: str = ..., weightH: Queryable[float] = ...) -> Union[str, bool, float, int]:
    """The ikHandle context command (ikHandleCtx) updates parameters of
    ikHandle tool.  The options for the tool will be set to the flags that
    the user specifies.
    Args:
        autoPriorityH (bool?): Specifies that this handle's priority is assigned  
                automatically.  
                C: The default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        createCurve (bool?): Specifies if a curve should be automatically created  
                for the ikSplineHandle. The flag is ignored in the ikHandleCtx.  
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        createRootAxis (bool?): Specifies if a root transform should automatically  
                be created above the joints affected by the ikSplineHandle.  
                This option is used to prevent the  
                root flipping singularity on a motion path. This flag is ignored in  
                the ikHandleCtx.  
                C: The default is off.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        forceSolverH (bool?): Specifies if the ikSolver is enabled for the ikHandle.  
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numSpans (int?): Specifies the number of spans in the automatically generated  
                curve of the ikSplineHandle. This flag is ignored in the  
                ikHandleCtx.  
                C: The default is 1.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        parentCurve (bool?): Specifies if the curve should automatically be parented to the  
                parent of the first joint affected by the ikSplineHandle. The  
                flag is ignored in the ikHandleCtx.  
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        poWeightH (Queryable[float]?): Specifies the position/orientation weight of the  
                ikHandle.  
                C: The default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        priorityH (Queryable[int]?): Specifies the priority of the ikHandle.  
                C: The default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        rootOnCurve (bool?): Specifies if the root is locked onto the curve  
                of the ikSplineHandle. This flag is ignored in the ikHandleCtx.   
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        rootTwistMode (bool?): Specifies whether the start joint is allowed to twist or not.  
                If not, then the required twist is distributed over the  
                remaining joints. This applies to all the twist types.  
                This flag is ignored in the ikHandleCtx.   
                C: The default is off.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        simplifyCurve (bool?): Specifies if the ikSplineHandle curve should be simplified.  
                This flag is ignored in the ikHandleCtx.  
                C: The default is on.   
                Q: When queried, this returns an int.  
                Properties: edit
        snapCurve (bool?): Specifies if the curve should automatically snap  
                to the first joint affected by the ikSplineHandle. This flag is  
                ignored in the ikHandleCtx.  
                C: The default is off.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        snapHandleH (bool?): Specifies if the ikHandle snapping is on.  
                C: The default is on.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        solverTypeH (Queryable[str]?): Lists what ikSolver is being used. The  
                ikSplineSolver may not be selected. To use an ikSplineSolver  
                use the ikSplineHandleCtx command.   
                C: The default solver is the default set by the user preferences.  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        stickyH (Queryable[str]?): Specifies if the ikHandle is sticky or not. Valid strings  
                are "sticky" and "off".  
                C: The default is "off".  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        twistType (str?): Specifies the type of interpolation to be used by the  
                ikSplineHandle. This flag is ignored in the ikHandleCtx.  
                The interpolation options are "linear", "easeIn", "easeOut", and  
                "easeInOut".   
                C: The default is "linear".   
                Q: When queried, this flag returns a string.  
                Properties: edit
        weightH (Queryable[float]?): Specifies the weight of the ikHandle.  
                C: The default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: Context name

    Example:
    """

def ikHandleDisplayScale(*args: Any) -> float:
    """This action modifies and queries the current display size of ikHandle.
    The default display scale is 1.0.
    Returns:
        float: Returns current display size of ikHandle.

    Example:
    """

def ikSolver(*args: str, edit: bool = ..., query: bool = ..., epsilon: Queryable[float] = ..., maxIterations: Queryable[int] = ..., name: Queryable[str] = ..., solverType: Queryable[str] = ...) -> Union[str, float, int]:
    """The ikSolver command is used to set the attributes for an IK Solver
    or create a new one. The standard edit (-e) and query (-q) flags are
    used for edit and query functions.
    Args:
        epsilon (Queryable[float]?): max error  
                Properties: create, query, edit
        maxIterations (Queryable[int]?): Sets the max iterations for a solution  
                Properties: create, query, edit
        name (Queryable[str]?): Name of solver  
                Properties: create, query, edit
        solverType (Queryable[str]?): valid solverType (only ikSystem knows what is valid) for  
                creation of a new solver (required)  
                Properties: create, query, edit

    Returns:
        str: Command result

    Example:
    """

def ikSplineHandleCtx(*args: Any, edit: bool = ..., query: bool = ..., autoPriorityH: bool = ..., createCurve: bool = ..., createRootAxis: bool = ..., exists: bool = ..., forceSolverH: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., numSpans: int = ..., parentCurve: bool = ..., poWeightH: Queryable[float] = ..., priorityH: Queryable[int] = ..., rootOnCurve: bool = ..., rootTwistMode: bool = ..., simplifyCurve: bool = ..., snapCurve: bool = ..., snapHandleH: bool = ..., solverTypeH: Queryable[str] = ..., stickyH: Queryable[str] = ..., twistType: str = ..., weightH: Queryable[float] = ...) -> Union[str, bool, float, int]:
    """The ikSplineHandle context command (ikSplineHandleCtx) updates parameters of
    ikSplineHandle tool.  The options for the tool will be set to the flags
    the user specifies.
    Args:
        autoPriorityH (bool?): Specifies that this handle's priority is assigned  
                automatically.  
                C: The default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        createCurve (bool?): Specifies if a curve should be automatically created  
                for the ikSplineHandle.   
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        createRootAxis (bool?): Specifies if a root transform should automatically  
                be created above the joints affected by the ikSplineHandle.  
                This option is used to prevent the  
                root flipping singularity on a motion path.   
                C: The default is off.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        forceSolverH (bool?): Specifies if the ikSolver is enabled for the ikHandle.  
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        numSpans (int?): Specifies the number of spans in the automatically generated  
                curve of the ikSplineHandle.   
                C: The default is 1.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        parentCurve (bool?): Specifies if the curve should automatically be parented to the  
                parent of the first joint affected by the ikSplineHandle.   
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        poWeightH (Queryable[float]?): Specifies the position/orientation weight of the  
                ikHandle.  
                C: The default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        priorityH (Queryable[int]?): Specifies the priority of the ikHandle.  
                C: The default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        rootOnCurve (bool?): Specifies if the root is locked onto the curve  
                of the ikSplineHandle.   
                C: The default is on.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        rootTwistMode (bool?): Specifies whether the start joint is allowed to twist or not.  
                If not, then the required twist is distributed over the  
                remaining joints. This applies to all the twist types.  
                C: The default is off.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        simplifyCurve (bool?): Specifies if the ikSplineHandle curve should be simplified.   
                C: The default is on.   
                Q: When queried, this returns an int.  
                Properties: edit
        snapCurve (bool?): Specifies if the curve should automatically snap  
                to the first joint affected by the ikSplineHandle.   
                C: The default is off.   
                Q: When queried, this flag returns an int.  
                Properties: edit
        snapHandleH (bool?): Specifies if the ikHandle snapping is on. This flag  
                is ignored for the ikSplineSolver.  
                C: The default is on.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        solverTypeH (Queryable[str]?): Lists what ikSolver is being used. For the  
                ikSplineContext the solver can only be the ikSplineSolver  
                and this flag is ignored.   
                C: The default solver is the ikSplineSolver.  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        stickyH (Queryable[str]?): Specifies if the ikHandle is sticky or not. Valid strings  
                are "sticky" and "off". This flag is ignored for the ikSplineSolver.  
                C: The default is "off".  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        twistType (str?): Specifies the type of interpolation to be used by the  
                ikSplineHandle.   
                The interpolation options are "linear", "easeIn", "easeOut", and  
                "easeInOut".  
                C: The default is "linear".   
                Q: When queried, this flag returns a string.  
                Properties: edit
        weightH (Queryable[float]?): Specifies the weight of the ikHandle. This flag is  
                ignored in the ikSplineHandleCtx.  
                C: The default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: The name of the context.

    Example:
    """

def ikSystem(*, edit: bool = ..., query: bool = ..., allowRotation: bool = ..., autoPriority: bool = ..., autoPriorityMC: bool = ..., autoPrioritySC: bool = ..., list: Queryable[Tuple[int, int]] = ..., snap: bool = ..., solve: bool = ..., solverTypes: bool = ...) -> Union[str, bool, Tuple[int, int]]:
    """The ikSystem command is used to set the global snapping flag for handles
    and set the global solve flag for solvers.  The standard edit (-e) and
    query (-q) flags are used for edit and query functions.
    Args:
        allowRotation (bool?): Set true to allow rotation of an ik handle with keys set on  
                translation.  
                Properties: query, edit
        autoPriority (bool?): set autoPriority for all ikHandles  
                Properties: edit
        autoPriorityMC (bool?): set autoPriority for all multiChain handles  
                Properties: edit
        autoPrioritySC (bool?): set autoPriority for all singleChain handles  
                Properties: edit
        list (Queryable[Tuple[int, int]]?): returns the solver execution order when in query  
                mode(list of strings) changes execution order when in edit mode  
                (int old position, int new position)  
                Properties: query, edit
        snap (bool?): Set global snapping  
                Properties: query, edit
        solve (bool?): Set global solve  
                Properties: query, edit
        solverTypes (bool?): returns a list of valid solverTypes ( query only )  
                Properties: query

    Returns:
        str: Command result

    Example:
    """

def ikSystemInfo(arg0: bool = ..., /, *, query: bool = ..., globalSnapHandle: bool = ...) -> bool:
    """This action modifies and queries the current ikSystem controls.
    Args:
        globalSnapHandle (bool?): If this flag is off, all ikHandles will not be snapped.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def ikfkDisplayMethod(*, query: bool = ..., display: Queryable[str] = ...) -> Union[bool, str]:
    """Thecommand is used to specify how ik/fk
          blending should be shownikfk
    Args:
        display (Queryable[str]?): Specify how ik/fk blending should be shown when the handle is selected.  
                Possible choices are "none" (do not display any blending), "ik" (only  
                show ik),"fk" (only show fk), and "ikfk" (show both ik and fk).  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def illustratorCurves(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., illustratorFilename: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., tolerance: Queryable[float] = ...) -> Union[List[str], bool, int, float]:
    """The illustratorCurves command creates NURBS curves from an input
    Adobe(R) Illustrator(R) file.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        illustratorFilename (str?): Input Adobe(R) Illustrator(R) file name.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        tolerance (Queryable[float]?): CVs on the output curve get snapped if the distance  
                between two contiguous CVs are lesser than this tolerance value.  
                Default: 0.001f  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name

    Example:
    """

def image(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a static image for non-xpm files.
    Any image file format supported by the file texture node is supported by
    this command.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): Sets the image given the file name.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the image created.

    Example:
    """

def imagePlane(*args: str, edit: bool = ..., query: bool = ..., camera: Queryable[str] = ..., counter: bool = ..., detach: bool = ..., dropFrame: bool = ..., fileName: str = ..., frameDuration: Queryable[int] = ..., height: Queryable[float] = ..., imageSize: Queryable[Tuple[int, int]] = ..., lookThrough: Queryable[str] = ..., maintainRatio: bool = ..., name: Queryable[str] = ..., negTimesOK: bool = ..., numFrames: Queryable[int] = ..., quickTime: bool = ..., showInAllViews: bool = ..., timeCode: Queryable[int] = ..., timeCodeTrack: bool = ..., timeScale: Queryable[int] = ..., twentyFourHourMax: bool = ..., width: Queryable[float] = ...) -> Union[bool, str, int, float, Tuple[int, int]]:
    """The imagePlane command allows querying of various properties of
            an image plane and any movie in use by the image plane. It also supports
            creating and edit.
            The object passed to the command may either be an imagePlane node,
            or a camera, in which case the command uses the image plane attached
            to the camera (if any). If no object is passed in, the current
            selection is used.
            Currently, most movie related queries work only on 64 bit Windows systems.image, plane
    Args:
        camera (Queryable[str]?): When creating, it will try to attach the created image plane to the specified camera.  
                If the given camera is invalid, creating will fail.  
                When querying, it will query which camera current image plane is attaching to.  
                If it has no camera attached to (free image plane), it will return an empty string.  
                When edit, it will make the image plane attach to the new specified camera.  
                If the camera given is invalid, it will do nothing.  
                When the image plane is attached to a camera, the image plane's transform node will be set identity.  
                The detach command will not restore the original position of the image plane.  
                but the undo command will restore the original position of the image plane.  
                Properties: create, query, edit
        counter (bool?): Query the 'counter' flag of the movie's timecode format.  
                If this is true, the timecode returned by the -timeCode flag will be a simple counter.  
                If false, the returned timecode will be an array of integers (hours, minutes, seconds, frames).
        detach (bool?): This flag can only be used in the edit mode, when this flag is used in edit, it will  
                detach current image plane from any camera it attaches to and make it a free image plane.  
                Properties: edit
        dropFrame (bool?): Query the 'drop frame' flag of the movie's timecode format.  
                Properties: query
        fileName (str?): Set the image name for image plane to read.  
                Properties: create, edit
        frameDuration (Queryable[int]?): Query the frame duration of the movie's timecode format.  
                Properties: query
        height (Queryable[float]?): Height of the image plane. When creating, if this flag is not specified,  
                it will use 10.0 as default height.  
                Properties: create, query, edit
        imageSize (Queryable[Tuple[int, int]]?): Get size of the loaded image.  
                Properties: query
        lookThrough (Queryable[str]?): The camera currently used for image plane to look through.  
                Properties: create, query, edit
        maintainRatio (bool?): Let the image plane respect the picture aspect ratio. When creating,  
                if this flag is not specified, it will use true as default value.  
                Properties: create, query, edit
        name (Queryable[str]?): Set the image plane node name when creating or return the image plane name when querying.  
                Properties: create, query
        negTimesOK (bool?): Query the 'neg times OK' flag of the movie's timecode format.  
                Properties: query
        numFrames (Queryable[int]?): Query the whole number of frames per second of the movie's timecode format.  
                Properties: query
        quickTime (bool?): Query whether the image plane is using a QuickTime movie.  
                Properties: query
        showInAllViews (bool?): The flag is used to show the current image plane in all views or not.  
                Properties: create, query, edit
        timeCode (Queryable[int]?): Query the whole number of frames per second of the movie's timecode format.  
                Properties: query
        timeCodeTrack (bool?): Query whether the movie on the image plane has a timecode track.  
                Properties: query
        timeScale (Queryable[int]?): Query the timescale of the movie's timecode format.  
                Properties: query
        twentyFourHourMax (bool?): Query the '24 hour max' flag of the movie's timecode format.  
                Properties: query
        width (Queryable[float]?): Width of the image plane. When creating, if this flag is not specified,  
                it will use 10.0 as default width.  
                Properties: create, query, edit

    Returns:
        bool: Command result

    Example:
    """

def imageWindowEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., autoResize: bool = ..., changeCommand: Tuple[str, str, str, str] = ..., clear: Tuple[int, int, float, float, float] = ..., control: bool = ..., drawAxis: bool = ..., doubleBuffer: bool = ..., displayImage: int = ..., displayStyle: str = ..., defineTemplate: str = ..., docTag: str = ..., exists: bool = ..., filter: str = ..., frameImage: bool = ..., forceMainConnection: str = ..., frameRegion: bool = ..., highlightConnection: str = ..., lockMainConnection: bool = ..., loadImage: str = ..., mainListConnection: str = ..., marquee: Tuple[float, float, float, float] = ..., nbImages: bool = ..., parent: str = ..., panel: str = ..., removeAllImages: bool = ..., refresh: bool = ..., removeImage: bool = ..., realSize: bool = ..., scaleBlue: float = ..., singleBuffer: bool = ..., scaleGreen: float = ..., saveImage: bool = ..., selectionConnection: str = ..., scaleRed: float = ..., showRegion: Tuple[int, int] = ..., stateString: bool = ..., toggle: bool = ..., unlockMainConnection: bool = ..., unParent: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., writeImage: str = ...) -> None: ...
def imfPlugins(arg0: str = ..., /, *, query: bool = ..., extension: Queryable[str] = ..., keyword: Queryable[str] = ..., multiFrameSupport: Queryable[str] = ..., pluginName: Queryable[str] = ..., readSupport: Queryable[str] = ..., writeSupport: Queryable[str] = ...) -> Union[List[str], str]:
    """This command queries all the available imf plugins for its
    name, keyword or image file extension.
    Only one of the attributes (name, keyword or extension) can be queried at a time.
    If no flags are specified, this command returns a list of all available plugin
    names.imf
    Args:
        extension (Queryable[str]?): image file extension  
                Properties: create, query
        keyword (Queryable[str]?): imf keyword  
                Properties: create, query
        multiFrameSupport (Queryable[str]?): multi frame IO is supported  
                Properties: create, query
        pluginName (Queryable[str]?): imf plugin name  
                Properties: create, query
        readSupport (Queryable[str]?): read operation is supported  
                Properties: create, query
        writeSupport (Queryable[str]?): write operation is supported  
                Properties: create, query

    Returns:
        List[str]: Command result

    Example:
    """

def inViewMessage(*, alpha: float = ..., assistMessage: str = ..., backColor: int = ..., clear: str = ..., clickKill: bool = ..., dragKill: bool = ..., fade: bool = ..., fadeInTime: int = ..., fadeOutTime: int = ..., fadeStayTime: int = ..., font: str = ..., fontSize: int = ..., frameOffset: int = ..., hide: bool = ..., message: str = ..., minimize: bool = ..., position: str = ..., restore: bool = ..., show: bool = ..., statusMessage: str = ..., textAlpha: float = ..., textOffset: int = ..., uvEditor: bool = ...) -> bool:
    """Used for displaying in-view messages.Note: On Linux, theandflags for inViewMessage are
    only supported when running a window manager that supports compositing (transparency
    and opacity).  Otherwise, they are ignored.  In addition, the flags for message
    fading:are supported,
    but the message will display without a fade effect if the window manager
    doesn't support compositing.
    Args:
        alpha (float?): Sets the maximum alpha transparency for the message box.  
                Properties: create
        assistMessage (str?): The user assistance message to be displayed, can be html format.  
                Properties: create
        backColor (int?): Sets the background color for the message using the format 0xAARRGGBB, alpha is not taken into account.  
                Properties: create
        clear (str?): Use this flag to clear the message at a specified position.  
                The supported positions are the same as for the -pos/position flag.  
                Properties: create
        clickKill (bool?): Use this flag if the message needs to be deleted on mouse click.  
                Properties: create
        dragKill (bool?): Use this flag if the message needs to be deleted on mouse drag.  
                Properties: create
        fade (bool?): Whether the message will fade after a time interval or not.  
                Properties: create
        fadeInTime (int?): Sets how long it takes for the image to fade in (milliseconds).  
                Properties: create
        fadeOutTime (int?): Sets how long it takes for the image to fade out (milliseconds).  
                Properties: create
        fadeStayTime (int?): Sets how long the image stays at max opacity  (milliseconds).  
                Properties: create
        font (str?): Sets the message to a font (eg. "Arial").  
                Properties: create
        fontSize (int?): Sets the message font size.  
                Properties: create
        frameOffset (int?): Sets how far the message appears from the edge of the viewport in pixels.  
                Properties: create
        hide (bool?): Hides all messages.  
                Properties: create
        message (str?): The message to be displayed, can be html format.  
                General message, inherited by -amg/assistMessage and -smg/statusMessage.  
                Properties: create
        minimize (bool?): Minimize all messages.  
                Properties: create
        position (str?): The position that the message will appear at relative to the active viewport.  
                The supported positions are:  
              
                "topLeft"  
                "topCenter"  
                "topRight"  
                "midLeft"  
                "midCenter"  
                "midCenterTop"  
                "midCenterBot"  
                "midRight"  
                "botLeft"  
                "botCenter"  
                "botRight"  
                Properties: create
        restore (bool?): Restore all messages.  
                Properties: create
        show (bool?): Shows all messages.  
                Properties: create
        statusMessage (str?): The status info message to be displayed, can be html format.  
                Properties: create
        textAlpha (float?): Sets the maximum alpha transparency for the message text.  
                Properties: create
        textOffset (int?): Sets how far the text appears from the edge of the message box in pixels.  
                Properties: create
        uvEditor (bool?): Show the message in the active UV editor view.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def inheritTransform(*args: str, query: bool = ..., off: bool = ..., on: bool = ..., preserve: bool = ..., toggle: bool = ...) -> bool:
    """This command toggles the inherit state of an object. If this
    flag is off the object will not inherit transformations from
    its parent. In other words transformations applied to the
    parent node will not affect the object and it will act as
    though it is under the world.If the -p flag is specified then the object's transformation will
    be modified to compensate when changing the inherit flag so the
    object will not change its world-space location.
    Args:
        off (bool?): turn off inherit state for the given object(s)  
                Properties: create, query
        on (bool?): turn on inherit state for the given object(s)  
                Properties: create, query
        preserve (bool?): preserve the objects world-space position  
                by modifying the object(s) transformation  
                matrix.  
                Properties: create, query
        toggle (bool?): toggle the inherit state for the given object(s)  
                (default if no flags are given)  
                -on  
                turn on inherit state for the given object(s)  
                -off  
                turn off inherit state for the given object(s)  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def insertJoint(arg0: str = ..., /) -> str:
    """This command will insert a new joint under the given or selected joint. If
    the given joint has child joints, they will be reparented under the new
    inserted joint.The given joint(or selected joint) should not have skin attached.
    The command works on the selected joint. No options or flags are necessary.
    Returns:
        str: The name of the new inserted joint

    Example:
    """

def insertJointCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """The command will create an insert joint context. The insert joint tool
    inserts joints into an existing chain of joints.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: The name of the context.

    Example:
    """

def insertKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., breakdown: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., preserveTangent: bool = ...) -> Union[str, bool]:
    """This command creates a context which may be used to insert keys
    within the graph editor
    Args:
        breakdown (bool?): Specifies whether or not to create breakdown keys  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        preserveTangent (bool?): Specifies whether or not to preserve tangent  
                Properties: query, edit

    Returns:
        str: Context name

    Example:
    """

def insertKnotCurve(*args: str, edit: bool = ..., query: bool = ..., addKnots: bool = ..., caching: bool = ..., insertBetween: bool = ..., nodeState: Queryable[int] = ..., numberOfKnots: Queryable[Multiuse[int]] = ..., parameter: Queryable[Multiuse[float]] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, Multiuse[int], Multiuse[float]]:
    """The insertKnotCurve command inserts knots into a curve given a list
    of parameter values. The number of knots to add at each parameter value
    and whether the knots are added or complemented can be specified.
    The name of the curve is returned.
    If construction history is on, the name of the resulting
    dependency node is also returned.An edit point will appear where you insert the knot. Also, the
    number of spans and CVs in the curve will increase in the area where
    the knot is inserted.You can insert up to "degree" knots at a
    curve parameter that isn't already an edit point. eg. for a
    degree three curve, you can insert up to 3 knots.Use this operation if you need more CVs in a local area of the curve.
    Use this operation (or "hardenPoint") if you want to create a corner
    in a curve.
    Args:
        addKnots (bool?): Whether to add knots or complement.  Complement means knots will be added to reach the specified number of knots.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        insertBetween (bool?): If set to true, and there is more than one parameter value specified,  
                the knots will get inserted at equally spaced intervals between  
                the given parameter values, rather than at the parameter values  
                themselves.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        numberOfKnots (Queryable[Multiuse[int]]?): How many knots to insert.  At any point on the curve, there can  
                be a maximum of "degree" knots.  
                Default: 1  
                Properties: create, query, edit, multiuse
        parameter (Queryable[Multiuse[float]]?): Parameter value(s) where knots are added  
                Default: 0.0  
                Properties: create, query, edit, multiuse
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def insertKnotSurface(*args: str, edit: bool = ..., query: bool = ..., addKnots: bool = ..., caching: bool = ..., direction: Queryable[int] = ..., insertBetween: bool = ..., nodeState: Queryable[int] = ..., numberOfKnots: Queryable[Multiuse[int]] = ..., parameter: Queryable[Multiuse[float]] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, Multiuse[int], Multiuse[float]]:
    """The insertKnotSurface command inserts knots (aka isoparms) into a
    surface given a list of parameter values.  The number of knots
    to add at each parameter value
    and whether the knots are added or complemented can be specified.
    The name of the surface is returned and
    if history is on, the name of the resulting dependency node is
    also returned.You must specify one, none or all number of knots with the "-nk" flag.
    eg. if you specify none, then the default (one) knot will be added
    at each specified parameter value.  If you specify one "-nk" value
    then that number of knots will be added at each parameter value.
    Otherwise, you must specify the same number of "-nk" flags as "-p" flags,
    defining the number of knots to be added at each specified parameter value.You can insert up to "degree" knots at a
    parameter value that isn't already an isoparm.  eg. for a degree 3
    surface, you can insert up to 3 knots.Use this operation if you need more CVs in a local area of the surface.
    Use this operation if you want to create a corner in the surface.Note: A single insertKnotSurface command cannot insert in both directions
    at once; you must use two separate commands to do this.
    Args:
        addKnots (bool?): Whether to add knots or complement.  Complement means knots will be added to reach the specified number of knots.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[int]?): Direction in which to insert knot:  
                0. V direction,  
                1. U direction  
                Default: 1  
                Properties: create, query, edit
        insertBetween (bool?): If set to true, and there is more than one parameter value specified,  
                the knots will get inserted at equally spaced intervals between  
                the given parameter values, rather than at the parameter values  
                themselves.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        numberOfKnots (Queryable[Multiuse[int]]?): How many knots to insert  
                Default: 1  
                Properties: create, query, edit, multiuse
        parameter (Queryable[Multiuse[float]]?): Parameter value(s) where knots are added  
                Default: 0.0  
                Properties: create, query, edit, multiuse
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def insertListItem() -> None: ...
def insertListItemBefore() -> None: ...
def instance(*args: str, leaf: bool = ..., name: str = ..., smartTransform: bool = ...) -> str:
    """Instancing is a way of making the same object appear twice in the
    scene. This is accomplished by creation of a new transform node
    that points to an exisiting object. Changes to the transform
    are independent but changes to the "instanced" object affect
    all instances since the node is shared.If no objects are given, then the selected list is instanced.
    When an object is instanced a  new transform node is created
    that points to the selected object.The smart transform feature allows instance to transform newly
    instanced objects based on previous transformations between instances.Example: Instance an object and move it to a new location.  Instance
    it again with the smart transform flag.  It should have moved once
    again the distance you had previously moved it.Note: changing the selected list between smart instances will cause
    the transform information to be deleted.It returns a list of the new objects created by the instance operation.duplicate
    Args:
        leaf (bool?): Instances leaf-level objects. Acts like duplicate  
                except leaf-level objects are instanced.  
                Properties: create
        name (str?): Name to give new instance  
                Properties: create
        smartTransform (bool?): Transforms instances item based on movements between  
                transforms  
                Properties: create

    Returns:
        str: - the name of the new transform node is returned.

    Example:
    """

def instanceable(*args: str, query: bool = ..., allow: bool = ..., recursive: bool = ..., shape: bool = ...) -> Union[None, List[bool], bool]:
    """Flags one or more DAG nodes so that they can (or cannot) be instanced.
    This command sets an internal state on the specified DAG nodes which is
    checked whenever Maya attempts an instancing operation.
    If no node names are provided on the command line then the current selection list is used.Sets are automatically expanded to their constituent objects. Nodes which are already
    instanced (or have children which are already instanced) cannot be marked as non-instancable.node, dependency, graph, instancing
    Args:
        allow (bool?): Specifies the new instanceable state for the node. Specify true to allow the node  
                to be instanceable, and false to prevent it from being instanced. The default is true  
                (i.e. nodes can be instanced by default).  
                Properties: create, query
        recursive (bool?): Can be specified with the -allow flag in create or edit mode to recursively apply the  
                -allow setting to all non-shape children of the selected node(s). To also affect  
                shapes, also specify the -shape flag along with -recursive.  
                Properties: create
        shape (bool?): Can be specified with the -allow flag in create or edit mode to apply the  
                -allow setting to all shape children of the selected node(s). This flag can be  
                specified in conjunction with the -recursive flag.  
                Properties: create

    Returns:
        None: For regular command execution.
        List[bool]: For query execution.

    Example:
    """

def instancer(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addObject: bool = ..., cycle: Queryable[str] = ..., cycleStep: Queryable[float] = ..., cycleStepUnits: Queryable[str] = ..., index: Queryable[int] = ..., levelOfDetail: Queryable[str] = ..., name: Queryable[str] = ..., object: Queryable[Multiuse[str]] = ..., objectPosition: Queryable[str] = ..., objectRotation: Queryable[str] = ..., objectScale: Queryable[str] = ..., pointDataSource: bool = ..., removeObject: bool = ..., rotationOrder: Queryable[str] = ..., rotationUnits: Queryable[str] = ..., valueName: Queryable[str] = ...) -> Union[str, float, int, Multiuse[str], bool]:
    """This command is used to create a instancer node and set the proper
    attributes in the node.instancer
    Args:
        addObject (bool?): This flag indicates that objects specified by the -object flag will be added to  
                the instancer node as instanced objects.  
                Properties: create, edit
        cycle (Queryable[str]?): This flag sets or queries the cycle attribute for the instancer node.  
                The options are "none" or "sequential".  The default is "none".  
                Properties: create, query, edit
        cycleStep (Queryable[float]?): This flag sets or queries the cycle step attribute for the instancer node.  This attribute  
                indicates the size of the step in frames or seconds (see cycleStepUnit).  
                Properties: create, query, edit
        cycleStepUnits (Queryable[str]?): This flag sets or queries the cycle step unit attribute for the instancer  
                node.  The options are "frames" or "seconds".  The default is "frames".  
                Properties: create, query, edit
        index (Queryable[int]?): This flag is used to query the name of the ith instanced object.  
                Properties: query
        levelOfDetail (Queryable[str]?): This flag sets or queries the level of detail of the instanced objects.  The  
                options are "geometry", "boundingBox", "boundingBoxes".  The default is  
                "geometry".  
                Properties: create, query, edit
        name (Queryable[str]?): This flag sets or queries the name of the instancer node.  
                Properties: create, query
        object (Queryable[Multiuse[str]]?): This flag indicates which objects will be add/removed from the list of instanced  
                objects.  The flag is used in conjuction with the -add and -remove flags.  If  
                neither of these flags is specified on the command line then -add is assumed.  
                Properties: create, query, edit, multiuse
        objectPosition (Queryable[str]?): This flag queries the given objects position.  This object can be any instanced object or  
                sub-object.  
                Properties: query
        objectRotation (Queryable[str]?): This flag queries the given objects rotation.  This object can be any instanced object or  
                sub-object.  
                Properties: query
        objectScale (Queryable[str]?): This flag queries the given objects scale.  This object can be any instanced object or  
                sub-object.  
                Properties: query
        pointDataSource (bool?): This flag is used to query the source node supply the data for the input points.  
                Properties: query
        removeObject (bool?): This flag indicates that objects specified by the -object flag will be  
                removed from the instancer node as instanced objects.  
                Properties: edit
        rotationOrder (Queryable[str]?): This flag specifies the rotation order associated with the rotation flag.  The  
                options are XYZ, XZY, YXZ, YZX, ZXY, or ZYX.  By default the attribute is XYZ.  
                Properties: create, query, edit
        rotationUnits (Queryable[str]?): This flag specifies the rotation units associated with the rotation flag.  The  
                options are degrees or radians.  By default the attribute is degrees.  
                Properties: create, query, edit
        valueName (Queryable[str]?): This flag is used to query the value(s) of the array associated with the given  
                name.  If the -index flag is used in conjuction with this flag then the ith  
                value will be returned.  Otherwise, the entire array will be returned.  
                Properties: query

    Returns:
        str: Command result

    Example:
    """

def intField(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enterCommand: Callable[..., Any] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., receiveFocusCommand: Callable[..., Any] = ..., statusBarMessage: str = ..., step: Queryable[int] = ..., useTemplate: str = ..., value: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a field control that accepts only integer values and is bound by
    a minimum and maximum value.  An invisible slider is attached to the
    field and accessed by holding down the Ctrl modifier key while pressing
    one of the mouse buttons.  Dragging the invisible slider to the right
    with the middle mouse button increases the field value by the amount
    specified with theflag, while dragging to the left
    decreases the value by the same amount.  The left and right mouse
    buttons apply a factor of 0.1 and 10 to the step value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when the value changes by dragging the  
                invisible slider.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is  
                set to true and the field value may be changed by typing into it.  
                If false then the field is 'read only' and can not be typed into.  
                The value of the field can always be changed with  
                the -v/value flag regardless of the state of  
                the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enterCommand (Callable[..., Any]?): Command executed when the keypad 'Enter' key is pressed.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): Upper limit of the field.  
                Properties: create, query, edit
        minValue (Queryable[int]?): Lower limit of the field.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        receiveFocusCommand (Callable[..., Any]?): Command executed when the field receives focus.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[int]?): Increment for the invisible slider.  The field value  
                will change by this amount when the invisible slider is dragged.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[int]?): Value of the field.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def intFieldGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enable1: bool = ..., enable2: bool = ..., enable3: bool = ..., enable4: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfFields: int = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., value: Queryable[Tuple[int, int, int, int]] = ..., value1: Queryable[int] = ..., value2: Queryable[int] = ..., value3: Queryable[int] = ..., value4: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Tuple[int, int, int, int], Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text and
    editable integer fields. The label text is optional and one to
    four fields can be created.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when the value of any of the  
                fields changes.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed when dragging the invisible slider  
                in any of the fields.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enable1 (bool?):   
                Properties: create, query, edit
        enable2 (bool?):   
                Properties: create, query, edit
        enable3 (bool?):   
                Properties: create, query, edit
        enable4 (bool?): Enable state for the respective field.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label in the group.  Sets the string to be label text to  
                the right of fields.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): If present on creation this specifies that there will be  
                a label to the left of the fields.  Sets the string to be the label  
                text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfFields (int?): Set the number of fields on creation.  One to four fields  
                are available.  The default is one field.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[Tuple[int, int, int, int]]?): Values for all fields.  
                Properties: create, query, edit
        value1 (Queryable[int]?):   
                Properties: create, query, edit
        value2 (Queryable[int]?):   
                Properties: create, query, edit
        value3 (Queryable[int]?):   
                Properties: create, query, edit
        value4 (Queryable[int]?): Value for the respective field.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def intScrollBar(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., largeStep: Queryable[int] = ..., manage: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., step: Queryable[int] = ..., useTemplate: str = ..., value: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a scroll bar control that accepts only integer values and is
    bound by a minimum and maximum value.  The scroll bar displays a marker
    indicating the current value of the scroll bar relative to its minimum
    and maximum values.  Click and drag the marker or on the scroll bar
    itself to change the current value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when the value changes by dragging the  
                scroll bar's value marker.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the scroll bar.  This flag is true by default,  
                which corresponds to a horizontally oriented scroll bar.  
                Properties: create, query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        largeStep (Queryable[int]?): Larger increment for the scroll bar, ie. the increment  
                used when the press is between the arrow button and the thumb.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): Upper limit of the scroll bar.  
                Properties: create, query, edit
        minValue (Queryable[int]?): Lower limit of the scroll bar.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[int]?): Smaller increment for the scroll bar, ie. the increment  
                used when the arrow buttons are pressed.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[int]?): Value of the scroll bar.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def intSlider(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., manage: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., step: Queryable[int] = ..., useTemplate: str = ..., value: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a slider control that accepts only integer values and is bound
    by a minimum and maximum value.  The slider displays a marker
    indicating the current value of the slider relative to its minimum
    and maximum values.  Click and drag the marker or on the slider itself
    to change the current value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when the value changes by dragging the  
                slider's value marker.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the slider.  This flag is true by default,  
                which corresponds to a horizontally oriented slider.  
                Properties: create, query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): Upper limit of the slider.  
                Properties: create, query, edit
        minValue (Queryable[int]?): Lower limit of the slider.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[int]?): The step value represents the amount the  
                value will increase or decrease when you click either side of the  
                slider.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[int]?): Value of the slider.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def intSliderGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., field: bool = ..., fieldMaxValue: Queryable[int] = ..., fieldMinValue: Queryable[int] = ..., fieldStep: Queryable[int] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., sliderStep: Queryable[int] = ..., statusBarMessage: str = ..., step: Queryable[int] = ..., useTemplate: str = ..., value: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of controls containing a
    label text, an integer field and an integer slider. The text and field
    controls are optional.  Editing or querying the field range values has
    no effect if theflag was not specified when the group was
    created.This group also allows you to enter values into the field outside of the
    slider range which is limited by theandflags.  To do this, use
    theandflags to
    specify a greater range of values.Note that the command will not allow you to specify
    agreater than thevalue nor
    aless than thevalue.If you do supply a larger field range with theandflags then you will notice that entering a
    value in the field that is outside of the slider range will result in
    extending the slider range as well.  For example, if you create a slider
    group with the following command:Then you will be able to use the slider to select any value from -10 to 10.
    At the same time you will be able to enter into the field any value
    from -100 to 100.  If you enter a value, say 20, then the new slider
    range will grow such that this value is now accessible through the slider
    as well.  In fact, the new slider limit will become double of that what you
    entered.  Note that the slider limits will never grow beyond the field
    limits, in other words if you entered the value 80 then the slider will be
    clipped to the field limit of 100 and not doubled to 160.TelfBaseGrpCmd.cpp
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): The command string executed when the value of the  
                slider changes.  It will be executed only once after a drag  
                of the slider.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): The command string executed repeatedly during a drag  
                of the slider.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label appearing after the slider.  Sets the string to be  
                the text for the extra label.  
                Properties: create, query, edit
        field (bool?): If true on creation the group will have an editable int field  
                present that reflects the value of the slider.  
                Properties: create
        fieldMaxValue (Queryable[int]?): Maximum value that may be entered in the field.  This  
                value may be set to any value greater than  
                the -max/maxValue flag.  By default, it is equal to  
                the -max/maxValue flag.  
                Properties: create, query, edit
        fieldMinValue (Queryable[int]?): Minimum value that may be entered in the field.  This  
                value may be set to any value less than  
                the -min/minValue flag.  By default, it is equal to  
                the -min/minValue flag.  
                Properties: create, query, edit
        fieldStep (Queryable[int]?): Increment for the field.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): If present on creation the group will have static text.  
                Returns a string on query.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): Sets the maximum value for both the slider and the field.  
                Properties: create, query, edit
        minValue (Queryable[int]?): Sets the minimum value for both the slider and the field.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        sliderStep (Queryable[int]?): On Linux the slider step value represents the  
                amount the value will increase or decrease when you click either  
                side of the slider.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[int]?): Increment for both the slider and field.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[int]?): Value of the group.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name of the control on creation.

    Example:
    """

def interactionStyle(*, query: bool = ..., style: str = ...) -> None: ...
def internalVar(*, mayaInstallDir: bool = ..., userAppDir: bool = ..., userBitmapsDir: bool = ..., userHotkeyDir: bool = ..., userMarkingMenuDir: bool = ..., userPrefDir: bool = ..., userPresetsDir: bool = ..., userScriptDir: bool = ..., userShelfDir: bool = ..., userTmpDir: bool = ..., userWorkspaceDir: bool = ...) -> str:
    """This command returns the values of internal variables.  No modification
    of these variables is supported.
    Args:
        mayaInstallDir (bool?): Return the Maya installation directory.  
                Properties: create
        userAppDir (bool?): Return the user application directory.  
                Properties: create
        userBitmapsDir (bool?): Return the user bitmaps prefs directory.  
                Properties: create
        userHotkeyDir (bool?): Return the user hotkey directory.  
                Properties: create
        userMarkingMenuDir (bool?): Return the user marking menu directory.  
                Properties: create
        userPrefDir (bool?): Return the user preference directory.  
                Properties: create
        userPresetsDir (bool?): Return the user presets directory.  
                Properties: create
        userScriptDir (bool?): Return the user script directory.  
                Properties: create
        userShelfDir (bool?): Return the user shelves directory.  
                Properties: create
        userTmpDir (bool?): Return a temp directory.  Will check for TMPDIR environment variable,  
                otherwise will return the current directory.  
                Properties: create
        userWorkspaceDir (bool?): Return the user workspace directory  
                (also known as the projects directory).  
                Properties: create

    Returns:
        str: The value of the variable specified by the flag use.

    Example:
    """

def intersect(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., firstSurface: bool = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, int, float]:
    """The intersect command creates a curve on surface where all surfaces
    intersect with each other. By default, the curve on surface is created
    for both surfaces. However, by using the -fs flag, only the first
    surface will have a curve on surface. Also, the intersection curve
    can be created as a 3D curve rather than a curve on surface.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        firstSurface (bool?): Creates a curve-on-surface on the first surface only or  
                on all surfaces (default).  
                Properties: query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance to fit to.  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def invertShape(arg0: str = ..., arg1: str = ..., /) -> None: ...
def iprEngine(*args: Any, edit: bool = ..., query: bool = ..., copy: str = ..., defineTemplate: str = ..., diagnostics: bool = ..., estimatedMemory: bool = ..., exists: bool = ..., iprImage: Queryable[str] = ..., motionVectorFile: bool = ..., object: Queryable[str] = ..., region: Queryable[Tuple[int, int, int, int]] = ..., relatedFiles: bool = ..., releaseIprImage: bool = ..., resolution: bool = ..., scanlineIncrement: Queryable[str] = ..., showProgressBar: bool = ..., startTuning: bool = ..., stopTuning: bool = ..., underPixel: Tuple[int, int] = ..., update: bool = ..., updateDepthOfField: bool = ..., updateLightGlow: bool = ..., updateMotionBlur: bool = ..., updatePort: Queryable[str] = ..., updateShaderGlow: bool = ..., updateShading: bool = ..., updateShadowMaps: bool = ..., useTemplate: str = ...) -> Union[str, bool, Tuple[int, int, int, int]]:
    """Command to create or edit an iprEngine.  A iprEngine
    is an object that watches for changes to shading
    networks and automatically reshades to generate an
    up-to-date image.
    Args:
        copy (str?): Copies the deep raster file, as well as its related files, to the  
                new location.  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        diagnostics (bool?): The diagnostics should be shown  
                Properties: edit
        estimatedMemory (bool?): Displays the estimated memory being used by IPR.  
                Properties: query
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        iprImage (Queryable[str]?): Specify the ipr image to use.  
                Properties: create, query, edit
        motionVectorFile (bool?): Returns the name of the motion vector file used by IPR.  
                Properties: query
        object (Queryable[str]?): The objects to be tuned.  
                Properties: create, query, edit
        region (Queryable[Tuple[int, int, int, int]]?): The coordinates of the region to be tuned.  
                The integers are in the sequence left bottom right top  
                or x1,y2  x2,y2  
                Properties: create, query, edit
        relatedFiles (bool?): Returns the names for the related files, e.g, the non-glow-non-blur image,  
                the motion vector file, and the depth-map files.  
                Properties: query
        releaseIprImage (bool?): The ipr image should be released and  
                memory should    be freed.  
                Properties: edit
        resolution (bool?): The width and height of the ipr file.  
                Properties: query
        scanlineIncrement (Queryable[str]?): Set the scanline increment percentage.  If the height of  
                the region being update is 240 pixels, and the scanlineIncrement  
                is 10% then the image will refresh blocks of 24 scanlines.  
                Properties: create, query, edit
        showProgressBar (bool?): Show progress bar during tuning.  
                Properties: create, query, edit
        startTuning (bool?): An ipr image has been specified and now changes  
                to shading    networks should force an image to be  
                produced.  
                Properties: create, query, edit
        stopTuning (bool?): Tuning should cease but ipr image should not be closed.  
                Properties: create, query, edit
        underPixel (Tuple[int, int]?): Get list of objects under the pixel sprcified.  
                Properties: edit
        update (bool?): Force an update.  
                Properties: create, edit
        updateDepthOfField (bool?): Force a refresh of depth-of-field.  
                Properties: create, edit
        updateLightGlow (bool?): Automatically update when light glow changes.  
                Properties: create, query, edit
        updateMotionBlur (bool?): Automatically update when 2.5D motion blur changes.  
                Properties: create, query, edit
        updatePort (Queryable[str]?): The name of the port that is to be updated when  
                pixel values are recomputed.  (not currently supported)  
                Properties: create, query, edit
        updateShaderGlow (bool?): Automatically update when shader glow changes.  
                Properties: create, query, edit
        updateShading (bool?): Automatically update shading.  
                Properties: create, query, edit
        updateShadowMaps (bool?): Force the shadow maps to be generated and an update to occur.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: - the name of the ipr engine created or modified

    Example:
    """

def isConnected(arg0: str = ..., arg1: str = ..., /, *, ignoreUnitConversion: bool = ...) -> bool:
    """Thecommand is used to check if two plugs are
    connected in the dependency graph. The return value isif they are not andif they are.The first string specifies the source plug to check for connection.The second one specifies the destination plug to check for connection.
    Args:
        ignoreUnitConversion (bool?): In looking for connections, skip past unit conversion nodes.  
                Properties: create

    Returns:
        bool: Are the two plugs connected?

    Example:
    """

def isDirty(*args: str, connection: bool = ..., datablock: bool = ...) -> bool:
    """Thecommand is used to check if a plug is dirty.  The
    return value is 0 if it is not and 1 if it is.  If more than one plug
    is specified then the result is the logical "or" of all objects
    (ie. returns 1 if *any* of the plugs are dirty).
    Args:
        connection (bool?): Check the connection of the plug (default).  
                Properties: create
        datablock (bool?): Check the datablock entry for the plug.  
                Properties: create

    Returns:
        bool: Is the plug dirty? If more than one plug is given then it returns the
            logical "and" of all dirty states.

    Example:
    """

def isTrue(arg0: str = ..., /) -> bool:
    """This commmand returns the state of the named condition. If the
    condition is true, it returns 1.  Otherwise it returns 0.
    Returns:
        bool:

    Example:
    """

def isolateSelect(arg0: str = ..., /, *, query: bool = ..., addDagObject: str = ..., addSelected: bool = ..., addSelectedObjects: bool = ..., loadSelected: bool = ..., removeDagObject: str = ..., removeSelected: bool = ..., state: bool = ..., update: bool = ..., viewObjects: bool = ...) -> bool:
    """This command turns on/off isolate select mode in a specified modeling
    view, specified as the argument. Isolate select mode is a display mode
    where the currently selected objects are added to a list and only
    those objects are displayed in the view. It allows for selective
    viewing of specific objects and object components.
    Args:
        addDagObject (str?): Add the specified object to the set of objects to be  
                displayed in the view.
        addSelected (bool?): Add the currently active objects to the set of  
                objects to be displayed in the view.
        addSelectedObjects (bool?): Add selected objects to the set of objects to be displayed in the view.  
                This flag differs from addSelected in that it will ignore selected components  
                and add the entire object.
        loadSelected (bool?): Replace the objects being displayed with the currently  
                active objects.
        removeDagObject (str?): Remove the specified object from the set of objects to be  
                displayed in the view.
        removeSelected (bool?): Remove the currently active objects to the set of  
                objects to be displayed in the view.
        state (bool?): Turns isolate select mode on/off.  
                Properties: query
        update (bool?): Update the view's list of objects due to a change  
                to the set of objects to be displayed.
        viewObjects (bool?): Returns the name (if any) of the objectSet which contains  
                the list of objects visible in the view if isolate select mode  
                is on. If isolate select mode is off, an empty string is  
                returned.  
                Properties: query

    Returns:
        bool: When used with query

    Example:
    """

def itemFilter(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., byBin: Queryable[Multiuse[str]] = ..., byName: Queryable[str] = ..., byScript: Queryable[str] = ..., byType: Queryable[Multiuse[str]] = ..., category: Queryable[Multiuse[str]] = ..., classification: Queryable[str] = ..., clearByBin: bool = ..., clearByType: bool = ..., difference: Queryable[Tuple[str, str]] = ..., exists: bool = ..., intersect: Queryable[Tuple[str, str]] = ..., listBuiltInFilters: bool = ..., listOtherFilters: bool = ..., listUserFilters: bool = ..., negate: bool = ..., parent: Queryable[str] = ..., pythonModule: Queryable[str] = ..., secondScript: Queryable[str] = ..., text: Queryable[str] = ..., union: Queryable[Tuple[str, str]] = ..., uniqueNodeNames: bool = ...) -> Union[str, List[str], Multiuse[str], Tuple[str, str], bool]:
    """This command creates a named itemFilter object.  This object
    can be attached to selectionConnection objects, or to editors,
    in order to filter the item lists going through them.  Using
    union, intersection and difference filters, complex composite
    filters can be created.
    Args:
        byBin (Queryable[Multiuse[str]]?): The filter will only pass items whose bin list  
                contains the given string as a bin name.  
                This is a multi-use flag.  
                If more than one occurance of this flag is used in a single  
                command, the filter will accept a node if it matches at least  
                one of the given bins (in other words, a union or logical or  
                of all given bins.  
                Properties: create, query, edit, multiuse
        byName (Queryable[str]?): The filter will only pass items whose names match the given regular  
                expression string.  This string can contain the special  
                characters * and ?.  '?' matches any one character, and '*'  
                matches any substring.  
                Properties: create, query, edit
        byScript (Queryable[str]?): The filter will run a MEL script named by the given string on each item name.  Items  
                will pass the filter if the script returns a non-zero value.  
                The script name string must be the name of a proc whose signature  
                is:  
                global proc int procName( string $name ) or  
                def procName(*args, **keywordArgs) if -pym/pythonModule is specified.  
                Note that if -secondScript is also used, it will always take precedence.  
                Properties: create, query, edit
        byType (Queryable[Multiuse[str]]?): The filter will only pass items whose typeName matches the  
                given string.  The typeName of an object can be found using  
                the nodeType command.  This is a multi-use flag.  
                If more than one occurance of this flag is used in a single  
                command, the filter will accept a node if it matches at least  
                one of the given types (in other words, a union or logical or  
                of all given types.  
                Properties: create, query, edit, multiuse
        category (Queryable[Multiuse[str]]?): A string for categorizing the filter.  
                Properties: create, query, edit, multiuse
        classification (Queryable[str]?): Indicates whether the filter is a built-in or user filter.  
                The string argument must be either "builtIn" or "user".  
                The "other" classification is deprecated. Use "user" instead.  
              
                Filters will not be deleted by a file new, and filter nodes will  
                be hidden from the UI (ex: Attribute Editor, Hypergraph etc) and  
                will not be accessible from the command-line.  
                Properties: create, query, edit
        clearByBin (bool?): This flag will clear any existing bins associated with this filter.  
                Properties: create, edit
        clearByType (bool?): This flag will clear any existing typeNames associated with this filter.  
                Properties: create, edit
        difference (Queryable[Tuple[str, str]]?): The filter will consist of the set difference of two other filters,  
                whose names are the given strings.  
                Items will pass this filter if and only if they pass the first filter but  
                not the second filter.  
                Properties: create, query, edit
        exists (bool?): Returns true|false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        intersect (Queryable[Tuple[str, str]]?): The filter will consist of the intersection of two other filters,  
                whose names are the given strings.  
                Items will pass this filter if and only if they pass both of  
                the contained filters.  
                Properties: create, query, edit
        listBuiltInFilters (bool?): Returns an array of all item filters with classification "builtIn".  
                Properties: query
        listOtherFilters (bool?): The "other" classification is deprecated. Use "user" instead.  
                Returns an array of all item filters with classification "other".  
                Properties: query
        listUserFilters (bool?): Returns an array of all item filters with classification "user".  
                Properties: query
        negate (bool?): This flag can be used to cause the filter to invert itself,  
                and reverse what passes and what fails.  
                Properties: create, query, edit
        parent (Queryable[str]?): Optional.  If specified, the filter's life-span is linked to  
                that of the parent.  When the parent goes out of scope, so  
                does the filter.  If not specified, the filter will exist  
                until explicitly deleted.  
                Properties: create, query, edit
        pythonModule (Queryable[str]?): Treat -bs/byScript and -ss/secondScript as Python functions located in the specified module.  
                Properties: create, query, edit
        secondScript (Queryable[str]?): Cannot be used in conjunction with the -bs flag.  The second  
                script is for filtering whole lists at once, rather than  
                individually.  Its signature must be:  
                global proc string[] procName( string[] $name ) or  
                def procName(*args, **keywordArgs) if -pym/pythonModule is specified.  
                It should take in a list of items, and return a filtered list  
                of items.  
                Properties: create, query, edit
        text (Queryable[str]?): Defines an annotation string to be stored with the filter  
                Properties: create, query, edit
        union (Queryable[Tuple[str, str]]?): The filter will consist of the union of two other filters, whose  
                names are the given strings.  
                Items will pass this filter if they pass at least one of the  
                contained filters.  
                Properties: create, query, edit
        uniqueNodeNames (bool?): Returns unique node names to script filters so there are no naming  
                conflicts.  
                Properties: create, query, edit

    Returns:
        str: Single command result
        List[str]: Multiple command result

    Example:
    """

def itemFilterAttr(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., byName: Queryable[str] = ..., byNameString: Queryable[Multiuse[str]] = ..., byScript: Queryable[str] = ..., classification: Queryable[str] = ..., dynamic: bool = ..., exists: bool = ..., hasCurve: bool = ..., hasDrivenKey: bool = ..., hasExpression: bool = ..., hidden: bool = ..., intersect: Queryable[Tuple[str, str]] = ..., keyable: bool = ..., listBuiltInFilters: bool = ..., listOtherFilters: bool = ..., listUserFilters: bool = ..., negate: bool = ..., parent: str = ..., published: bool = ..., readable: bool = ..., scaleRotateTranslate: bool = ..., secondScript: Queryable[str] = ..., text: Queryable[str] = ..., union: Queryable[Tuple[str, str]] = ..., writable: bool = ...) -> Union[str, List[str], Multiuse[str], bool, Tuple[str, str]]:
    """This command creates a named itemFilterAttr object.  This object
    can be attached to editors, in order to filter the attributes
    going through them.
    Using union and intersection filters, complex composite filters can
    be created.
    Args:
        byName (Queryable[str]?): The filter will only pass items whose names match the given regular  
                expression string.  This string can contain the special  
                characters * and ?.  '?' matches any one character, and '*'  
                matches any substring.  
                This flag cannot be used in conjunction with the -byScript or -secondScript flags.  
                Properties: create, query, edit
        byNameString (Queryable[Multiuse[str]]?): The filter will only pass items whose names match the given string.  
                This is a multi-use flag which allows the user to specify several strings.  
                The filter will pass items that match any of the strings.  
                This flag cannot be used in conjunction with the -byScript or -secondScript flags.  
                Properties: create, query, edit, multiuse
        byScript (Queryable[str]?): The filter will run a MEL script named by the given string on each  
                attribute name.  Attributes will pass the filter if the script  
                returns a non-zero value.  
                The script name string must be the name of a proc whose signature  
                is:  
                global proc int procName( string $nodeName string $attrName )  
                This flag cannot be used in conjunction with the -byName or -byNameString flags.  
                Properties: create, query, edit
        classification (Queryable[str]?): Indicates whether the filter is a built-in or user filter.  
                The string argument must be either "builtIn" or "user".  
                The "other" filter classification is deprecated. Use "user"  
                instead.  
              
                Filters created by Maya should be classified as "builtIn".  
                Filters created by plugins or user scripts should be classified  
                as "user".  
              
                Filters will not be deleted by a file new. Filter nodes will  
                be hidden from the UI (ex: Attribute Editor, Hypergraph etc) and  
                will not be accessible from the command-line.  
                Properties: create, query, edit
        dynamic (bool?): The filter will only pass dynamic attributes  
                Properties: create, query, edit
        exists (bool?): The filter will only pass attributs that exist  
                Properties: create, query, edit
        hasCurve (bool?): The filter will only pass attributes that are driven by animation  
                curves.  
                Properties: create, query, edit
        hasDrivenKey (bool?): The filter will only pass attributes that are driven by driven keys  
                Properties: create, query, edit
        hasExpression (bool?): The filter will only pass attributes that are driven by expressions  
                Properties: create, query, edit
        hidden (bool?): The filter will only pass attributes that are hidden to the user  
                Properties: create, query, edit
        intersect (Queryable[Tuple[str, str]]?): The filter will consist of the intersection of two other filters,  
                whose names are the given strings.  
                Attributes will pass this filter if and only if they pass both of  
                the contained filters.  
                Properties: create, query, edit
        keyable (bool?): The filter will only pass attributes that are keyable  
                Properties: create, query, edit
        listBuiltInFilters (bool?): Returns an array of all attribute filters with classification "builtIn".  
                Properties: query
        listOtherFilters (bool?): The "other" classification has been deprecated. Use "user" instead.  
                Returns an array of all attribute filters with classification "other".  
                Properties: query
        listUserFilters (bool?): Returns an array of all attribute filters with classification "user".  
                Properties: query
        negate (bool?): This flag can be used to cause the filter to invert itself,  
                and reverse what passes and what fails.  
                Properties: create, query, edit
        parent (str?): This flag is no longer supported.
        published (bool?): The filter will only pass attributes that are published on the container.  
                Properties: create, query, edit
        readable (bool?): The filter will only pass attributes that are readable (outputs)  
                Properties: create, query, edit
        scaleRotateTranslate (bool?): The filter will show only SRT attributes: scale, rotate, translate and  
                their children  
                Properties: create, query, edit
        secondScript (Queryable[str]?): Can be used in conjunction with the -bs flag.  The second  
                script is for filtering whole lists at once, rather than  
                individually.  Its signature must be:  
                global proc string[] procName( string[] $nodeName string[] $attrName )  
                It should take in a list of attributes, and return a filtered list  
                of attributes.  
                This flag cannot be used in conjunction with the -byName or -byNameString flags.  
                Properties: create, query, edit
        text (Queryable[str]?): Defines an annotation string to be stored with the filter  
                Properties: create, query, edit
        union (Queryable[Tuple[str, str]]?): The filter will consist of the union of two other filters, whose  
                names are the given strings.  
                Attributes will pass this filter if they pass at least one of the  
                contained filters.  
                Properties: create, query, edit
        writable (bool?): The filter will only pass attributes that are writable (inputs)  
                Properties: create, query, edit

    Returns:
        str: Single command result
        List[str]: Multiple command result

    Example:
    """

def itemFilterRender(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., anyTextures: bool = ..., category: Multiuse[str] = ..., classification: str = ..., exists: bool = ..., exclusiveLights: bool = ..., lights: bool = ..., listBuiltInFilters: bool = ..., linkedLights: bool = ..., listOtherFilters: bool = ..., lightSets: bool = ..., listUserFilters: bool = ..., nodeClassification: Multiuse[str] = ..., negate: bool = ..., nonIlluminatingLights: bool = ..., nonExclusiveLights: bool = ..., parent: str = ..., postProcess: bool = ..., renderingNode: bool = ..., renderableObjectSets: bool = ..., renderUtilityNode: bool = ..., shaders: bool = ..., text: str = ..., textures2d: bool = ..., textures3d: bool = ..., texturesProcedural: bool = ...) -> None: ...
def itemFilterType(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., text: Queryable[str] = ..., type: bool = ...) -> Union[str, List[str], bool]:
    """This command queries a named itemFilter object.  This object
    can be attached to selectionConnection objects, or to editors,
    in order to filter the item lists going through them.  Using
    union and intersection filters, complex composite filters can
    be created.
    Args:
        text (Queryable[str]?): Defines an annotation string to be stored with the filter  
                Properties: query, edit
        type (bool?): Query the type of the filter object. Possible return values are:  
                itemFilter, attributeFilter, renderFilter, or unknownFilter.  
                Properties: query

    Returns:
        str: Single command result
        List[str]: Multiple command result

    Example:
    """

def iterOnNurbs(*args: Any, **kwargs: Any) -> None: ...
def joint(*args: str, edit: bool = ..., query: bool = ..., absolute: bool = ..., angleX: Queryable[float] = ..., angleY: Queryable[float] = ..., angleZ: Queryable[float] = ..., assumePreferredAngles: bool = ..., automaticLimits: bool = ..., children: bool = ..., component: bool = ..., degreeOfFreedom: Queryable[str] = ..., exists: Queryable[str] = ..., limitSwitchX: bool = ..., limitSwitchY: bool = ..., limitSwitchZ: bool = ..., limitX: Queryable[Tuple[float, float]] = ..., limitY: Queryable[Tuple[float, float]] = ..., limitZ: Queryable[Tuple[float, float]] = ..., name: Queryable[str] = ..., orientJoint: str = ..., orientation: Queryable[Tuple[float, float, float]] = ..., position: Queryable[Tuple[float, float, float]] = ..., radius: Queryable[float] = ..., relative: bool = ..., rotationOrder: Queryable[str] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleCompensate: bool = ..., scaleOrientation: Queryable[Tuple[float, float, float]] = ..., secondaryAxisOrient: str = ..., setPreferredAngles: bool = ..., stiffnessX: Queryable[float] = ..., stiffnessY: Queryable[float] = ..., stiffnessZ: Queryable[float] = ..., symmetry: bool = ..., symmetryAxis: str = ..., zeroScaleOrient: bool = ...) -> Union[str, bool, float, Tuple[float, float], Tuple[float, float, float]]:
    """The joint command is used to create, edit, and query, joints
    within Maya. (The standard edit(-e) and query(-q) flags are
    used for edit and query functions). If the object is not
    specified, the currently selected object (dag object) will be
    used.Multiple objects are allowed only for the edit mode. The same
    edit flags will be applied on all the joints selected, except
    for -p without -r (set joint position in the world space). An
    ik handle in the object list is equivalent to the list of
    joints the ik handle commands. When -ch/children is present,
    all the child joints of the specified joints, including the
    joints implied by possible ik handles, will also be included.In the creation mode, a new joint will be created as a child
    of a selected transform or starts a hierarchy by itself if no
    transform is selected. An ik handle will be treated as a
    transform in the creation mode.The default values of the arguments are:-degreeOfFreedom xyz-name "Joint#"-position 0 0 0-absolute-dof "xyz"-scale 1.0 1.0 1.0-scaleCompensate true-orientation 0.0 0.0 0.0-scaleOrientation 0.0 0.0 0.0-limitX -360 360-limitY -360 360-limitZ -360 360-angleX 0.0-angleY 0.0-angleZ 0.0-stiffnessX 0.0-stiffnessY 0.0-stiffnessZ 0.0-limitSwitchX no-limitSwitchY no-limitSwitchZ no-rotationOrder xyzThose arguments can be specified in the creation mode,
    editied in the edit mode (-e), or queried in the query mode
    (-q).
    Args:
        absolute (bool?): The joint center position is in absolute world coordinates.  
                (This is the default.)  
                Properties: create, query, edit
        angleX (Queryable[float]?): Set the x-axis angle. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        angleY (Queryable[float]?): Set the y-axis angle. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        angleZ (Queryable[float]?): Set the z-axis angle. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        assumePreferredAngles (bool?): Meaningful only in the edit mode. It sets the  
                joint angles to the corresponding preferred  
                angles.  
                Properties: edit
        automaticLimits (bool?): Meaningful only in edit mode. It sets the joint to  
                appropriate hinge joint with joint limits. It modifies  
                the joint only if (a) it connects exactly to two  
                joints (one parent, one child), (b) it does not lie on  
                the line drawn between the two connected joints, and  
                the plane it forms with the two connected joints  
                is perpendicular to one of its rotation axes.  
                Properties: create
        children (bool?): It tells the command to apply all the edit options  
                not only to the selected joints, but also to their  
                descendent joints in the DAG.  
                Properties: edit
        component (bool?): Use with the -position switch to position the joint  
                relative to its parent (like -relative) but to compute  
                new positions for all children joints so their world  
                coordinate positions do not change.  
                Properties: create, edit
        degreeOfFreedom (Queryable[str]?): Specifies the degrees of freedom for the IK.  
                Valid strings consist of non-duplicate letters from x,  
                y, and z. The letters in the string indicate what  
                rotations are to be used by IK. The order a letter  
                appear in the string does not matter. Examples are x,  
                yz, xyz. When queried, this flag returns a string.  
                Modifying dof will change the locking state of the  
                corresponding rotation attributes. The rule is: if an  
                rotation is turned into a dof, it will be unlocked if  
                it is currently locked. When it is turned into a  
                non-dof, it will be locked if it is not currently  
                locked.  
                Properties: create, query, edit
        exists (Queryable[str]?): Does the named joint exist? When queried, this flag  
                returns a boolean.  
                Properties: query
        limitSwitchX (bool?): Use the limit the x-axis rotation? When  
                queried, this flag returns a boolean.  
                Properties: create, query, edit
        limitSwitchY (bool?): Use the limit the y-axis rotation? When  
                queried, this flag returns a boolean.  
                Properties: create, query, edit
        limitSwitchZ (bool?): Use the Limit the z-axis rotation? When  
                queried, this flag returns a boolean.  
                Properties: create, query, edit
        limitX (Queryable[Tuple[float, float]]?): Set lower and upper limits on the x-axis of  
                rotation.  Also turns on  
                the joint limit. When queried, this flag returns 2 floats.  
                Properties: create, query, edit
        limitY (Queryable[Tuple[float, float]]?): Set lower and upper limits on the y-axis of  
                rotation.  Also turns on  
                the joint limit. When queried, this flag returns 2 floats.  
                Properties: create, query, edit
        limitZ (Queryable[Tuple[float, float]]?): Set lower and upper limits on the z-axis of  
                rotation.  Also turns on  
                the joint limit. When queried, this flag returns 2 floats.  
                Properties: create, query, edit
        name (Queryable[str]?): Specifies the name of the joint. When queried,  
                this flag returns a string.  
                Properties: create, query, edit
        orientJoint (str?): The argument can be one of the following strings: xyz,  
                yzx, zxy, zyx, yxz, xzy, none.  
              
                It modifies the joint orientation and scale orientation  
                so that the axis indicated by the first letter in the argument  
                will be aligned with the vector from this joint to its first  
                child joint. For example, if the argument is "xyz", the x-axis will  
                point towards the child joint.  
              
                The alignment of the remaining two joint orient axes are  
                dependent on whether or not the -sao/-secondaryAxisOrient flag  
                is used. If the -sao flag is used, see the documentation for  
                that flag for how the remaining axes are aligned.  
              
                In the absence of a user specification for the secondary axis  
                orientation, the rotation axis indicated by the last letter in  
                the argument will be aligned with the vector perpendicular to  
                first axis and the vector from this joint to its parent joint.  
              
                The remaining axis is aligned according the right hand rule.  
              
                If the argument is "none", the joint orientation  
                will be set to zero and its effect to the hierarchy  
                below will be offset by modifying the scale  
                orientation.  
              
                The flag will be ignored if:  
              
                A. the joint has non-zero rotations when the argument  
                is not "none".  
              
                B. the joint does not have child joint, or the  
                distance to the child joint is zero when the argument  
                is not "none".  
              
                C. either flag -o or -so is set.  
                Properties: edit
        orientation (Queryable[Tuple[float, float, float]]?): The joint orientation. When queried, this flag  
                returns 3 floats.  
                Properties: create, query, edit
        position (Queryable[Tuple[float, float, float]]?): Specifies the position of the center of the joint.  
                This position may be relative to the joint's parent  
                or in absolute world coordinates (see -r and -a  
                below). When queried, this flag returns 3 floats.  
                Properties: create, query, edit
        radius (Queryable[float]?): Specifies the joint radius.  
                Properties: create, query, edit
        relative (bool?): The joint center position is relative to the joint's parent.  
                Properties: create, query, edit
        rotationOrder (Queryable[str]?): The rotation order of the joint. The  
                argument can be one of the following strings: xyz,  
                yzx, zxy, zyx, yxz, xzy.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scale of the joint. When queried, this flag  
                returns 3 floats.  
                Properties: create, query, edit
        scaleCompensate (bool?): It sets the scaleCompenstate attribute of  
                the joint to the given argument. When this is true,  
                the scale of the parent joint will be compensated  
                before any rotation of this joint is applied, so that  
                the bone to the joint is scaled but not the bones to  
                its child joints. When queried, this flag returns an  
                boolean.  
                Properties: create, query, edit
        scaleOrientation (Queryable[Tuple[float, float, float]]?): Set the orientation of the coordinate axes for  
                scaling. When queried, this flag returns 3 floats.  
                Properties: create, query, edit
        secondaryAxisOrient (str?): The argument can be one of the following strings: xup, xdown,  
                yup, ydown, zup, zdown, none.  
              
                This flag is used in conjunction with the -oj/orientJoint  
                flag. It specifies the scene axis that the second axis should  
                align with. For example, a flag combination of "-oj yzx -sao yup"  
                would result in the y-axis pointing down the bone, the  
                z-axis oriented with the scene's positive y-axis, and  
                the x-axis oriented according to the right hand rule.  
                Properties: edit
        setPreferredAngles (bool?): Meaningful only in the edit mode. It sets the  
                preferred angles to the current joint angles.  
                Properties: edit
        stiffnessX (Queryable[float]?): Set the stiffness (from 0 to 100.0) for x-axis.  
                When queried, this flag returns a float.  
                Properties: create, query, edit
        stiffnessY (Queryable[float]?): Set the stiffness (from 0 to 100.0) for y-axis.  
                When queried, this flag returns a float.  
                Properties: create, query, edit
        stiffnessZ (Queryable[float]?): Set the stiffness (from 0 to 100.0) for z-axis.  
                When queried, this flag returns a float.  
                Properties: create, query, edit
        symmetry (bool?): Create a symmetric joint from the current joint.  
                Properties: create, edit
        symmetryAxis (str?): This flag specifies the axis used to mirror symmetric joints. Any combination of x, y, z can be used. This option is only used when the symmetry flag is set to True.  
                Properties: create, edit
        zeroScaleOrient (bool?): It sets the scale orientation to zero and  
                compensate the change by modifing the translation and  
                joint orientation for joint or rotation for general  
                transform of all its child transformations.  
              
                The flag will be ignored if the flag -so is set.  
                Properties: edit

    Returns:
        str: Command result

    Example:
    """

def jointCluster(*args: str, edit: bool = ..., query: bool = ..., aboveBound: Queryable[float] = ..., aboveCluster: bool = ..., aboveDropoffType: Queryable[str] = ..., aboveValue: Queryable[float] = ..., belowBound: Queryable[float] = ..., belowCluster: bool = ..., belowDropoffType: Queryable[str] = ..., belowValue: Queryable[float] = ..., deformerTools: bool = ..., joint: str = ..., name: str = ...) -> Union[str, float, bool]:
    """The joint cluster command adds high-level controls to
    manage the cluster percentage values on a bound skin
    around a joint. JointClusters are one way
    to create smooth bending behaviour on skin when joints
    rotate.CVs/vertices between Joint1 and aaaaa (aboveBound) receive only
    translation/rotation/scale from Joint1. CVs vertices between aaaa and
    bbbb transition between translation/rotatation/scale from Joint1 and
    Joint2. CV2 beyand bbbbb (below bound) receive only translation/
    rotation scale from Joint3.
    Args:
        aboveBound (Queryable[float]?): Specifies the where the drop-off begins in the  
                direction of the bone above the joint. A value of 100 indicates  
                the entire length of the bone. The default value is 10.  
                Properties: create, query, edit
        aboveCluster (bool?): Returns the name of the cluster associated with the bone  
                above this joint.  
                Properties: query
        aboveDropoffType (Queryable[str]?): Specifies the type of percentage drop-off in the direction  
                of the bone above this joint. Valid values are "linear",  
                "exponential", "sine" and "none". Default is linear.  
                Properties: create, query, edit
        aboveValue (Queryable[float]?): Specifies the drop-off percentage of the joint cluster in the  
                direction of the bone above the cluster. A value of 100 indicates  
                the entire length of the bone. The default value is 50.  
                Properties: create, query, edit
        belowBound (Queryable[float]?): Specifies where the drop-off ends in the  
                direction of the bone below the joint. A value of 100 indicates  
                the entire length of the bone. The default value is 10.  
                Properties: create, query, edit
        belowCluster (bool?): Returns the name of the cluster associated with this joint.  
                Properties: query
        belowDropoffType (Queryable[str]?): Specifies the type of type of percentage drop-off in the direction  
                of the bone below this joint. Valid values are "linear",  
                "exponential", "sine" and "none".  
                Default is linear.  
                Properties: create, query, edit
        belowValue (Queryable[float]?): Specifies the drop-off percentage of the joint cluster in the  
                direction of the joint below the cluster. A value of 100 indicates  
                the entire length of the bone. The default value is 50.  
                Properties: create, query, edit
        deformerTools (bool?): Used to query for the helper nodes associated with the jointCluster.  
                Properties: query
        joint (str?): Specifies the joint that the cluster should act about.  
                Properties: create
        name (str?): This flag is obsolete.  
                Properties: create

    Returns:
        str: Name of the new jointCluster node

    Example:
    """

def jointCtx(*args: Any, edit: bool = ..., query: bool = ..., autoJointOrient: Queryable[str] = ..., autoPriorityH: bool = ..., createIKHandle: bool = ..., degreeOfFreedomJ: Queryable[str] = ..., exists: bool = ..., forceSolverH: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., jointAutoLimits: bool = ..., jointOrientationJ: Queryable[Tuple[float, float, float]] = ..., largeBoneLength: Queryable[float] = ..., largeBoneRadius: Queryable[float] = ..., poWeightH: Queryable[float] = ..., priorityH: Queryable[int] = ..., scaleCompensateJ: bool = ..., scaleJ: Queryable[Tuple[float, float, float]] = ..., scaleOrientationJ: Queryable[Tuple[float, float, float]] = ..., secondaryAxisOrient: Queryable[str] = ..., smallBoneLength: Queryable[float] = ..., smallBoneRadius: Queryable[float] = ..., snapHandleH: bool = ..., solverTypeH: Queryable[str] = ..., stickyH: Queryable[str] = ..., symmetry: bool = ..., symmetryAxis: Queryable[str] = ..., variableBoneSize: bool = ..., weightH: Queryable[float] = ...) -> Union[str, bool, Tuple[float, float, float], float, int]:
    """The joint context command (jointCtx) updates the parameters of the
    joint tool. The options for the tool will be set by the flags the user
    specifies.
    Args:
        autoJointOrient (Queryable[str]?): Specifies the joint orientation. Valid string choices are  
                permutations of the axes; "none", "xyz", "yzx", "zxy", "xzy", "yxz",  
                "zyx". The first letter determines which axis is aligned with the  
                bone.  
                C: The default is "xyz".  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        autoPriorityH (bool?): Specifies if the ikHandle's priority is assigned  
                automatically.  
                C: The default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        createIKHandle (bool?): Enables the joint tool to create an ikHandle when the tool  
                is completed.  
                C: The default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        degreeOfFreedomJ (Queryable[str]?): Specifies the degrees of freedom for all of the joints  
                created by the tool. Valid string choices are the free axes;  
                "x", "y", "z", "xy", "xz", "yz", "xyz", and "none".  
                C: The default is "xyz".  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        forceSolverH (bool?): Specifies if the ikSolver for the ikHandle is enabled.  
                C: The default is on.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        jointAutoLimits (bool?): Automatically computes the joint limits based on the  
                kind of joint created.   
                C: The default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        jointOrientationJ (Queryable[Tuple[float, float, float]]?): Sets the orientation of the joints created by the tool.  
                If autoJointOrient in on, these values will be ignored.  
                C: The default is 0 0 0.  
                Q: When queried, this flag returns an array of three floats.  
                Properties: create, query, edit
        largeBoneLength (Queryable[float]?): Specifies the length above which bones should be assigned the largeBoneRadius.  
                Properties: create, query, edit
        largeBoneRadius (Queryable[float]?): Specifies the radius for bones whose length is above the largeBoneLength  
                Properties: create, query, edit
        poWeightH (Queryable[float]?): Specifies the position/orientation weight of the ikHandle.  
                C: The default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        priorityH (Queryable[int]?): Specifies the priority of the ikHandle.  
                C: The default is on.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        scaleCompensateJ (bool?): Specifies if scale compensate is enabled.  
                C: The default is on.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        scaleJ (Queryable[Tuple[float, float, float]]?): Sets the scale for the joints created by the tool.  
                C: The default is 1 1 1.  
                Q: When queried, this flag returns an array of three floats.  
                Properties: create, query, edit
        scaleOrientationJ (Queryable[Tuple[float, float, float]]?): Sets the current value for the scale orientation.  
                If autoJointOrient in on, these values will be ignored.  
                C: The default is 0 0 0.  
                Q: When queried, this flag returns an array of three floats.  
                Properties: create, query, edit
        secondaryAxisOrient (Queryable[str]?): Specifies the orientation of the secondary rotate axis.  
                Valid string choices are: "xup", "xdown",  
                "yup", "ydown", "zup", "zdown", "none".  
                Properties: create, query, edit
        smallBoneLength (Queryable[float]?): Specifies the length below which bones should be assigned the smallBoneRadius.  
                Properties: create, query, edit
        smallBoneRadius (Queryable[float]?): Specifies the radius for bones whose length is below the smallBoneLength.  
                Properties: create, query, edit
        snapHandleH (bool?): Sepcifies if snapping is enabled for the ikHandle.   
                C: The default is on.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        solverTypeH (Queryable[str]?): Sets the name of the solver to use with the ikHandle.   
                C: The default is the solver set to the default in the user  
                preferences.  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        stickyH (Queryable[str]?): Specifies if the ikHandle is sticky or not. If "sticky" is  
                passed then the ikHandle will be sticky. If "off" is used then  
                ikHandle stickiness will be turned off.  
                C: The default is "off".  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        symmetry (bool?): Automaticaly create a symmetry joint based if symmetry is on.   
                C: The default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        symmetryAxis (Queryable[str]?): Automaticaly create a symmetry joint use x, y , z axis or combination to do the symmetry.   
                C: The default is x.  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        variableBoneSize (bool?): Specifies whether or not variable bone length and radius settings should be used.  
                Properties: create, query, edit
        weightH (Queryable[float]?): Specifies the weight of the ikHandle. The weight is  
                relative to the other ikHandles in the scene.  
                C: The default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: The name of the context.

    Example:
    """

def jointDisplayScale(arg0: float = ..., /, *, edit: bool = ..., query: bool = ..., absolute: bool = ..., ikfk: Queryable[float] = ...) -> Union[float, bool]:
    """This action modifies and queries the current display size of
    skeleton joints. The joint display size is controlled by a
    scale factor; a scale factor of 1 sets the display size to its
    default, which is 1 in diameter.
    With the plain format, the float argument is the factor with
    respect to the default size. When -a/absolute is used, the
    float argument refers to the diameter of the joint
    display size.
    Args:
        absolute (bool?): Interpret the float argument as the display size as  
                opposed to the scale factor.  
                Properties: create, query, edit
        ikfk (Queryable[float]?): Set the display size of ik/fk skeleton joints.  
                Properties: create, query, edit

    Returns:
        float: Returns current display size of skeleton joints.

    Example:
    """

def jointLattice(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., creasing: Queryable[float] = ..., deformerTools: bool = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., joint: str = ..., lengthIn: Queryable[float] = ..., lengthOut: Queryable[float] = ..., lowerBindSkin: str = ..., lowerTransform: str = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., rounding: Queryable[float] = ..., selectedComponents: bool = ..., split: bool = ..., upperBindSkin: str = ..., upperTransform: str = ..., useComponentTags: bool = ..., widthLeft: Queryable[float] = ..., widthRight: Queryable[float] = ...) -> Union[str, bool, float, Multiuse[str]]:
    """This command creates/edits/queries a jointLattice deformer. The name
    of the created/edited object is returned. Usually you would make use of
    this functionality through the higher level flexor command.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        creasing (Queryable[float]?): Affects the bulging of lattice points on the inside of  
                the bend.  Positive/negative values cause the points to bulge  
                outwards/inwards. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        joint (str?): Specifies the joint which will be used to drive the  
                bulging behaviours.  
                Properties: create
        lengthIn (Queryable[float]?): Affects the location of lattice points on the parent  
                bone.  Positive/negative values cause the points to move  
                away/towards the joint. Changing this parameter also modifies  
                the regions affected by the creasing, rounding and width  
                parameters. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        lengthOut (Queryable[float]?): Affects the location of lattice points on the child bone.  
                Positive/negative values cause the points to move away/towards  
                the joint. Changing this parameter also modifies the regions  
                affected by the creasing, rounding and width parameters. Default  
                value is 0.0. When queried, this flag returns a float.  
                Properties: create, query, edit
        lowerBindSkin (str?): Specifies the node which is performing the bind skin  
                operation on the geometry associated with the lower bone.  
                Properties: create
        lowerTransform (str?): Specifies which dag node is being used to rigidly transform  
                the lower part of the lattice which this node is going to deform.  
                If this flag is not specified an identity matrix will be assumed.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        rounding (Queryable[float]?): Affects the bulging of lattice points on the outside  
                of the bend. Positive/negative values cause the points to bulge  
                outwards/inwards. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        upperBindSkin (str?): Specifies the node which is performing the bind skin  
                operation on the geometry associated with the upper bone.  
                Properties: create
        upperTransform (str?): Specifies which dag node is being used to rigidly transform  
                the upper part of the lattice which this node is going to deform.  
                If this flag is not specified an identity matrix will be assumed.  
                Properties: create
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        widthLeft (Queryable[float]?): Affects the bulging of lattice points on the left side  
                of the bend. Positive/negative values cause the points to bulge  
                outwards/inwards. Default value is 0.0. When queried, this flag  
                returns a float.  
                Properties: create, query, edit
        widthRight (Queryable[float]?): Affects the bulging of lattice points on the right  
                side of the bend. Positive/negative values cause the points to  
                bulge outwards/inwards. Default value is 0.0. When queried, this  
                flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: Name of joint lattice algorithm node created/edited.

    Example:
    """

def journal(*, query: bool = ..., comment: str = ..., flush: bool = ..., highPrecision: bool = ..., state: bool = ...) -> None: ...
def keyTangent(*args: str, edit: bool = ..., query: bool = ..., absolute: bool = ..., animation: str = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., g: bool = ..., hierarchy: str = ..., inAngle: Queryable[float] = ..., inTangentType: Queryable[str] = ..., inWeight: Queryable[float] = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., ix: Queryable[float] = ..., iy: Queryable[float] = ..., lock: bool = ..., outAngle: Queryable[float] = ..., outTangentType: Queryable[str] = ..., outWeight: Queryable[float] = ..., ox: Queryable[float] = ..., oy: Queryable[float] = ..., pluginTangentTypes: Queryable[str] = ..., relative: bool = ..., shape: bool = ..., stepAttributes: bool = ..., time: Multiuse[NullableRange[float]] = ..., unify: bool = ..., weightLock: bool = ..., weightedTangents: bool = ...) -> Union[int, float, str, bool]:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command edits or queries tangent properties of keyframes
    in a keyset.  It is also used to edit or query the default
    tangent type of newly created keyframes (see the setKeyframe
    command for more information on how to override this default).Tangents help manage the shape of the animation curve and affect
    the interpolation between keys.  The tangent angle specifies the
    direction the curve will take as it leaves (or enters) a key.
    The tangent weight specifies how much influence the tangent angle
    has on the curve before the curve starts towards the next key.Maya internally represents tangents as x and y values.  Refer to the API
    documentation for MFnAnimCurve for a description of the relationship
    between tangent angle and weight and the internal x and y values.
    Args:
        absolute (bool?): Changes to tangent positions are NOT relative to the  
                current position.  
                Properties: create, edit
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        g (bool?): Required for all operations on the global tangent type.  
                The global tangent type is used by the setKeyframe command  
                when tangent types have not been specifically applied, except  
                in combination with flags such as 'i/insert' which preserve the shape  
                of the curve.  It is also used when keys are set from the menu.  
                The only flags that can appear on a keyTangent command  
                with the 'g/global' flag are 'itt/inTangentType',  
                'ott/outTangentType' and 'wt/weightedTangents'.  
                Properties: create
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        inAngle (Queryable[float]?): New value for the angle of the in-tangent.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        inTangentType (Queryable[str]?): Specify the in-tangent type.  Valid values are  
                "spline," "linear," "fast," "slow," "flat," "step," "stepnext,"  
                "fixed," "clamped," "plateau", "auto", "autoease", "automix", and "autocustom".  
                Returns a string[] when queried.  
                Properties: create, query, edit
        inWeight (Queryable[float]?): New value for the weight of the in-tangent.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        ix (Queryable[float]?): New value for the x-component of the in-tangent.  
                This is a unit independent representation of the tangent  
                component.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        iy (Queryable[float]?): New value for the y-component of the in-tangent.  
                This is a unit independent representation of the tangent  
                component.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        lock (bool?): Lock a tangent so in and out tangents move together.  
                Returns an int[] when queried.  
                Properties: create, query, edit
        outAngle (Queryable[float]?): New value for the angle of the out-tangent.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        outTangentType (Queryable[str]?): Specify the out-tangent type.  Valid values are  
                "spline," "linear," "fast," "slow," "flat," "step," "stepnext,"  
                "fixed," "clamped," "plateau" and "auto", "autoease", "automix", and  
                "autocustom".  
                Returns a string[] when queried.  
                Properties: create, query, edit
        outWeight (Queryable[float]?): New value for the weight of the out-tangent.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        ox (Queryable[float]?): New value for the x-component of the out-tangent.  
                This is a unit independent representation of the tangent  
                component.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        oy (Queryable[float]?): New value for the y-component of the out-tangent.  
                This is a unit independent representation of the tangent  
                component.  
                Returns a float[] when queried.  
                Properties: create, query, edit
        pluginTangentTypes (Queryable[str]?): Returns a list of the plug-in tangent types that have been loaded.  
                Return type is a string array.  
                Properties: query
        relative (bool?): Changes to tangent positions are relative to the  
                current position.  
                Properties: create, edit
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        stepAttributes (bool?): The setKeyframe command will automatically set  
                tangents for boolean and enumerated attributes to step.  This  
                flag mirrors this behavior for the keyTangent command.  When  
                set to false, tangents for these attributes will not be  
                edited.  When set to true (the default) tangents for these  
                attributes will be edited.  
                Properties: create, edit
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        unify (bool?): Unify a tangent so in and out tangents are equal and move together.  
                Properties: create, edit
        weightLock (bool?): Lock the weight of a tangent so it is fixed.  
                Returns an int[] when queried.  
                Note: weightLock is only obeyed within the graph editor.  It  
                is not obeyed when -inWeight/-outWeight are issued from a command.  
                Properties: create, query, edit
        weightedTangents (bool?): Specify whether or not the tangents on  
                the animCurve are weighted  
                Note: switching a curve from weightedTangents  
                true to false and back to true again will not  
                preserve fixed tangents properly. Use undo instead.  
                Properties: create, query, edit

    Returns:
        int: Number of curves on which tangents were modified.

    Example:
    """

def keyframe(*args: str, edit: bool = ..., query: bool = ..., absolute: bool = ..., adjustBreakdown: bool = ..., animation: str = ..., attribute: Multiuse[str] = ..., breakdown: bool = ..., clipTime: Tuple[int, int, float] = ..., controlPoints: bool = ..., eval: bool = ..., float: Multiuse[Range[float]] = ..., floatChange: Queryable[float] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., indexValue: bool = ..., keyframeCount: bool = ..., lastSelected: bool = ..., name: bool = ..., option: str = ..., relative: bool = ..., selected: bool = ..., shape: bool = ..., tickDrawSpecial: bool = ..., time: Multiuse[NullableRange[float]] = ..., timeChange: Queryable[int] = ..., valueChange: Queryable[float] = ...) -> Union[int, bool, float]:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command edits the time and/or value of keys of
    specified objects and/or parameter curvesUnless otherwise specified by the -query flag, the command
    defaults to editing keyframes.
    Args:
        absolute (bool?): Move amounts are absolute.  
                Properties: create
        adjustBreakdown (bool?): When false, moving keys will not preserve breakdown  
                timing, when true (the default) breakdowns will be adjusted  
                to preserve their timing relationship.  
                Properties: create
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        breakdown (bool?): Sets the breakdown state for the key.  Returns  
                an integer.  Default is false.  The breakdown state of a key  
                cannot be set in the same command as it is moved (i.e., via  
                the -tc or -fc flags).  
                Properties: create, query, edit
        clipTime (Tuple[int, int, float]?): Modifies the final time where a key is inserted using an  
                offset, pivot, and scale.  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        eval (bool?): Returns the value(s) of the animCurves when evaluated  
                (without regard to input connections)  
                at the times given by the -t/time or -f/float flags.  Cannot  
                be used in combination with other query flags, and  
                cannot be used with time ranges (-t "5. 10").  
                When no -t or -f flags appear on the command line, the  
                evals are queried at the current time.  Query returns a float[].  
                Properties: create, query
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        floatChange (Queryable[float]?): How much (with -relative) or where (with -absolute)  
                to move keys (on non-time-input animation curves)  
                along the x (float) axis. Returns float[] when queried.  
                Properties: create, query, edit
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        indexValue (bool?): Query-only flag that returns an int for the key's index.  
                Properties: create, query
        keyframeCount (bool?): Returns an int for the number of keys found for the  
                targets.  
                Properties: create, query
        lastSelected (bool?): When used in queries, this flag returns requested values  
                for the last selected key.  
                Properties: create, query
        name (bool?): Returns the names of animCurves of specified nodes,  
                attributes or keys.  
                Properties: create, query
        option (str?): Valid values are "move," "insert," "over," and  
                "segmentOver." When you "move" a key, the key will not cross over  
                (in time) any keys before or after it. When you "insert" a key,  
                all keys before or after (depending upon the -timeChange value)  
                will be moved an equivalent amount. When you "over" a key, the key  
                is allowed to move to any time (as long as a key is not there already).  
                When you "segmentOver" a set of keys (this option only has a  
                noticeable effect when more than one key is being moved) the first  
                key (in time) and last key define a segment (unless you specify a  
                time range). That segment is then allowed to move over other keys,  
                and keys will be moved to make room for the segment.  
                Properties: create, edit
        relative (bool?): Move amounts are relative to a key's current position.  
                Properties: create
        selected (bool?): When used in queries, this flag returns requested values  
                for any active keys.  
                Properties: create, query
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        tickDrawSpecial (bool?): Sets the special drawing state for this key when it  
                is drawn as a tick in the timeline.  
                Properties: create, edit
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        timeChange (Queryable[int]?): How much (with -relative) or where (with -absolute)  
                to move keys (on time-input animation curves)  
                along the x (time) axis.  Returns float[] when queried.  
                Properties: create, query, edit
        valueChange (Queryable[float]?): How much (with -relative) or where (with -absolute)  
                to move keys along the y (value) axis. Returns float[]  
                when queried.  
                Properties: create, query, edit

    Returns:
        int: (except where noted below)
            Number of curves on which keys were modified.
            In -query mode, the command can return a variety of things,
            as described with each queryable flag below.

    Example:
    """

def keyframeOutliner(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., animCurve: str = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., display: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates/edits/queries a keyframe outliner control.
    Args:
        animCurve (str?): Name of the animation curve for which to display keyframes.  
                Properties: edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        display (Queryable[str]?): narrow | wide  
                What columns to display.  When "narrow", time and value will  
                be displayed, when "wide" tangent information will be displayed  
                as well  
                Properties: query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the outliner control.

    Example:
    """

def keyframeRegionCurrentTimeCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command creates a context which may be used to change current time
    within the keyframe region of the dope sheet editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionDirectKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., option: str = ...) -> str:
    """This command creates a context which may be used to directly manipulate keyframes
    within the dope sheet editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        option (str?): Valid values are "move," "insert," "over," and  
                "segmentOver." When you "move" a key, the key will not cross over  
                (in time) any keys before or after it. When you "insert" a key,  
                all keys before or after (depending upon the -timeChange value)  
                will be moved an equivalent amount. When you "over" a key, the key  
                is allowed to move to any time (as long as a key is not there already).  
                When you "segmentOver" a set of keys (this option only has a  
                noticeable effect when more than one key is being moved) the first  
                key (in time) and last key define a segment (unless you specify a  
                time range). That segment is then allowed to move over other keys,  
                and keys will be moved to make room for the segment.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionDollyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command can be used to create a dolly context
    for the dope sheet editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionInsertKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., breakdown: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> Union[str, bool]:
    """This command creates a context which may be used to insert keys
    within the keyframe region of the dope sheet editor
    Args:
        breakdown (bool?): Specifies whether or not to create breakdown keys  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionMoveKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., option: Queryable[str] = ...) -> str:
    """This command creates a context which may be used to move keyframes
    within the keyframe region of the dope sheet editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        option (Queryable[str]?): Valid values are "move," "insert," "over," and  
                "segmentOver". Specifies the keyframe -option to use.  When you  
                "move" a key, the key will not cross over  
                (in time) any keys before or after it. When you "insert" a key,  
                all keys before or after (depending upon the -timeChange value)  
                will be moved an equivalent amount. When you "over" a key, the key  
                is allowed to move to any time (as long as a key is not there already).  
                When you "segmentOver" a set of keys (this option only has a  
                noticeable effect when more than one key is being moved) the first  
                key (in time) and last key define a segment (unless you specify a  
                time range). That segment is then allowed to move over other keys,  
                and keys will be moved to make room for the segment.  
                Properties: create, query, edit

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionScaleKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., scaleSpecifiedKeys: bool = ..., type: str = ...) -> Union[str, bool]:
    """This command creates a context which may be used to scale keyframes
    within the keyframe region of the dope sheet editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        scaleSpecifiedKeys (bool?): Determines if only the specified keys should be scaled. If false,  
                the non-selected keys will be adjusted during the scale. The default  
                is true.  
                Properties: query, edit
        type (str?): rect | manip  
                Specifies the type of scale manipulator to use  
                Properties: edit

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionSelectKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command creates a context which may be used to select keyframes
    within the keyframe region of the dope sheet editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionSetKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., breakdown: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> Union[str, bool]:
    """This command creates a context which may be used to set keys
    within the keyframe region of the dope sheet editor
    Args:
        breakdown (bool?): Specifies whether or not to create breakdown keys  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeRegionTrackCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command can be used to create a track context
    for the dope sheet editor.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name

    Example:
    """

def keyframeStats(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., animEditor: Queryable[str] = ..., annotation: Queryable[str] = ..., autoUnitWidth: Queryable[int] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., classicMode: bool = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: Queryable[int] = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., timeAnnotation: Queryable[str] = ..., useTemplate: str = ..., valueAnnotation: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, int, Tuple[float, float, float], bool, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates, edits, queries a keyframe stats control.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        animEditor (Queryable[str]?): The name of the animation editor which is associated with the control  
                Properties: query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        autoUnitWidth (Queryable[int]?): When this is non-zero the time fied widget will automatically scale  
                based on the unit time settings (frame or timecode). The value  
                of autoUnitWidth specifies the number of digits that should be  
                able to be displayed as the frame number. So a value of 4 will  
                make sure frame number 8723 can be displayed.  
                When the value is zero the normal widget width will be used.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        classicMode (bool?): Edit display mode. True means stats only, otherwise show time value.  
                Properties: query, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (Queryable[int]?): Controls the number of digits to the right of the decimal  
                point that will be displayed for float-valued channels.  
                Default is 3.  Queried, returns an int.  
                Properties: query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        timeAnnotation (Queryable[str]?): Annotate the time field with an extra string value.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        valueAnnotation (Queryable[str]?): Annotate the value field with an extra string value.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the stats control.

    Example:
    """

def keyframeTangentControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: Queryable[int] = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates, edits, queries a keyframe tangent control.
    The control displays fields for modifying the selected keyframe's tangent
    angle and weight.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (Queryable[int]?): Controls the number of digits to the right of the decimal  
                point that will be displayed.  
                Default is 3. Queried, returns an int.  
                Properties: query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the tangent control.

    Example:
    """

def keyingGroup(*args: str, edit: bool = ..., query: bool = ..., activator: Queryable[str] = ..., addElement: str = ..., afterFilters: bool = ..., anyMember: str = ..., category: Queryable[str] = ..., clear: str = ..., color: Queryable[int] = ..., copy: str = ..., edges: bool = ..., editPoints: bool = ..., empty: bool = ..., excludeDynamic: bool = ..., excludeRotate: bool = ..., excludeScale: bool = ..., excludeTranslate: bool = ..., excludeVisibility: bool = ..., facets: bool = ..., flatten: str = ..., forceElement: str = ..., include: str = ..., intersection: str = ..., isIntersecting: str = ..., isMember: str = ..., layer: bool = ..., minimizeRotation: bool = ..., name: str = ..., noIntermediate: bool = ..., noSurfaceShader: bool = ..., noWarnings: bool = ..., nodesOnly: bool = ..., remove: str = ..., removeActivator: str = ..., renderable: bool = ..., setActiveFilter: Queryable[str] = ..., size: bool = ..., split: str = ..., subtract: str = ..., text: Queryable[str] = ..., union: str = ..., vertices: bool = ...) -> Union[str, List[str], bool, int]:
    """This command is used to manage the membership of a keying group.  Keying
    groups allow users to effectively manage related keyframe data, allowing
    keys on attributes in the keying group to be set and edited as a single
    entity.
    Args:
        activator (Queryable[str]?): Sets the selected node(s) as activators for the given keying group.  
                In query mode, returns list of objects that activate the given keying group  
                Properties: query, edit
        addElement (str?): Adds the list of items to the given set.  If some of the  
                items cannot be added to the set because they are in another  
                set which is in the same partition as the set to edit, the  
                command will fail.  
                Properties: edit
        afterFilters (bool?): Default state is false. This flag is valid in edit mode only.  
                This flag is for use on sets that are acted on by deformers  
                such as sculpt, lattice, blendShape. The default edit mode  
                is to edit the membership of the group acted on by the deformer.  
                If you want to edit the group but not change the membership of  
                the deformer, set the flag to true.  
                Properties: edit
        anyMember (str?): An operation which tests whether any of the given items  
                are members of the given set.  
                Properties: create
        category (Queryable[str]?): Sets the keying group's category. This is what the global, active keying  
                group filter will use to match.  
                Properties: create, query, edit
        clear (str?): An operation which removes all items from the given set making  
                the set empty.  
                Properties: edit
        color (Queryable[int]?): Defines the hilite color of the set. Must be a value in  
                range [-1, 7] (one of the user defined colors).  -1 marks the  
                color has being undefined and therefore not having any affect.  
                Only the vertices of a vertex set will be displayed in this  
                color.  
                Properties: create, query, edit
        copy (str?): Copies the members of the given set to a new set.  
                This flag is for use in creation mode only.  
                Properties: create
        edges (bool?): Indicates the new set can contain edges only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query
        editPoints (bool?): Indicates the new set can contain editPoints only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query
        empty (bool?): Indicates that the set to be created should be empty. That is,  
                it ignores any arguments identifying objects to be added to  
                the set. This flag is only valid for operations that create a new set.  
                Properties: create
        excludeDynamic (bool?): When creating the keying group, exclude dynamic attributes.  
                Properties: create
        excludeRotate (bool?): When creating the keying group, exclude rotate attributes from  
                transform-type nodes.  
                Properties: create
        excludeScale (bool?): When creating the keying group, exclude scale attributes from  
                transform-type nodes.  
                Properties: create
        excludeTranslate (bool?): When creating the keying group, exclude translate attributes from  
                transform-type nodes. For example, if your keying group contains  
                joints only, perhaps you only want to include rotations in the  
                keying group.  
                Properties: create
        excludeVisibility (bool?): When creating the keying group, exclude visibility attribute from  
                transform-type nodes.  
                Properties: create
        facets (bool?): Indicates the new set can contain facets only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query
        flatten (str?): An operation that flattens the structure of the given set.  
                That is, any sets contained by the given set will be replaced by  
                its members so that the set no longer contains other sets but  
                contains the other sets' members.  
                Properties: edit
        forceElement (str?): For use in edit mode only. Forces addition of the items  
                to the set. If the items are in another set which is in the  
                same partition as the given set, the items will be removed  
                from the other set in order to keep the sets in the partition  
                mutually exclusive with respect to membership.  
                Properties: edit
        include (str?): Adds the list of items to the given set.  If some of the  
                items cannot be added to the set, a warning will be issued.  
                This is a less strict version of the -add/addElement operation.  
                Properties: edit
        intersection (str?): An operation that returns a list of items which are members of  
                all the sets in the list.  
                Properties: create
        isIntersecting (str?): An operation which tests whether the sets in the list have  
                common members.  
                Properties: create
        isMember (str?): An operation which tests whether all the given items  
                are members of the given set.  
                Properties: create
        layer (bool?): OBSOLETE. DO NOT USE.  
                Properties: create
        minimizeRotation (bool?): This flag only affects the attribute contained in the immediate keyingGroup.  
                It does not affect attributes in sub-keyingGroups.  
                Those will need to set minimizeRotation on their respective keyingGroups  
                Properties: create, query, edit
        name (str?): Assigns string as the name for a new set. This flag is  
                only valid for operations that create a new set.  
                Properties: create
        noIntermediate (bool?): Excludes intermediate objects when querying set members or  
                using the subtract, union, itersection, or isIntersecting  
                flags.  
                Properties: create, query
        noSurfaceShader (bool?): If set is renderable, do not connect it to the default surface  
                shader.  Flag has no meaning or effect for non renderable sets.  
                This flag is for use in creation mode only.  
                The default value is false.  
                Properties: create
        noWarnings (bool?): Indicates that warning messages should not be reported such  
                as when trying to add an invalid item to a set. (used by UI)  
                Properties: create
        nodesOnly (bool?): This flag is usable with the -q/query flag but is ignored if  
                used with another queryable flags. This flag modifies the results  
                of the set membership query such that  
                when there are attributes (e.g. sphere1.tx) or components of  
                nodes included in the set, only the nodes will be listed.  
                Each node will only be listed once, even if more than one attribute  
                or component of the node exists in the set.  
                Properties: query
        remove (str?): Removes the list of items from the given set.  
                Properties: edit
        removeActivator (str?): Removes the selected node(s) as activators for the given keying group.  
                Properties: edit
        renderable (bool?): This flag indicates that a special type of set should  
                be created. This type of set (shadingEngine as opposed to  
                objectSet) has certain restrictions on its membership in that  
                it can only contain renderable elements such as lights and  
                geometry. These sets are referred to as shading groups and  
                are automatically connected to the "renderPartition" node when  
                created (to ensure mutual exclusivity of the set's members with  
                the other sets in the partition).  
                This flag is for use in creation or query mode only.  
                The default value is false which means a normal set is  
                created.  
                Properties: create, query
        setActiveFilter (Queryable[str]?): Sets the global, active keying group filter, which will affect activation of  
                keying groups. Only keying groups with categories that match the filter will be  
                activated. If the setActiveFilter is set to "NoKeyingGroups", keying groups will  
                not be activated at all. If the setActiveFilter is set to "AllKeyingGroups", we  
                will activate any keying group rather than just those with matching categories.  
                Properties: create, query, edit
        size (bool?): Use the size flag to query the length of the set.  
                Properties: query
        split (str?): Produces a new set with the list of items and removes  
                each item in the list of items from the given set.  
                Properties: create
        subtract (str?): An operation between two sets which returns the members of the  
                first set that are not in the second set.  
                Properties: create
        text (Queryable[str]?): Defines an annotation string to be stored with the set.  
                Properties: create, query, edit
        union (str?): An operation that returns a list of all the members of all sets  
                listed.  
                Properties: create
        vertices (bool?): Indicates the new set can contain vertices only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query

    Returns:
        str: For creation operations (name of the keying group that was created or edited)
        List[str]: For query operation (names of items in the keying group)
        bool: For isMember operation

    Example:
    """

def lassoContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., drawClosed: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> Union[str, bool]:
    """Creates a context to perform selection via a "lasso".  Use for
    irregular selection regions, where the "marquee-style" select
    of the "selectContext" is inappropriate.
    Args:
        drawClosed (bool?): Turns the closed display of the lasso on/off.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Name of the context created

    Example:
    """

def lattice(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., commonParent: bool = ..., components: bool = ..., deformerTools: bool = ..., divisions: Queryable[Tuple[int, int, int]] = ..., dualBase: bool = ..., exclusive: Queryable[str] = ..., freezeMapping: bool = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., latticeReset: bool = ..., ldivisions: Queryable[Tuple[int, int, int]] = ..., minimumSize: float = ..., name: str = ..., objectCentered: bool = ..., outsideFalloffDistance: float = ..., outsideLattice: int = ..., parallel: bool = ..., position: Tuple[float, float, float] = ..., prune: bool = ..., remove: Multiuse[bool] = ..., removeTweaks: bool = ..., rotation: Tuple[float, float, float] = ..., scale: Tuple[float, float, float] = ..., selectedComponents: bool = ..., split: bool = ..., useComponentTags: bool = ...) -> Union[List[str], bool, Tuple[int, int, int], str, Multiuse[str]]:
    """This command creates a lattice deformer that will deform the selected
    objects. If the object centered flag is used, the initial lattice will
    fit around the selected objects. The lattice will be selected
    when the command is completed. The lattice deformer has an associated
    base lattice. Only objects which are contained by the base lattice
    will be deformed by the lattice.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        commonParent (bool?): Group the base lattice and the deformed lattice under  
                a common transform. This means that you can resize the lattice  
                without affecting the deformation by resizing the common  
                transform.  
                Properties: create
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        divisions (Queryable[Tuple[int, int, int]]?): Set the number of lattice slices in x, y, z. Default  
                is 2, 5, 2. When queried, this flag returns float float float.  
                When you change the number of divisions, any tweaking or  
                animation of lattice points must be redone.  
                Properties: create, query, edit
        dualBase (bool?): Create a special purpose ffd deformer node which  
                accepts 2 base lattices. The default is off which results  
                in the creation of a normal ffd deformer node.  
                Intended for internal usage only.  
                Properties: create
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        freezeMapping (bool?): The base position of the geometries points is fixed  
                at the time this flag is set.  When mapping is frozen, moving  
                the geometry with respect to the lattice will not cause the  
                deformation to be recomputed.  
                Properties: create, query, edit
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        latticeReset (bool?): Reset the lattice to match its base position. This will  
                undo any deformations that the lattice is causing. The lattice  
                will only deform points that are enclosed within the lattice's  
                reset (base) position.  
                Properties: edit
        ldivisions (Queryable[Tuple[int, int, int]]?): Set the number of local lattice slices in x, y, z.  
                Properties: create, query, edit
        minimumSize (float?): Set the minimum size of a side of the lattice during creation  
                using the objectCentered flag which causes the lattice size to  
                be determined from the geometry that is being deformed.  
                When f.e. the object is a flat plane this can avoid the lattice  
                to have size 0.0 along one side.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        objectCentered (bool?): Centers the lattice around the selected object(s) or  
                components. Default is off which centers the  
                lattice at the origin.  
                Properties: create
        outsideFalloffDistance (float?): Set the falloff distance used when the setting for  
                transforming points outside of the base lattice is set to 2.  
                The distance value is a positive number which specifies the  
                size of the falloff distance as a multiple of the base lattice  
                size, thus a value of 1.0 specifies that only points up to  
                the base lattice width/height/depth away are transformed.  
                A value of 0.0 is equivalent to an outsideLattice value of  
                0 (i.e. no points outside the base lattice are transformed).  
                A huge value is equivalent to transforming an outsideLattice  
                value of 1 (i.e. all points are transformed).  
                Properties: create
        outsideLattice (int?): Set the mode describing how points outside the base  
                lattice are transformed. 0 (the default) specifies that no  
                outside points are transformed. 1 specifies that all outside  
                points are transformed, and 2 specifies that only those  
                outside points which fall within the "falloff distance" (see  
                the -ofd/outsideFalloffDistance flag) are transformed. When  
                querying, the current setting for the lattice is returned.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        position (Tuple[float, float, float]?): Used to specify the position of the newly created lattice.  
                Properties: create
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        removeTweaks (bool?): Remove any lattice deformations caused by moving lattice  
                points. Translations/rotations and scales on the lattice itself  
                are not removed.  
                Properties: edit
        rotation (Tuple[float, float, float]?): Used to specify the initial rotation of the newly created lattice.  
                Properties: create
        scale (Tuple[float, float, float]?): Used to specify the initial scale of the newly created lattice.  
                Properties: create
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        List[str]: Ffd node name, lattice name, base lattice name.

    Example:
    """

def latticeDeformKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., envelope: Queryable[float] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., latticeColumns: Queryable[int] = ..., latticeRows: Queryable[int] = ..., name: str = ..., scaleLatticePts: bool = ...) -> Union[str, float, int, bool]:
    """This command creates a context which may be used to
    deform key frames with lattice manipulator.  This context
    only works in the graph editor.
    Args:
        envelope (Queryable[float]?): Specifies the influence of the lattice.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        latticeColumns (Queryable[int]?): Specifies the number column points the lattice contains.  
                Properties: query, edit
        latticeRows (Queryable[int]?): Specifies the number of rows the lattice contains.  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        scaleLatticePts (bool?): Specifies if the selected lattice points should scale  
                around the pick point. If this value is false the  
                the default operation is 'move'  
                Properties: query, edit

    Returns:
        str: Context name

    Example:
    """

def launch(*, directory: str = ..., movie: str = ..., pdfFile: str = ..., webPage: str = ...) -> bool:
    """Launch the appropriate application to open the document, web page or directory
    specified.
    Args:
        directory (str?): A directory.  
                Properties: create
        movie (str?): A movie file. The only acceptable movie file formats are MPEG,  
                Quicktime, and Windows Media file. The file's name must end  
                with .mpg, .mpeg, .mp4, .wmv, .mov, or .qt.  
                Properties: create
        pdfFile (str?): A PDF (Portable Document Format) document. The file's name must  
                end with .pdf.  
                Properties: create
        webPage (str?): A web page.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def launchImageEditor(*, editImageFile: str = ..., viewImageFile: str = ...) -> bool:
    """Launch the appropriate application to edit/view the image files specified.
    This command works only on the Macintosh and Windows platforms.
    Args:
        editImageFile (str?): If the file is a PSD, then the specified verison of Photoshop is launched,  
                and the file is opened in it. If file is any other image type,  
                then the preferred image editor is launched, and the file is opened in it.  
                Properties: create
        viewImageFile (str?): Opens up an Image editor to view images.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def layerButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., color: Tuple[float, float, float] = ..., command: Callable[..., Any] = ..., current: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., doubleClickCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., hideOnPlaybackCommand: Callable[..., Any] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., identification: Queryable[int] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelWidth: bool = ..., layerHideOnPlayback: bool = ..., layerState: Queryable[str] = ..., layerVisible: bool = ..., manage: bool = ..., name: Queryable[str] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., renameCommand: str = ..., select: bool = ..., statusBarMessage: str = ..., transparent: bool = ..., typeCommand: Callable[..., Any] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., visibleCommand: Callable[..., Any] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Creates a layer bar button widget.  This widget contains both the name of
    the layer to which it refers and a color swatch indicating it's color
    assignment.  It is used primarily in the construction of the layerBar
    and layer Editor window, being the widget used for each layer in the
    respective lists.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Set the command to call on a change of any kind.  
                Properties: create, edit
        color (Tuple[float, float, float]?): Layer color, specified with normalized real numbers in R, G,  
                B space.  
                Properties: create, edit
        command (Callable[..., Any]?): Set the command to call on a single click.  
                Properties: create, edit
        current (bool?): Set this button to display as the current layer.  The current  
                layer is the one which the user has the option of adding all newly  
                created objects into.  NB: Setting the layer button to this state  
                has no effect on the actual current layer.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Callable[..., Any]?): Set the command to call on a double click.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        hideOnPlaybackCommand (Callable[..., Any]?): Command that is called when the hide on playback indicator of  
                the layer button is pressed.  
                Properties: create, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        identification (Queryable[int]?): This is the integer identification number associated with  
                the layer.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the button.  
                Properties: create, query, edit
        labelWidth (bool?): Query the width of the label part so as to determine if  
                button clicks are in the label part or the colour swatch part.  
                Properties: query
        layerHideOnPlayback (bool?): Indicates whether the layer is visible or invisible during the playback.  
                Properties: create, query, edit
        layerState (Queryable[str]?): Describes the state of the layer.  This may be one of  
                normal, template, or reference.  
                Properties: create, query, edit
        layerVisible (bool?): Indicates whether the layer is visible or invisible.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        name (Queryable[str]?): Name of the layer.  
                Properties: create, query
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        renameCommand (str?): Set the command to call when the layer gets renamed. The string  
                '#1' will be substituted with the control's name and '#2' will be  
                replaced with the layer's new name.  
                Properties: create, edit
        select (bool?): Set this button to display as a selected layer.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        transparent (bool?): Indicate whether the layer color is visible or transparent.  
                Properties: create, query, edit
        typeCommand (Callable[..., Any]?): Command that is called when the type indicator of  
                the layer button is pressed.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        visibleCommand (Callable[..., Any]?): Command that is called when the visibility indicator of  
                the layer button is pressed.  
                Properties: create, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def layeredShaderPort(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., node: str = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., selectedColorControl: str = ..., selectedTransparencyControl: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a 3dPort that displays an image representing
    the layered shader node specified.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        node (str?): Specifies the name of the newLayeredShader  
                node this port will represent.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        selectedColorControl (str?): Specifies the name of the UI-control that  
                represents the currently selected layer's color.  
                Properties: create
        selectedTransparencyControl (str?): Specifies the name of the UI-control that  
                represents the currently selected layer's transparency.  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def layeredTexturePort(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., node: str = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., selectedAlphaControl: str = ..., selectedBlendModeControl: str = ..., selectedColorControl: str = ..., selectedIsVisibleControl: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a 3dPort that displays an image representing
    the layered texture node specified.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        node (str?): Specifies the name of the newLayeredTexture  
                node this port will represent.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        selectedAlphaControl (str?): Specifies the name of the UI-control that  
                represents the currently selected layer's alpha.  
                Properties: create
        selectedBlendModeControl (str?): Specifies the name of the UI-control that  
                represents the currently selected layer's blend mode.  
                Properties: create
        selectedColorControl (str?): Specifies the name of the UI-control that  
                represents the currently selected layer's color.  
                Properties: create
        selectedIsVisibleControl (str?): Specifies the name of the UI-control that  
                represents the currently selected layer's visibility.  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def layout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[bool, str, Tuple[float, float, float], int, Callable[..., Any]]:
    """This command allows you to edit or query the properties of any
    layout. The argument is the name of the layout.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def layoutDialog(*, backgroundColor: Tuple[float, float, float] = ..., dismiss: str = ..., parent: str = ..., title: str = ..., uiScript: Callable[..., Any] = ...) -> str:
    """The layoutDialog command creates a modal dialog containing a formLayout
    with 100 divisions. The formLayout can be populated with arbitrary UI
    elements through use of the '-ui/-uiScript' flag.NOTE:A layoutDialog is not a window and certain UI elements will not function
    properly within it. In particular menuBars and panels containing menuBars
    should not be used with the layoutDialog.
    Args:
        backgroundColor (Tuple[float, float, float]?): The background color of the dialog. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0. (Windows only flag)  
                Properties: create
        dismiss (str?): Dismiss the current layoutDialog. The specified string will  
                be set as the result of the initial layoutDialog command.  
                Properties: create
        parent (str?): Specify the parent window for the dialog.  The dialog will  
                be centered on this window and raise and lower with it's parent.  
                By default, the dialog is not parented to a particular window and  
                is simply centered on the screen.  
                Properties: create
        title (str?): The dialog title.  
                Properties: create
        uiScript (Callable[..., Any]?): The specified MEL procedure name will be invoked to build the  
                UI of the layoutDialog. This flag is required when creating  
                a layoutDialog.  
                The top-level control of a layoutDialog is a formLayout with  
                100 divisions. It can be accessed by calling 'setParent -q' at  
                the beginning of the specified MEL procedure.  
                Properties: create

    Returns:
        str: The string specified by the -dismiss flag, or "dismiss" if the dialog
            was closed.

    Example:
    """

def license(*, borrow: bool = ..., info: bool = ..., isBorrowed: bool = ..., isExported: bool = ..., isTrial: bool = ..., licenseMethod: bool = ..., productChoice: bool = ..., r: bool = ..., showBorrowInfo: bool = ..., showProductInfoDialog: bool = ..., status: bool = ..., usage: bool = ...) -> str:
    """This command displays version information about the application if it is
    executed without flags.  If one of the above flags is specified
    then the specified version information is returned.
    Args:
        borrow (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        info (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        isBorrowed (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        isExported (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        isTrial (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        licenseMethod (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        productChoice (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        r (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        showBorrowInfo (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        showProductInfoDialog (bool?): Show the Product Information Dialog  
                Properties: create
        status (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        usage (bool?): This flag is obsolete and no longer supported.  
                Properties: create

    Returns:
        str: The application's license information.

    Example:
    """

def licenseCheck(*, mode: str = ..., type: str = ...) -> None: ...
def lightList(*args: str, edit: bool = ..., query: bool = ..., add: str = ..., remove: str = ...) -> bool:
    """Add/Remove a relationship between an object and the
    current light.
    Soon to be replaced by the connect-attribute command.
    Args:
        add (str?): add object(s) to light list.  
                Properties: create
        remove (str?): remove object(s) to light list.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def lightlink(*args: str, query: bool = ..., b: bool = ..., hierarchy: bool = ..., light: Multiuse[str] = ..., make: bool = ..., object: Multiuse[str] = ..., sets: bool = ..., shadow: bool = ..., shapes: bool = ..., transforms: bool = ..., useActiveLights: bool = ..., useActiveObjects: bool = ...) -> Union[str, List[str]]:
    """This command is used to make, break and query light linking
    relationships between lights/sets of lights and objects/sets of
    objects.If no make, break or query flag is specified and both lights and
    objects flags are present, the make flag is assumed to be specified.If no make, break or query flag is specified and only one of the
    lights and objects flags is present, the query flag is assumed to be
    specified.You can specify as many lights and objects as you like, using the
    multiuse -light and -object flags.A better way to perform light linking is to make sets of lights and
    sets of geometry. If you create a set which contains lights (such as
    the ceiling lights in your scene) and a set which contains geometry
    (such as the geometry of your character), you can then link thecontaining lights with thecontaining geometry
    in order to get those lights to illuminate those pieces of geometry.
    In addition, you can add and remove lights and geometry from their
    respective sets without having to make and break light links.
    Args:
        b (bool?): The presence of this flag on the command indicates that the  
                command is being invoked to break links between lights and  
                renderable objects.  
                Properties: create
        hierarchy (bool?): When querying, specifies whether the result should include the  
                hierarchy of transforms above shapes linked to the queried  
                light/object. The transforms considered part of the hierarchy do  
                not include the transform immediately above the shape. Default  
                is true.  
                Properties: create
        light (Multiuse[str]?): The argument to the light flag specifies a node to be used by  
                the command in performing the action as if the node is a light.  
                This is a multiuse flag -- many light nodes can be specified in  
                a single invocation of the lightlink command.  
                Properties: create, multiuse
        make (bool?): The presence of this flag on the command indicates that the  
                command is being invoked to make links between lights and  
                renderable objects.  
                Properties: create
        object (Multiuse[str]?): The argument to the object flag specifies a node to be used by  
                the command in performing the action as if the node is an object.  
                This is a multiuse flag -- many object nodes can be specified in  
                a single invocation of the lightlink command.  
                Properties: create, multiuse
        sets (bool?): When querying, specifies whether the result should include sets  
                linked to the queried light/object. Default is true.  
                Properties: create
        shadow (bool?): Specify that shadows are to be linked.  
                Properties: create
        shapes (bool?): When querying, specifies whether the result should include shapes  
                linked to the queried light/object. Default is true.  
                Properties: create
        transforms (bool?): When querying, specifies whether the result should include  
                transforms immediately above shapes linked to the queried  
                light/object. Default is true.  
                Properties: create
        useActiveLights (bool?): Specify that active lights are to be used.  
                Properties: create
        useActiveObjects (bool?): Specify that active objects are to be used.  
                Properties: create

    Returns:
        str: Single element command result
        List[str]: Multi element command result

    Example:
    """

def linearPrecision(arg0: int = ..., /) -> bool:
    """This command controls the display of linear strings in the interface.
    (See the linearField command). Setting this affects any linear strings
    displayed afterwards, formatting them so they will show at most the
    specified number of digits after the decimal point. Allowed values are
    0 through 6.
    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def listAnimatable(*args: str, active: bool = ..., manip: bool = ..., manipHandle: bool = ..., shape: bool = ..., type: bool = ...) -> List[str]:
    """This command list the animatable attributes of a node.  Command flags
    allow filtering by the current manipulator, or node type.
    Args:
        active (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        manip (bool?): Return only those attributes affected by the current manip.  
                If there is no manip active and any other flags are  
                specified, output is the same as if the "-manip" flag were not present.  
                Properties: create
        manipHandle (bool?): Return only those attributes affected by the current manip handle.  
                If there is no manip handle active and any other flags are  
                specified, output is the same as if the "-manipHandle" flag were not present.  
                Properties: create
        shape (bool?): This flag is obsolete and no longer supported.  
                Properties: create
        type (bool?): Instead of returning attributes, Return the types of nodes that  
                are currently animatable.  
                Properties: create

    Returns:
        List[str]: All animatable attributes found

    Example:
    """

def listAttr(*args: str, array: bool = ..., attributeType: Multiuse[str] = ..., caching: bool = ..., category: Multiuse[str] = ..., changedSinceFileOpen: bool = ..., channelBox: bool = ..., connectable: bool = ..., extension: bool = ..., fromPlugin: bool = ..., fullNodeName: bool = ..., hasData: bool = ..., hasNullData: bool = ..., inUse: bool = ..., keyable: bool = ..., leaf: bool = ..., locked: bool = ..., multi: bool = ..., nodeName: bool = ..., output: bool = ..., ramp: bool = ..., read: bool = ..., readOnly: bool = ..., scalar: bool = ..., scalarAndArray: bool = ..., settable: bool = ..., shortNames: bool = ..., string: Multiuse[str] = ..., unlocked: bool = ..., usedAsFilename: bool = ..., userDefined: bool = ..., visible: bool = ..., write: bool = ...) -> List[str]:
    """This command lists the attributes of a node.  If no flags are specified
    all attributes are listed.
    Args:
        array (bool?): only list array (not multi) attributes  
                Properties: create
        attributeType (Multiuse[str]?): Return attributes of a particular type.  
                Properties: create, multiuse
        caching (bool?): only show attributes that are cached internally  
                Properties: create
        category (Multiuse[str]?): only show attributes belonging to the given category.  
                Category string can be a regular expression.  
                Properties: create, multiuse
        changedSinceFileOpen (bool?): Only list the attributes that have been changed  
                since the file they came from was opened. Typically useful  
                only for objects/attributes coming from referenced files.  
                Properties: create
        channelBox (bool?): only show non-keyable attributes that appear in the channelbox  
                Properties: create
        connectable (bool?): only show connectable attributes  
                Properties: create
        extension (bool?): list user-defined attributes for all nodes of this type (extension attributes)  
                Properties: create
        fromPlugin (bool?): only show attributes that were created by a plugin  
                Properties: create
        fullNodeName (bool?): Return full node name in result.  
                Properties: create
        hasData (bool?): list only attributes that have data (all attributes  
                except for message attributes)  
                Properties: create
        hasNullData (bool?): list only attributes that have null data.  
                This will list all attributes that have  
                data (see hasData flag) but the data value  
                is uninitialized.  
                A common example where an attribute may have null  
                data is when a string attribute is  
                created but not yet assigned an initial value.  
                Similarly array attribute data is often null until  
                it is initialized.  
                Properties: create
        inUse (bool?): only show attributes that are currently marked as in use. This flag indicates  
                that an attribute affects the scene data in some way. For example it has a  
                non-default value or it is connected to another attribute.  This is the  
                general concept though the precise implementation is subject to change.  
                Properties: create
        keyable (bool?): only show attributes that can be keyframed  
                Properties: create
        leaf (bool?): Only list the leaf-level name of the attribute.  
                controlPoints[44].xValue would be listed as "xValue".  
                Properties: create
        locked (bool?): list only attributes which are locked  
                Properties: create
        multi (bool?): list each currently existing element of a multi-attribute  
                Properties: create
        nodeName (bool?): Return node name in result.  
                Properties: create
        output (bool?): List only the attributes which are numeric or which  
                are compounds of numeric attributes.  
                Properties: create
        ramp (bool?): list only attributes which are ramps  
                Properties: create
        read (bool?): list only attributes which are readable  
                Properties: create
        readOnly (bool?): List only the attributes which are readable and not  
                writable.  
                Properties: create
        scalar (bool?): only list scalar numerical attributes  
                Properties: create
        scalarAndArray (bool?): only list scalar and array attributes  
                Properties: create
        settable (bool?): list attribute which are settable  
                Properties: create
        shortNames (bool?): list short attribute names (default is to list long names)  
                Properties: create
        string (Multiuse[str]?): List only the attributes that match the other  
                criteria AND match the string(s) passed from this flag.  
                String can be a regular expression.  
                Properties: create, multiuse
        unlocked (bool?): list only attributes which are unlocked  
                Properties: create
        usedAsFilename (bool?): list only attributes which are designated to be treated as filenames  
                Properties: create
        userDefined (bool?): list user-defined (dynamic) attributes  
                Properties: create
        visible (bool?): only show visible or non-hidden attributes  
                Properties: create
        write (bool?): list only attributes which are writable  
                Properties: create

    Returns:
        List[str]: : List of attributes matching criteria

    Example:
    """

def listAttrPatterns(*, patternType: bool = ..., verbose: bool = ...) -> List[str]:
    """Attribute patterns are plain text descriptions of an entire Maya attribute forest. ("forest"
    because there could be an arbitrary number of root level attributes, it's not restricted to
    having a single common parent though in general that practice is a good idea.)
    This command lists the various pattern types available, usually created via plugin, as well as
    any specific patterns that have already been instantiated. A pattern type is a thing that knows
    how to take some textual description of an attribute tree, e.g. XML or plaintext, and convert it
    into an attribute pattern that can be applied to any node or node type in Maya.attribute, pattern
    Args:
        patternType (bool?): If turned on then show the list of pattern types rather than actual instantiated patterns.  
                Properties: create
        verbose (bool?): If turned on then show detailed information about the patterns or pattern types.  
                The same list of instance or pattern names is returned as for the non-verbose case.  
                Properties: create

    Returns:
        List[str]: List of patterns or pattern instances available

    Example:
    """

def listCameras(*, orthographic: bool = ..., perspective: bool = ...) -> List[str]:
    """Command to list all cameras. If no flags are given, both
    perspective and orthographic cameras will be displayed. This
    command returns an array of camera names. When the transform name
    uniquely identifies the camera it is used, otherwise the shape
    name will be returned.
    Args:
        orthographic (bool?): Display all orthographic cameras.  
                Properties: create
        perspective (bool?): Display all perspective cameras.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def listConnections(*args: str, connections: bool = ..., destination: bool = ..., exactType: bool = ..., fullNodeName: bool = ..., plugs: bool = ..., shapes: bool = ..., skipConversionNodes: bool = ..., source: bool = ..., type: str = ...) -> List[str]:
    """This command returns a list of all attributes/objects of
    a specified type that are connected to the given object(s).
    If no objects are specified then the command lists the connections
    on selected nodes.connection, dg, dependency, graph, plug, connect
    Args:
        connections (bool?): If true, return both attributes involved in the connection. The one  
                on the specified object is given first.  Default false.  
                Properties: create
        destination (bool?): Give the attributes/objects that are on the "destination" side of  
                connection to the given object.  Default true.  
                Properties: create
        exactType (bool?): When set to true, -t/type only considers node of this exact  
                type. Otherwise, derived types are also taken into account.  
                Properties: create
        fullNodeName (bool?): Return full node name in result.  
                Properties: create
        plugs (bool?): If true, return the connected attribute names; if false, return the  
                connected object names only.  Default false;  
                Properties: create
        shapes (bool?): Actually return the shape name instead of the transform when the  
                shape is "selected".  Default false.  
                Properties: create
        skipConversionNodes (bool?): If true, skip over unit conversion nodes and return the  
                node connected to the conversion node on the other side.  Default false.  
                Properties: create
        source (bool?): Give the attributes/objects that are on the "source" side of  
                connection to the given object.  Default true.  
                Properties: create
        type (str?): If specified, only take objects of a specified type.  
                Properties: create

    Returns:
        List[str]: List of connection plugs/nodes

    Example:
    """

def listDeviceAttachments(*args: Any, attribute: str = ..., axis: str = ..., clutch: str = ..., device: str = ..., file: str = ..., selection: bool = ..., write: bool = ...) -> str:
    """This command lists the current set of device attachments.
    The listing is in the form of the commands required to
    recreate them.  This includes both attachments and device
    mappings.
    Args:
        attribute (str?): specify the attribute attachments to list  
                Properties: create
        axis (str?): specify the axis attachments to list  
                Properties: create
        clutch (str?): List only attachment clutched with this button  
                Properties: create
        device (str?): specify which device attachments to list  
                Properties: create
        file (str?): Specify the name of the file to write out device  
                attachments.  
                Properties: create
        selection (bool?): This flag list only attachments on selection  
                Properties: create
        write (bool?): Write out device attachments to a file specified  
                by the -f flag, is set.  If -f is not set, it'll  
                write out to a file named for the device.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def listHistory(*args: str, query: bool = ..., allConnections: bool = ..., allFuture: bool = ..., allGraphs: bool = ..., breadthFirst: bool = ..., fastIteration: bool = ..., fullNodeName: bool = ..., future: bool = ..., futureLocalAttr: bool = ..., futureWorldAttr: bool = ..., groupLevels: bool = ..., historyAttr: bool = ..., interestLevel: int = ..., leaf: bool = ..., levels: int = ..., pruneDagObjects: bool = ...) -> Union[List[str], bool]:
    """This command traverses backwards or forwards in the graph from
    the specified node and returns all of the nodes whose construction
    history it passes through. The construction history consists of
    connections to specific attributes of a node defined as the
    creators and results of the node's main data, eg. the curve for
    a Nurbs Curve node.For information on history connections through specific plugs use
    the "listConnections" command first to find where the history begins
    then use this command on the resulting node.
    Args:
        allConnections (bool?): If specified, the traversal that searches for the history or future will  
                not restrict its traversal across nodes to only dependent plugs.  
                Thus it will reach all upstream nodes (or all downstream nodes for f/future).  
                Properties: create
        allFuture (bool?): If listing the future, list all of it. Otherwise if a shape has  
                an attribute that represents its output geometry data, and that plug  
                is connected, only list the future history downstream from that  
                connection.  
                Properties: create
        allGraphs (bool?): This flag is obsolete and has no effect.  
                Properties: create
        breadthFirst (bool?): The breadth first traversal will return the closest nodes in the  
                traversal first. The depth first traversal will follow a complete  
                path away from the node, then return to any other paths from the  
                node. Default is depth first.  
                Properties: create
        fastIteration (bool?): This flag enables a faster iteration mode that offers more scalable performance,  
                especially when traversing nodes with numerous connections.  However, the results can  
                be slightly different, especially in cases with transitive dependencies between  
                attributes (attribute A is affected by B which is affected by C, but A is not  
                directly affected by C).  
                Properties: create
        fullNodeName (bool?): Return full node name in result.  
                Properties: create
        future (bool?): List the future instead of the history.  
                Properties: create
        futureLocalAttr (bool?): This flag allows querying of the local-space future-related attribute(s) on shape nodes.  
                Properties: query
        futureWorldAttr (bool?): This flag allows querying of the world-space future-related attribute(s) on shape nodes.  
                Properties: query
        groupLevels (bool?): The node names are grouped depending on the level.  > 1 is  
                the lead, the rest are grouped with it.  
                Properties: create
        historyAttr (bool?): This flag allows querying of the attribute where history connects on shape nodes.  
                Properties: query
        interestLevel (int?): If this flag is set, only nodes whose historicallyInteresting  
                attribute value is not less than the value will be listed.  
                The historicallyInteresting attribute is 0 on nodes which are  
                not of interest to non-programmers.  1 for the TDs, 2 for the users.  
                Properties: create
        leaf (bool?): If transform is selected, show history for its leaf  
                shape. Default is true.  
                Properties: create
        levels (int?): Levels deep to traverse. Setting the number of levels to  
                0 means do all levels. All levels is the default.  
                Properties: create
        pruneDagObjects (bool?): If this flag is set, prune at dag objects.  
                Properties: create

    Returns:
        List[str]: List of history nodes

    Example:
    """

def listInputDeviceAxes(*args: Any) -> List[str]:
    """This command lists all of the axes of the specified
    input device.
    Returns:
        List[str]: Command result

    Example:
    """

def listInputDeviceButtons(*args: Any) -> List[str]:
    """This command lists all of the buttons of the specified
    input device specified as an argument.
    Returns:
        List[str]: Command result

    Example:
    """

def listInputDevices(*args: Any, free: bool = ..., primary: bool = ..., secondary: bool = ...) -> List[str]:
    """This command lists all input devices that maya knows about.
    Args:
        free (bool?): List the free devices  
                Properties: create
        primary (bool?): List the primary devices  
                Properties: create
        secondary (bool?): List the secondary devices  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def listNodeTypes(arg0: str = ..., /, *, exclude: str = ...) -> List[str]:
    """Lists dependency node types satisfying a specified classification string.See the 'getClassification' command for a list of the standard classification
    strings.
    Args:
        exclude (str?): Nodes that satisfies this exclude classification will be filtered out.  
                Properties: create

    Returns:
        List[str]: The type names of all node types in the system that satisfy the
            given classification string.

    Example:
    """

def listNodesWithIncorrectNames() -> bool:
    """List all nodes with incorrect names in the Script Editor.
    Returns:
        bool:

    Example:
    """

def listRelatives(*args: str, allDescendents: bool = ..., allParents: bool = ..., children: bool = ..., fullPath: bool = ..., noIntermediate: bool = ..., parent: bool = ..., path: bool = ..., shapes: bool = ..., type: Multiuse[str] = ...) -> List[str]:
    """This command lists parents and children of DAG objects. The flags
    -c/children, -ad/allDescendents, -s/shapes, -p/parent and -ap/allParents
    are mutually exclusive. Only one can be used in a command.Unlike ls, this command does not return a unique path but simply returns
    the object's name by default. To get a unique path the -path flag must
    be used.When listing parents of objects directly under the world, the command
    will return an empty parent list. Listing parents of objects directly
    under a shape (underworld objects) will return their containing shape
    node in the list of parents. Listing parents of components of objects
    will return the object.When listing children, shape nodes will return their underworld
    objects in the list of children. Listing children of components of
    objects returns nothing.The -ni/noIntermediate flag works with the -s/shapes flag.
    It causes any intermediate shapes among the descendents to be ignored.
    Args:
        allDescendents (bool?): Returns all the children, grand-children etc. of  
                this dag node.  If a descendent is instanced,  
                it will appear only once on the list returned.  
                Note that it lists grand-children before children.  
                Properties: create
        allParents (bool?): Returns all the parents of this dag node. Normally, this  
                command only returns the parent corresponding to the first  
                instance of the object  
                Properties: create
        children (bool?): List all the children of this dag node (default).  
                Properties: create
        fullPath (bool?): Return full pathnames instead of object names.  
                Properties: create
        noIntermediate (bool?): No intermediate objects  
                Properties: create
        parent (bool?): Returns the parent of this dag node  
                Properties: create
        path (bool?): Return a proper object name that can be passed to other commands.  
                Properties: create
        shapes (bool?): List all the children of this dag node that are  
                shapes (ie, not transforms)  
                Properties: create
        type (Multiuse[str]?): List all relatives of the specified type.  
                Properties: create, multiuse

    Returns:
        List[str]: Command result

    Example:
    """

def listSets(*, allSets: bool = ..., extendToShape: bool = ..., object: str = ..., type: int = ...) -> List[str]:
    """The listSets command is used to get a list of all the sets an
    object belongs to. To get sets of a specific type for an object
    use the type flag as well.To get a list of all sets in the scene then don't use an object
    in the command line but use one of the flags instead.
    Args:
        allSets (bool?): Returns all sets in the scene.  
                Properties: create
        extendToShape (bool?): When requesting a transform's sets also walk down to the shape  
                immediately below it for its sets.  
                Properties: create
        object (str?): Returns all sets which this object is a member of.  
                Properties: create
        type (int?): Returns all sets in the scene of the given type:  
              
                1. all rendering sets  
                2. all deformer sets  
                Properties: create

    Returns:
        List[str]: (string array of all sets the object belongs to)

    Example:
    """

def loadFluid(*args: str, edit: bool = ..., query: bool = ..., currentTime: bool = ..., frame: Queryable[float] = ..., initialConditions: bool = ...) -> Union[bool, float]:
    """A command to set builtin fluid attributes such as Density, Velocity, etc
    for all cells in the grid from the initial state cachefluid
    Args:
        currentTime (bool?): This flag is now obsolete. Move the cache clip in the Trax editor to view different frames of the playback cache.  
                Properties: create, query, edit
        frame (Queryable[float]?): This flag is now obsolete. Move the cache clip in the Trax editor to view different frames of the playback cache.  
                Properties: create, query, edit
        initialConditions (bool?): load initial conditions cache  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def loadModule(*, allModules: bool = ..., load: str = ..., scan: bool = ...) -> List[str]:
    """Maya plug-ins may be installed individually within one of Maya's standard plug-in directories, or they may be packaged up with other resources in a "module". Each module resides in its own directory and provides a module definition file to make Maya aware of the plug-ins it provides.When Maya starts up it loads all of the module files it finds, making the module's plug-ins, scripts and other resources available for use. Note that the plug-ins themselves are not loaded at this time, Maya is simply made aware of them so that they can be loaded if needed.The loadModule command provides the ability to list and load any new modules which have been added since Maya started up, thereby avoiding the need to restart Maya before being able to use them.module
    Args:
        allModules (bool?): Load all new modules not yet loaded in Maya. New modules are the one returned by the -scan option.  
                Properties: create
        load (str?): Load the module specified by the module definition file.  
                Properties: create
        scan (bool?): Rescan module presence. Returns the list of module definition files found and not yet loaded into Maya. Does not load any of these newly found modules, nor change the Maya state.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def loadPlugin(*args: str, addCallback: Callable[..., Any] = ..., allPlugins: bool = ..., name: str = ..., quiet: bool = ..., removeCallback: Callable[..., Any] = ...) -> List[str]:
    """Load plug-ins into Maya. The parameter(s) to this command
    are either the names or pathnames of plug-in files.  The
    convention for naming plug-ins is to use a .so extension
    on Linux, a .mll extension on Windows and .bundle
    extension on Mac OS X. If no extension is provided then the default
    extension for the platform will be used. To load a Python plugin
    you must explicitly supply the '.py' extension.If the plugin was specified with a pathname then that is
    where the plugin will be searched for. If no pathname was
    provided then the current working directory (i.e. the one
    returned by Maya's 'pwd' command) will be searched, followed
    by the directories in the MAYA_PLUG_IN_PATH environment variable.When the plug-in is loaded, the name used in Maya's
    internal plug-in registry for the plug-in information will
    be the file name with the extension removed.  For example,
    if you load the plug-in "newNode.mll" the name used in
    the Maya's registry will be "newNode".  This value as
    well as that value with either a ".so", ".mll" or ".bundle"
    extension can be used as valid arguments to either the
    unloadPlugin or pluginInfo commands.
    Args:
        addCallback (Callable[..., Any]?): Add a MEL or Python callback script to be called after a plug-in is loaded.  
              
                For MEL, the procedure should have the following signature:  
                global proc procedureName(string $pluginName).  
              
                For Python, you may specify either a script as a string, or a Python callable  
                object such as a function.  If you specify a string, then put the formatting  
                specifier "%s" where you want the name of the plug-in to be inserted.  If you  
                specify a callable such as a function, then the name of the plug-in will be  
                passed as an argument.  
                Properties: create
        allPlugins (bool?): Cause all plug-ins in the search path specified  
                in MAYA_PLUG_IN_PATH to be loaded.  
                Properties: create
        name (str?): Set a user defined name for the plug-ins  
                that are loaded.  If the name is already taken, then a number  
                will be added to the end of the name to make it unique.  
                Properties: create
        quiet (bool?): Don't print a warning if you attempt to load a plug-in that  
                is already loaded.  
                Properties: create
        removeCallback (Callable[..., Any]?): Removes a procedure which was previously added  
                with -addCallback.  
                Properties: create

    Returns:
        List[str]: the internal names of the successfully loaded plug-ins

    Example:
    """

def loadPrefObjects() -> bool:
    """This command loads preference dependency nodes from "userPrefObjects.ma", if it
    exists, from the user preference directory.
    Returns:
        bool: True if successful.

    Example:
    """

def loadUI(*, listTypes: bool = ..., uiFile: str = ..., uiString: str = ..., verbose: bool = ..., workingDirectory: str = ...) -> str:
    """loadUI lets you generate a Maya user interface from a Qt user interface (.ui) file.
    While creating the interface, if a Qt widgetâ€™s class is recognized, and a Maya-equivalent exists,
    the Maya-equivalent widget will be used.
    Any dynamic widget properties starting with a â€˜-â€™ will be treated as a MEL key/value pair.
    Widget properties starting with a â€˜+â€™ will be treated as a Python key/value pair.
    Properties will be applied to the widget upon creation.
    For additional details about ui files, please refer to Qt docs.
    Args:
        listTypes (bool?): Returns the list of recognized UI types and their associated Maya command.  
                Properties: create
        uiFile (str?): Full path to a user interface file to load.  
                Properties: create
        uiString (str?): Load UI from a formated string.  
                Properties: create
        verbose (bool?): Extra information about created controls will be printed.  
                Properties: create
        workingDirectory (str?): Sets the working directory, the loader looks for resources  
                such as icons and resouce files in paths relative to this directory.  
                Properties: create

    Returns:
        str: Full path name to the root control.

    Example:
    """

def lockNode(*args: str, query: bool = ..., ignoreComponents: bool = ..., lock: bool = ..., lockName: bool = ..., lockUnpublished: bool = ...) -> Union[None, List[bool], bool]:
    """Locks or unlocks one or more dependency nodes. A locked node is restricted
    in the following ways:Note that an unlocked attribute of a locked node may still have its value
    set, or connections to it made or broken. For more information on attribute
    locking, see thecommand.If no node names are specified then the current selection list is used.There are a few special behaviors when locking containers. Containers are
    automatically expanded to their constituent objects. When a container is
    locked, members of the container may not be unlocked and the container
    membership may not be modified. Containers may also be set to lock unpublished
    attributes. When in this state, unpublished member attributes may not have
    existing connections broken, new connections cannot be made, and values on unconnected
    attributes may not be modified. Parenting is allowed to change on members of locked
    containers that have been published as parent or child anchors.node, dependency, graph, lock
    Args:
        ignoreComponents (bool?): Normally, the presence of a component in the list of objects to be locked  
                will cause the command to fail with an error. But if this flag is supplied  
                then components will be silently ignored.  
                Properties: create, query
        lock (bool?): Specifies the new lock state for the node. The default is true.  
                Properties: create, query
        lockName (bool?): Specifies the new lock state for the node's name.  
                Properties: create, query
        lockUnpublished (bool?): Used in conjunction with the lock flag. On a container, lock or unlock all  
                unpublished attributes on the members of the container. For non-containers,  
                lock or unlock unpublished attributes on the specified node.  
                Properties: create, query

    Returns:
        None: For regular command execution.
        List[bool]: For query execution.

    Example:
    """

def loft(*args: str, edit: bool = ..., query: bool = ..., autoReverse: bool = ..., caching: bool = ..., close: bool = ..., createCusp: Queryable[Multiuse[bool]] = ..., degree: Queryable[int] = ..., nodeState: Queryable[int] = ..., reverse: Queryable[Multiuse[bool]] = ..., reverseSurfaceNormals: bool = ..., sectionSpans: Queryable[int] = ..., uniform: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., range: bool = ..., rebuild: bool = ...) -> Union[List[str], bool, Multiuse[bool], int]:
    """This command computes a skinned (lofted) surface passing through
    a number of NURBS curves. There must be at least two curves
    present. The NURBS curves may be surface isoparms, curve on
    surfaces, trimmed edges or polygon edges.
    Args:
        autoReverse (bool?): If set to true, the direction of the curves for the loft is computed automatically.  If set to false, the values of the multi-use reverse flag are used instead.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        close (bool?): If set to true, the resulting surface will be closed (periodic) with the start (end) at the first curve.  If set to false, the surface will remain open.  
                Default: false  
                Properties: create, query, edit
        createCusp (Queryable[Multiuse[bool]]?): Multi-use flag; each occurence of the flag refers to the matching curve in the loft operation; if the flag is set the particular profile will have a cusp (tangent break) in the resulting surface.  
                Default: false  
                Properties: create, query, edit, multiuse
        degree (Queryable[int]?): The degree of the resulting surface  
                Default: 3  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        reverse (Queryable[Multiuse[bool]]?): Multi-use flag; each occurence of the flag refers to the matching curve in the loft operation; if the flag is set the particular curve will be reversed before being used in the loft operation.  
                Default: false  
                Properties: create, query, edit, multiuse
        reverseSurfaceNormals (bool?): If set, the surface normals on the output NURBS surface will be reversed.  This is accomplished by swapping the U and V parametric directions.  
                Default: false  
                Properties: create, query, edit
        sectionSpans (Queryable[int]?): The number of surface spans between consecutive curves in the loft.  
                Default: 1  
                Properties: create, query, edit
        uniform (bool?): If set to true, the resulting surface will have uniform parameterization in the loft direction.  If set to false, the parameterization will be chord length.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        rebuild (bool?): Rebuild the input curve(s) before using them in the operation.  Use nurbsCurveRebuildPref to set the parameters for the conversion.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def lookThru(arg0: str = ..., arg1: str = ..., /, *, query: bool = ..., farClip: float = ..., nearClip: float = ...) -> bool:
    """This command sets a particular camera to look through in a view. This
    command may also be used to view the negative z axis of lights or
    other DAG objects. The standard camera tools can then be used to place
    the object.Note: if there are multiple objects under the transform selected,
    cameras and lights take precedence.
    Args:
        farClip (float?): Used when setting clip far plane for a new look thru camera. Will  
                not affect the attributes of an existing camera.  
                Clip values must come before shape or view.  
                Properties: create
        nearClip (float?): Used when setting near clip plane for a new look thru camera. Will  
                not affect the attributes of an existing camera.  
                Clip values must come before shape or view.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def ls(*args: str, absoluteName: bool = ..., allPaths: bool = ..., assemblies: bool = ..., cameras: bool = ..., containerType: Multiuse[str] = ..., containers: bool = ..., dagObjects: bool = ..., defaultNodes: bool = ..., dependencyNodes: bool = ..., exactType: Multiuse[str] = ..., excludeType: Multiuse[str] = ..., flatten: bool = ..., geometry: bool = ..., ghost: bool = ..., head: int = ..., hilite: bool = ..., intermediateObjects: bool = ..., invisible: bool = ..., leaf: bool = ..., lights: bool = ..., live: bool = ..., lockedNodes: bool = ..., long: bool = ..., materials: bool = ..., modified: bool = ..., noIntermediate: bool = ..., nodeTypes: bool = ..., objectsOnly: bool = ..., orderedSelection: bool = ..., partitions: bool = ..., persistentNodes: bool = ..., planes: bool = ..., preSelectHilite: bool = ..., readOnly: bool = ..., recursive: bool = ..., referencedNodes: bool = ..., references: bool = ..., renderGlobals: bool = ..., renderQualities: bool = ..., renderResolutions: bool = ..., renderSetups: bool = ..., selection: bool = ..., sets: bool = ..., shapes: bool = ..., shortNames: bool = ..., showNamespace: bool = ..., showType: bool = ..., tail: int = ..., templated: bool = ..., textures: bool = ..., transforms: bool = ..., type: Multiuse[str] = ..., ufeObjects: bool = ..., undeletable: bool = ..., untemplated: bool = ..., uuid: bool = ..., visible: bool = ...) -> List[str]:
    """Thecommand returns the names (and
    optionally the type names) of objects in the scene.The most common use ofis to filter or
    match objects based on their name (using wildcards) or based on their
    type.
    By defaultwill match any object in the
    scene but it can also be used to filter or list the selected
    objects when used in conjunction with the -selection flag.If type names are requested, using the showType flag, they
    will be interleaved with object names so the result will be
    pairs ofvalues.Internal nodes (for example itemFilter nodes) are typically filtered
    so that only scene objects are returned. However, using a wildcard
    will cause all the nodes matching the wild card to show up, including
    internal nodes.  For example,will list all
    nodes whether internal or not.Use the syntax "::" to denote a recursive namespace search when listing nodes.
    For example,would match objects named
    "pSphere1" in any namespace, at any depth.would match any node in namespace "ns" or children namespaces.When Maya is in relativeNames mode, thecommand
    will return namesto the current namespace andwill list from the the current namespace.
    For more details, please refer to theflag of thecommand.The command may also be passed node UUIDs instead of names/paths, and
    can return UUIDs instead of names via the -uuid flag.
    Args:
        absoluteName (bool?): This flag can be used in conjunction with the showNamespace flag to specify  
                that the namespace(s) returned by the command be in absolute namespace format.  
                The absolute name of the namespace is a full namespace path, starting from the root namespace ":"  
                and including all parent namespaces.  For example ":ns:ball" is an absolute namespace  
                name while "ns:ball" is not.  
                The absolute namespace name is invariant and is not affected by the current namespace or  
                relative namespace modes.  
                Properties: create
        allPaths (bool?): List all paths to nodes in DAG. This flag only works  
                if -dag is also specified or if an object name is  
                supplied.  
                Properties: create
        assemblies (bool?): List top level transform Dag objects  
                Properties: create
        cameras (bool?): List camera shapes.  
                Properties: create
        containerType (Multiuse[str]?): List containers with the specified user-defined type.  
                 This flag cannot be used in conjunction with the type or exactType flag.  
                Properties: create, multiuse
        containers (bool?): List containers. Includes both standard containers as well as other types of  
                containers such as dagContainers.  
                Properties: create
        dagObjects (bool?): List Dag objects of any type. If object name arguments are  
                passed to the command then this flag will list all Dag objects  
                below the specified object(s).  
                Properties: create
        defaultNodes (bool?): Returns default nodes.  
                A default node is one that Maya creates automatically and does not get  
                saved out with the scene, although some of its attribute values may.  
                Properties: create
        dependencyNodes (bool?): List dependency nodes. (including Dag objects)  
                Properties: create
        exactType (Multiuse[str]?): List all objects of the specified type, but not objects that are  
                descendents of that type. This flag can appear  
                multiple times on the command line. Note: the type passed to  
                this flag is the same type name returned from the showType  
                flag.  
                 This flag cannot be used in conjunction with the type or excludeType flag.  
                Properties: create, multiuse
        excludeType (Multiuse[str]?): List all objects that are not of the specified type.  
                This flag can appear multiple times on the command line. Note: the type passed to  
                this flag is the same type name returned from the showType flag.  
                 This flag cannot be used in conjunction with the type or exactType flag.  
                Properties: create, multiuse
        flatten (bool?): Flattens the returned list of objects so that each component  
                is identified individually.  
                Properties: create
        geometry (bool?): List geometric Dag objects.  
                Properties: create
        ghost (bool?): List ghosting objects.  
                Properties: create
        head (int?): This flag  specifies the maximum number of elements to be  
                returned from the beginning of the list of items.  
                Note: each type flag will return at most this many items so  
                if multiple type flags are specified then the number of items  
                returned can be greater than this amount.  
                Properties: create
        hilite (bool?): List objects that are currently hilited for component selection.  
                Properties: create
        intermediateObjects (bool?): List only intermediate dag nodes.  
                Properties: create
        invisible (bool?): List only invisible dag nodes.  
                Properties: create
        leaf (bool?): List all leaf nodes in Dag. This flag is a modifier and must  
                be used in conjunction with the -dag flag.  
                Properties: create
        lights (bool?): List light shapes.  
                Properties: create
        live (bool?): List objects that are currently live.  
                Properties: create
        lockedNodes (bool?): Returns locked nodes, which cannot be deleted or renamed. However, their status may change.  
                Properties: create
        long (bool?): Return full path names for Dag objects. By default the  
                shortest unique name is returned.  
                Properties: create
        materials (bool?): List materials or shading groups.  
                Properties: create
        modified (bool?): When this flag is set, only nodes modified since the last save will be returned.  
                Properties: create
        noIntermediate (bool?): List only non intermediate dag nodes.  
                Properties: create
        nodeTypes (bool?): Lists all registered node types.  
                Properties: create
        objectsOnly (bool?): When this flag is set only object names will be returned and  
                components/attributes will be ignored.  
                Properties: create
        orderedSelection (bool?): List objects and components that are currently selected in their order of selection.  This flag depends  
                on the value of the -tso/trackSelectionOrder flag of the selectPref command.  If that flag is not  
                enabled than this flag will return the same thing as the -sl/selection flag would.  
                Properties: create
        partitions (bool?): List partitions.  
                Properties: create
        persistentNodes (bool?): Returns persistent nodes, which are nodes that stay in the Maya session after a file > new.  
                These are a special class of default nodes that do not get reset on file > new.  
                Ex: itemFilter and selectionListOperator nodes.  
                Properties: create
        planes (bool?): List construction plane shapes.  
                Properties: create
        preSelectHilite (bool?): List components that are currently hilited for pre-selection.  
                Properties: create
        readOnly (bool?): Returns referenced nodes. Referenced nodes are read only.  
                NOTE: Obsolete. Please use "-referencedNodes".  
                Properties: create
        recursive (bool?): When set to true, this command will look for name matches  
                in all namespaces. When set to false, this command will only look  
                for matches in namespaces that are requested (e.g. by specifying  
                a name containing the ':'... "ns1. pSphere1").  
                Properties: create
        referencedNodes (bool?): Returns referenced nodes. Referenced nodes are read only.  
                Properties: create
        references (bool?): List references associated with files. Excludes special reference  
                nodes such as the sharedReferenceNode and unknown reference nodes.  
                Properties: create
        renderGlobals (bool?): List render globals.  
                Properties: create
        renderQualities (bool?): List named render qualities.  
                Properties: create
        renderResolutions (bool?): List render resolutions.  
                Properties: create
        renderSetups (bool?): Alias for -renderGlobals.  
                Properties: create
        selection (bool?): List objects that are currently selected.  
                Properties: create
        sets (bool?): List sets.  
                Properties: create
        shapes (bool?): List shape objects.  
                Properties: create
        shortNames (bool?): Return short attribute names. By default long attribute names  
                are returned.  
                Properties: create
        showNamespace (bool?): Show the namespace of each object after the object name.  
                 This flag cannot be used in conjunction with the showType flag.  
                Properties: create
        showType (bool?): List the type of each object after its name.  
                Properties: create
        tail (int?): This flag specifies the maximum number of elements to be  
                returned from the end of the list of items.  
                Note: each    type flag will return at most this many items so  
                if multiple type flags are specified then the number of items  
                returned can be greater than this amount  
                Properties: create
        templated (bool?): List only templated dag nodes.  
                Properties: create
        textures (bool?): List textures.  
                Properties: create
        transforms (bool?): List transform objects.  
                Properties: create
        type (Multiuse[str]?): List all objects of the specified type. This flag can appear  
                multiple times on the command line. Note: the type passed to  
                this flag is the same type name returned from the showType  
                flag. Note: some selection items in Maya do not have a specific  
                object/data type associated with them and will return "untyped"  
                when listed with this flag.  
                 This flag cannot be used in conjunction with the exactType or excludeType flag.  
                Properties: create, multiuse
        ufeObjects (bool?): When used in conjunction with the -sl/selection flag, will return objects that are  
                defined through the UFE interface as well as native Maya objects.  
                Properties: create
        undeletable (bool?): Returns nodes that cannot be deleted (which includes locked nodes). These nodes also cannot be renamed.  
                Properties: create
        untemplated (bool?): List only un-templated dag nodes.  
                Properties: create
        uuid (bool?): Return node UUIDs instead of names.  
                Note that there are no "UUID paths" - combining this  
                flag with e.g. the -long flag will not result in a path  
                formed of node UUIDs.  
                Properties: create
        visible (bool?): List only visible dag nodes.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def lsThroughFilter(arg0: str = ..., /, *args: str, item: Multiuse[str] = ..., nodeArray: bool = ..., reverse: bool = ..., selection: bool = ..., sort: str = ...) -> List[str]:
    """List all objects in the world that pass a given filter.
    Args:
        item (Multiuse[str]?): Run the filter on specified node(s), using the fast  
                version of this command.  
                Properties: create, multiuse
        nodeArray (bool?): Fast version that runs an entire array of  
                nodes through the filter at one time.  
                Properties: create
        reverse (bool?): Only available in conjunction with nodeArray flag.  
                Reverses the order of nodes in the returned arrays if true.  
                Properties: create
        selection (bool?): Run the filter on selected nodes only, using the fast  
                version of this command.  
                Properties: create
        sort (str?): Only available in conjunction with nodeArray flag.  
                Orders the nodes in the returned array. Current options are:  
                "byName", "byType", and "byTime".  
                Properties: create

    Returns:
        List[str]: List of nodes passing the filter

    Example:
    """

def lsUI(*args: str, cmdTemplates: bool = ..., collection: bool = ..., contexts: bool = ..., controlLayouts: bool = ..., controls: bool = ..., dumpWidgets: bool = ..., editors: bool = ..., head: int = ..., long: bool = ..., menuItems: bool = ..., menus: bool = ..., numWidgets: bool = ..., panels: bool = ..., radioMenuItemCollections: bool = ..., tail: int = ..., type: Multiuse[str] = ..., windows: bool = ..., workspaceControls: bool = ...) -> List[str]:
    """This command returns the names of UI objects.
    Args:
        cmdTemplates (bool?): UI command templates created using ELF UI commands.  
                Properties: create
        collection (bool?): Control collections created using ELF UI commands.  
                Properties: create
        contexts (bool?): Tool contexts created using ELF UI commands.  
                Properties: create
        controlLayouts (bool?): Control layouts created using ELF UI commands [e.g. formLayouts, paneLayouts, etc.]  
                Properties: create
        controls (bool?): Controls created using ELF UI commands. [e.g. buttons, checkboxes, etc]  
                Properties: create
        dumpWidgets (bool?): Dump all QT widgets used by Maya.  
                Properties: create
        editors (bool?): All currently existing editors.  
                Properties: create
        head (int?): The parameter specifies the maximum number of elements to be returned  
                from the beginning of the list of items. (Note: each flag  
                will return at most this many items so if multiple flags are specified  
                then the number of items returned will be greater than the value  
                specified).  
                Properties: create
        long (bool?): Use long pathnames instead of short non-path names.  
                Properties: create
        menuItems (bool?): Menu items created using ELF UI commands.  
                Properties: create
        menus (bool?): Menus created using ELF UI commands.  
                Properties: create
        numWidgets (bool?): Reports the number of QT widgets used by Maya.  
                Properties: create
        panels (bool?): All currently existing panels.  
                Properties: create
        radioMenuItemCollections (bool?): Menu item collections created using ELF UI commands.  
                Properties: create
        tail (int?): The parameter specifies the maximum number of elements to be returned  
                from the end of the list of items. (Note: each flag  
                will return at most this many items so if multiple flags are specified  
                then the number of items returned will be greater than the value  
                specified).  
                Properties: create
        type (Multiuse[str]?): List all objects of a certain type specified by the string argument.  
                For example, "window", "menu", "control", or "controlLayout".  
                Properties: create, multiuse
        windows (bool?): Windows created using ELF UI commands.  
                Properties: create
        workspaceControls (bool?): Workspace controls created using ELF UI commands.  
                Properties: create

    Returns:
        List[str]: The names of the object arguments.

    Example:
    """

def makeIdentity(*args: str, apply: bool = ..., jointOrient: bool = ..., normal: int = ..., preserveNormals: bool = ..., rotate: bool = ..., scale: bool = ..., translate: bool = ...) -> bool:
    """The makeIdentity command is a quick way to reset the selected
    transform and all of its children down to the shape level by the
    identity transformation.  You can also specify which of transform,
    rotate or scale is applied down from the selected transform.
    The identity transformation means:If a transform is a joint, then the "translate" attribute may not be 0,
    but will be used to position the joints so that they preserve their
    world space positions.  The translate flag doesn't apply to joints,
    since joints must preserve their world space positions.  Only the rotate
    and scale flags are meaningful when applied to joints.If the -a/apply flag is true, then the transforms that are reset
    are accumulated and applied to the all shapes below the modified
    transforms, so that the shapes will not move. The pivot positions are
    recalculated so that they also will not move in world space.
    If this flag is false, then the transformations are reset to identity,
    without any changes to preserve position.
    Args:
        apply (bool?): If this flag is true, the accumulated transforms are applied to  
                the shape after the transforms are made identity, such that the  
                world space positions of the transforms pivots are preserved,  
                and the shapes do not move. The default is false.  
                Properties: create
        jointOrient (bool?): If this flag is set, the joint orient on joints will be reset  
                to align with worldspace.  
                Properties: create
        normal (int?): If this flag is set to 1, the normals on polygonal objects  
                will be frozen.  This flag is valid only when the -apply flag is on.  
                If this flag is set to 2, the normals on polygonal objects will  
                be frozen only if its a non-rigid transformation matrix.  
                ie, a transformation that does not contain shear, skew or  
                non-proportional scaling.  
                The default behaviour is not to freeze normals.  
                Properties: create
        preserveNormals (bool?): If this flag is true, the normals on polygonal objects will be  
                reversed if the objects are negatively scaled (reflection).  
                This flag is valid only when the -apply flag is on.  
                Properties: create
        rotate (bool?): If this flag is true, only the rotation is applied to the shape.  
                The rotation will be changed to 0, 0, 0.  
                If neither translate nor rotate nor scale flags are specified,  
                then all (t, r, s) are applied.  
                Properties: create
        scale (bool?): If this flag is true, only the scale is applied to the shape.  
                The scale factor will be changed to 1, 1, 1.  
                If neither translate nor rotate nor scale flags are specified,  
                then all (t, r, s) are applied.  
                Properties: create
        translate (bool?): If this flag is true, only the translation is applied to the shape.  
                The translation will be changed to 0, 0, 0.  
                If neither translate nor rotate nor scale flags are specified,  
                then all (t, r, s)  are applied.  (Note: the translate flag is not  
                meaningful when applied to joints, since joints are made to preserve  
                their world space position.  This flag will have no effect on joints.)  
                Properties: create

    Returns:
        bool:

    Example:
    """

def makeLive(*args: str, edit: bool = ..., query: bool = ..., addObjects: bool = ..., none: bool = ..., registry: Queryable[int] = ..., registryCount: bool = ..., registryReset: bool = ..., registrySize: Queryable[int] = ..., removeObjects: bool = ...) -> Union[bool, int]:
    """This commmand makes one or several objects live.  A live object defines the
    surface on which to create objects and to move objects relative to.
    Only construction planes, nurbs surfaces and polygon meshes can be made live.The makeLive command expects one of these types of objects as an explicit
    argument.  If no argument is explicitly specified, then there are a number
    of default behaviours based on what is currently active.  The command will
    fail if the active object(s) is/are not one of the valid types of objects.
    If there is nothing active, the current live object(s) will become dormant.
    Otherwise, the active object(s) will become the live object(s).The command allows for a limited number of objects collections to be saved
    in a registry entry. These collections can be queried and/or made live.
    Args:
        addObjects (bool?): Add the listed object(s) to the current live list.  
                If an object is already in the live list, it is ignored.  
                Properties: edit
        none (bool?): If the -n/none flag, the live object(s) will become dormant.  
                Use of this flag causes any arguments to be ignored.  
                Properties: create
        registry (Queryable[int]?): Make live the objects defined in the specified registry entry.  
                In Query mode, return the list of objects defined in the specified registry entry.  
                Properties: create, query
        registryCount (bool?): Return the actual number of registry entries.  
                This number ranges from 0 to 'registrySize' - 1.  
                Properties: query
        registryReset (bool?): Reset the maximum number of registry entries to the default value and clear all stored data.  
                Properties: create
        registrySize (Queryable[int]?): Defines the maximum number of registry entries that are remembered by the command.  
                In Query mode, returns the maximum number currently set.  
                Properties: create, query
        removeObjects (bool?): Remove the listed object(s) from the current live list.  
                If an object is not in the list, it is ignored.  
                Properties: edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def makePaintable(arg0: str = ..., arg1: str = ..., /, *, query: bool = ..., activate: bool = ..., activateAll: bool = ..., altAttribute: Queryable[Multiuse[str]] = ..., attrType: Queryable[str] = ..., clearAll: bool = ..., remove: bool = ..., shapeMode: Queryable[str] = ..., uiName: Queryable[str] = ...) -> Union[bool, Multiuse[str], str]:
    """Make attributes of nodes paintable to Attribute Paint Tool.
    This command is used to register new attributes to the
    Attribute Paint tool as paintable. Once registered the
    attributes will be recognized by the Attribute Paint tool
    and the user will be able to paint them.attributes, paint
    Args:
        activate (bool?): Activate / deactivate the given paintable attribute. Used  
                to filter out some nodes in the attribute paint tool.  
                Properties: create, query
        activateAll (bool?): Activate / deactivate all the registered paintable attributes. Used  
                to filter out some nodes in the attribute paint tool.  
                Properties: create, query
        altAttribute (Queryable[Multiuse[str]]?): Define an alternate attribute which will also receive the same  
                values. There can be multiple such flags.  
                Properties: create, query, multiuse
        attrType (Queryable[str]?): Paintable attribute type.  
                   Supported types: intArray, doubleArray, vectorArray, multiInteger, multiFloat, multiDouble, multiVector.  
                Properties: create, query
        clearAll (bool?): Removes all paintable attribute definitions.  
                Properties: create, query
        remove (bool?): Make the attribute not paintable any more.  
                Properties: create, query
        shapeMode (Queryable[str]?): This flag controls how Artisan correlates the paintable node to a  
                corresponding shape node.  It is used for attributes of type multi  
                of multi, where the first multi dimension corresponds to the shape  
                index (i.e. cluster nodes). At present, only one value of this flag  
                is supported: "deformer". By default this flag is an empty string,  
                which means that there is a direct indexing (no special mapping  
                required) of the attribute with respect to vertices on the shape.  
                Properties: create, query
        uiName (Queryable[str]?): UI name. Default is the attribute name.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def makeSingleSurface(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., stitchTolerance: float = ...) -> Union[List[str], bool, int]:
    """This command performs a stitch and tessellate operation.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        stitchTolerance (float?): Stitch tolerance.  
                Default: 0.1  
                Properties: edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def makebot(*, checkdepends: bool = ..., checkres: int = ..., input: str = ..., nooverwrite: bool = ..., output: str = ..., verbose: bool = ...) -> bool:
    """The makebot command takes an image file and produces a block
    ordered texture (BOT) file, to be used for texture caching.
    If a relative pathname is specified for the input image file,
    project management rules apply.  If a relative pathname is
    specified for the output BOT file, project management rules
    apply and gets put into the sourceImages directory.
    Args:
        checkdepends (bool?): the BOT file should only be generated if it doesn't already exists,  
                or if it is older than the source file  
                Properties: create
        checkres (int?): the BOT file should only be generated if its resolution (maximum of  
                width and height) is larger than the minimum value specified by the  
                argument  
                Properties: create
        input (str?): input image file  
                Properties: create
        nooverwrite (bool?): If -c and/or -r indicate that the BOT file should be generated but  
                if already exists, then this flag will prevent the file from being  
                overwritten  
                Properties: create
        output (str?): output BOT file  
                Properties: create
        verbose (bool?): Makebot will provide feedback if this flag is specified  
                Properties: create

    Returns:
        bool:

    Example:
    """

def manipComponentPivot(*args: Any, **kwargs: Any) -> None: ...
def manipComponentUpdate() -> None: ...
def manipMoveContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeHandle: Queryable[int] = ..., activeHandleNormal: Queryable[int] = ..., alignAlong: Tuple[float, float, float] = ..., bakePivotOri: bool = ..., constrainAlongNormal: bool = ..., currentActiveHandle: Queryable[int] = ..., editPivotMode: bool = ..., editPivotPosition: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., interactiveUpdate: bool = ..., lastMode: Queryable[int] = ..., manipVisible: bool = ..., mode: Queryable[int] = ..., orientAxes: Queryable[Tuple[float, float, float]] = ..., orientJoint: Queryable[str] = ..., orientJointEnabled: bool = ..., orientObject: str = ..., orientTowards: Tuple[float, float, float] = ..., pinPivot: bool = ..., pivotOriHandle: bool = ..., position: bool = ..., postCommand: Callable[..., Any] = ..., postDragCommand: Tuple[Callable[..., Any], str] = ..., preCommand: Callable[..., Any] = ..., preDragCommand: Tuple[Callable[..., Any], str] = ..., preserveChildPosition: bool = ..., preserveUV: bool = ..., reflection: bool = ..., reflectionAbout: int = ..., reflectionAxis: int = ..., reflectionTolerance: float = ..., secondaryAxisOrient: Queryable[str] = ..., snap: bool = ..., snapComponentsRelative: bool = ..., snapLiveFaceCenter: bool = ..., snapLivePoint: bool = ..., snapPivotOri: bool = ..., snapPivotPos: bool = ..., snapRelative: bool = ..., snapValue: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., tweakMode: bool = ..., xformConstraint: Queryable[str] = ...) -> Union[str, int, bool, Tuple[float, float, float], float]:
    """This command can be used to create, edit, or query a move
    manip context.
    Note that the flags -s, -sv, -sr, -scr, -slp, -slf control
    the global behaviour of all move manip context.  Changing one
    context independently is not allowed.  Changing a context's
    behaviour using the above flags, will change all existing move
    manip context.
    Args:
        activeHandle (Queryable[int]?): Sets the default active handle for the manip.  That is, the handle  
                which should be initially active when the tool is activated.  
                Values can be:  
              
                0. X axis handle is active  
                1. Y axis handle is active  
                2. Z axis handle is active  
                3. Center handle (all 3 axes) is active (default)  
                Properties: query, edit
        activeHandleNormal (Queryable[int]?): 0. U axis handle is active  
                1. V axis handle is active  
                2. N axis handle is active ( default )  
                3. Center handle (all 3 axes) is active  
              
                applicable only when the manip mode is 3.  
                Properties: query, edit
        alignAlong (Tuple[float, float, float]?): Aligns active handle along vector.  
                Properties: create, edit
        bakePivotOri (bool?): Bake pivot orientation. Automatically bake pivot orientation changes into the transform hierarchy / geometry.  
                Properties: query, edit
        constrainAlongNormal (bool?): When true, transform constraints are applied along the vertex normal first  
                and only use the closest point when no intersection is found along the normal.  
                Properties: query, edit
        currentActiveHandle (Queryable[int]?): Sets the active handle for the manip.  
                Values can be:  
              
                0. X axis handle is active  
                1. Y axis handle is active  
                2. Z axis handle is active  
                3. Center handle (all 3 axes) is active  
                4. XY plane handle is active  
                5. YZ plane handle is active  
                6. XZ plane handle is active  
                Properties: query, edit
        editPivotMode (bool?): Returns true manipulator is in edit pivot mode  
                Properties: query
        editPivotPosition (bool?): Returns the current position of the edit pivot manipulator.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        interactiveUpdate (bool?): Value can be : true or false.  
                This flag value is valid only if the mode is 3 i.e. move vertex normal.  
                Properties: query, edit
        lastMode (Queryable[int]?): Returns the previous translation mode.  
                Properties: query
        manipVisible (bool?): Returns true if the main translate manipulator is visible.  
                Properties: query
        mode (Queryable[int]?): Translate mode:  
              
                0. Object Space  
                1. Local Space  
                2. World Space (default)  
                3. Move Along Vertex Normal  
                4. Move Along Rotation Axis  
                5. Move Along Live Object Axis  
                6. Custom Axis Orientation  
                10. Component Space  
                Properties: query, edit
        orientAxes (Queryable[Tuple[float, float, float]]?): Orients manipulator rotating around axes by specified angles  
                Properties: query, edit
        orientJoint (Queryable[str]?): Specifies the type of orientation for joint orientation. Valid options are:  
                none, xyz, xzy, yxz, yzx, zxy, zyx.  
                Properties: query, edit
        orientJointEnabled (bool?): Specifies if joints should be reoriented when moved.  
                Properties: query, edit
        orientObject (str?): Orients manipulator to the passed in object/component  
                Properties: create, edit
        orientTowards (Tuple[float, float, float]?): Orients active handle towards world point  
                Properties: create, edit
        pinPivot (bool?): Pin component pivot. When the component pivot is set and pinned selection  
                changes will not reset the pivot position and orientation.  
                Properties: query, edit
        pivotOriHandle (bool?): When true, the pivot manipulator will show the orientation handle during editing.  
                Default is true.  
                Properties: query, edit
        position (bool?): Returns the current position of the manipulator  
                Properties: query
        postCommand (Callable[..., Any]?): Specifies a command to be executed when the tool is exited.  
                Properties: create, edit
        postDragCommand (Tuple[Callable[..., Any], str]?): Specifies a command and a node type. The command will be executed at  
                the end of a drag when a node of the specified type is in the selection.  
                Properties: create, edit
        preCommand (Callable[..., Any]?): Specifies a command to be executed when the tool is entered.  
                Properties: create, edit
        preDragCommand (Tuple[Callable[..., Any], str]?): Specifies a command and a node type. The command will be executed at  
                the start of a drag when a node of the specified type is in the selection.  
                Properties: create, edit
        preserveChildPosition (bool?): When false, the children objects move when their parent is moved.  
                When true, the worldspace position of the children will be maintained as  
                the parent is moved. Default is false.  
                Properties: query, edit
        preserveUV (bool?): When false, the uvs are not changes to match the vertex edit.  
                When true, the uvs are edited to project to new values to stop texture  
                swimming as vertices are moved.  
                Properties: query, edit
        reflection (bool?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionAbout (int?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionAxis (int?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionTolerance (float?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        secondaryAxisOrient (Queryable[str]?): Specifies the global axis (in world coordinates) that should be used  
                to should be used to align the second axis of the orientJointType triple.  
                Valid options are xup, yup, zup, xdown, ydown, zdown, none.  
                Properties: query, edit
        snap (bool?): Value can be : true or false.  
                Enable/Disable the discrete move.  
                If set to true, the move manipulator of all the  
                move contexts would snap at discrete points  
                along the active handle during mouse drag.  The  
                interval between the points can be controlled  
                using the 'snapValue' flag.  
                Properties: query, edit
        snapComponentsRelative (bool?): Value can be : true or false.  
                If true, while snapping a group of CVs/Vertices, the  
                relative spacing between them will be preserved.  
                If false, all the CVs/Vertices will be snapped to the  
                target point  
                (is used during grid snap(hotkey 'x'), and  
                point snap(hotkey 'v'))  
                Depress the 'x' key before click-dragging the manip handle  
                and check to see the behaviour of moving a bunch of CVs,  
                with this flag ON and OFF.  
                Properties: query, edit
        snapLiveFaceCenter (bool?): Value can be : true or false.  
                If true, while moving on the live polygon object, the  
                move manipulator will snap to the face centers of the object.  
                Properties: query, edit
        snapLivePoint (bool?): Value can be : true or false.  
                If true, while moving on the live polygon object, the  
                move manipulator will snap to the vertices of the object.  
                Properties: query, edit
        snapPivotOri (bool?): Snap pivot orientation. Modify pivot orientation when snapping the pivot to a component.  
                Properties: query, edit
        snapPivotPos (bool?): Snap pivot position. Modify pivot position when snapping the pivot to a component.  
                Properties: query, edit
        snapRelative (bool?): Value can be : true or false.  
                Applicable only when the snap is enabled.  
                If true, the snapValue is treated relative to the  
                original position before moving.  
                If false, the snapValue is treated relative to the  
                world origin.  
                NOTE:    If in local/object Space Mode,  
                the snapRelative should be ON.  
                Absolute discrete move is not supported  
                in local/object mode.  
                Properties: query, edit
        snapValue (Queryable[float]?): Applicable only when the snap is enabled.  
                The manipulator of all move contexts would move in  
                steps of 'snapValue'  
                Properties: query, edit
        translate (Queryable[Tuple[float, float, float]]?): Returns the translation of the manipulator for its current orientation/mode.  
                Properties: query, edit
        tweakMode (bool?): When true, the manipulator is hidden and highlighted components can be selected  
                and moved in one step using a click-drag interaction.  
                Properties: query, edit
        xformConstraint (Queryable[str]?): none - no transform constraint  
                edge - edge transform constraint  
                surface - surface transform constraint  
                Properties: query, edit

    Returns:
        str: The name of the new context

    Example:
    """

def manipMoveLimitsCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Create a context for the translate limits manipulator.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Name of newly created context

    Example:
    """

def manipOptions(*, query: bool = ..., enableSmartDuplicate: bool = ..., enableSmartExtrude: bool = ..., forceRefresh: bool = ..., handleSize: Queryable[float] = ..., hideManipOnCtrl: bool = ..., hideManipOnShift: bool = ..., hideManipOnShiftCtrl: bool = ..., linePick: Queryable[float] = ..., lineSize: Queryable[float] = ..., middleMouseRepositioning: bool = ..., pivotRotateHandleOffset: Queryable[int] = ..., planeHandleOffset: Queryable[int] = ..., pointSize: Queryable[float] = ..., preselectHighlight: bool = ..., refreshMode: Queryable[int] = ..., relative: bool = ..., rememberActiveHandle: bool = ..., rememberActiveHandleAfterToolSwitch: bool = ..., scale: Queryable[float] = ..., showExtrudeSliders: bool = ..., showPivotRotateHandle: bool = ..., showPlaneHandles: bool = ..., smartDuplicateType: Queryable[int] = ...) -> Union[bool, float, int]:
    """Changes the global manipulator parameters
    Args:
        enableSmartDuplicate (bool?): Enables Shift-Duplicate option on t/r/s manips.  
                Properties: create, query
        enableSmartExtrude (bool?): Enables Shift-Extrude option on t/r/s manips.  
                Properties: create, query
        forceRefresh (bool?): Force a refresh if there is any deferred evaluation.  
                Properties: create
        handleSize (Queryable[float]?): Sets the maximum handles size in pixels, for small handles  
                Properties: create, query
        hideManipOnCtrl (bool?): Hide transform manip when the Ctrl key is pressed.  
                Properties: create, query
        hideManipOnShift (bool?): Hide transform manip when the Shift key is pressed.  
                Properties: create, query
        hideManipOnShiftCtrl (bool?): Hide transform manip when the Shift and Ctrl keys are both pressed.  
                Properties: create, query
        linePick (Queryable[float]?): Set the width of picking zone for long handles  
                Properties: create, query
        lineSize (Queryable[float]?): Set the width of long handles (drawn as lines)  
                Properties: create, query
        middleMouseRepositioning (bool?): Specify if the middle mouse should reposition  
                Properties: create, query
        pivotRotateHandleOffset (Queryable[int]?): Set the offset of the pivot rotation handle.  
                Properties: create, query
        planeHandleOffset (Queryable[int]?): Set the offset of the planar drag handles.  
                Properties: create, query
        pointSize (Queryable[float]?): Set the size of points (used to display previous states)  
                Properties: create, query
        preselectHighlight (bool?): Set whether manip handles should be highlighted when moving mouse.  
                Properties: create, query
        refreshMode (Queryable[int]?): Set the global refresh mode.  
                Properties: create, query
        relative (bool?): All values are interpreted as multiplication factors instead  
                of final values.  
                Properties: create
        rememberActiveHandle (bool?): Set whether manip handles should be remembered after selection change.  
                Properties: create, query
        rememberActiveHandleAfterToolSwitch (bool?): Set whether manip handles should be remembered after manipulator change.  
                Properties: create, query
        scale (Queryable[float]?): Global scaling factor of all manipulators  
                Properties: create, query
        showExtrudeSliders (bool?): Specify if the extrude sliders are to be shown on the manip  
                Properties: create, query
        showPivotRotateHandle (bool?): Toggles the visibility of the pivot rotation handle.  
                Properties: create, query
        showPlaneHandles (bool?): Toggles the visibility of the planar drag handles.  
                Properties: create, query
        smartDuplicateType (Queryable[int]?): Change Shift-Duplicate or Shift-Extrude between Copy and Instance on t/r/s manips.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def manipPivot(*, query: bool = ..., bakeOri: bool = ..., moveToolOri: int = ..., ori: Queryable[Tuple[float, float, float]] = ..., oriValid: bool = ..., pinPivot: bool = ..., pos: Queryable[Tuple[float, float, float]] = ..., posValid: bool = ..., reset: bool = ..., resetOri: bool = ..., resetPos: bool = ..., rotateToolOri: int = ..., scaleToolOri: int = ..., snapOri: bool = ..., snapPos: bool = ..., valid: bool = ...) -> Union[bool, Tuple[float, float, float]]:
    """Changes transform component pivot used by the move/rotate/scale manipulators.
    Args:
        bakeOri (bool?): Bake pivot orientation. Automatically bake pivot orientation changes into the transform hierarchy / geometry.  
                Properties: create, query
        moveToolOri (int?): Change move tool's axis orientation to the specified mode. This flag is the same  
                as using "manipMoveContext -e -mode" on the Move tool except that this command  
                is undoable.  
                Properties: create
        ori (Queryable[Tuple[float, float, float]]?): Component pivot orientation in world-space.  
                Properties: create, query
        oriValid (bool?): Returns true if component pivot orientation is valid.  
                Properties: query
        pinPivot (bool?): Pin component pivot. Selection changes will not reset the pivot position/orientation  
                when a custom pivot is set and pinning is on.  
                Properties: create, query
        pos (Queryable[Tuple[float, float, float]]?): Component pivot position in world-space.  
                Properties: create, query
        posValid (bool?): Returns true if component pivot position is valid.  
                Properties: query
        reset (bool?): Clear the saved component pivot position and orientation.  
                Properties: create
        resetOri (bool?): Clear the saved component pivot orientation.  
                Properties: create
        resetPos (bool?): Clear the saved component pivot position.  
                Properties: create
        rotateToolOri (int?): Change rotate tool's axis orientation to the specified mode. This flag is the same  
                as using "manipRotateContext -e -mode" on the Rotate tool except that this command  
                is undoable.  
                Properties: create
        scaleToolOri (int?): Change scale tool's axis orientation to the specified mode. This flag is the same  
                as using "manipScaleContext -e -mode" on the Scale tool except that this command  
                is undoable.  
                Properties: create
        snapOri (bool?): Snap pivot orientation. Modify pivot orientation when snapping the pivot to a component.  
                Properties: create, query
        snapPos (bool?): Snap pivot position. Modify pivot position when snapping the pivot to a component.  
                Properties: create, query
        valid (bool?): Returns true if component pivot position or orientation is valid.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def manipRotateContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeHandle: Queryable[int] = ..., alignAlong: Tuple[float, float, float] = ..., bakePivotOri: bool = ..., centerTrackball: bool = ..., constrainAlongNormal: bool = ..., currentActiveHandle: Queryable[int] = ..., editPivotMode: bool = ..., editPivotPosition: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., lastMode: Queryable[int] = ..., manipVisible: bool = ..., mode: Queryable[int] = ..., modifyTranslation: bool = ..., orientAxes: Queryable[Tuple[float, float, float]] = ..., orientObject: str = ..., orientTowards: Tuple[float, float, float] = ..., pinPivot: bool = ..., pivotOriHandle: bool = ..., position: bool = ..., postCommand: Callable[..., Any] = ..., postDragCommand: Tuple[Callable[..., Any], str] = ..., preCommand: Callable[..., Any] = ..., preDragCommand: Tuple[Callable[..., Any], str] = ..., preserveChildPosition: bool = ..., preserveUV: bool = ..., reflection: bool = ..., reflectionAbout: int = ..., reflectionAxis: int = ..., reflectionTolerance: float = ..., rotate: Queryable[Tuple[float, float, float]] = ..., snap: bool = ..., snapPivotOri: bool = ..., snapPivotPos: bool = ..., snapRelative: bool = ..., snapValue: Queryable[float] = ..., tweakMode: bool = ..., useCenterPivot: bool = ..., useManipPivot: bool = ..., useObjectPivot: bool = ..., xformConstraint: Queryable[str] = ...) -> Union[str, int, bool, Tuple[float, float, float], float]:
    """This command can be used to create, edit, or query a rotate manip context.
    Args:
        activeHandle (Queryable[int]?): Sets the default active handle for the manip.  That is, the handle  
                which should be initially active when the tool is activated.  
                Values can be:  
              
                0. X axis handle is active  
                1. Y axis handle is active  
                2. Z axis handle is active  
                3. View rotation handle (outer ring) is active (default)  
                Properties: query, edit
        alignAlong (Tuple[float, float, float]?): Aligns active handle along vector.  
                Properties: create, edit
        bakePivotOri (bool?): Bake pivot orientation. Automatically bake pivot orientation changes into the transform hierarchy / geometry.  
                Properties: query, edit
        centerTrackball (bool?): Specify if the center is to be handled like a trackball  
                Properties: create, query, edit
        constrainAlongNormal (bool?): When true, transform constraints are applied along the vertex normal first  
                and only use the closest point when no intersection is found along the normal.  
                Properties: query, edit
        currentActiveHandle (Queryable[int]?): Sets the active handle for the manip.  
                Values can be:  
              
                0. X axis handle is active  
                1. Y axis handle is active  
                2. Z axis handle is active  
                3. View rotation handle (outer ring) is active  
                4. Arc Ball is active  
                Properties: query, edit
        editPivotMode (bool?): Returns true manipulator is in edit pivot mode  
                Properties: query
        editPivotPosition (bool?): Returns the current position of the edit pivot manipulator.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        lastMode (Queryable[int]?): Returns the previous rotation mode.  
                Properties: query
        manipVisible (bool?): Returns true if the rotate manipulator is visible.  
                Properties: query
        mode (Queryable[int]?): Rotate mode:  
              
                0. Object Space (default)  
                1. World Space  
                2. Gimbal Mode  
                3. Custom Axis Orientation  
                10. Component Space  
                Properties: query, edit
        modifyTranslation (bool?): When false, and an object is rotated about a point other than its rotate pivot,  
                its rotateTranslate attribute is modified to put the object at the  
                correct position. When true, its translate attribute is used instead.  
                Default is false.  
                Properties: query, edit
        orientAxes (Queryable[Tuple[float, float, float]]?): Orients manipulator rotating around axes by specified angles  
                Properties: query, edit
        orientObject (str?): Orients manipulator to the passed in object/component  
                Properties: create, edit
        orientTowards (Tuple[float, float, float]?): Orients active handle towards world point  
                Properties: create, edit
        pinPivot (bool?): Pin component pivot. When the component pivot is set and pinned selection  
                changes will not reset the pivot position and orientation.  
                Properties: query, edit
        pivotOriHandle (bool?): When true, the pivot manipulator will show the orientation handle during editing.  
                Default is true.  
                Properties: query, edit
        position (bool?): Returns the current position of the manipulator.  
                Properties: query
        postCommand (Callable[..., Any]?): Specifies a command to be executed when the tool is exited.  
                Properties: create, edit
        postDragCommand (Tuple[Callable[..., Any], str]?): Specifies a command and a node type. The command will be executed at  
                the end of a drag when a node of the specified type is in the selection.  
                Properties: create, edit
        preCommand (Callable[..., Any]?): Specifies a command to be executed when the tool is entered.  
                Properties: create, edit
        preDragCommand (Tuple[Callable[..., Any], str]?): Specifies a command and a node type. The command will be executed at  
                the start of a drag when a node of the specified type is in the selection.  
                Properties: create, edit
        preserveChildPosition (bool?): When false, the children objects move when their parent is rotated.  
                When true, the worldspace position of the children will be maintained as  
                the parent is moved. Default is false.  
                Properties: query, edit
        preserveUV (bool?): When false, the uvs are not changes to match the vertex edit.  
                When true, the uvs are edited to project to new values to stop texture  
                swimming as vertices are moved.  
                Properties: query, edit
        reflection (bool?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionAbout (int?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionAxis (int?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionTolerance (float?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        rotate (Queryable[Tuple[float, float, float]]?): Returns the rotation of the manipulator for its current orientation/mode.  
                Properties: query, edit
        snap (bool?): Specify that the manipulation is to use absolute snap  
                Properties: create, query, edit
        snapPivotOri (bool?): Snap pivot orientation. Modify pivot orientation when snapping the pivot to a component.  
                Properties: query, edit
        snapPivotPos (bool?): Snap pivot position. Modify pivot position when snapping the pivot to a component.  
                Properties: query, edit
        snapRelative (bool?): Specify that the manipulation is to use relative snap  
                Properties: create, query, edit
        snapValue (Queryable[float]?): Specify the snapping value  
                Properties: create, query, edit
        tweakMode (bool?): When true, the manipulator is hidden and highlighted components can be selected  
                and rotated in one step using a click-drag interaction.  
                Properties: query, edit
        useCenterPivot (bool?): When true, use the center of the selection's bounding box as the center of the rotation  
                (for all objects).  
                Properties: query, edit
        useManipPivot (bool?): When true, use the manipulator's center as the center of the rotation  
                (for all objects).  
                Properties: query, edit
        useObjectPivot (bool?): When true, use each object's pivot as the center of its rotation.  
                Properties: query, edit
        xformConstraint (Queryable[str]?): none - no transform constraint  
                edge - edge transform constraint  
                surface - surface transform constraint  
                Properties: query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def manipRotateLimitsCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Create a context for the rotate limits manipulator.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Name of newly created context

    Example:
    """

def manipScaleContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeHandle: Queryable[int] = ..., alignAlong: Tuple[float, float, float] = ..., bakePivotOri: bool = ..., constrainAlongNormal: bool = ..., currentActiveHandle: Queryable[int] = ..., editPivotMode: bool = ..., editPivotPosition: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., lastMode: Queryable[int] = ..., manipVisible: bool = ..., mode: Queryable[int] = ..., orientAxes: Queryable[Tuple[float, float, float]] = ..., orientObject: str = ..., orientTowards: Tuple[float, float, float] = ..., pinPivot: bool = ..., pivotOriHandle: bool = ..., position: bool = ..., postCommand: Callable[..., Any] = ..., postDragCommand: Tuple[Callable[..., Any], str] = ..., preCommand: Callable[..., Any] = ..., preDragCommand: Tuple[Callable[..., Any], str] = ..., preserveChildPosition: bool = ..., preserveUV: bool = ..., preventNegativeScale: bool = ..., reflection: bool = ..., reflectionAbout: int = ..., reflectionAxis: int = ..., reflectionTolerance: float = ..., scale: Queryable[Tuple[float, float, float]] = ..., snap: bool = ..., snapPivotOri: bool = ..., snapPivotPos: bool = ..., snapRelative: bool = ..., snapValue: Queryable[float] = ..., tweakMode: bool = ..., useManipPivot: bool = ..., useObjectPivot: bool = ..., xformConstraint: Queryable[str] = ...) -> Union[str, int, bool, Tuple[float, float, float], float]:
    """This command can be used to create, edit, or query a scale manip context.
    Args:
        activeHandle (Queryable[int]?): Sets the default active handle for the manip.  That is, the handle  
                which should be initially active when the tool is activated.  
                Values can be:  
              
                0. X axis handle is active  
                1. Y axis handle is active  
                2. Z axis handle is active  
                3. Center handle (all axes) is active (default)  
                Properties: query, edit
        alignAlong (Tuple[float, float, float]?): Aligns active handle along vector.  
                Properties: create, edit
        bakePivotOri (bool?): Bake pivot orientation. Automatically bake pivot orientation changes into the transform hierarchy / geometry.  
                Properties: query, edit
        constrainAlongNormal (bool?): When true, transform constraints are applied along the vertex normal first  
                and only use the closest point when no intersection is found along the normal.  
                Properties: query, edit
        currentActiveHandle (Queryable[int]?): Sets the active handle for the manip.  
                Values can be:  
              
                0. X axis handle is active  
                1. Y axis handle is active  
                2. Z axis handle is active  
                3. Center handle (all axes) is active  
                4. XY plane handle is active  
                5. YZ plane handle is active  
                6. XZ plane handle is active  
                Properties: query, edit
        editPivotMode (bool?): Returns true manipulator is in edit pivot mode  
                Properties: query
        editPivotPosition (bool?): Returns the current position of the edit pivot manipulator.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        lastMode (Queryable[int]?): Returns the previous scaling mode.  
                Properties: query
        manipVisible (bool?): Returns true if the scale manipulator is visible.  
                Properties: query
        mode (Queryable[int]?): Scale mode:  
              
                0. Object Space  
                1. Local Space  
                2. World Space (default)  
                3. Scale Along Vertex Normal  
                4. Scale Along Rotation Axis  
                5. Scale Along Live Object Axis  
                6. Custom Axis Orientation  
                10. Component Space  
                Properties: query, edit
        orientAxes (Queryable[Tuple[float, float, float]]?): Orients manipulator rotating around axes by specified angles  
                Properties: query, edit
        orientObject (str?): Orients manipulator to the passed in object/component  
                Properties: create, edit
        orientTowards (Tuple[float, float, float]?): Orients active handle towards world point  
                Properties: create, edit
        pinPivot (bool?): Pin component pivot. When the component pivot is set and pinned selection  
                changes will not reset the pivot position and orientation.  
                Properties: query, edit
        pivotOriHandle (bool?): When true, the pivot manipulator will show the orientation handle during editing.  
                Default is true.  
                Properties: query, edit
        position (bool?): Returns the current position of the manipulator.  
                Properties: query
        postCommand (Callable[..., Any]?): Specifies a command to be executed when the tool is exited.  
                Properties: create, edit
        postDragCommand (Tuple[Callable[..., Any], str]?): Specifies a command and a node type. The command will be executed at  
                the end of a drag when a node of the specified type is in the selection.  
                Properties: create, edit
        preCommand (Callable[..., Any]?): Specifies a command to be executed when the tool is entered.  
                Properties: create, edit
        preDragCommand (Tuple[Callable[..., Any], str]?): Specifies a command and a node type. The command will be executed at  
                the start of a drag when a node of the specified type is in the selection.  
                Properties: create, edit
        preserveChildPosition (bool?): When false, the children objects move when their parent is rotated.  
                When true, the worldspace position of the children will be maintained as  
                the parent is moved. Default is false.  
                Properties: query, edit
        preserveUV (bool?): When false, the uvs are not changes to match the vertex edit.  
                When true, the uvs are edited to project to new values to stop texture  
                swimming as vertices are moved.  
                Properties: query, edit
        preventNegativeScale (bool?): When this is true, negative scale is not allowed.  
                Properties: query
        reflection (bool?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionAbout (int?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionAxis (int?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        reflectionTolerance (float?): This flag is obsolete. Reflection is now managed as part of selection itself  
                using the symmetricModeling command.
        scale (Queryable[Tuple[float, float, float]]?): Returns the scale of the manipulator for its current orientation/mode.  
                Properties: query, edit
        snap (bool?): Specify that the manipulation is to use absolute snap  
                Properties: create, query, edit
        snapPivotOri (bool?): Snap pivot orientation. Modify pivot orientation when snapping the pivot to a component.  
                Properties: query, edit
        snapPivotPos (bool?): Snap pivot position. Modify pivot position when snapping the pivot to a component.  
                Properties: query, edit
        snapRelative (bool?): Specify that the manipulation is to use relative snap  
                Properties: create, query, edit
        snapValue (Queryable[float]?): Specify the snapping value  
                Properties: create, query, edit
        tweakMode (bool?): When true, the manipulator is hidden and highlighted components can be selected  
                and scaled in one step using a click-drag interaction.  
                Properties: query, edit
        useManipPivot (bool?): Specify whether to pivot on the manip  
                Properties: create, query, edit
        useObjectPivot (bool?): Specify whether to pivot on the object  
                Properties: create, query, edit
        xformConstraint (Queryable[str]?): none - no transform constraint  
                edge - edge transform constraint  
                surface - surface transform constraint  
                Properties: query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def manipScaleLimitsCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Create a context for the scale limits manipulator.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Name of newly created context.

    Example:
    """

def marker(*args: str, edit: bool = ..., query: bool = ..., attach: bool = ..., detach: bool = ..., frontTwist: Queryable[float] = ..., orientationMarker: bool = ..., positionMarker: bool = ..., sideTwist: Queryable[float] = ..., time: Queryable[int] = ..., upTwist: Queryable[float] = ..., valueU: Queryable[float] = ...) -> Union[List[str], float, bool, int]:
    """The marker command creates one or two markers, on a motion path curve,
    at the specified time and location.
    The optionnal string argument is the parent object name.One can specify "-pm -om" option to create both, a position marker
    and an orientation marker.Since there is only one keyframe for each marker of the same type,
    no more than one marker of the same type with the same time value
    can exist.The default marker type is the position marker. The default time is
    the current time.
    Args:
        attach (bool?): This flag specifies to attach the selected 3D position markers  
                to their parent geometry.  
                Properties: create
        detach (bool?): This flag specifies to detach the selected position markers from  
                their parent geometry to the 3D space.  
                Properties: create
        frontTwist (Queryable[float]?): This flag specifies the amount of twist angle about  
                the front vector for the marker.  
                Default is 0.  
                When queried, this flag returns a angle.  
                Properties: query
        orientationMarker (bool?): This flag specifies creation of an orientation marker.  
                Default is not set..  
                When queried, this flag returns a boolean.  
                Properties: query
        positionMarker (bool?): This flag specifies creation of a position marker.  
                Default is set.  
                When queried, this flag returns a boolean.  
                Properties: query
        sideTwist (Queryable[float]?): This flag specifies  the amount of twist angle about  
                the side vector for the marker.  
                Default is 0.  
                When queried, this flag returns a angle.  
                Properties: query
        time (Queryable[int]?): This flag specifies the time for the marker.  
                Default is the current time.  
                When queried, this flag returns a time.  
                Properties: query
        upTwist (Queryable[float]?): This flag specifies the amount of twist angle about  
                the up vector for the marker.  
                Default is 0.  
                When queried, this flag returns a angle.  
                Properties: query
        valueU (Queryable[float]?): This flag specifies the location of the position marker  
                w.r.t. the parent geometry u parameterization.  
                Default is the value at current time.  
                When queried, this flag returns a linear.  
                Properties: query

    Returns:
        List[str]: (name of the created markers)

    Example:
    """

def matchTransform(*args: str, pivots: bool = ..., position: bool = ..., positionX: bool = ..., positionY: bool = ..., positionZ: bool = ..., rotatePivot: bool = ..., rotation: bool = ..., rotationX: bool = ..., rotationY: bool = ..., rotationZ: bool = ..., scale: bool = ..., scaleBox: bool = ..., scalePivot: bool = ..., scaleX: bool = ..., scaleY: bool = ..., scaleZ: bool = ...) -> bool:
    """This command modifies the source object's transform to match the
    target object's transform.If no flags are specified then the command will match position,
    rotation and scaling.
    Args:
        pivots (bool?): Match the source object(s) scale/rotate pivot positions to the target transform's pivot.  
                Properties: create
        position (bool?): Match the source object(s) position to the target object.  
                Properties: create
        positionX (bool?): Match the source object(s) X position to the target object.  
                Properties: create
        positionY (bool?): Match the source object(s) Y position to the target object.  
                Properties: create
        positionZ (bool?): Match the source object(s) Z position to the target object.  
                Properties: create
        rotatePivot (bool?): Match the source object(s) rotate pivot position to the target transform's pivot.  
                Properties: create
        rotation (bool?): Match the source object(s) rotation to the target object.  
                Properties: create
        rotationX (bool?): Match the source object(s) X rotation to the target object.  
                Properties: create
        rotationY (bool?): Match the source object(s) Y rotation to the target object.  
                Properties: create
        rotationZ (bool?): Match the source object(s) Z rotation to the target object.  
                Properties: create
        scale (bool?): Match the source object(s) scale to the target transform.  
                Properties: create
        scaleBox (bool?): Use the source/target object's child bounding box size when matching scaling.  
                Properties: create
        scalePivot (bool?): Match the source object(s) scale pivot position to the target transform's pivot.  
                Properties: create
        scaleX (bool?): Match the source object(s) X scale to the target object.  
                Properties: create
        scaleY (bool?): Match the source object(s) Y scale to the target object.  
                Properties: create
        scaleZ (bool?): Match the source object(s) Z scale to the target object.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def mateCtx(*args: Any, **kwargs: Any) -> None: ...
def matrix() -> None: ...
def matrixUtil(arg0: float = ..., arg1: float = ..., arg2: float = ..., arg3: float = ..., arg4: float = ..., arg5: float = ..., arg6: float = ..., arg7: float = ..., arg8: float = ..., arg9: float = ..., arg10: float = ..., arg11: float = ..., arg12: float = ..., arg13: float = ..., arg14: float = ..., arg15: float = ..., /, *, edit: bool = ..., query: bool = ..., inverse: bool = ..., quaternion: Queryable[Tuple[float, float, float, float]] = ..., relative: bool = ..., rotation: Queryable[Tuple[float, float, float]] = ..., scale: Queryable[Tuple[float, float, float]] = ..., shear: Queryable[Tuple[float, float, float]] = ..., translation: Queryable[Tuple[float, float, float]] = ..., transpose: bool = ...) -> Union[str, bool, Tuple[float, float, float, float], Tuple[float, float, float]]:
    """Command to deal with matrix, composition and decompositionmatrix, decomposeMatrix, decomposeMatrix
    Args:
        inverse (bool?): Compose or query will return the inversed matrix.  
                Properties: create, query, edit
        quaternion (Queryable[Tuple[float, float, float, float]]?): Compose, edit or query a matrix using specified quaternion values as rotation components.  
                Properties: create, query, edit
        relative (bool?): Add translation, rotation, scale or shear, instead of seting it as absolute.  
                Properties: create, query, edit
        rotation (Queryable[Tuple[float, float, float]]?): Compose, edit or query a matrix using specified values as rotation components.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Compose, edit or query a matrix using specified values as scale components.  
                Properties: create, query, edit
        shear (Queryable[Tuple[float, float, float]]?): Compose, edit or query a matrix using specified values as shear components.  
                Properties: create, query, edit
        translation (Queryable[Tuple[float, float, float]]?): Compose a matrix using specified values as translation components.  
                Properties: create, query, edit
        transpose (bool?): Compose or query will return the transposed matrix.  
                Properties: create, query, edit

    Returns:
        str: Command result

    Example:
    """

def mayaDpiSetting(*, query: bool = ..., mode: Queryable[int] = ..., realScaleValue: bool = ..., scaleValue: Queryable[float] = ..., systemDpi: bool = ...) -> Union[int, float, bool]:
    """Provide Maya interface scaling based on system DPI or custom scale setting or no scaling. Please note that the change will only take effect after relaunching Maya.The mayaDpiSetting command is not available on macOS. System scaling should be used to change Maya UI scaling.mayaDpiSetting, dpi
    Args:
        mode (Queryable[int]?): Specifies the interface scaling mode:  
              
                0. System Dpi Based Scaling  
                1. Custom Scaling (Must provide the custom scale value with flag "-scaleValue")  
                2. No Scaling  
                Properties: create, query
        realScaleValue (bool?): This is a query mode only flag which returns the real scale value depending on current scaling mode and defined scale value:  
              
                mode 0. Return the current real scale value which is the ratio of current system dpi to default system dpi  
                mode 1. Return the current real scale value which is the product of the defined scale value and the ratio of current system dpi to default system dpi  
                mode 2. Always return 1.0 which indicates real scale is 100% when the scaling mode is no scaling.  
                Properties: query
        scaleValue (Queryable[float]?): Specifies the custom scale of the interface if scaling mode is 1. The allowed values are [1.0, 1.25, 1.5, 2.0].  
                In query mode, return the scale value depend on current scaling mode:  
              
                mode 0. Always return 1.0 which indicates 100% scaling  
                mode 1. Return the custom scale value used  
                mode 2. Always return 1.0 which indicates no custom scaling  
                Properties: create, query
        systemDpi (bool?): This is a query mode only flag which returns the current system dpi value.  
                Properties: query

    Returns:
        int: Scale mode or system DPI value, as queried
        float: Defined scale or real scale, as queried

    Example:
    """

def mayaDpiSettingAction(*args: Any, **kwargs: Any) -> None: ...
def mayaHasRenderSetup(*, edit: bool = ..., query: bool = ..., enableCurrentSession: bool = ..., enableDuringTests: bool = ...) -> bool:
    """This command controls and queries render setup states.render, setup
    Args:
        enableCurrentSession (bool?): Enables or disables render setup for this Maya session only.  
                This flag should only be called during Maya intialization. This flag is for internal use only, may change at any time and is unsupported.  
                Properties: query, edit
        enableDuringTests (bool?): Switches render setup for this Maya session only, as legacy render layer mode is assumed during testing.  
                This flag is for internal use only, may change at any time and is unsupported.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def mayaPreviewRenderIntoNewWindow() -> None: ...
def melInfo() -> List[str]:
    """This command returns the names of all global MEL procedures that are currently
    defined as a string array. The user can query the definition of each MEL
    procedure using the "whatIs" command.mel
    Returns:
        List[str]: procedure names

    Example:
    """

def melOptions(*, query: bool = ..., duplicateVariableWarnings: bool = ...) -> bool:
    """Set and query options that affect the behavior of Maya's Embedded Language
    (MEL).
    Args:
        duplicateVariableWarnings (bool?): When turned on, this option will cause a warning to be generated whenever a  
                MEL variable is declared within the same scope as another variable with  
                the same name.  
                The warnings will be generated when the script is sourced, not when it  
                is executed. Usually these warnings indicate an error in the script.  
              
                On query the current setting of the option will be returned.  
              
                The corresponding preference optionVar is melDuplicateVariableWarnings.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def memory(*, adjustedVirtualMemory: bool = ..., asFloat: bool = ..., debug: bool = ..., freeMemory: bool = ..., gigaByte: bool = ..., heapMemory: bool = ..., kiloByte: bool = ..., megaByte: bool = ..., pageFaults: bool = ..., pageReclaims: bool = ..., physicalMemory: bool = ..., processVirtualMemory: bool = ..., summary: bool = ..., swapFree: bool = ..., swapLogical: bool = ..., swapMax: bool = ..., swapPhysical: bool = ..., swapReserved: bool = ..., swapVirtual: bool = ..., swaps: bool = ...) -> bool:
    """Used to query essential statistics on memory availability and usage.By default memory sizes are returned in bytes. Since Maya's command engine
    only supports 32-bit signed integers, any returned value which cannot fit
    into 31 bits will be truncated to 2,147,483,647 and a warning message displayed.
    To avoid having memory sizes truncated use one of the memory size flags to
    return the value in larger units (e.g. megabytes) or use the asFloat flag to
    return the value as a float.
    Args:
        adjustedVirtualMemory (bool?): Returns size of adjusted virtual memory allocated by the process.  
                The adjustment is done by computing an offset when the application is launched  
                that will be subtracted from the process virtual memory in order to give the  
                adjusted value.  The returned size is an approximation of the memory used by the  
                process that can be more reliable in some cases, for instance on platforms where  
                display drivers can reserve large ranges of memory addresses, therefore increasing  
                the size of the process virtual memory, even though those addresses are actually  
                not used.  
                Properties: create
        asFloat (bool?): Causes numeric values to be returned as floats rather than ints. This can  
                be useful if you wish to retain some of the significant digits lost when  
                using the unit size flags.  
                Properties: create
        debug (bool?): Print debugging statistics on arena memory (if it exists)  
                Properties: create
        freeMemory (bool?): Returns size of free memory  
                Properties: create
        gigaByte (bool?): Return memory sizes in gigabytes (1024*1024*1024 bytes)  
                Properties: create
        heapMemory (bool?): Returns size of memory heap  
                Properties: create
        kiloByte (bool?): Return memory sizes in kilobytes (1024 bytes)  
                Properties: create
        megaByte (bool?): Return memory sizes in megabytes (1024*1024 bytes)  
                Properties: create
        pageFaults (bool?): Returns number of page faults  
                Properties: create
        pageReclaims (bool?): Returns number of page reclaims  
                Properties: create
        physicalMemory (bool?): Returns size of physical memory  
                Properties: create
        processVirtualMemory (bool?): Returns size of virtual memory allocated by the process  
                Properties: create
        summary (bool?): Returns a summary of memory usage. The size flags are ignored and all  
                memory sizes are given in megabytes.  
                Properties: create
        swapFree (bool?): Returns size of free swap  
                Properties: create
        swapLogical (bool?): Returns size of logical swap  
                Properties: create
        swapMax (bool?): Returns maximum swap size  
                Properties: create
        swapPhysical (bool?): Returns size of physical swap  
                Properties: create
        swapReserved (bool?): Returns size of reserved swap  
                Properties: create
        swapVirtual (bool?): Returns size of virtual swap  
                Properties: create
        swaps (bool?): Returns number of swaps  
                Properties: create

    Returns:
        bool:

    Example:
    """

def menu(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowOptionBoxes: bool = ..., defineTemplate: str = ..., deleteAllItems: bool = ..., docTag: Queryable[str] = ..., enable: bool = ..., exists: bool = ..., familyImage: Queryable[str] = ..., helpMenu: bool = ..., itemArray: bool = ..., label: Queryable[str] = ..., mnemonic: Queryable[str] = ..., numberOfItems: bool = ..., parent: str = ..., postMenuCommand: Callable[..., Any] = ..., postMenuCommandOnce: bool = ..., scrollable: bool = ..., tearOff: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ...) -> Union[str, bool]:
    """This command creates a new menu and adds it to the default window's
    menubar if no parent is specified.  The menu can be enabled/disabled.
    Note that this command may also be used on menu objects created using
    the command
    Args:
        allowOptionBoxes (bool?): Deprecated. All menus now always allow option boxes.  
                Indicate whether the menu will be able to support option box  
                menu items.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteAllItems (bool?): Delete all the items in this menu.  
                Properties: create, edit
        docTag (Queryable[str]?): Attaches a tag to the menu.  
                Properties: create, query, edit
        enable (bool?): Enables/disables the menu.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        familyImage (Queryable[str]?): The filename of the icon associated with the menu. This  
                icon will be used if a menu item does not have an icon image  
                defined.  
                Properties: create, query, edit
        helpMenu (bool?): Indicates that this menu is the help menu and will be the  
                right most menu in the menu bar. On Unix systems the help menu  
                is also right justified in the menu bar.  
                Properties: create, query, edit
        itemArray (bool?): Return string array of the menu item names.  
                Properties: query
        label (Queryable[str]?): The text that is displayed for the menu.  If no label is  
                supplied then the menuName will be used.  
                Properties: create, query, edit
        mnemonic (Queryable[str]?): Set the Alt key to post that menu.  The character  
                specified must match the case of its corresponding character in  
                the menu item text, but selection from the keyboard is case  
                insensitive.  
                Properties: create, query, edit
        numberOfItems (bool?): Return number of items in the menu.  
                Properties: query
        parent (str?): Specify the window that the menu will appear in.  
                Properties: create
        postMenuCommand (Callable[..., Any]?): Specify a script to be executed when the menu is about to be  
                shown.  
                Properties: create, edit
        postMenuCommandOnce (bool?): Indicate the -pmc/postMenuCommand should only be  
                invoked once.  Default value is false, ie.  
                the -pmc/postMenuCommand is invoked every time the menu is  
                shown.  
                Properties: create, query, edit
        scrollable (bool?): Make the popup menus support scrolling. Default value is false.  
                Properties: create, query, edit
        tearOff (bool?): Makes the menu tear-off-able.  
                Properties: create
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this menu feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2014", "2015"). Currently only accepts major version  
                numbers (e.g. 2014.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): Shows/hides the menu.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the menu.

    Example:
    """

def menuBarLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., menuArray: bool = ..., menuBarVisible: bool = ..., menuIndex: Tuple[str, int] = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfMenus: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a layout containing a menu bar.  The menu bar will appear and behave
    similar to any menu bar created with the 'window -menuBar true' command.
    Menus may be created with a menuBarLayout as their parent.  Child controls
    are simply positioned to fill the menuBarLayout area beneath the menu bar
    consequently, some other layout should be used as the immediate child.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        menuArray (bool?): Return a string array containing the names of the menus in  
                the layout's menu bar.  
                Properties: query
        menuBarVisible (bool?): Visibility of the menu bar.  
                Properties: create, query, edit
        menuIndex (Tuple[str, int]?): Sets the index of a specified menu.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfMenus (bool?): Return the number of menus attached to the layout's menu bar.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def menuEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., cellHeight: Queryable[int] = ..., cellWidth: Queryable[int] = ..., cellWidthHeight: Tuple[int, int] = ..., checkBoxPresent: Queryable[Tuple[bool, str, int]] = ..., checkBoxState: Queryable[Tuple[bool, str, int]] = ..., command: Queryable[Tuple[str, str, int]] = ..., defineTemplate: str = ..., delete: Tuple[str, int] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., iconMenuCallback: str = ..., image: Queryable[Tuple[str, str, int]] = ..., isObscured: bool = ..., label: Queryable[Tuple[str, str, int]] = ..., manage: bool = ..., menuItemTypes: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., optionBoxCommand: Queryable[Tuple[str, str, int]] = ..., optionBoxPresent: Queryable[Tuple[bool, str, int]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., radioButtonPresent: Queryable[Tuple[bool, str, int]] = ..., radioButtonState: Queryable[Tuple[bool, str, int]] = ..., separator: Queryable[Tuple[str, int]] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., subMenuAt: Tuple[str, int] = ..., subMenuEditorWindow: str = ..., subMenuEditorsOpen: bool = ..., subMenuOf: Tuple[str, str, int] = ..., topLevelMenu: Queryable[str] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, Tuple[bool, str, int], Tuple[str, str, int], bool, Tuple[str, int], Callable[..., Any]]:
    """A menuEditor displays the contents of a popup menu and allows the
    menu's items to be edited. Menu items are represented by labelled
    icons which can be dragged around within the editor to change the
    menu's layout.  Various objects can be dragged and dropped into
    the menuEditor to create new menu items: toolButtons from the shelf
    or toolbox, shelfButtons from the shelf, iconTextButtons with attached
    commands, and scripts from the command window.When editing a Marking Menu, the radial menu items correspond to 8
    icons arranged in a circle within the menuEditor.  Overflow items in
    the Marking Menu (or linear items in a normal menu) are displayed in
    a column below the radial items.To edit a submenu of a popup menu, a new menuEditor instance must be
    created (typically within its own window) and attached to its parent
    menuEditor.Some flags require the position of a menu item to be passed in as an
    argument.  For these, positions are specified with a (string,int)
    pair, where the string corresponds to a radial position
    (possibily "None") and the int corresponds to a linear position
    (possibly equal to 0 for none).  Radial positions are specified by
    one of ("N",0), ("NE",0), ("E",0), ("SE",0), ("S",0), ("SW",0),
    ("W",0) or ("NW",0).  Overflow, or linear positions, are specified
    with ("None",i), where i is a 1-based index giving the position of
    the item within the overflow column.This command is not meant to be called explicitly. It was
    created to support the Marking Menu editor. It is recommended that you
    use that editor to modify marking menus.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        cellHeight (Queryable[int]?): The height of the icons in the menuEditor.  
                Properties: query, edit
        cellWidth (Queryable[int]?): The width of the icons in the menuEditor.  
                Properties: query, edit
        cellWidthHeight (Tuple[int, int]?): The width and height of the icons in the menuEditor.  
                Properties: edit
        checkBoxPresent (Queryable[Tuple[bool, str, int]]?): This controls whether a menu item has a check box or not.  
                The arguments are a flag indicating presence, followed by the position of the menu item.  
                This flag is ignored if the menu item is a submenu item.  
                If queried, an array of booleans is returned containing all the flags.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        checkBoxState (Queryable[Tuple[bool, str, int]]?): The state of the check box associated with a menu item.  
                The arguments are a flag indicating state, followed by the position of the menu item.  
                This flag is ignored if the menu item does not have a check box.  
                If queried, an array of booleans is returned containing all the flags.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        command (Queryable[Tuple[str, str, int]]?): The command or script executed by a menu item.  
                The arguments are the command string or script name, followed by the  
                position of the menu item. This flag is ignored if the menu item is  
                a submenu item or a separator item.  
                If queried, an array of strings is returned containing all the commands.  
                The first 8 entries of the array correspond to radial items (in  
                order, "N", "NE", ... "NW"), and all later entries correspond to  
                overflow (or linear) menu items.  
                Properties: query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        delete (Tuple[str, int]?): Deletes the menu item at the given position, removing it from  
                the menu.  If the menu item has a submenu, and a sub-menuEditor is  
                open and attached to it, then the sub-menuEditor's window and  
                all its child menuEditor windows will be closed recursively.  
                Properties: edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        iconMenuCallback (str?): This is the name of a MEL callback procedure that is called to  
                create the popup menus attached to icons in the menuEditor.  The  
                callback is called once for each newly created icon, and once each  
                time an icon is moved within the menuEditor.  Popup menus created  
                by the callback should contain commands for editing the menu item  
                associated with the icon.  Operations accessible through the menu  
                should include deletion of the item, editing of the  
                item's label/command/image/checkbox/optionbox, creation of a submenu,  
                and popping up a sub-menuEditor.  
              
                The arguments to the callback must match this form:  
              
                callbackProc(string $menuEditorName, string $parentIconName, string $menuTitle, string $radialPosition, int $overflowRow);  
              
                The popup menu's parent should be $parentIconName.  
              
                Note that when a sub-menuEditor is created, this flag need not be  
                re-specified as it adopts a default value equal to the value of  
                its parent menuEditor's -imc/iconMenuCallback flag.  
                Properties: create
        image (Queryable[Tuple[str, str, int]]?): The filename of the icon associated with a menu item.  
                This icon is displayed by the menuEditor to represent the menu item.  
                The arguments are the icon filename, followed by the position of the menu item.  
                If queried, an array of strings is returned containing all the icon filenames.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[Tuple[str, str, int]]?): The label of a menu item.  
                The arguments are the label text, followed by the position of the  
                menu item. If queried, an array of strings is returned containing  
                all the labels. The first 8 entries of the array correspond to radial  
                items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        menuItemTypes (bool?): This is a query only flag.  Returns an array of strings indicating the type of contents in  
                each cell of the menuEditor.  Cells can be "vacant", or may contain a regular menu "item",  
                or a "separator", or a "submenu" item.  In each case, the corresponding string is returned.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        optionBoxCommand (Queryable[Tuple[str, str, int]]?): The command or script executed by a menu item's associated option box item.  
                The arguments are the command string or script name, followed by the position of the menu item.  
                This flag is ignored if the menu item does not have an associated option box item.  
                If queried, an array of strings is returned containing all the commands.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        optionBoxPresent (Queryable[Tuple[bool, str, int]]?): This controls whether a menu item has an associated option box item or not.  
                The arguments are a flag indicating presence, followed by the position of the menu item.  
                This flag is ignored if the menu item is a submenu item.  
                If queried, an array of booleans is returned containing all the flags.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        radioButtonPresent (Queryable[Tuple[bool, str, int]]?): This controls whether a menu item has a radio button or not.  
                The arguments are a flag indicating presence, followed by the position of the menu item.  
                This flag is ignored if the menu item is a submenu item.  
                If queried, an array of booleans is returned containing all the flags.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        radioButtonState (Queryable[Tuple[bool, str, int]]?): The state of the radio button associated with a menu item.  
                The arguments are a flag indicating state, followed by the position of the menu item.  
                This flag is ignored if the menu item does not have a radio button.  
                If queried, an array of booleans is returned containing all the flags.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        separator (Queryable[Tuple[str, int]]?): In edit mode this adds a separator to the menuEditor at the  
                specified position. The parameters are the radialPosition and the  
                overflowRow. If queried, an array of booleans is returned indicating  
                if the item is a separator item. The first 8 entries of the array  
                correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): This is the style of icons within the menuEditor. Valid styles  
                are "iconOnly", "textOnly", "iconAndTextHorizontal"  
                and "iconAndTextVertical".  
                Properties: query, edit
        subMenuAt (Tuple[str, int]?): Creates a submenu item at the given position.  A submenu item  
                created within the radial portion of a menu will overwrite whatever  
                item (if any) is currently at the given position. A submenu item  
                created within the overflow (linear) portion of a menu will be  
                inserted before  
                the item currently at the given position.  
                Properties: edit
        subMenuEditorWindow (str?): The name of the window which contains a sub-menuEditor.  Only use  
                when creatitg a sub-menuEditor. This window will automatically be  
                closed if a parent menuEditor is closed or if a parent menu item  
                is deleted.  
                Properties: create
        subMenuEditorsOpen (bool?): This is a query only flag.  Returns an array of booleans, each of which indicates if a  
                sub-menuEditor is open and attached to the menu item in a particular cell.  One boolean  
                is returned for each cell in the menuEditor, even if the cell is vacant or contains  
                a non-submenu item (false will be returned in both these cases).  Only when a cell contains  
                a submenu item can true possibily be returned.  
                The first 8 entries of the array correspond to radial items (in order, "N", "NE", ... "NW"),  
                and all later entries correspond to overflow (or linear) menu items.  
                Properties: query
        subMenuOf (Tuple[str, str, int]?): Attaches a sub-menuEditor to its parent menuEditor.  Only use when  
                creatitg a sub-menuEditor. The arguments are the name  
                of the parent menuEditor, followed by the position of a submenu item  
                within the parent. A submenu item must already exist within the parent  
                at the given position. A submenu item cannot have multiple  
                sub-menuEditors attached to it.  
                Properties: create
        topLevelMenu (Queryable[str]?): The popup menu to attach to the editor.  All editing operations  
                performed in the editor (i.e. inserting/deleting/moving an item) will  
                be immediately reflected in this menu. This flag is ignored if the  
                editor is a sub-menuEditor.  The editor will update gracefully if the  
                value of the flag is changed from its initial value.  
                Properties: query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the editor.

    Example:
    """

def menuItem(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowOptionBoxes: bool = ..., annotation: Queryable[str] = ..., boldFont: bool = ..., checkBox: bool = ..., collection: Queryable[str] = ..., command: Queryable[Callable[..., Any]] = ..., data: Queryable[int] = ..., defineTemplate: str = ..., divider: bool = ..., dividerLabel: Queryable[str] = ..., docTag: Queryable[str] = ..., dragDoubleClickCommand: Queryable[Callable[..., Any]] = ..., dragMenuCommand: Queryable[Callable[..., Any]] = ..., echoCommand: bool = ..., enable: bool = ..., enableCommandRepeat: bool = ..., exists: bool = ..., familyImage: Queryable[str] = ..., image: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., insertAfter: str = ..., isCheckBox: bool = ..., isOptionBox: bool = ..., isRadioButton: bool = ..., italicized: bool = ..., label: Queryable[str] = ..., longDivider: bool = ..., optionBox: bool = ..., optionBoxIcon: Queryable[str] = ..., parent: str = ..., postMenuCommand: Queryable[Callable[..., Any]] = ..., postMenuCommandOnce: bool = ..., radialPosition: Queryable[str] = ..., radioButton: bool = ..., runTimeCommand: str = ..., sourceType: Queryable[str] = ..., subMenu: bool = ..., tearOff: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ...) -> Union[str, bool, Callable[..., Any], int]:
    """This command creates/edits/queries menu items.
    Args:
        allowOptionBoxes (bool?): Deprecated. All menus and menu items always allow option boxes.  
                In the case of submenu items this flag specifies whether the  
                submenu will be able to support option box menu items.  
                Always returns true.  
                Properties: create, query
        annotation (Queryable[str]?): Annotate the menu item with an extra string value.  
                Properties: create, query, edit
        boldFont (bool?): Specify if text should be bold. Only supported in menus  
                which use the marking menu implementation.  Default is false  
                for Windows, and true for all other platforms.  
                Properties: create, query
        checkBox (bool?): Creates a check box menu item.  Argument specifies the  
                check box value.  
                Properties: create, query, edit
        collection (Queryable[str]?): To explicitly add a radio menu item to a radioMenuItemCollection.  
                Properties: create, query
        command (Queryable[Callable[..., Any]]?): Attaches a command/script that will be executed when the  
                item is selected. Note this command is not executed when the  
                menu item is in an optionMenu control.  
                Properties: create, query, edit
        data (Queryable[int]?): Attaches a piece of user-defined data to the menu item.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        divider (bool?): Creates a divider menu item.  
                Properties: create, query
        dividerLabel (Queryable[str]?): Adds a label to a divider menu item.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Attaches a tag to the menu item.  
                Properties: create, query, edit
        dragDoubleClickCommand (Queryable[Callable[..., Any]]?): If the menu item is put on the shelf then this command  
                will be invoked when the corresponding shelf object is double  
                clicked.  
                Properties: create, query, edit
        dragMenuCommand (Queryable[Callable[..., Any]]?): If the menu item is put on the shelf then this command  
                will be invoked when the corresponding shelf object is clicked.  
                Properties: create, query, edit
        echoCommand (bool?): Specify whether the action attached with  
                the c/command flag should echo to the command output  
                areas when invoked. This flag is false by default and must be  
                specified with the c/command flag.  
                Properties: create, query, edit
        enable (bool?): Enable state for the menu item.  A disabled menu item is  
                dimmed and unresponsive.  An enabled menu item is selectable and  
                has normal appearance.  
                Properties: create, query, edit
        enableCommandRepeat (bool?): This flag only affects menu items to which a command can be  
                attached.  Specify true and the command may be repeated by  
                executing the command repeatLast.  This flag is true by  
                default for all items except for option box items.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        familyImage (Queryable[str]?): Get the filename of the family icon associated with the menu.  
                The family icon will be used for the shelf unless an icon is specified with  
                the image flag.  
                Properties: query
        image (Queryable[str]?): The filename of the icon associated with the menu item.  If  
                the menu containing the menu item is being edited with a  
                menuEditor widget, then the menuEditor will use this icon to  
                represent the menu item. This icon will be displayed on the  
                shelf when the menu item is placed there.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): Specify a short (5 character) text string to be overlayed  
                on top of the icon associated with the menu item. This is primarily  
                a mechanism for differentiating menu items that are using a Family  
                icon due to the fact that an icon image had not been explicitly  
                defined. The image overlay label will not be used if an icon  
                image is defined for the menu item.  
                Properties: create, query, edit
        insertAfter (str?): Specify After which item the new one will be placed. If  
                this flag is not specified, item is added at the end of the  
                menu. Use the empty string "" to insert before the first  
                item of the menu.  
                Properties: create
        isCheckBox (bool?): Returns true if the item is a check box item.  
                Properties: query
        isOptionBox (bool?): Returns true if the item is an option box item.  
                Properties: query
        isRadioButton (bool?): Returns true if the item is a radio button item.  
                Properties: query
        italicized (bool?): Specify if text should be italicized. Only supported in menus  
                which use the marking menu implementation.  Default is false.  
                Properties: create, query
        label (Queryable[str]?): The text that appears in the item.  
                Properties: create, query, edit
        longDivider (bool?): Indicate whether the divider is long or short. Has no effect  
                if divider label is set. Default is true.  
                Properties: create, query, edit
        optionBox (bool?): Indicates that the menu item will be an option box item.  This  
                item will appear to the right of the preceeding menu item.  
                Properties: create, query
        optionBoxIcon (Queryable[str]?): The filename of an icon to be used instead of the usual option box icon.  
                The icon is searched for in the folder specified by the XBMLANGPATH  
                environment variable.  
                The icon can be any size, but will be resized to the standard 16x16 pixels  
                when drawn.  
                Properties: create, query, edit
        parent (str?): Specify the menu that the item will appear in.  
                Properties: create
        postMenuCommand (Queryable[Callable[..., Any]]?): Specify a script to be executed when the submenu is about  
                to be shown.  
                Properties: create, query, edit
        postMenuCommandOnce (bool?): Indicate the pmc/postMenuCommand should only be  
                invoked once.  Default value is false, ie.  
                the pmc/postMenuCommand is invoked everytime the sub menu  
                is shown.  
                Properties: create, query, edit
        radialPosition (Queryable[str]?): The radial position of the menu item if it is in a Marking  
                Menu.  Radial positions are given in the form of a cardinal  
                direction, and may be "N", "NW", "W", "SW", "S", "SE", "E" or "NE".  
                Properties: create, query, edit
        radioButton (bool?): Creates a radio button menu item.  Argument specifies the  
                radio button value.  
                Properties: create, query, edit
        runTimeCommand (str?): A shortcut flag to link the menu item with a runTimeCommand.  
                The value is the name of the runTimeCommand (unique).  
                It copies the following fields from the runTimeCommand if those  
                fields have not been provided to this command:  
                label, annotation, image, command.  
                Note: command will be set to the runTimeCommand itself.  
                Properties: create, edit
        sourceType (Queryable[str]?): Set the language type for a command script. Can only be used in  
                conjunction with a command flag.  Without this flag, commands are  
                assumed to be the same language of the executing script.  In query  
                mode, will return the language of the specified command.  
                Valid values are "mel" and "python".  
                Properties: create, query, edit
        subMenu (bool?): Indicates that the item will have a submenu.  
                Subsequent menuItems will be added to the submenu  
                until setParent -menu is called.  Note that a submenu item  
                creates a menu object and consequently the menu command may  
                be used on the submenu item.  
                Properties: create, query
        tearOff (bool?): For the case where the menu item is a sub menu this flag will  
                make the sub menu tear-off-able. Note that this flag has no  
                effect on the other menu item types.  
                Properties: create, query
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this menu item feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the menu item.  A menu item is created  
                visible by default.  Note that a menu item's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit

    Returns:
        str: Full path name to the menu item.

    Example:
    """

def menuSet(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addMenu: str = ..., allMenuSets: bool = ..., currentMenuSet: Queryable[str] = ..., exists: str = ..., hotBoxVisible: bool = ..., insertMenu: Tuple[str, int] = ..., label: Queryable[str] = ..., menuArray: Queryable[List[str]] = ..., moveMenu: Tuple[str, int] = ..., moveMenuSet: Tuple[str, int] = ..., numberOfMenuSets: bool = ..., numberOfMenus: bool = ..., permanent: bool = ..., removeMenu: str = ..., removeMenuSet: str = ...) -> Union[str, bool, List[str]]:
    """Create a menu set which is used to logically order menus for display
    in the main menu bar.  Such menu sets can be edited and reordered
    dynamically.
    Args:
        addMenu (str?): Appends a menu onto the end of the current menu set.  
                Properties: create
        allMenuSets (bool?): Returns an array of the all the menu set object names in use.  Query returns string array.  
                Properties: query
        currentMenuSet (Queryable[str]?): The currently active menu set under which all operations affect (append, insert, remove, etc.).  Query returns string.  
                Properties: create, query
        exists (str?): Returns whether the specified menu set exists.  This query flag supports string arguments.  
                ie. menuSet -q -exists animationMenuSet;  
                      In query mode, this flag needs a value.  
                Properties: query
        hotBoxVisible (bool?): Whether this menu set should be displayed in the hotbox as well as in the main menubar.  
                Properties: create, query, edit
        insertMenu (Tuple[str, int]?): Inserts a menu into a specified index in the current menu set.  
                Properties: create
        label (Queryable[str]?): The label of the current menu set.  Query returns string.  
                Properties: create, query
        menuArray (Queryable[List[str]]?): An array of menu names (strings) in the current menu set.  Query returns string array.  
                Properties: create, query
        moveMenu (Tuple[str, int]?): Moves a specified menu from the current menu set to a new position.  
                Properties: create
        moveMenuSet (Tuple[str, int]?): Moves a specified menu set to another index.  
                Properties: create
        numberOfMenuSets (bool?): Number of menuSets in total.  Query returns int.  
                Properties: query
        numberOfMenus (bool?): The mumber of menus in the current menu set.  Query returns int.  
                Properties: query
        permanent (bool?): Whether this menu set can be removed.  
                Properties: create, query, edit
        removeMenu (str?): Removes a specified menu from the current menu set.  
                Properties: create
        removeMenuSet (str?): Removes the specified menu set object from the list of all menu sets.  
                Properties: create

    Returns:
        str: Name of resulting menu set.  (If there are no menu sets left, an empty string is returned)

    Example:
    """

def menuSetPref(*, edit: bool = ..., query: bool = ..., exists: bool = ..., force: bool = ..., loadAll: bool = ..., removeAll: bool = ..., saveAll: bool = ..., saveBackup: bool = ..., version: bool = ...) -> bool:
    """Provides the functionality to save and load menuSets between sessions of Maya.
    For Internal Use Only!
    Args:
        exists (bool?): Returns whether the menuSet preferences file exists or not.  
                Properties: query
        force (bool?): Forces a specified operation to continue even if errors are encountered (such as invalid  
                preferences).  
                Properties: create, edit
        loadAll (bool?): Loads all the menuSets from the preferences file only if the preferences version matches,  
                or the -force flag is enabled.  On successful load, of a prefs file, an empty string is returned,  
                otherwise, a description of the problem encountered is returned.  
                Properties: create
        removeAll (bool?): Removes all the menuSets from the preferences file (removes the whole file).  
                Properties: create
        saveAll (bool?): Saves all the current menuSets into the preferences file.  
                Properties: create
        saveBackup (bool?): Saves a backup of the current menu set preferences file if one exists.  This backup will  
                be saved in the same location as the current preferences file.  
                Properties: create
        version (bool?): The base version string which is saved out to file. It is also checked upon loading  
                in order to indicate changes in the default prefs since the prefs were last saved out.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def meshIntersectTest(*args: Any, **kwargs: Any) -> None: ...
def messageLine(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a message line where tool feedback
    is shown.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: : Full path name to the control.

    Example:
    """

def mimicManipulation(*, manipulations: str = ..., prevalidation: bool = ..., refresh: bool = ...) -> List[bool]:
    """This command mimics what various manipulators do to support
    Evaluation-Manager-accelerated manipulation.  This command should be
    use for testing, debugging and benchmarking purposes.
    Manipulations are described using a string representing a JSON object.
    This object must have a member named "session" containing an array,
    where each member of that array represents a manipulation transaction,
    i.e. plugs set by a single manipulation action.  Each of these transactions
    is also an array of plugs to set.  A plug to set is an object with a
    "plug" member, which is a string describing the plug to be manipulated,
    and a "value" member, which is the value to set to this plug.  Note that
    only plugs with attributes of type "double" or "double3" can currently be
    set and the value must be a number or an array of 3 numbers.
    A session can be thought of as the global action of a manipulation, from
    the time the manipulator is grabbed to the moment it is released, including
    the movements in between.  A transaction can be thought of as one delta
    inside the manipulation after which evaluation must happen to show the
    results, like a single mouse movement while the manipulator is held after
    which evaluation and viewport refresh must occur.manipulation
    Args:
        manipulations (str?): JSON string representing the manipulations to be performed.  
                Properties: create
        prevalidation (bool?): Flag to control if prevalidation of the manipulated plugs will be  
                performed.  If it is and the plugs are already properly supported by  
                the Evaluation Manager, Evaluation Manager manipulation will be used  
                on the very first frame instead of requiring an initial frame with  
                dirty propagation and DG evaluation to validate Evaluation Manager  
                manipulation can be safely performed.  
                Properties: create
        refresh (bool?): Flag to control if a refresh is triggered after each manipulation.  
                Note that refresh is necessary for evaluation to kick in.  
                Properties: create

    Returns:
        List[bool]: True if the transaction could be evaluated by the Evaluation Manager, false otherwise, for each provided transaction

    Example:
    """

def mimicMnipulation(*args: Any, **kwargs: Any) -> None: ...
def minimizeApp() -> bool:
    """This command minimizes (iconifies) all of the application's windows
    into a single desktop icon.  To restore the application click on the
    desktop icon.
    Returns:
        bool:

    Example:
    """

def mirrorJoint(arg0: str = ..., /, *, mirrorBehavior: bool = ..., mirrorXY: bool = ..., mirrorXZ: bool = ..., mirrorYZ: bool = ..., searchReplace: Tuple[str, str] = ...) -> List[str]:
    """This command will duplicate a branch of the skeleton from the selected
    joint symmetrically about a plane in world space.
    There are three mirroring modes(xy-, yz-, xz-plane).
    Args:
        mirrorBehavior (bool?): The mirrorBehavior flag is used to specify that when performing the  
                mirror, the joint orientation axes should be mirrored such that equal  
                rotations on the original and mirrored joints will place the skeleton  
                in a mirrored position (symmetric across the mirroring plane). Thus,  
                animation curves from the original joints can be copied to the mirrored  
                side to produce a similar (but symmetric) behavior. When mirrorBehavior  
                is not specified, the joint orientation on the mirrored side will be identical  
                to the source side.  
                Properties: create
        mirrorXY (bool?): mirror skeleton from the selected joint about xy-plane in world space.  
                Properties: create
        mirrorXZ (bool?): mirror skeleton from the selected joint about xz-plane in world space.  
                Properties: create
        mirrorYZ (bool?): mirror skeleton from the selected joint about yz-plane in world space.  
                Properties: create
        searchReplace (Tuple[str, str]?): After performing the mirror, rename the new joints by searching the name for the  
                first specified string and replacing it with the second specified string.  
                Properties: create

    Returns:
        List[str]: Names of the mirrored joints

    Example:
    """

def mirrorShape(arg0: str = ..., arg1: str = ..., /, *, mirrorAxis: str = ...) -> None: ...
def modelCurrentTimeCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., percent: Queryable[float] = ...) -> Union[str, float]:
    """This command creates a context which may be used to change current time
    within the model views.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        percent (Queryable[float]?): Percent of the screen space that represents the full time  
                slider range (default is 50%)  
                Properties: query, edit

    Returns:
        str: Context name

    Example:
    """

def modelEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeComponentsXray: bool = ..., activeCustomEnvironment: str = ..., activeCustomGeometry: Queryable[str] = ..., activeCustomLighSet: Queryable[str] = ..., activeCustomOverrideGeometry: Queryable[str] = ..., activeCustomRenderer: Queryable[str] = ..., activeOnly: bool = ..., activeShadingGraph: Queryable[str] = ..., activeView: bool = ..., addObjects: str = ..., addSelected: bool = ..., addSelectedObjects: bool = ..., allObjects: bool = ..., backfaceCulling: bool = ..., bluePencil: bool = ..., bufferMode: Queryable[str] = ..., bumpResolution: Queryable[Tuple[int, int]] = ..., camera: Queryable[str] = ..., cameraName: str = ..., cameraSet: Queryable[str] = ..., cameraSetup: bool = ..., cameras: bool = ..., capture: Queryable[str] = ..., captureSequenceNumber: Queryable[int] = ..., clipGhosts: bool = ..., cmEnabled: bool = ..., colorMap: bool = ..., colorResolution: Queryable[Tuple[int, int]] = ..., control: bool = ..., controlVertices: bool = ..., cullingOverride: Queryable[str] = ..., default: bool = ..., defineTemplate: str = ..., deformers: bool = ..., dimensions: bool = ..., displayAppearance: Queryable[str] = ..., displayLights: Queryable[str] = ..., displayTextures: bool = ..., docTag: Queryable[str] = ..., dynamicConstraints: bool = ..., dynamics: bool = ..., editorChanged: Queryable[Callable[..., Any]] = ..., excludeObjectMask: Queryable[int] = ..., excludeObjectPreset: Queryable[str] = ..., excludePluginList: Queryable[Multiuse[str]] = ..., exists: bool = ..., exposure: Queryable[float] = ..., filter: Queryable[str] = ..., filteredObjectList: bool = ..., fluids: bool = ..., fogColor: Queryable[Tuple[float, float, float, float]] = ..., fogDensity: Queryable[float] = ..., fogEnd: Queryable[float] = ..., fogMode: Queryable[str] = ..., fogSource: Queryable[str] = ..., fogStart: Queryable[float] = ..., fogging: bool = ..., follicles: bool = ..., forceMainConnection: Queryable[str] = ..., gamma: Queryable[float] = ..., greasePencils: bool = ..., grid: bool = ..., hairSystems: bool = ..., handles: bool = ..., headsUpDisplay: bool = ..., height: bool = ..., highlightConnection: Queryable[str] = ..., hulls: bool = ..., ignorePanZoom: bool = ..., ikHandles: bool = ..., imagePlane: bool = ..., interactive: bool = ..., interactiveBackFaceCull: bool = ..., interactiveDisableShadows: bool = ..., isFiltered: bool = ..., jointXray: bool = ..., joints: bool = ..., lights: bool = ..., lineWidth: Queryable[float] = ..., locators: bool = ..., lockMainConnection: bool = ..., lowQualityLighting: bool = ..., mainListConnection: Queryable[str] = ..., manipulators: bool = ..., maxConstantTransparency: Queryable[float] = ..., maximumNumHardwareLights: bool = ..., modelPanel: str = ..., motionTrails: bool = ..., nCloths: bool = ..., nParticles: bool = ..., nRigids: bool = ..., noUndo: bool = ..., nurbsCurves: bool = ..., nurbsSurfaces: bool = ..., objectFilter: Queryable[Callable[..., Any]] = ..., objectFilterList: Queryable[Callable[..., Any]] = ..., objectFilterListUI: Queryable[Callable[..., Any]] = ..., objectFilterShowInHUD: bool = ..., objectFilterUI: Queryable[Callable[..., Any]] = ..., occlusionCulling: bool = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., particleInstancers: bool = ..., pivots: bool = ..., planes: bool = ..., pluginObjects: Multiuse[Tuple[str, bool]] = ..., pluginShapes: bool = ..., polymeshes: bool = ..., queryPluginObjects: Queryable[str] = ..., removeSelected: bool = ..., rendererDeviceName: bool = ..., rendererList: bool = ..., rendererListUI: bool = ..., rendererName: Queryable[str] = ..., rendererOverrideList: bool = ..., rendererOverrideListUI: bool = ..., rendererOverrideName: Queryable[str] = ..., resetCustomCamera: bool = ..., sceneRenderFilter: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., selectionHiliteDisplay: bool = ..., setSelected: bool = ..., shadingModel: Queryable[int] = ..., shadows: bool = ..., smallObjectCulling: bool = ..., smallObjectThreshold: Queryable[float] = ..., smoothWireframe: bool = ..., sortTransparent: bool = ..., stateString: bool = ..., stereoDrawMode: bool = ..., strokes: bool = ..., subdivSurfaces: bool = ..., textureAnisotropic: bool = ..., textureCompression: bool = ..., textureDisplay: Queryable[str] = ..., textureEnvironmentMap: bool = ..., textureHilight: bool = ..., textureMaxSize: Queryable[int] = ..., textureMemoryUsed: bool = ..., textureSampling: Queryable[int] = ..., textures: bool = ..., toggleExposure: bool = ..., toggleGamma: bool = ..., transpInShadows: bool = ..., transparencyAlgorithm: Queryable[str] = ..., twoSidedLighting: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateColorMode: bool = ..., updateMainConnection: bool = ..., useBaseRenderer: bool = ..., useColorIndex: bool = ..., useDefaultMaterial: bool = ..., useInteractiveMode: bool = ..., useRGBImagePlane: bool = ..., useReducedRenderer: bool = ..., useTemplate: str = ..., userNode: Queryable[str] = ..., viewObjects: bool = ..., viewSelected: bool = ..., viewTransformName: Queryable[str] = ..., viewType: bool = ..., width: bool = ..., wireframeBackingStore: bool = ..., wireframeOnShaded: bool = ..., xray: bool = ...) -> Union[str, bool, Tuple[int, int], int, Callable[..., Any], Multiuse[str], float, Tuple[float, float, float, float]]:
    """Create, edit or query a model editor.Note that some of the flags of this command may have different settings
    for normal mode and for interactive/playback mode.  For example, a
    modelEditor can be set to use shaded mode normally, but to use wireframe
    during playback for greater speed.  Some flags also support having
    defaults set so that new model editors will be created with those settings.
    Args:
        activeComponentsXray (bool?): Turns on or off Xray mode for active components.  
                Properties: query, edit
        activeCustomEnvironment (str?): Specifies a path to an image file to be used as environment map.  
                It is only enabled when a valid scene render filter is specified.  
                Properties: edit
        activeCustomGeometry (Queryable[str]?): Specifies an identifier for custom geometry to override the geometry  
                to display. It is only enabled when a valid scene render filter is specified.  
                Properties: query, edit
        activeCustomLighSet (Queryable[str]?): Specifies an identifier for the light set to use  
                with a scene render filter. It is only enabled when a valid scene render filter is specified.  
                Properties: query, edit
        activeCustomOverrideGeometry (Queryable[str]?): Specifies an identifier for an override on the custom geometry for a scene  
                render filter.  
                Properties: query, edit
        activeCustomRenderer (Queryable[str]?): Specifies an identifier for custom renderer to use when  
                a valid scene render filter is also specified.  
                Properties: query, edit
        activeOnly (bool?): Sets whether only active objects should appear shaded in  
                shaded display.  
                Properties: query, edit
        activeShadingGraph (Queryable[str]?): Specifies the shading graph to use to override material display.  
                Only enabled when a valid scene render filter is specified.  
                Properties: query, edit
        activeView (bool?): Sets this model editor to be the active view.  Returns true  
                if successful.  On query this flag will return whether the view is  
                the active view.  
                Properties: query, edit
        addObjects (str?): This flag causes the objects contained within the selection  
                connection to be added to the list of objects visible in the view  
                (if viewSelected is true).  
                Properties: edit
        addSelected (bool?): This flag causes the currently active objects to be added  
                to the list of objects visible in the view (if viewSelected is true).  
                Properties: edit
        addSelectedObjects (bool?): If set then add the selected objects to the editor  
                Properties: create
        allObjects (bool?): Turn on/off the display of all objects for the view of  
                the model editor. This excludes NURBS, CVs, hulls, grids and  
                manipulators.  
                Properties: query, edit
        backfaceCulling (bool?): Turns on or off backface culling for the whole view.  This  
                setting overrides the culling settings of individual objects.  All  
                objects draw in the view will be backface culled.  When backface  
                culling is turned on, surfaces becomes invisible in areas where the  
                normal is pointing away from the camera.  
                Properties: query, edit
        bluePencil (bool?): Define whether the blue pencil should be added or not  
                Properties: create, query, edit
        bufferMode (Queryable[str]?): Deprecated: this is not supported in Viewport 2.0.  Sets the  
                graphic buffer mode.  Possible values are "single" or "double".  
                Properties: query, edit
        bumpResolution (Queryable[Tuple[int, int]]?): Set the resolution for "baked" bump map textures when using the  
                hardware renderer. The default value is 512, 512 respectively.  
                Properties: query, edit
        camera (Queryable[str]?): Change or query the name of the camera in model editor.  
                Properties: query, edit
        cameraName (str?): Set the name of the panel's camera transform and shape. The  
                shape name is computed by appending the string "Shape" to the  
                transform name. This flag may not be queried.  
                Properties: create, edit
        cameraSet (Queryable[str]?): Name of the camera set  
                Properties: create, query, edit
        cameraSetup (bool?): Based on the model editor name passed in will  
                returns a string list containing camera setups.  
                A camera setup can contain one or more cameras  
                which are associated with each other.  
                Camera setups are defined as pairs of consecutive  
                strings in the list. Each pair is comprised of:  
                a string which identifies an active camera,  
                and a string which defines a script  
                to set up a given active camera. As many pairs of strings  
                can be returned as the number of active cameras. If nothing  
                is returned then it is assumed that no set up is  
                required to activate a given camera.  
                Properties: query
        cameras (bool?): Turn on/off the display of cameras for the view of the  
                model editor.  
                Properties: query, edit
        capture (Queryable[str]?): Perform an one-time capture of the viewport to the named image file on disk.  
                Properties: query, edit
        captureSequenceNumber (Queryable[int]?): When a number greater or equal to 0 is specified each subsequent refresh will  
                save an image file to disk if the capture flag has been enabled.  
              
                The naming of the file is:  
              
                {root name}.#.{extension}  
              
                if the name {root name}.{extension} is used for the capture flag argument.  
              
                The value of # starts at the number specified to for this argument and  
                increments for each subsequent refresh.  
              
                Sequence capture can be disabled by specifying a number less than 0 or an  
                empty file name for the capture flag.  
                Properties: query, edit
        clipGhosts (bool?): Define whether the clip ghosts should be added or not  
                Properties: create, query, edit
        cmEnabled (bool?): Turn on or off applying color management in the editor.  If set, the color  
                management configuration set in the current editor is used.  
                Properties: query, edit
        colorMap (bool?): Queries the color map style for the model panel. Possible  
                values are "colorIndex" and "rgb".  
                Properties: query
        colorResolution (Queryable[Tuple[int, int]]?): Set the resolution for "baked" color textures when using the  
                hardware renderer. The default value is 256, 256 respectively.  
                Properties: query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        controlVertices (bool?): Turn on/off the display of NURBS CVs for the view of the  
                model editor.  
                Properties: query, edit
        cullingOverride (Queryable[str]?): Set whether to override the culling attributes on objects when using  
                the hardware renderer. The options are:  
              
                "none" : Use the culling object attributes per object.  
                "doubleSided" : Force all objects to be double sided.  
                "singleSided": Force all objects to be single sided.  
              
                The default value is "none".  
                Properties: query, edit
        default (bool?): Causes this command to modify the default value of this setting.  
                Newly created model editors will inherit the values.  This flag may  
                be used with the -interactive to set default interactive settings.  
                Properties: query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deformers (bool?): Turn on/off the display of deformer objects for the view  
                of the model editor.  
                Properties: query, edit
        dimensions (bool?): Turn on/off the display of dimension objects for the view  
                of the model editor.  
                Properties: query, edit
        displayAppearance (Queryable[str]?): Sets the display appearance of the model panel.  Possible  
                values are "wireframe", "points", "boundingBox", "smoothShaded",  
                "flatShaded".  This flag may be used with the -interactive  
                and -default flags.  Note that only "wireframe", "points", and  
                "boundingBox" are valid for the interactive mode.  
                Properties: query, edit
        displayLights (Queryable[str]?): Sets the lighting for shaded mode.  Possible values are  
                "selected", "active", "all", "default", "none".  
                Properties: query, edit
        displayTextures (bool?): Turns on or off display of textures in shaded mode  
                Properties: query, edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        dynamicConstraints (bool?): Turn on/off the display of dynamicConstraints for the view  
                of the model editor.  
                Properties: query, edit
        dynamics (bool?): Turn on/off the display of dynamics objects for the view  
                of the model editor.  
                Properties: query, edit
        editorChanged (Queryable[Callable[..., Any]]?): An optional script callback which is called when the editors  
                options have changed.  This is useful in a situation where a scripted  
                panel contains a modelEditor and wants to be notified when the contained  
                editor changes its options.  
                Properties: create, query, edit
        excludeObjectMask (Queryable[int]?): Set exclude object display settings for all individual objects at once using  
                a integer mask.  
                Properties: create, query, edit
        excludeObjectPreset (Queryable[str]?): Set exclude object display settings for all individual objects at once using  
                a named preset.  
                Properties: create, query, edit
        excludePluginList (Queryable[Multiuse[str]]?): Set exclude object display settings for a plugin object.  
                Properties: create, query, edit, multiuse
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        exposure (Queryable[float]?): The exposure value used by the color management of the current editor.  
                Properties: query, edit
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        filteredObjectList (bool?): For model editors with filtering on (either using an object filter, or isolate  
                select), this flag returns a string list of the objects which are displayed in  
                this editor. Note that this list does not take into account visibility (based on  
                camera frustum or flags), it purely captures the objects which are considered  
                when rendering the view.  
                Properties: query
        fluids (bool?): Turn on/off the display of fluids for the view  
                of the model editor.  
                Properties: query, edit
        fogColor (Queryable[Tuple[float, float, float, float]]?): The color used for hardware fogging.  
                Properties: query, edit
        fogDensity (Queryable[float]?): Determines the density of hardware fogging.  
                Properties: query, edit
        fogEnd (Queryable[float]?): The end location of hardware fogging.  
                Properties: query, edit
        fogMode (Queryable[str]?): This determines the drop-off mode for fog. The possibilities are:  
              
                "linear" : linear drop-off  
                "exponent" : exponential drop-off  
                "exponent2" : squared exponential drop-off  
                Properties: query, edit
        fogSource (Queryable[str]?): Set the type of fog algorithm to use. If the argument  
                is "fragment" (default) then fog is computed per pixel. If  
                the argument is "coordinate" then if the geometry has  
                specified vertex fog coordinates, and the OpenGL extension  
                for vertex fog is supported by the graphics system, then  
                fog is computed per vertex.  
                Properties: query, edit
        fogStart (Queryable[float]?): The start location of hardware fogging.  
                Properties: query, edit
        fogging (bool?): Set whether hardware fogging is enabled or not.  
                Properties: query, edit
        follicles (bool?): Turn on/off the display of follicles for the view  
                of the model editor.  
                Properties: query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        gamma (Queryable[float]?): The gamma value used by the color management of the current editor.  
                Properties: query, edit
        greasePencils (bool?): Define whether the grease pencil marks should be added or not  
                Properties: create, query, edit
        grid (bool?): Turn on/off the display of the grid for the view of the  
                model editor.  
                Properties: query, edit
        hairSystems (bool?): Turn on/off the display of hairSystems for the view  
                of the model editor.  
                Properties: query, edit
        handles (bool?): Turn on/off the display of select handles for the view  
                of the model editor.  
                Properties: query, edit
        headsUpDisplay (bool?): Sets whether the model panel will draw any enabled heads up  
                display	elements in this window (if true).  Currently this requires  
                the HUD elements to be globally enabled.  
                Properties: query, edit
        height (bool?): Return the height of the associated viewport in pixels  
                Properties: query
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        hulls (bool?): Turn on/off the display of NURBS hulls for the view of the  
                model editor.  
                Properties: query, edit
        ignorePanZoom (bool?): Sets whether the model panel will ignore the 2D pan/zoom value to  
                give an overview of the scene.  
                Properties: query, edit
        ikHandles (bool?): Turn on/off the display of ik handles and end effectors  
                for the view of the model editor.  
                Properties: query, edit
        imagePlane (bool?): Turn on/off the display of image plane for the view  
                Properties: query, edit
        interactive (bool?): Causes this command to modify the interactive refresh settings of  
                the view.  In this way it is possible to change the behavior of the  
                model editor during playback for improved performance.  
                Properties: query, edit
        interactiveBackFaceCull (bool?): Define whether interactive backface culling should be on or not  
                Properties: create, query, edit
        interactiveDisableShadows (bool?): Define whether interactive shadows should be disabled or not  
                Properties: create, query, edit
        isFiltered (bool?): Returns true for model editors with filtering applied to their view of the  
                scene. This could either be an explicit object filter, or a display option such  
                as isolate select which filters the objects that are displayed.  
                Properties: query
        jointXray (bool?): Turns on or off Xray mode for joints.  
                Properties: query, edit
        joints (bool?): Turn on/off the display of joints for the view of the  
                model editor.  
                Properties: query, edit
        lights (bool?): Turn on/off the display of lights for the view of the  
                model editor.  
                Properties: query, edit
        lineWidth (Queryable[float]?): Set width of lines for display  
                Properties: query, edit
        locators (bool?): Turn on/off the display of locator objects for the view  
                of the model editor.  
                Properties: query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lowQualityLighting (bool?): Set whether to use "low quality lighting" when using the  
                hardware renderer. The default value is false.  
                Properties: query, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        manipulators (bool?): Turn on/off the display of manipulator objects for the view  
                of the model editor.  
                Properties: query, edit
        maxConstantTransparency (Queryable[float]?): Sets the maximum constant transparency.  Setting this value remaps  
                constant transparency values from the range [0.0, 1.0] to the range  
                [0.0, maxConstantTransparency]. All transparency values are shifted  
                linearly to the new range, so a fully transparency object  
                (transparency 1.0) would  
                appear with a transparency of maxConstantTransparency in the viewport,  
                allowing highly transparent objects to be made visible.  This flag only  
                affects constant (non-textured) transparent objects.  
                Properties: query, edit
        maximumNumHardwareLights (bool?): Define whether the hardware light maximum should be respected or not  
                Properties: create, query, edit
        modelPanel (str?): Allows the created model editor to be embedded in the named model panel.  
                Intended for use with custom model editors created via the API (i.e. the  
                flag would be used on the derived MPxModelEditorCommand), though the flag  
                may also be used on the base modelEditor command to restore a default Maya  
                model editor to the panel.  
                Note that the model editor previously owned by the panel is deleted.  
                Properties: create
        motionTrails (bool?): Turn on/off the Motion Trail display in the Viewport.  
                Properties: query, edit
        nCloths (bool?): Turn on/off the display of nCloths for the view  
                of the model editor.  
                Properties: query, edit
        nParticles (bool?): Turn on/off the display of nParticles for the view  
                of the model editor.  
                Properties: query, edit
        nRigids (bool?): Turn on/off the display of nRigids for the view  
                of the model editor.  
                Properties: query, edit
        noUndo (bool?): This flag prevents some viewport operations (such as isolate  
                select) from being added to the undo queue.  
                Properties: edit
        nurbsCurves (bool?): Turn on/off the display of nurbs curves for the view  
                of the model editor.  
                Properties: query, edit
        nurbsSurfaces (bool?): Turn on/off the display of nurbs surfaces for the view  
                of the model editor.  
                Properties: query, edit
        objectFilter (Queryable[Callable[..., Any]]?): Set or query the current object filter name. An object filter  
                is required to have already been registered.  
                Properties: query, edit
        objectFilterList (Queryable[Callable[..., Any]]?): Return a list of names of registered filters.  
                Properties: query
        objectFilterListUI (Queryable[Callable[..., Any]]?): Return a list of UI names of registered filters.  
                Properties: query
        objectFilterShowInHUD (bool?): Sets whether or not to display the object filter UI name in the heads  
                up display when an object filter is active. This string is concatenated  
                with the camera name.  
                Properties: query, edit
        objectFilterUI (Queryable[Callable[..., Any]]?): Query the current object filter UI name. The object filter  
                is required to have already been registered.  
                Properties: query
        occlusionCulling (bool?): Set whether to enable occlusion culling testing when using  
                the hardware renderer. The default value is false.  
                Properties: query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        particleInstancers (bool?): Define whether the particle instances should be shown or not  
                Properties: create, query, edit
        pivots (bool?): Turn on/off the display of transform pivots for the view  
                of the model editor.  
                Properties: query, edit
        planes (bool?): Turn on/off the display of sketch planes for the view  
                of the model editor.  
                Properties: query, edit
        pluginObjects (Multiuse[Tuple[str, bool]]?): Turn on/off the display of plug-in objects for the view.  
                It depends on the plug-in implementation whether to respect this flag.  
                Properties: edit, multiuse
        pluginShapes (bool?): Turn on/off the display of plug-in shapes for the view.  
                It depends on the plug-in implementation whether to respect this flag.  
                Properties: edit
        polymeshes (bool?): Turn on/off the display of polygon meshes for the view  
                of the model editor.  
                Properties: query, edit
        queryPluginObjects (Queryable[str]?): Query the on/off state of plug-in objects display for the view.  
                To set the on/off state, use -pluginObjects instead.  
                Properties: query
        removeSelected (bool?): This flag causes the currently active objects to be removed  
                from the list of objects visible in the view (if viewSelected is true).  
                Properties: edit
        rendererDeviceName (bool?): Query for the name of the draw API used by the Viewport 2.0 renderer for a 3d modeling viewport.  
                The possible return values are "VirtualDeviceGL" if Maya is set to use "OpenGL - Legacy" for Viewport 2.0,  
                "VirtualDeviceGLCore" if Maya is set to use "OpenGL - Core Profile" (either Compatibility or Strict) for  
                Viewport 2.0, or "VirtualDeviceDx11" if Maya is set to use DirectX for Viewport 2.0.  
                If the renderer for the 3d modeling viewport is not Viewport 2.0, an empty string will be returned.  
                Properties: query
        rendererList (bool?): Query for a list of the internal names for renderers available for use with the  
                3d modeling viewport. The default list contains at least "vp2Renderer", if supported. See  
                rendererName for more details on these renderers. Any plug-in viewport renderers will also appear  
                in this list.  
                Properties: query
        rendererListUI (bool?): Query for a list of the UI names for renderers available for use with the  
                3d modeling viewport. The default list consists of the UI name for "vp2Renderer", if it is supported.  
                Any plug-in viewport renderer's UI names will also appear in this list. This list  
                and the list returned from rendererList have a 1. 1 correspondance.  
                Properties: query
        rendererName (Queryable[str]?): Set or get the renderer used for a 3d modeling viewport. The name provided  
                should be an internal name of a renderer. The 'rendererList' flag  
                can be used to query for a list of available names.  
                The default renderer is "vp2Renderer": Viewport 2.0.  
                Properties: query, edit
        rendererOverrideList (bool?): Query for a list of the internal names for renderer overrides for a 3d viewport renderer.  
                Currently only the "Viewport 2" renderer supports renderer overrides.  
                Properties: query
        rendererOverrideListUI (bool?): Query for a list of the UI names for renderer overrides for a 3d viewport renderer.  
                Currently only the "Viewport 2" renderer supports renderer overrides.  
                Properties: query
        rendererOverrideName (Queryable[str]?): Set or get the override used for a 3d viewport renderer. The name provided  
                should be the internal name for an override.  The 'rendererOverrideList' flag  
                can be used to query for a list of available names.  
                Currently only the "Viewport 2" renderer  supports renderer overrides.  
                Setting an empty string will unset any currently active override.  
                Properties: query, edit
        resetCustomCamera (bool?): When specified will reset the camera transform for the active custom camera  
                used for a scene render filter. It is only enabled when a valid scene render filter is specified.  
                Properties: edit
        sceneRenderFilter (Queryable[str]?): Specifies the name of a scene render filter  
                Properties: query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        selectionHiliteDisplay (bool?): Sets whether the model panel will draw any selection hiliting  
                on the objects in this window.  
                Properties: query, edit
        setSelected (bool?): This flag causes the currently active objects to be the  
                only objects visible in the view (if viewSelected is true).  
                Properties: edit
        shadingModel (Queryable[int]?): Shading model to use  
                Properties: create, query, edit
        shadows (bool?): Turn on/off the display of hardware shadows in shaded mode.  
                Properties: query, edit
        smallObjectCulling (bool?): Define whether small object culling should be enabled or not  
                Properties: create, query, edit
        smallObjectThreshold (Queryable[float]?): Threshold used for small object culling  
                Properties: create, query, edit
        smoothWireframe (bool?): Turns on or off smoothing of wireframe lines and points  
                Properties: query, edit
        sortTransparent (bool?): This flag turns on/off sorting of transparent objects during  
                shaded mode refresh. Normally, objects are sorted according to their  
                origin in camera space but when this flag is turned off they will be  
                drawn according to their (depth-first traversal) order in the scene  
                graph. This is a global flag that affects all model editors.  
                Properties: query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        stereoDrawMode (bool?): If this flag is used then set stereo draw mode  
                Properties: create, query, edit
        strokes (bool?): Turn on/off the display of Paint Effects strokes for the view  
                Properties: query, edit
        subdivSurfaces (bool?): Turn on/off the display of subdivision surfaces for the view  
                of the model editor.  
                Properties: query, edit
        textureAnisotropic (bool?): Set whether to perform anisotropic texture filtering.  
                Will work only if the anisotropic texture filtering extension  
                is supported in OpenGL on the graphics system.  
                Properties: query, edit
        textureCompression (bool?): Defines whether texture compression should be used or not  
                Properties: create, query, edit
        textureDisplay (Queryable[str]?): Set the type of blending to use for textures.  
                The blend is performed between the destination fragment  
                and the texture fragment. The source is usually the  
                material color. Argument options are:  
                "modulate" : multiply the destination and texture fragment  
                "decal" : overwrite the destination with the texture fragment  
                Properties: query, edit
        textureEnvironmentMap (bool?): If true then use a texture environment map  
                Properties: create, query, edit
        textureHilight (bool?): Set whether to show specular hilighting  
                when the display is in shaded textured mode.  
                Properties: query, edit
        textureMaxSize (Queryable[int]?): Set maximum texture size for hardware texturing.  The integer  
                value must be a power of 2.  Recommended values are 128 or 256.  If  
                the value specified is larger than the OpenGL maximim textures size  
                for the graphics hardware it will be clamped to the OpenGL size.  If  
                many large textures are used in a scene reducing this value improves  
                performance.  On Impact texture memory is pinned in RAM so using  
                large textures can cause reliability and performance problems. Again  
                reducing this value will help. Software rendering does not use this  
                value.  
                This flag is obsolete as of Maya 6.5. The maxTextureResolution/mtr  
                argument on the displayPref command should be used instead.  
                Properties: query, edit
        textureMemoryUsed (bool?): Returns the total number of bytes used by all texture maps.  This  
                is typicly width*height*channels for all texture objects in the scene  
                If the texture is mip mapped all mip map levels are included in the  
                total though not never more than two level will be in use at one time  
                Properties: query
        textureSampling (Queryable[int]?): Set the type of sampling to be used for texture  
                display. The argument can be either:  
              
                1. means to perform point sample  
                2. means to perform bilinear interpolation (default)  
                Properties: query, edit
        textures (bool?): Turn on/off the display of texture objects for the view  
                Properties: query, edit
        toggleExposure (bool?): Toggles between the current and the default exposure value of the editor.  
                Properties: edit
        toggleGamma (bool?): Toggles between the current and the default gamma value of the editor.  
                Properties: edit
        transpInShadows (bool?): Set whether to enable display of transparency in shadows when  
                using the hardware renderer. The default value is false.  
                Properties: query, edit
        transparencyAlgorithm (Queryable[str]?): Set the transparency algorithm.  
                The options are:  
              
                1) "frontAndBackCull" : Two pass front and back culling technique.  
                2) "perPolygonSort" : Draw transparent polygons in back-to-front order technique.  
              
                transparency pptions 1) and 2) are supported by the hardware renderer. Options 1) is  
                supported by the interactive modeling viewports.  
                The default value is "frontAndBackCull".  
                Properties: query, edit
        twoSidedLighting (bool?): Turns on or off two sided lighting.  This may be used with  
                the -default flag.  
                Properties: query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateColorMode (bool?): Using this flag tells the model panel to check which color  
                mode it should be in, and to switch accordingly.  This flag may  
                be used to update a model panel after a camera image plane has  
                been added or removed.  
                Properties: edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useBaseRenderer (bool?): Set whether to use the "base" renderer when using  
                the hardware renderer and in "interactive display mode" (-useInteractiveMode)  
                The default value is false.  
                Properties: query, edit
        useColorIndex (bool?): Sets whether the model panel will attempt to use color index  
                mode when possible.  Color index mode can provide a performance  
                increase for point, bounding box, and wireframe display modes.  
                This may be used with the -default flag.  
                Properties: query, edit
        useDefaultMaterial (bool?): Sets whether the model panel will draw all the shaded surfaces  
                using the default material as opposed to using the material(s) currently  
                assigned to the surfaces.  
                Properties: query, edit
        useInteractiveMode (bool?): Turns on or off the use of the special interaction settings  
                during playback.  This flag may be used with the -default flag.  
                Properties: query, edit
        useRGBImagePlane (bool?): Sets whether the model panel will be forced into RGB mode  
                when there is an image plane attached to the panel's camera.  
                Properties: query, edit
        useReducedRenderer (bool?): Set true if using the reduced renderer  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        userNode (Queryable[str]?): Allows the user to associate a node name with the modelEditor.  
                The value is automatically updated in the event the node is deleted  
                or renamed.  
                Properties: query, edit
        viewObjects (bool?): Returns the name (if any) of the objectSet which contains the  
                list of objects visible in the view if viewSelected is true and the  
                list of objects being displayed does not come from the  
                active list.  
                Properties: query
        viewSelected (bool?): This flag turns on/off viewing of selected objects. When the  
                flag is set to true, the currently active objects are captured and  
                used as the list of objects to view.  
                Properties: query, edit
        viewTransformName (Queryable[str]?): Sets the view pipeline to be applied if color management is enabled in the  
                current editor.  
                Properties: query, edit
        viewType (bool?): Returns a string indicating the type of the model editor. For the  
                default model editor, returns the empty string. For custom model  
                editor types created via the API, returns the same string as is  
                returned via the method MPx3dModelView::viewType().  
                Properties: query
        width (bool?): Return the width of the associated viewport in pixels.  
                Properties: query
        wireframeBackingStore (bool?): Sets whether a backing store is used to optimization the drawing  
                of active objects. This mode can provide a performance increase in  
                wireframe mode for certain scenes.  
                Properties: query, edit
        wireframeOnShaded (bool?): Sets whether the model panel will draw the wireframe on  
                all shaded objects (if true) or only for active objects (if false).  
                Properties: query, edit
        xray (bool?): Turns on or off Xray mode.  This may be used with the -default  
                flag.  
                Properties: query, edit

    Returns:
        str: the name of the editor.

    Example:
    """

def modelPanel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., barLayout: bool = ..., camera: Queryable[str] = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., modelEditor: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command creates a panel consisting of a model editor. See
    thecommand documentation for more information.
    Args:
        barLayout (bool?): This flag returns the name of the layout which is the parent of  
                the panels icon bar.  
                Properties: query
        camera (Queryable[str]?): Query or edit the camera in a modelPanel.  
                Properties: query, edit
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        modelEditor (bool?): This flag returns the name of the model editor  
                contained by the panel.  
                Properties: query
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the panel.

    Example:
    """

def modelingToolkitSuperCtx(*args: Any, **kwargs: Any) -> None: ...
def moduleInfo(*, definition: bool = ..., listModules: bool = ..., moduleName: str = ..., path: bool = ..., version: bool = ...) -> List[str]:
    """Returns information on modules found by Maya.module
    Args:
        definition (bool?): Returns module definition file name for the module specified by the -moduleName parameter.  
                Properties: create
        listModules (bool?): Returns an array containing the names of all currently loaded modules.  
                Properties: create
        moduleName (str?): The name of the module whose information you want to retrieve. Has to be used with either -definition / -path / -version flags.  
                Properties: create
        path (bool?): Returns the module path for the module specified by the -moduleName parameter.  
                Properties: create
        version (bool?): Returns the module version for the module specified by the -moduleName parameter.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def mouldMesh(*args: Any, **kwargs: Any) -> None: ...
def mouldSrf(*args: str) -> None: ...
def mouldSubdiv(*args: Any, **kwargs: Any) -> None: ...
def mouse(*, enableScrollWheel: bool = ..., mouseButtonTracking: int = ..., mouseButtonTrackingStatus: bool = ..., scrollWheelStatus: bool = ...) -> int:
    """This command allows to configure mouse.
    Args:
        enableScrollWheel (bool?): Enable or disable scroll wheel support.  
                Properties: create
        mouseButtonTracking (int?): Set the number (1, 2 or 3) of mouse buttons to track.  
                Note: this is only supported on Macintosh  
                Properties: create
        mouseButtonTrackingStatus (bool?): returns the current number of mouse buttons being tracked.  
                Properties: create
        scrollWheelStatus (bool?): returns the current status of scroll wheel support.  
                Properties: create

    Returns:
        int: When -scrollWheelStatus flag is used, will return 1 if scroll wheel support enabled, otherwise 0.
            When -mouseButtonTrackingStatus flag is used, will return the number of mouse buttons being tracked.

    Example:
    """

def movIn(*args: str, file: str = ..., startTime: int = ...) -> bool:
    """Imports a .mov file into animation curves connected to  the listed
    attributes. The attribute must be writable, since an animation curve
    will be created and connected to the attribute. If an animation curve
    already is connected to the attribute, the imported data is pasted onto
    that curve.The starting time used for the .mov file importation is the current time
    when the command is executed.Valid attribute types are numeric attributes; time attributes; linear
    attributes; angular attributes; compound attributes made of the types
    listed previously; and multi attributes composed of the types listed
    previously. If an unsuppoted attribute type is requested, the command
    will fail and no data will be imported. It is important that your
    user units are set to the same units used in the .mov file, otherwise
    linear and angular values will be incorrect.To export a .mov file, use the movOut command.
    Args:
        file (str?): The name of the .mov file. If no extension is used, a .mov will be  
                added.  
                Properties: create
        startTime (int?): The default start time for importing the .mov file is the  
                current time. The startTime option sets the starting time for  
                the .mov data in the current time unit.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def movOut(*args: str, comment: bool = ..., file: str = ..., precision: int = ..., time: NullableRange[float] = ...) -> bool:
    """Exports a .mov file from the listed attributes. Valid attribute types
    are numeric attributes; time attributes; linear attributes; angular
    attributes; compound attributes made of the types listed previously;
    and multi attributes composed of the types listed previously.Length, angle, and time values will be written to the file in the
    user units.If an unsupported attribute type is requested, the action will fail.
    The .mov file may be read back into Maya using the movIn command.
    Args:
        comment (bool?): If true, the attributes written to the .mov file will be listed  
                in a commented section at the top of the .mov file. The default is  
                false.  
                Properties: create
        file (str?): The name of the .mov file. If no extension is used, a .mov will be  
                added.  
                Properties: create
        precision (int?): Sets the number of digits to the right of the decimal place in  
                the .mov file.  
                C: The default is 6.  
                Properties: create
        time (NullableRange[float]?): The time range to save as a .mov file. The default is the current  
                time range.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def move(arg0: float = ..., arg1: float = ..., arg2: float = ..., /, *args: str, absolute: bool = ..., componentOffset: bool = ..., componentSpace: bool = ..., constrainAlongNormal: bool = ..., deletePriorHistory: bool = ..., localSpace: bool = ..., moveX: bool = ..., moveXY: bool = ..., moveXYZ: bool = ..., moveXZ: bool = ..., moveY: bool = ..., moveYZ: bool = ..., moveZ: bool = ..., objectSpace: bool = ..., orientJoint: str = ..., parameter: bool = ..., preserveChildPosition: bool = ..., preserveGeometryPosition: bool = ..., preserveUV: bool = ..., reflection: bool = ..., reflectionAboutBBox: bool = ..., reflectionAboutOrigin: bool = ..., reflectionAboutX: bool = ..., reflectionAboutY: bool = ..., reflectionAboutZ: bool = ..., reflectionTolerance: float = ..., relative: bool = ..., rotatePivotRelative: bool = ..., scalePivotRelative: bool = ..., secondaryAxisOrient: str = ..., symNegative: bool = ..., worldSpace: bool = ..., worldSpaceDistance: bool = ..., xformConstraint: str = ...) -> bool:
    """The move command is used to change the positions of geometric
    objects.The default behaviour, when no objects or flags are passed, is
    to do a absolute move on each currently selected object in the
    world space. The value of the coordinates are interpreted as
    being defined in the current linear unit unless the unit is
    explicitly mentioned.When using -objectSpace there are two ways to use this command.
    If numbers are typed without units then the internal values of
    the object are set to these values. If, on the other hand a
    unit is specified then the internal value is set to the equivalent
    internal value that represents that world-space distance.The -localSpace flag moves the object in its parent space. In this
    space the x,y,z values correspond directly to the tx, ty, tz
    channels on the object.The -rotatePivotRelative/-scalePivotRelative flags can be used
    with the -absolute flag to translate an object so that its
    pivot point ends up at the given absolute position. These
    flags will be ignored if components are specified.The -worldSpaceDistance flag is a modifier flag that may be used
    in conjunction with the -objectSpace/-localSpace flags. When this
    flag is specified the command treats the x,y,z values as world
    space units so the object will move the specified world space
    distance but it will move along the axis specified by the
    -objectSpace/-localSpace flag. The default behaviour, without
    this flag, is to treat the x,y,z values as units in object
    space or local space. In other words, the worldspace distance
    moved will depend on the transformations applied to the object
    unless this flag is specified.
    Args:
        absolute (bool?): Perform an absolute operation.  
                Properties: create
        componentOffset (bool?): Move components individually in local space  
                Properties: create
        componentSpace (bool?): Move in local component space  
                Properties: create
        constrainAlongNormal (bool?): When true, transform constraints are applied along the vertex normal first  
                and only use the closest point when no intersection is found along the normal.  
                Properties: create
        deletePriorHistory (bool?): If true then delete the history prior to the current operation.  
                Properties: create
        localSpace (bool?): Move in local space  
                Properties: create
        moveX (bool?): Move in X direction  
                Properties: create
        moveXY (bool?): Move in XY direction  
                Properties: create
        moveXYZ (bool?): Move in all directions (default)  
                Properties: create
        moveXZ (bool?): Move in XZ direction  
                Properties: create
        moveY (bool?): Move in Y direction  
                Properties: create
        moveYZ (bool?): Move in YZ direction  
                Properties: create
        moveZ (bool?): Move in Z direction  
                Properties: create
        objectSpace (bool?): Move in object space  
                Properties: create
        orientJoint (str?): Default is xyz.  
                Properties: create
        parameter (bool?): Move in parametric space  
                Properties: create
        preserveChildPosition (bool?): When true, transforming an object will apply an opposite transform to its  
                child transform to keep them at the same world-space position.  
                Default is false.  
                Properties: create
        preserveGeometryPosition (bool?): When true, transforming an object will apply an opposite transform to its  
                geometry points to keep them at the same world-space position.  
                Default is false.  
                Properties: create
        preserveUV (bool?): When true, UV values on translated components are projected along the translation  
                in 3d space. For small edits, this will freeze the world space texture mapping  
                on the object.  
                When false, the UV values will not change for a selected vertices.  
                Default is false.  
                Properties: create
        reflection (bool?): To move the corresponding symmetric components also.  
                Properties: create
        reflectionAboutBBox (bool?): Sets the position of the reflection axis  at the geometry bounding box  
                Properties: create
        reflectionAboutOrigin (bool?): Sets the position of the reflection axis  at the origin  
                Properties: create
        reflectionAboutX (bool?): Specifies the X=0 as reflection plane  
                Properties: create
        reflectionAboutY (bool?): Specifies the Y=0 as reflection plane  
                Properties: create
        reflectionAboutZ (bool?): Specifies the Z=0 as reflection plane  
                Properties: create
        reflectionTolerance (float?): Specifies the tolerance to findout the corresponding reflected components  
                Properties: create
        relative (bool?): Perform a operation relative to the object's current position  
                Properties: create
        rotatePivotRelative (bool?): Move relative to the object's rotate pivot point.  
                Properties: create
        scalePivotRelative (bool?): Move relative to the object's scale pivot point.  
                Properties: create
        secondaryAxisOrient (str?): Default is xyz.  
                Properties: create
        symNegative (bool?): When set the component transformation is flipped so it is relative to the  
                negative side of the symmetry plane. The default (no flag) is to transform  
                components relative to the positive side of the symmetry plane.  
                Properties: create
        worldSpace (bool?): Move in world space  
                Properties: create
        worldSpaceDistance (bool?): Move is specified in world space units  
                Properties: create
        xformConstraint (str?): Apply a transform constraint to moving components.  
              
                none - no constraint  
                surface - constrain components to the surface  
                edge - constrain components to surface edges  
                live - constraint components to the live surface  
                Properties: create

    Returns:
        bool:

    Example:
    """

def moveKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., moveFunction: Queryable[str] = ..., name: str = ..., option: Queryable[str] = ...) -> str:
    """This command creates a context which may be used to move keyframes
    within the graph editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        moveFunction (Queryable[str]?): linear | power | constant. Specifies how the keys are  
                dragged. The default move type is constant where all  
                keys move the same amount as controlled by user movement.  
                Power provides a fall-off function where the center of  
                the drag moves the most and the keys around the drag move  
                less.  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        option (Queryable[str]?): Valid values are "move," "insert," "over," and  
                "segmentOver." When you "move" a key, the key will not cross over  
                (in time) any keys before or after it. When you "insert" a key,  
                all keys before or after (depending upon the -timeChange value)  
                will be moved an equivalent amount. When you "over" a key, the key  
                is allowed to move to any time (as long as a key is not there already).  
                When you "segmentOver" a set of keys (this option only has a  
                noticeable effect when more than one key is being moved) the first  
                key (in time) and last key define a segment (unless you specify a  
                time range). That segment is then allowed to move over other keys,  
                and keys will be moved to make room for the segment.  
                Properties: create, query, edit

    Returns:
        str: Context name

    Example:
    """

def moveVertexAlongDirection(*args: str, direction: Multiuse[Tuple[float, float, float]] = ..., magnitude: Multiuse[float] = ..., normalDirection: Multiuse[float] = ..., uDirection: Multiuse[float] = ..., uvNormalDirection: Multiuse[Tuple[float, float, float]] = ..., vDirection: Multiuse[float] = ...) -> bool:
    """The command moves the selected vertex ( control vertex ) in
    the specified unit direction by the given magnitude. The vertex(ices)
    may also be moved in the direction of unit normal ( -n flag ).
    For NURBS surface vertices the direction of movement could also
    be either in tangent along U or tangent along V.  The flags -n,
    -u, -v and -d are mutually exclusive, ie. the selected vertices
    can be all moved in only -n or -u or -v or -d.
    Args:
        direction (Multiuse[Tuple[float, float, float]]?): move the vertex along the direction as specified. The direction is  
                normalized.  
                Properties: create, multiuse
        magnitude (Multiuse[float]?): move by the specified magnitude in the direction vector.  
                Properties: create, multiuse
        normalDirection (Multiuse[float]?): move components in the direction of normal by the given magnitude at  
                the respective components. The normal is 'normalized'.  
                Properties: create, multiuse
        uDirection (Multiuse[float]?): move components in the direction of tangent along U at the  
                respective components where appropriate. The flag is ignored  
                for polygons, NURBS curves. The u direction is normalized.  
                Properties: create, multiuse
        uvNormalDirection (Multiuse[Tuple[float, float, float]]?): move in the triad space [u,v,n] at the respective components by the  
                specified displacements. The flag is ignored for polygons, NURBS curves.  
                Properties: create, multiuse
        vDirection (Multiuse[float]?): move components in the direction of tangent along V at the  
                respective components where appropriate. The flag is ignored  
                for polygons, NURBS curves.  
                Properties: create, multiuse

    Returns:
        bool:

    Example:
    """

def movieCompressor(*args: Any, **kwargs: Any) -> None: ...
def movieInfo(arg0: str = ..., /, *, counter: bool = ..., dropFrame: bool = ..., frameCount: bool = ..., frameDuration: bool = ..., height: bool = ..., movieTexture: bool = ..., negTimesOK: bool = ..., numFrames: bool = ..., quickTime: bool = ..., timeCode: bool = ..., timeCodeTrack: bool = ..., timeScale: bool = ..., twentyFourHourMax: bool = ..., width: bool = ...) -> bool:
    """movieInfo provides a mechanism for querying information about movie
    files.movie, imageplane, avi, quicktime
    Args:
        counter (bool?): Query the 'counter' flag of the movie's timecode format.  
                If this is true, the timecode returned by the -timeCode flag will be a simple counter.  
                If false, the returned timecode will be an array of integers (hours, minutes, seconds, frames).  
                Properties: create
        dropFrame (bool?): Query the 'drop frame' flag of the movie's timecode format.  
                Properties: create
        frameCount (bool?): Query the number of frames in the movie file  
                Properties: create
        frameDuration (bool?): Query the frame duration of the movie's timecode format.  
                Properties: create
        height (bool?): Query the height of the movie  
                Properties: create
        movieTexture (bool?): If set, the string argument is interpreted as the name of a movie texture node,  
                and the command then operates on the movie loaded by that node.  
                Properties: create
        negTimesOK (bool?): Query the 'neg times OK' flag of the movie's timecode format.  
                Properties: create
        numFrames (bool?): Query the whole number of frames per second of the movie's timecode format.  
                Properties: create
        quickTime (bool?): Query whether the movie is a QuickTime movie.  
                Properties: create
        timeCode (bool?): Query the timecode of the current movie frame.  
                Properties: create
        timeCodeTrack (bool?): Query whether the movie has a timecode track.  
                Properties: create
        timeScale (bool?): Query the timescale of the movie's timecode format.  
                Properties: create
        twentyFourHourMax (bool?): Query the '24 hour max' flag of the movie's timecode format.  
                Properties: create
        width (bool?): Query the width of the movie  
                Properties: create

    Returns:
        bool:

    Example:
    """

def mpBirailCtx(*args: Any, **kwargs: Any) -> None: ...
def mrMapVisualizer() -> None: ...
def mrShaderManager() -> None: ...
def multiProfileBirailSurface(arg0: str = ..., arg1: str = ..., arg2: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., tangentContinuityProfile1: bool = ..., tangentContinuityProfile2: bool = ..., transformMode: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], bool, int]:
    """The cmd creates a railed surface by sweeping the profiles using two
    rail curves. The two rails are the last two arguments. For examples,
    if 5 curves are specified, they will correspond to "curve1" "curve2"
    "curve3" "rail1" "rail2".In this case, the cmd creates a railed surface by sweeping the profile
    "curve1" to profile "curve2", profile "curve2" to profile "curve3"
    along the two rail curves "rail1", "rail2". There must be atleast 3
    profile curves followed by the two rail curves. The profile curves
    must intersect the two rail curves. The constructed may be made
    tangent continuous to the first and last profile using the flags -tp1,
    -tp2 provided the profiles are surface curves i.e. isoparms, curve on
    surface or trimmed edge.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tangentContinuityProfile1 (bool?): Tangent continuous across the first profile. The profile must be a surface curve.  
                Default: false  
                Properties: create, query, edit
        tangentContinuityProfile2 (bool?): Tangent continuous across the last profile. The profile must be a surface curve.  
                Default: false  
                Properties: create, query, edit
        transformMode (Queryable[int]?): transform mode ( Non proportional, proportional ). Non proportional is default value.  
                Default: 0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def multiTouch(*args: Any, query: bool = ..., gestures: bool = ..., trackpad: Queryable[int] = ...) -> Union[bool, int]:
    """Used to interact with the Gestura (multi-touch) library.
    Args:
        gestures (bool?): Enables/Disables multi touch gestures.  
                Properties: create, query
        trackpad (Queryable[int]?): Sets the trackpad mode.  Values can be:  
              
                1. Cursor Control only  
                2. Multi-touch Gestures Only  
                3. Cursor and Multi-touch  
              
                Note: this is a "Mac" only flag.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def mute(*args: str, query: bool = ..., disable: bool = ..., force: bool = ...) -> List[str]:
    """The mute command is used to disable and enable playback on a channel. When a channel is muted, it retains the value that it was at prior to being muted.mute, animation, channels
    Args:
        disable (bool?): Disable muting on the channels  
                Properties: create
        force (bool?): Forceable disable of muting on the channels. If there are keys on the mute channel,  
                the animation and mute node will both be removed.  If this flag is not set, then  
                mute nodes with animation will only be disabled.  
                Properties: create

    Returns:
        List[str]: Name(s) of the mute node(s)

    Example:
    """

def myTestCmd(*args: Any, **kwargs: Any) -> None: ...
def nBase(*args: str, edit: bool = ..., query: bool = ..., clearCachedTextureMap: str = ..., clearStart: bool = ..., stuffStart: bool = ..., textureToVertex: str = ...) -> bool:
    """Edits one or more nBase objects. Note that nBase objects include nCloth, nRigid
    and nParticle objects, but the options on this command do not currently apply
    to nParticle objects.nBase
    Args:
        clearCachedTextureMap (str?): Clear the cached texture map for the specified attribute from  
                the nBase.  
                Properties: create, edit
        clearStart (bool?): Indicates that start state should be cleared  
                Properties: create, edit
        stuffStart (bool?): Indicates that current state should be stuffed into the start state  
                Properties: create, edit
        textureToVertex (str?): Transfer the texture map data for the specified attribute into  
                the related per-vertex attribute.  
                Properties: create, edit

    Returns:
        bool: Command result

    Example:
    """

def nClothAppend() -> None: ...
def nClothAppendOpt() -> None: ...
def nClothCache() -> None: ...
def nClothCacheOpt() -> None: ...
def nClothCreate() -> None: ...
def nClothCreateOptions() -> None: ...
def nClothDeleteCacheFrames() -> None: ...
def nClothDeleteCacheFramesOpt() -> None: ...
def nClothDeleteCacheOpt() -> None: ...
def nClothDeleteHistory() -> None: ...
def nClothDeleteHistoryOpt() -> None: ...
def nClothDisplayCurrentMesh() -> None: ...
def nClothDisplayInputMesh() -> None: ...
def nClothLocalToWorld() -> None: ...
def nClothMakeCollide() -> None: ...
def nClothMakeCollideOptions() -> None: ...
def nClothMergeCache() -> None: ...
def nClothMergeCacheOpt() -> None: ...
def nClothRemove() -> None: ...
def nClothReplaceCache() -> None: ...
def nClothReplaceCacheOpt() -> None: ...
def nClothReplaceFrames() -> None: ...
def nClothReplaceFramesOpt() -> None: ...
def nClothRestToInput() -> None: ...
def nClothRestToInputStart() -> None: ...
def nClothRestToMesh() -> None: ...
def nClothWorldToLocal() -> None: ...
def nConstraintAddMembers() -> None: ...
def nConstraintAttractToMatch() -> None: ...
def nConstraintAttractToMatchOptions() -> None: ...
def nConstraintCollisionExclusion() -> None: ...
def nConstraintCollisionExclusionOptions() -> None: ...
def nConstraintComponent() -> None: ...
def nConstraintComponentOptions() -> None: ...
def nConstraintComponentToComponent() -> None: ...
def nConstraintComponentToComponentOptions() -> None: ...
def nConstraintConstraintMembershipTool() -> None: ...
def nConstraintDisableCollision() -> None: ...
def nConstraintDisableCollisionOptions() -> None: ...
def nConstraintForceField() -> None: ...
def nConstraintForceFieldOptions() -> None: ...
def nConstraintPointToSurface() -> None: ...
def nConstraintPointToSurfaceOptions() -> None: ...
def nConstraintRemoveMembers() -> None: ...
def nConstraintReplaceMembers() -> None: ...
def nConstraintSelectMembers() -> None: ...
def nConstraintSlideOnSurface() -> None: ...
def nConstraintSlideOnSurfaceOptions() -> None: ...
def nConstraintTearableSurface() -> None: ...
def nConstraintTearableSurfaceOptions() -> None: ...
def nConstraintTransform() -> None: ...
def nConstraintTransformOptions() -> None: ...
def nConstraintWeldBorders() -> None: ...
def nConstraintWeldBordersOptions() -> None: ...
def nParticle(*args: str, edit: bool = ..., query: bool = ..., attribute: str = ..., cache: bool = ..., conserve: Queryable[float] = ..., count: bool = ..., deleteCache: bool = ..., dynamicAttrList: bool = ..., floatValue: float = ..., gridSpacing: Queryable[Multiuse[float]] = ..., inherit: Queryable[float] = ..., jitterBasePoint: Queryable[Multiuse[Tuple[float, float, float]]] = ..., jitterRadius: Queryable[Multiuse[float]] = ..., lowerLeft: Queryable[Multiuse[Tuple[float, float, float]]] = ..., name: Queryable[str] = ..., numJitters: Queryable[Multiuse[int]] = ..., order: int = ..., particleId: int = ..., perParticleDouble: bool = ..., perParticleVector: bool = ..., position: Multiuse[Tuple[float, float, float]] = ..., shapeName: Queryable[str] = ..., upperRight: Queryable[Multiuse[Tuple[float, float, float]]] = ..., vectorValue: Tuple[float, float, float] = ...) -> Union[str, bool, float, Multiuse[float], Multiuse[Tuple[float, float, float]], Multiuse[int]]:
    """The nParticle command creates a new nParticle object from a list of
    world space points. If an nParticle object is created, the command
    returns the names of the new particle shape and its associated particle
    object dependency node. If an object was queried, the results of the
    query are returned. Per particle attributes can be queried using the
    particleId or the order of the particle in the particle array.
    If an object was edited, nothing is returned.
    Args:
        attribute (str?): Used in per particle attribute query and edit. Specifies the  
                name of the attribute being queried or edited.  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        cache (bool?): Turns caching on/off for the particle shape.  
                Properties: create, query, edit
        conserve (Queryable[float]?): Conservation of momentum control (between 0 and 1).  Specifies  
                the fraction of the particle shape's existing momentum which is  
                conserved from frame to frame.  
                A value of 1 (the default) corresponds to true Newtonian physics,  
                in which momentum is conserved.  
                Properties: query, edit
        count (bool?): Returns the number of particles in the object.  
                Properties: query
        deleteCache (bool?): Deletes the particle shapes cache. This command is not undoable.  
                Properties: create
        dynamicAttrList (bool?): Returns a list of the dynamic attributes in the object.  
                Properties: query
        floatValue (float?): Used only in per particle attribute edit.  Specifies that the edit is  
                of a float attribute and must be followed by the new float value.  
                Properties: edit
        gridSpacing (Queryable[Multiuse[float]]?): Spacing between particles in the grid.  
                Properties: create, query, multiuse
        inherit (Queryable[float]?): Inherit this fraction (0. 1) of emitting object's velocity.  
                Properties: query, edit
        jitterBasePoint (Queryable[Multiuse[Tuple[float, float, float]]]?): Base point (center point) for jitters.  The command will create  
                one swatch of jitters for each base point.  It will pair up  
                other flags with base points in the order they are given in the  
                command line.  If not enough instances of the other flags are  
                availble, the last one on the line with be used for all other  
                instances of -jpb.  
                Properties: create, query, multiuse
        jitterRadius (Queryable[Multiuse[float]]?): Max radius from the center to place the particle instances.  
                Properties: create, query, multiuse
        lowerLeft (Queryable[Multiuse[Tuple[float, float, float]]]?): Lower left point of grid.  
                Properties: create, query, multiuse
        name (Queryable[str]?): name of particle object  
                Properties: query, edit
        numJitters (Queryable[Multiuse[int]]?): Number of jitters (instances) per particle.  
                Properties: create, query, multiuse
        order (int?): Used in per particle attribute query and edit. Specifies the  
                zero-based order (index) of the particle whose attribute is being  
                queried  or edited in the  
                particle array. Querying the value of a per particle attribute  
                requires the -attribute and -id or -order flags and their arguments  
                to precede the -q flag.  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        particleId (int?): Used in per particle attribute query and edit. Specifies the  
                id of the particle whose attribute is being queried or edited.  
                Querying the value of a per particle attribute  
                requires the -attribute and -id or -order flags and their arguments  
                to precede the -q flag.  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        perParticleDouble (bool?): Returns a list of the per-particle double attributes,  
                excluding initial-state, cache, and information-only attributes.  
                Properties: query
        perParticleVector (bool?): Returns a list of the per-particle vector attributes,  
                excluding initial-state, cache, and information-only attributes.  
                Properties: query
        position (Multiuse[Tuple[float, float, float]]?): World-space position of each particle.  
                Properties: multiuse
        shapeName (Queryable[str]?): Specify the shape name used for geometry instancing.  
                DO not confuse this with the -n flag which names the particle object.  
                Properties: query, edit
        upperRight (Queryable[Multiuse[Tuple[float, float, float]]]?): Upper right point of grid.  
                Properties: create, query, multiuse
        vectorValue (Tuple[float, float, float]?): Used only in per particle attribute edit.  Specifies that the edit is  
                of a vector attribute and must be followed by all three float values  
                for the vector.  
                Properties: edit

    Returns:
        str: The name of the nParticle object created

    Example:
    """

def nSoft(*args: str, query: bool = ..., convert: bool = ..., duplicate: bool = ..., duplicateHistory: bool = ..., goal: float = ..., hideOriginal: bool = ...) -> str:
    """Makes a nSoft body from the object(s) passed on the command
    line or in the selection list.  The geometry can be a NURBS, polygonal,
    lattice object.  The resulting nSoft body is made up of a hierarchy
    with a particle shape and a geometry shape, thus:Dynamics are applied to the particle shape and the resulting particle
    positions then drive the locations of the geometry's CVs, vertices, or
    lattice points.With the convert option, the particle shape and its transform are simply
    inserted below the original shape's hierarchy.
    With the duplicate option, the original geometry's transform and shape are
    duplicated underneath its parent, and the particle shape is placed under
    the duplicate.  Note that any animation on
    the hierarchy will affect the particle shape as well.  If you do not want
    them, then reparent the structure outside the hierarchy.When duplicating, the nSoft portion (the duplicate) is given the name
    "copyOf" + "original object name".  The particle portion is always
    given the name "original object name" + "Particles."None of the flags of the nSoft command can be queried.  The nSoft -q
    command is used only to identify when an object is a nSoft body,
    or when two objects are part of the same nSoft body.
    See the examples.
    Args:
        convert (bool?): This tells the command that you want the original object  
                to be the actual deformed object.  The particle shape portion of the  
                nSoft body will be inserted in the same hierarchy as the original,  
                under the same parent (with one additional intervening transform  
                which is initially the identity).  If no flags are passed, then this  
                is assumed.  The combination -c -h 1 is not valid; if you have  
                this in your scripts, remove the -h 1.  
                Properties: create
        duplicate (bool?): This tells the command that you want to make a copy of  
                the original object and use the copy as the deforming geometry.  
                Input connections to the original object are duplicated.  You would  
                do this if you wanted to keep the original object in your scene and  
                also have a copy of it that was a nSoft body.  
                This flag and -dh are mutually exclusive.  
                Properties: create
        duplicateHistory (bool?): This is the same as -d, except that upstream history,  
                is duplicated as well, instead of just input connections.  
                This flag and -d are mutually exclusive.  
                Properties: create
        goal (float?): This is the same as -d, but in addition it tells the command that  
                you want the resulting nSoft body to try to  
                follow the original geometry, using the set goal weight as the value  
                that controls how strongly it is to follow it.  A value of 1.0 will  
                try to follow exactly, and a value of 0.0 will not follow at all.  
                The default value is 0.5.  This value must be from 0.0 to 1.0.  
                You could use -d with -g, but it is redundant.  If you want history to  
                be duplicated, you can use -dh and -g together.  
                Properties: create
        hideOriginal (bool?): This flag is used only when duplicating (-d, -g, or -dh).  If set to true,  
                whichever of the two objects is NOT the nSoft object will be hidden.  
                In other words, with -d -h true, the original object will be hidden;  
                with -d -c -h 1 the duplicate object will be hidden.  
                You would typically do this if you want to use the non-dynamic object as  
                a goal for the nSoft one (see -g) but you do not want it visible in the scene.  
                The flags -h 1 and -c are mutually exclusive.  
                Properties: create

    Returns:
        str: array

    Example:
    """

def nameCommand(arg0: str = ..., /, *, annotation: str = ..., command: Callable[..., Any] = ..., data1: str = ..., data2: str = ..., data3: str = ..., default: bool = ..., sourceType: str = ...) -> str:
    """This command creates a nameCommand object. Each nameCommand object
    can be connected to a hotkey. Thereafter, the nameCommand's command
    string will be executed whenever the hotkey is pressed (or released,
    as specified by the user).
    Args:
        annotation (str?): A description of the command.  
                Properties: create
        command (Callable[..., Any]?): The command that is executed  
                when the nameCommand is invoked.  
                Properties: create
        data1 (str?):   
                Properties: create
        data2 (str?):   
                Properties: create
        data3 (str?): These are optional, user-defined data strings that  
                are attached to the nameCommand object.  They can be  
                edited or queried using the assignCommand command.  
                Properties: create
        default (bool?): Indicate that this name command is a default command.  
                Default name commands will not be saved to preferences.  
                Properties: create
        sourceType (str?): Sets the language type for the command script. Can only be used in conjunction with the -command flag.  
                Valid values are "mel" (enabled by default), and "python".  
                Properties: create

    Returns:
        str: The name of the nameCommand object created

    Example:
    """

def nameField(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., drawInactiveFrame: bool = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., nameChangeCommand: Queryable[Callable[..., Any]] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., object: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., receiveFocusCommand: Queryable[Callable[..., Any]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int]:
    """This command creates an editable field that can be linked to the name
    of a Maya object. The field will always show the name of the object.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Queryable[Callable[..., Any]]?): This command is executed when the field text is changed by the user.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        drawInactiveFrame (bool?): Sets whether the name field draws itself with a frame when it is inactive.  
                By default, this option is false.  
                Properties: create, query, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        nameChangeCommand (Queryable[Callable[..., Any]]?): This command is executed when the name of the node changes.  
                NOTE: this will be executed when the node name changes, whether  
                or not the name-change originated with the user typing  
                into the field. If you want to attach a command to be executed  
                when the user types into the field, use the -cc/changeCommand flag.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        object (Queryable[str]?): Attaches the field to the named dag/ufe object, so that  
                the field will always display the object's name.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        receiveFocusCommand (Queryable[Callable[..., Any]]?): Command executed when the field receives focus.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def namespace(*, query: bool = ..., absoluteName: bool = ..., addNamespace: str = ..., collapseAncestors: str = ..., deleteNamespaceContent: bool = ..., exists: str = ..., force: bool = ..., isRootNamespace: Queryable[str] = ..., mergeNamespaceWithOther: str = ..., mergeNamespaceWithParent: bool = ..., mergeNamespaceWithRoot: bool = ..., moveNamespace: Tuple[str, str] = ..., parent: str = ..., recurse: bool = ..., relativeNames: bool = ..., removeNamespace: str = ..., rename: Tuple[str, str] = ..., setNamespace: str = ..., validateName: str = ...) -> Union[str, bool]:
    """This command allows a namespace to be created, set or removed.A namespace is a simple grouping of objects under a given name.
    Namespaces are primarily used to resolve name-clash issues in Maya,
    where a new object has the same name as an existing object (from
    importing a file, for example).  Using namespaces, you can have two
    objects with the same name, as long as they are contained in
    differenct namespaces.Namespaces are reminiscent of hierarchical structures like file
    systems where namespaces are analogous to directories and objects are
    analogous to files. The colon (':') character is the separator used to
    separate the names of namespaces and nodes instead of the slash ('/')
    or backslash ('\\') character.  Namespaces can contain other namespaces
    as well as objects.  Like objects, the names of namespaces must be
    unique within another namespace. Objects and namespaces can be in only
    one namespace. Namespace names and object names don't clash so a
    namespace and an object contained in another namespace can have the
    same name.There is an unnamed root namespace specified with a leading colon
    (':').  Any object not in a named namespace is in the root namespace.
    Normally, the leading colon is omitted from the name of an object as
    it's presence is implied. The presence of a leading colon is
    important when moving objects between namespaces using the 'rename'
    command.  For the 'rename' command, the new name is relative to the
    current namespace unless the new name is fully qualified with a
    leading colon.Namespaces are created using the 'add/addNamespace' flag. By default they are
    created under the current namespace. Changing the current namespace is
    done with the 'set/setNamespace' flag. To reset the current namespace to
    the root namespace, use 'namespace -set ":";'. Whenever an object is
    created, it is added by default to the current namespace.When creating a new namespace using a qualified name, any intervening namespaces which do
    not yet exist will be automatically created. For example, if the name of
    the new namespace is specified as "A:B" and the current namespace already
    has a child namespace named "A" then a new child namespace named "B" will
    be created under "A". But if the current namespace does not yet have a
    child named "A" then it will be created automatically. This applies
    regardless of the number of levels in the provided name (e.g. "A:B:C:D").The 'p/parent' flag can be used to explicitly specify the parent namespace
    under which the new one should be created, rather than just defaulting to
    the current namespace.If the name given for the new namespace is absolute (i.e. it begins with a
    colon, as in ":A:B") then both the current namespace and the 'parent' flag
    will be ignored and the new namespace will be created under the root namespace.The relativeNamespace flag can be used to change the way node names
    are displayed in the UI and returned by the 'ls' command. Here are
    some specific details on how the return from the 'ls' command works in
    relativeNamespace mode:
    Args:
        absoluteName (bool?): This is a general flag which can be used to specify the desired format for  
                the namespace(s) returned by the command.  
                The absolute name of the namespace is a full namespace path, starting from the root namespace ":"  
                and including all parent namespaces.  For example ":ns:ball" is an absolute namespace  
                name while "ns:ball" is not.  
                Properties: create, query
        addNamespace (str?): Create a new namespace with the given name. Both qualified names ("A:B") and unqualified names ("A") are acceptable. If any of the higher-level namespaces in a qualified name do not yet exist, they will be created.  
                If the supplied name contains invalid characters it will first be modified as per the validateName flag.  
                Properties: create
        collapseAncestors (str?): Delete all empty ancestors of the given namespace.  
                An empty namespace is a a namespace that does not contain any objects  
                or other nested namespaces  
                Properties: create
        deleteNamespaceContent (bool?): Used with the 'rm/removeNamespace' flag to indicate that when removing a namespace  
                the contents of the namespace will also be removed.  
                Properties: create
        exists (str?): Returns true if the specified namespace exists, false if not.  
                Properties: create
        force (bool?): Used with 'mv/moveNamespace' to force the move operation to ignore  
                name clashes.  
                Properties: create
        isRootNamespace (Queryable[str]?): Returns true if the specified namespace is root, false if not.  
                Properties: query
        mergeNamespaceWithOther (str?): Used with the 'rm/removeNamespace' flag.  
                When removing a namespace, move the rest of the namespace  
                content to the specified namespace.  
                Properties: create
        mergeNamespaceWithParent (bool?): Used with the 'rm/removeNamespace' flag.  
                When removing a namespace, move the rest of the namespace  
                content to the parent namespace.  
                Properties: create
        mergeNamespaceWithRoot (bool?): Used with the 'rm/removeNamespace' flag.  
                When removing a namespace, move the rest of the namespace  
                content to the root namespace.  
                Properties: create
        moveNamespace (Tuple[str, str]?): Move the contents of the first namespace into the second namespace.  
                Child namespaces will also be moved.  
              
                Attempting to move a namespace containing referenced nodes will  
                result in an error; use the 'file' command ('file -edit -namespace')  
                to change a reference namespace.  
              
                If there are objects in the source namespace with the same name as  
                objects in the destination namespace, an error will be issued. Use  
                the 'force' flag to override this error - name clashes will be  
                resolved by renaming the objects to ensure uniqueness.  
                Properties: create
        parent (str?): Used with the 'addNamespace' or 'rename' flags to specifiy  
                the parent of the new namespace. The full namespace parent path is required.  
                When using 'addNamespace' with an absolute name, the 'parent' will be ignored  
                and the command will display a warning  
                Properties: create
        recurse (bool?): Can be used with the 'exists' flag to recursively look for the  
                specified namespace  
                Properties: query
        relativeNames (bool?): Turns on relative name lookup, which causes name lookups within Maya  
                to be relative to the current namespace. By default this is off, meaning  
                that name lookups are always relative to the root namespace. Be careful  
                turning this feature on since commands such as setAttr will behave  
                differently. It is wise to only turn this feature on while executing  
                custom procedures that you have written to be namespace independent and  
                turning relativeNames off when returning control from your custom procedures.  
                Note that Maya will turn on relative naming during file I/O. Although it  
                is not recommended to leave relativeNames turned on, if you try to toggle  
                the value during file I/O you may notice that the value stays "on" because  
                Maya has already temporarily enabled it internally.  
              
                When relativeNames are enabled, the returns provided by the 'ls' command  
                will be relative to the current namespace. See the main description of this  
                command for more details.  
                Properties: create, query
        removeNamespace (str?): Deletes the given namespace.  The namespace  
                must be empty for it to be deleted.  
                Properties: create
        rename (Tuple[str, str]?): Rename the first namespace to second namespace name. Child namespaces will  
                also be renamed. Both names are relative to the current namespace. Use the  
                'parent' flag to specify a parent namespace for the renamed namespace.  
                An error is issued if the second namespace name already exists.  
                If the supplied name contains invalid characters it will first be modified  
                as per the validateName flag.  
                Properties: create
        setNamespace (str?): Sets the current namespace.  
                Properties: create
        validateName (str?): Convert the specified name to a valid name to make it contain no illegal characters.  
                The leading illegal characters will be removed and other illegal characters will be converted to '_'.  
                Specially, the leading numeric characters and trailing space characters will be also removed.  
              
                Full name path can be validated as well. However, if the namespace of the path does not exist, command will only  
                return the base name. For example, ":nonExistentNS:name" will be converted to "name".  
              
                If the entire name consists solely of illegal characters, e.g. "123" which contains only leading digits, then the returned string will be empty.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def namespaceInfo(arg0: str = ..., /, *, absoluteName: bool = ..., baseName: bool = ..., currentNamespace: bool = ..., dagPath: bool = ..., fullName: bool = ..., internal: bool = ..., isRootNamespace: bool = ..., listNamespace: bool = ..., listOnlyDependencyNodes: bool = ..., listOnlyNamespaces: bool = ..., parent: bool = ..., recurse: bool = ..., shortName: bool = ...) -> str:
    """This command displays information about a namespace. The target namespace can optionally be specified on the command line.
    If no namespace is specified, the command will display information about the current namespace.A namespace is a simple grouping of objects under a given name.
    Each item in a namespace can then be identified by its own name, along
    with what namespace it belongs to.  Namespaces can contain other
    namespaces like sets, with the restriction that all namespaces
    are disjoint.Namespaces are primarily used to resolve name-clash issues in Maya,
    where a new object has the same name as an existing object
    (from importing a file, for example).
    Using namespaces, you can have two objects with the same name, as long as
    they are contained in different namespaces.Note that namespaces are a simple grouping of names, so
    they do not effect selection, the DAG, the Dependency Graph, or any other
    aspect of Maya.  All namespace names are colon-separated.The namespace format flags are: baseName(shortName), fullName and absoluteName.
    The flags are used in conjunction with the main query flags to specify the desired namespace format of the returned result. They can also be used to return the different formats of a specified namespace.
    By default, when no format is specified, the result will be returned as a full name.
    Args:
        absoluteName (bool?): This is a general flag which can be used to specify the desired format for  
                the namespace(s) returned by the command.  
                The absolute name of the namespace is a full namespace path, starting from the root namespace ":"  
                and including all parent namespaces.  For example ":ns:ball" is an absolute namespace  
                name while "ns:ball" is not.  
                The absolute namespace name is invariant and is not affected by the current namespace or  
                relative namespace modes.  
                See also other format modifiers 'baseName', 'fullName', etc  
                Properties: create
        baseName (bool?): This is a general flag which can be used to specify the desired format for  
                the namespace(s) returned by the command. The base name of the namespace  
                contains only the leaf level name and does not contain its parent namespace(s).  
                For example the base name of an object named "ns:ball" is "ball".  
                This mode will always return the base name in the same manner, and is not affected by the  
                current namespace or relative namespace mode.  
                See also other format modifiers 'absoluteName', 'fullName', etc  
                The flag 'shortName' is a synonym for 'baseName'.  
                Properties: create
        currentNamespace (bool?): Display the name of the current namespace.  
                Properties: create
        dagPath (bool?): This flag modifies the 'listNamespace' and  
                'listOnlyDependencyNodes' flags to indicate that the names  
                of any dag objects returned will include as much of the dag path  
                as is necessary to make the names unique. If this flag is not  
                present, the names returned will not include any dag paths.  
                Properties: create
        fullName (bool?): This is a general flag which can be used to specify the desired format for  
                the namespace(s) returned by the command. The full name of the namespace  
                contains both the namespace path and the base name, but without the leading colon representing  
                the root namespace.  
                For example "ns:ball" is a full name, whereas ":ns:ball" is an absolute name.  
                This mode is affected by the current namespace and relative namespace modes.  
                See also other format modifiers 'baseName', 'absoluteName', etc.  
                Properties: create
        internal (bool?): This flag is used together with the 'listOnlyDependencyNodes' flag.  
                When this flag is set, the returned list will  
                include internal nodes (for example itemFilters) that are not listed by default.  
                Properties: create
        isRootNamespace (bool?): Returns true if the namespace is root(":"), false if not.  
                Properties: create
        listNamespace (bool?): List the contents of the namespace.  
                Properties: create
        listOnlyDependencyNodes (bool?): List all dependency nodes in the namespace.  
                Properties: create
        listOnlyNamespaces (bool?): List all namespaces in the namespace.  
                Properties: create
        parent (bool?): Display the parent of the namespace.  
                By default, the list returned will not include internal nodes (such as itemFilters).  
                To include the internal nodes, use the 'internal' flag.  
                Properties: create
        recurse (bool?): Can be specified with 'listNamespace', 'listOnlyNamespaces'  
                or 'listOnlyDependencyNode' to cause the listing to recursively  
                include any child namespaces of the namespaces;  
                Properties: create
        shortName (bool?): This flag is deprecated and may be removed in future releases of Maya.  
                It is a synonym for the baseName flag. Please use the baseName flag instead.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def newton(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., minDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A Newton field pulls an object towards the exerting object with
    force dependent on the exerting object's mass, using Newton's
    universal law of gravitation.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        minDistance (Queryable[float]?): Minimum distance at which field is exerted.  
                Distance is in the denominator of the field force equation.  
                Setting md to a small positive number avoids bizarre behavior  
                when the distance gets extremely small.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def nodeCast(arg0: str = ..., arg1: str = ..., /, *, copyDynamicAttrs: bool = ..., disableAPICallbacks: bool = ..., disableScriptJobCallbacks: bool = ..., disconnectUnmatchedAttrs: bool = ..., force: bool = ..., swapNames: bool = ..., swapValues: bool = ...) -> int:
    """Given two nodes, a source node of type A and a target node of type B,
    where type A is either type B or a sub-type of B, this command will replace the
    target node with the source node. That is, all node connections, DAG hierarchy
    and attribute values on the target node will be removed from the target node
    and placed on the source node. This operation will fail if either object is
    referenced, locked or if the nodes do not share a common sub-type.
    This operation is atomic. If the given parameters fail, then the source and
    target nodes will remain in their initial state prior to execution of the
    command.
    IMPORTANT: the command will currently ignore instance connections and
    instance objects.  It will also ignore reference nodes.node, swap, cast
    Args:
        copyDynamicAttrs (bool?): If the target node contains any dynamic attributes that are not defined on the  
                source node, then create identical dynamic attricutes on the source node and copy  
                the values and connections from the target node into them.  
                Properties: create
        disableAPICallbacks (bool?): add comment  
                Properties: create
        disableScriptJobCallbacks (bool?): add comment  
                Properties: create
        disconnectUnmatchedAttrs (bool?): If the node that is being swapped out has any connections that do not exist  
                on the target node, then indicate if the connection should be disconnected.  
                By default these connections are not removed because they cannot be restored  
                if the target node is swapped back with the source node.  
                Properties: create
        force (bool?): Forces the command to do the node cast operation even if the nodes do  
                not share a common base object. When this flag is specified the command  
                will try to do the best possible attribute matching when swapping the  
                command.  It is not recommended to use the '-swapValues/sv' flag with  
                this flag.  
                Properties: create
        swapNames (bool?): Swap the names of the nodes. By default names are not swapped.  
                Properties: create
        swapValues (bool?): Indicates if the commands should exchange attributes on the common attributes  
                between the two nodes.  For example, if the nodes are the same base type  
                as a transform node, then rotate, scale, translate values would be copied  
                over.  
                Properties: create

    Returns:
        int: 0 for success, 1 for failure.

    Example:
    """

def nodeGrapher(*args: Any, **kwargs: Any) -> None: ...
def nodeIconButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., command: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., disabledImage: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., flipX: bool = ..., flipY: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelOffset: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., overlayLabelBackColor: Queryable[Tuple[float, float, float, float]] = ..., overlayLabelColor: Queryable[Tuple[float, float, float]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rotation: Queryable[float] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useAlpha: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int, Tuple[float, float, float, float], float]:
    """This control supports up to 3 icon images and 4 different display
    styles.  The icon image displayed is the one that best fits the
    current size of the control given its current style.This command creates a button that can be displayed with different
    icons, with or without a text label. If the button is drag and dropped
    onto other controls (e.g., HyperShade), the command will be executed and
    the return string will be used as the name of a dropped node.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center". By default, the label is aligned "center".  
                Currently only available when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        command (Queryable[Callable[..., Any]]?): Command executed when the control is pressed. The command  
                should return a string which will be used to facilitate node drag  
                and drop.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disabledImage (Queryable[str]?): Image used when the button is disabled. Image size must  
                be the same as the image specified with the i/image flag.  
                This is a Windows only flag.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        flipX (bool?): Is the image flipped horizontally?  
                Properties: create, query, edit
        flipY (bool?): Is the image flipped vertically?  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): If you are not providing images with different sizes then you may  
                use this flag for the control's image. If the "iconOnly" style is  
                set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string, up to 6 characters, representing a label that will be displayed  
                on top of the image.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The text that appears in the control.  
                Properties: create, query, edit
        labelOffset (Queryable[int]?): The label offset. Default is 0. Currently only available  
                when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): The number of pixels above and below the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): The number of pixels on either side of the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        overlayLabelBackColor (Queryable[Tuple[float, float, float, float]]?): The RGBA color of the shadow behind the label defined by  
                imageOverlayLabel. Default is 50% transparent black: 0 0 0 .5  
                Properties: create, query, edit
        overlayLabelColor (Queryable[Tuple[float, float, float]]?): The RGB color of the label defined by imageOverlayLabel. Default is a  
                light grey: .8 .8 .8  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rotation (Queryable[float]?): The rotation value of the image in radians.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal", "iconAndTextVertical", and  
                "iconAndTextCentered". (Note: "iconAndTextCentered" is only available on Windows).  
                If the "iconOnly" style is set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        useAlpha (bool?): Is the image using alpha channel?  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the button

    Example:
    """

def nodeOutliner(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addCommand: Queryable[Callable[..., Any]] = ..., addObject: str = ..., annotation: Queryable[str] = ..., attrAlphaOrder: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., connectivity: Queryable[str] = ..., currentSelection: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., filter: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., lastClickedNode: bool = ..., lastMenuChoice: Queryable[str] = ..., longNames: bool = ..., manage: bool = ..., menuCommand: Callable[..., Any] = ..., menuMultiOption: bool = ..., multiSelect: bool = ..., niceNames: bool = ..., noBackground: bool = ..., noConnectivity: bool = ..., nodesDisplayed: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., pressHighlightsUnconnected: bool = ..., preventOverride: bool = ..., redraw: bool = ..., redrawRow: bool = ..., remove: Multiuse[str] = ..., removeAll: bool = ..., replace: Queryable[str] = ..., selectCommand: Queryable[Callable[..., Any]] = ..., showConnectedOnly: bool = ..., showHidden: bool = ..., showInputs: bool = ..., showNonConnectable: bool = ..., showNonKeyable: bool = ..., showOutputs: bool = ..., showPublished: bool = ..., showReadOnly: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[bool, Callable[..., Any], str, Tuple[float, float, float], int]:
    """The nodeOutliner command creates, edits and queries an outline control
    that shows dependency nodes and their attributes. Compound attributes
    are further expandable to show their children. Additional configure
    flags allow multi selection, customizable commands to issue upon
    selection, and showing connections (and connectability) to a single
    input attribute. There are also the abilities to add/remove/replace
    nodes through the command line interface, and drag/add.In some configurations, dragging a connected attribute of a node will
    load the node at the other end of the connection.There is a right mouse button menu and a flag to attach a command to
    it. The menu is used to list the specific connections of a connected
    attribute. Clicking over any spot but the row of a connected attribute
    will show an empty menu. By default, there is no command attached to
    the menu.
    Args:
        addCommand (Queryable[Callable[..., Any]]?): Command executed when the node outliner adds something.  
                String commands use substitution of the term %node for whatever is added, eg,  
                if you want to print the object added, the command should be  
                "print(\\"%node \\\\n\\")".  Callable python objects are passed the node name.  
                Properties: create, query, edit
        addObject (str?): add the given object to the display  
                Properties: edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attrAlphaOrder (Queryable[str]?): Specify how attributes are to be sorted.  Current recognised values  
                are "default" for no sorting and "ascend" to sort attributes from 'a' to ''z' and  
                "descend" to sort from 'z' to 'a'.  
                Notes: a) this only applies to top level attributes.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        connectivity (Queryable[str]?): Takes an attribute argument ("nodeName.attributeName"), dims any attributes  
                that can't connect to the given, and highlights any attributes already connected  
                Properties: query, edit
        currentSelection (bool?): Retruns a string array containing what is currently selected  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): filter attributes based on a regular expression  
                Properties: query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        lastClickedNode (bool?): Returns a string with the last clicked node  
                Properties: query
        lastMenuChoice (Queryable[str]?): Returns the text of the most recent menu selection.  
                Properties: query
        longNames (bool?): Controls whether long or short attribute names will be used  
                in the interface.  Note that this flag is ignored if the niceNames  
                flag is set.  Default is short names. Queried, returns a boolean.  
                Properties: query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        menuCommand (Callable[..., Any]?): Attaches the given command to each item in the popup menu.  
                Properties: edit
        menuMultiOption (bool?): Sets whether a menu option labelled "next available" will appear as the first  
                option on any multi-attribute's right mouse button menu.  Defaults to True.  
                Properties: query, edit
        multiSelect (bool?): Allow multiSelect; more than one thing to be selected at a time  
                Properties: query, edit
        niceNames (bool?): Controls whether the attribute names will be displayed in  
                a more user-friendly, readable way.  When this is on, the longNames  
                flag is ignored.  When this is off, attribute names will be displayed  
                either long or short, according to the longNames flag.  
                Default is on. Queried, returns a boolean.  
                Properties: query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        noConnectivity (bool?): Reset the node outliner to not show any connectivity, ie, redraw all rows normally.  
                Properties: edit
        nodesDisplayed (bool?): Returns a string array containing the list of nodes showing in the node Outliner  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        pressHighlightsUnconnected (bool?): Sets whether clicking on an unconnected plug will select it or not.  Default is True.  
                Properties: query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        redraw (bool?): Redraws the displayed space  
                Properties: edit
        redrawRow (bool?): Redraws the given row  
                Properties: edit
        remove (Multiuse[str]?): remove the given object from the display  
                Properties: edit, multiuse
        removeAll (bool?): remove all objects from the display  
                Properties: edit
        replace (Queryable[str]?): replace what's displayed with the given objects  
                Properties: query, edit
        selectCommand (Queryable[Callable[..., Any]]?): Command issued by selecting.  Different from the c flag in that this  
                command will only be issued if something is selected.  
                Properties: query, edit
        showConnectedOnly (bool?): show (true) or hide (false) only attributes that are connected matching input/output criteria  
                Properties: query, edit
        showHidden (bool?): show (true) or hide (false) UI invisible attributes that match the input/output criteria  
                Properties: query, edit
        showInputs (bool?): show only UI visible attributes that can be connected to  
                Properties: query, edit
        showNonConnectable (bool?): show (true) or hide (false) non connectable attributes that match the input/output criteria  
                Properties: query, edit
        showNonKeyable (bool?): show (true) or hide (false) non keyframeable (animatable) attributes that match the input/output criteria  
                Properties: query, edit
        showOutputs (bool?): show only UI visible attributes that can be connected from  
                Properties: query, edit
        showPublished (bool?): Show only published attributes for an asset or a member of an asset.  
                This flag is ignored on nodes not related to assets.  
                Properties: query, edit
        showReadOnly (bool?): show only read only attributes attributes that can be connected from  
                Properties: query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def nodePreset(*, attributes: str = ..., custom: str = ..., delete: Tuple[str, str] = ..., exists: Tuple[str, str] = ..., isValidName: str = ..., list: str = ..., load: Tuple[str, str] = ..., save: Tuple[str, str] = ...) -> bool:
    """Command to save and load preset settings for a node.
    This command allows you to take a snapshot of the values of all attributes of a
    node and save it to disk as a preset with user specified name. Later the saved
    preset can be loaded and applied onto a different node of the same type. The
    end result is that the node to which the preset is applied takes on the same
    values as the node from which the preset was generated had at the time of the
    snapshot.preset, render, globals
    Args:
        attributes (str?): A white space separated string of the named attributes to save to the  
                preset file. If not specified, all attributes will be stored.  
                Properties: create
        custom (str?): Specifies a MEL script for custom handling of node attributes that are not  
                handled by the general save preset mechanism (ie. multis, dynamic attributes,  
                or connections). The identifiers #presetName and #nodeName will be expanded  
                before the script is run. The script must return an array of strings which  
                will be saved to the preset file and issued as commands when the preset is  
                applied to another node.  
                The custom script can query #nodeName in determining what should be saved  
                to the preset, or issue commands to query the selected node in deciding how  
                the preset should be applied.  
                Properties: create
        delete (Tuple[str, str]?): Deletes the existing preset for the node specified by the first argument with  
                the name specified by the second argument.  
                Properties: create
        exists (Tuple[str, str]?): Returns true if the node specified by the first argument already has a preset  
                with a name specified by the second argument. This flag can be used to check if  
                the user is about to overwrite an existing preset and thereby provide the user  
                with an opportunity to choose a different name.  
                Properties: create
        isValidName (str?): Returns true if the name consists entirely of valid characters for  
                a preset name. Returns false if not. Because the preset name will  
                become part of a file name and part of a MEL procedure name, some  
                characters must be disallowed. Only alphanumeric characters and underscore  
                are valid characters for the preset name.  
                Properties: create
        list (str?): Lists the names of all presets which can be loaded onto the specified  
                node.  
                Properties: create
        load (Tuple[str, str]?): Sets the settings of the node specified by the first argument according to the  
                preset specified by the second argument. Any attributes on the node which are  
                the destinations of connections or whose children (multi children or compound  
                children) are destinations of connections will not be changed by the preset.  
                Properties: create
        save (Tuple[str, str]?): Saves the current settings of the node specified by the first argument to a  
                preset of the name specified by the second argument. If a preset for that node  
                with that name already exists, it will be overwritten with no warning. You can  
                use the -exists flag to check if the preset already exists. If an attribute of  
                the node is the destination of a connection, the value of the attribute will  
                not be written as part of the preset.  
                Properties: create

    Returns:
        bool: if isValidName or exists is used.

    Example:
    """

def nodeTreeLister(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addFavorite: Multiuse[str] = ..., addItem: Multiuse[Tuple[str, str, Callable[..., Any]]] = ..., addVnnItem: Multiuse[Tuple[str, str, str, str]] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clearContents: bool = ..., collapsePath: Multiuse[str] = ..., defineTemplate: str = ..., displayName: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., executeItem: str = ..., exists: bool = ..., expandPath: Multiuse[str] = ..., expandToDepth: int = ..., favoritesCallback: Callable[..., Any] = ..., favoritesList: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., itemScript: str = ..., manage: bool = ..., noBackground: bool = ..., nodeLibrary: Queryable[str] = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., refreshCommand: Queryable[Callable[..., Any]] = ..., removeFavorite: Multiuse[str] = ..., removeItem: Multiuse[str] = ..., resultsPathUnderCursor: bool = ..., selectPath: Multiuse[str] = ..., setDisplayName: Multiuse[Tuple[str, str]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., vnnString: bool = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates/edits/queries the node tree lister control.
    nodeTreeLister is a treeLister, but items are assumed to have commands which
    return dependency node names.  Dragging from the results pane is supported.The optional argument is the name of the control.
    Args:
        addFavorite (Multiuse[str]?): Add an item path to the favorites folder.  The item path does not have to actually be in the tree.  
                Properties: create, edit, multiuse
        addItem (Multiuse[Tuple[str, str, Callable[..., Any]]]?): Add an item to the control.  The arguments are item-path,icon path,command  
                where item-path is the path from the root of the tree to the item's name  
                icon path is the icon displayed in the results list  
                command is the script which is executed when the item is LMB clicked  
                Properties: create, edit, multiuse
        addVnnItem (Multiuse[Tuple[str, str, str, str]]?): Add a VNN (Virtual Node Network) item to the control.  The arguments are:  
                item-path, icon-path, vnn-string, vnn-action.  
                Where item-path is the path from the root of the tree to the item's name,  
                icon-path is the icon displayed in the results list,  
                vnn-string is used for drag data when MMB dragging the item  
                and vnn-action is the script which is executed when the item is LMB clicked.  
                The vnn-string should be comprised of: 'VNN runtime,VNN library,VNN node',  
                where the VNN library can contain sub-libraries, using / to separate.  
                Properties: create, edit, multiuse
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clearContents (bool?): Clears the contents of the control.  
                Properties: edit
        collapsePath (Multiuse[str]?): Collapse a path in the tree.  
                Properties: edit, multiuse
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayName (Queryable[str]?): Query the display name of a given item.  
                Properties: query
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        executeItem (str?): Execute the command associated with an item.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        expandPath (Multiuse[str]?): Expand a path in the tree.  
                Properties: edit, multiuse
        expandToDepth (int?): Expand the tree to the given depth.  
                Properties: edit
        favoritesCallback (Callable[..., Any]?): This script is called whenever a favorite is added or removed.  
                It is passed two arguments: The item's path and a boolean indicating if it  
                is being added to favorites (True) or removed (False).  
                Properties: create, edit
        favoritesList (bool?): Returns the list of favorite items.  
                Properties: query
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        itemScript (str?): Returns the language and script command of the passed item path as a  
                two-element list, the first element is the string "MEL" or "Python" and  
                the second is the command script. Note that items with Python callable  
                commands will be returned as strings.  
                      In query mode, this flag needs a value.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        nodeLibrary (Queryable[str]?): The node library that this tree lister is currently displaying.  
                Properties: create, query, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        refreshCommand (Queryable[Callable[..., Any]]?): Command executed when the refresh button is pressed.  Note: by default the  
                refresh button is hidden and will be shown automatically when this command  
                script is attached.  
                Properties: create, query, edit
        removeFavorite (Multiuse[str]?): Remove an item from favorites.  Accepts the full favorite path or the tail of the full path.  
                Properties: edit, multiuse
        removeItem (Multiuse[str]?): Remove an item path.  
                Properties: edit, multiuse
        resultsPathUnderCursor (bool?): Returns the path to the result (right-pane) item under the mouse cursor.  
                Returns an empty string if there is no such item.  
                Properties: query
        selectPath (Multiuse[str]?): Select a path in the tree.  
                Properties: edit, multiuse
        setDisplayName (Multiuse[Tuple[str, str]]?): Edit the displayed name of a given item.  
                Properties: edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        vnnString (bool?): Returns the VNN (Virtual Node Network) string of the passed item path.  
                Properties: query
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the created control.

    Example:
    """

def nodeType(arg0: str = ..., /, *, apiType: bool = ..., derived: bool = ..., inherited: bool = ..., isTypeName: bool = ..., ufeRuntimeName: bool = ...) -> Union[str, List[str]]:
    """This command returns a string which identifies the given node's type.When no flags are used, the unique type name is returned.  This can be
    useful for seeing if two nodes are of the same type.When theflag is used, the MFn::Type of the node is returned.
    This can be useful for seeing if a plug-in node belongs to a given
    class. Theflag cannot be used in conjunction with any other
    flags.When theflag is used, the command returns a string array
    containing the names of all the currently known node types which derive
    from the node type of the given object.When theflag is used, the command returns a string array
    containing the names of all the base node types inherited by the
    the given node.If theflag is present then the argument provided to the
    command is taken to be the name of a node type rather than the name of a
    specific node. This makes it possible to query the hierarchy of node types
    without needing to have instances of each node type.
    Args:
        apiType (bool?): Return the MFn::Type value (as a string) corresponding  
                to the given node.  This is particularly useful when  
                the given node is defined by a plug-in, since in this  
                case, the MFn::Type value corresponds to the  
                underlying proxy class.  
              
                This flag cannot be used in combination with any of the other flags.  
                Properties: create
        derived (bool?): Return a string array containing the names of all the currently known node  
                types which derive from the type of the specified node.  
                Properties: create
        inherited (bool?): Return a string array containing the names of all the  
                base node types inherited by the specified node.  
                Properties: create
        isTypeName (bool?): If this flag is present, then the argument provided to the command  
                is the name of a node type rather than the name of a specific node.  
                Properties: create
        ufeRuntimeName (bool?): Return the UFE Runtime name corresponding to the given node.  
                This is particularly useful to filter between native Maya objects  
                and non-native objects exposed to Maya through the UFE interface.  
                Properties: create

    Returns:
        str: Single command result
        List[str]: Multiple command result

    Example:
    """

def nonLinear(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., autoParent: bool = ..., before: bool = ..., commonParent: bool = ..., components: bool = ..., defaultScale: bool = ..., deformerTools: bool = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., split: bool = ..., type: str = ..., useComponentTags: bool = ...) -> Union[List[str], bool, str, Multiuse[str]]:
    """This command creates a functional deformer of the specified type that
    will deform the selected objects.  The deformer consists of
    three nodes: The deformer driver that gets connected to the
    history of the selected objects, the deformer handle transform
    that controls position and orientation of the axis of the deformation
    and the deformer handle that maintains the deformation parameters.
    The type of the deformer handle shape created depends on the
    specified type of the deformer.  The deformer handle
    will be positioned at the center of the selected objects' bounding
    box and oriented to match the orientation of the leading object
    in the selection list.  The deformer handle transform will be
    selected when the command is completed.The nonLinear command has some flags which are specific to the
    nonLinear type specified with the -type flag. The flags correspond to
    the primary keyable attributes related to the specific type of
    nonLinear node. For example, if the type is "bend", then the flags
    "-curvature", "-lowBound" and "-highBound" may be used to initialize,
    edit or query those attribute values on the bend node. Examples
    of this are covered in the example section below.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        autoParent (bool?): Parents the deformer handle under the selected object's  
                transform. This flag is valid only when a single object  
                is selected.  
                Properties: create
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        commonParent (bool?): Creates a new transform and parents the selected object  
                and the deformer handle under it.  This flag is valid only  
                when a single object is selected.  
                Properties: create
        components (bool?): Returns the components used by the deformer  
                Properties: query
        defaultScale (bool?): Sets the scale of the deformation handle to 1.  By default  
                the deformation handle is scaled to the match the largest  
                dimension of the selected objects' bounding box.  
                [deformerFlags]  
                The attributes of the deformer handle shape  
                can be set upon creation, edited and queried as normal flags  
                using either the long or the short attribute name.  e.g.  
                Properties: create
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        type (str?): Specifies the type of deformation. The current valid  
                deformation types are:  bend, twist, squash, flare,  
                sine and wave  
                Properties: create
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        List[str]: Deformer driver name, deformer handle transform name.

    Example:
    """

def nop(*args: Any, **kwargs: Any) -> None: ...
def normalConstraint(*args: str, edit: bool = ..., query: bool = ..., aimVector: Queryable[Tuple[float, float, float]] = ..., layer: str = ..., name: Queryable[str] = ..., remove: bool = ..., targetList: bool = ..., upVector: Queryable[Tuple[float, float, float]] = ..., weight: Queryable[float] = ..., weightAliasList: bool = ..., worldUpObject: Queryable[str] = ..., worldUpType: Queryable[str] = ..., worldUpVector: Queryable[Tuple[float, float, float]] = ...) -> Union[List[str], Tuple[float, float, float], str, bool, float]:
    """Constrain an object's orientation based on the normal of the target
    surface(s) at the closest point(s) to the object.A normalConstraint takes as input one or more surface shapes (the
    targets) and a DAG transform node (the object).  The normalConstraint
    orients the constrained object such that the aimVector (in the
    object's local coordinate system) aligns in world space to combined
    normal vector.  The upVector (again the the object's local coordinate
    system) is aligned in world space with the worldUpVector.  The
    combined normal vector is a weighted average of the normal vector
    for each target surface at the point closest to the constrained object.
    Args:
        aimVector (Queryable[Tuple[float, float, float]]?): Set the aim vector.  This is the vector in local  
                coordinates that points at the target.  If not given at creation  
                time, the default value of (1.0, 0.0, 0.0) is used.  
                Properties: create, query, edit
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        targetList (bool?): Return the list of target objects.  
                Properties: query
        upVector (Queryable[Tuple[float, float, float]]?): Set local up vector.  This is the vector in local  
                coordinates that aligns with the world up vector.  If not given  
                at creation time, the default value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query
        worldUpObject (Queryable[str]?): Set the DAG object use for worldUpType "object" and  
                "objectrotation". See worldUpType for greater detail.  
                The default value is no up object, which is interpreted  
                as world space.  
                Properties: create, query, edit
        worldUpType (Queryable[str]?): Set the type of the world up vector computation.  
                The worldUpType can have one of 5 values: "scene",  
                "object", "objectrotation", "vector", or "none".  
                If the value is "scene", the upVector is  
                aligned with the up axis of the scene and  
                worldUpVector and worldUpObject are ignored.  
                If the value is "object", the upVector is  
                aimed as closely as possible to the  
                origin of the space of the worldUpObject and  
                the worldUpVector is ignored.  
                If the value is "objectrotation" then the  
                worldUpVector is interpreted as being in  
                the coordinate space of the worldUpObject, transformed into  
                world space and the upVector is aligned as  
                closely as possible to the result.  
                If the value is "vector", the upVector  
                is aligned with worldUpVector as closely as  
                possible and worldUpMatrix is ignored.  
                Finally, if the value is "none" no twist calculation  
                is performed by the constraint, with the resulting "upVector"  
                orientation based previous orientation of the  
                constrained object, and the "great circle" rotation needed  
                to align the aim vector with its constraint.  
                The default worldUpType is "vector".  
                Properties: create, query, edit
        worldUpVector (Queryable[Tuple[float, float, float]]?): Set world up vector.  This is the vector in world  
                coordinates that up vector should align with.  
                See -wut/worldUpType (below)for greater detail.  
                If not given at creation time, the default  
                value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def notifyDecorator() -> None: ...
def notifyPostRedo() -> None: ...
def notifyPostUndo() -> None: ...
def nucleusDisplayDynamicConstraintNodes() -> None: ...
def nucleusDisplayMaterialNodes() -> None: ...
def nucleusDisplayNComponentNodes() -> None: ...
def nucleusDisplayOtherNodes() -> None: ...
def nucleusDisplayTextureNodes() -> None: ...
def nucleusDisplayTransformNodes() -> None: ...
def nucleusGetEffectsAsset() -> None: ...
def nucleusGetnClothExample() -> None: ...
def nucleusGetnParticleExample() -> None: ...
def nurbsBoolean(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., operation: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., nsrfsInFirstShell: int = ..., object: bool = ..., smartConnection: bool = ...) -> Union[List[str], bool, int, float]:
    """This command performs a boolean operation.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        operation (Queryable[int]?): Type of Boolean operation.  
                Default: 0  
                Properties: create, query, edit
        tolerance (Queryable[float]?): fitting tolerance.  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nsrfsInFirstShell (int?): The number of selection items comprising the first shell.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        smartConnection (bool?): Look for any of the selection items having a boolean operation as  
                history.  
                Default is true.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def nurbsCopyUVSet(*args: str) -> bool:
    """This is only a sample command for debugging purposes,
    which makes a copy of the implicit st parameterization
    on a nurbs surface to be the 1st explicit uvset.nurbs, uvSet, copyUVSet
    Returns:
        bool: Success or Failure.

    Example:
    """

def nurbsCube(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., degree: Queryable[int] = ..., heightRatio: Queryable[float] = ..., lengthRatio: Queryable[float] = ..., nodeState: Queryable[int] = ..., patchesU: Queryable[int] = ..., patchesV: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., width: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The nurbsCube command creates a new NURBS Cube made up of six
    planes. It creates an unit cube with center at origin by default.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): The primitive's axis  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface.  
                1. linear,  
                2. quadratic,  
                3. cubic,  
                5. quintic,  
                7. heptic  
                Default: 3  
                Properties: create, query, edit
        heightRatio (Queryable[float]?): Ratio of "height" to "width"  
                Default: 1.0  
                Properties: create, query, edit
        lengthRatio (Queryable[float]?): Ratio of "length" to "width"  
                Default: 1.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        patchesU (Queryable[int]?): Number of sections in U  
                Default: 1  
                Properties: create, query, edit
        patchesV (Queryable[int]?): Number of sections in V  
                Default: 1  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The primitive's pivot point  
                Properties: create, query, edit
        width (Queryable[float]?): Width of the object  
                Default: 1.0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def nurbsCurveRebuildPref(*, query: bool = ..., degree: int = ..., endKnots: int = ..., fitRebuild: int = ..., keepControlPoints: bool = ..., keepEndPoints: bool = ..., keepRange: int = ..., keepTangents: bool = ..., rebuildType: int = ..., spans: int = ..., smartSurfaceCurve: bool = ..., tolerance: float = ...) -> None: ...
def nurbsCurveToBezier() -> List[str]:
    """The nurbsCurveToBezier command attempts to convert an existing NURBS curve
    to a Bezier curve.
    Returns:
        List[str]: (object name and node name)

    Example:
    """

def nurbsEditUV(*args: str, query: bool = ..., angle: Queryable[float] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., relative: bool = ..., rotateRatio: Queryable[float] = ..., rotation: bool = ..., scale: bool = ..., scaleU: Queryable[float] = ..., scaleV: Queryable[float] = ..., uValue: Queryable[float] = ..., vValue: Queryable[float] = ...) -> Union[bool, float]:
    """Command Edits UVs on NURBS objects. When used with the query flag, it
    returns the UV values associated with the specified components.nurbs, editUV, tweakUV, uvEditing
    Args:
        angle (Queryable[float]?): Specifies the angle value (in degrees) by which the UV values are to be rotated.  
                Properties: create, query
        pivotU (Queryable[float]?): Specifies the pivot value, in the u direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        pivotV (Queryable[float]?): Specifies the pivot value, in the v direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        relative (bool?): Specifies whether this command is editing the values relative to the currently  
                existing values. Default is true;  
                Properties: create, query
        rotateRatio (Queryable[float]?): Specifies the ratio value by which the UV values are to be rotated.  
                Default is 1.0  
                Properties: create, query
        rotation (bool?): Specifies whether this command is editing the values with rotation values  
                Properties: create, query
        scale (bool?): Specifies whether this command is editing the values with scale values  
                Properties: create, query
        scaleU (Queryable[float]?): Specifies the scale value in the u direction.  
                Properties: create, query
        scaleV (Queryable[float]?): Specifies the scale value in the v direction.  
                Properties: create, query
        uValue (Queryable[float]?): Specifies the value, in the u direction - absolute if relative flag is false..  
                Properties: create, query
        vValue (Queryable[float]?): Specifies the value, in the v direction - absolute if relative flag is false..  
                Properties: create, query

    Returns:
        bool: Success or Failure.

    Example:
    """

def nurbsPlane(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., degree: Queryable[int] = ..., lengthRatio: Queryable[float] = ..., nodeState: Queryable[int] = ..., patchesU: Queryable[int] = ..., patchesV: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., width: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The nurbsPlane command creates a new NURBS Plane and return the name
    of the new surface. It creates an unit plane with center at origin by
    default.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): The primitive's axis  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface  
                1. linear,  
                2. quadratic,  
                3. cubic,  
                5. quintic,  
                7. heptic  
                Default: 3  
                Properties: create, query, edit
        lengthRatio (Queryable[float]?): The ratio of "length" to "width" of the plane.  
                Default: 1.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        patchesU (Queryable[int]?): The number of spans in the U direction.  
                Default: 1  
                Properties: create, query, edit
        patchesV (Queryable[int]?): The number of spans in the V direction.  
                Default: 1  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The primitive's pivot point  
                Properties: create, query, edit
        width (Queryable[float]?): The width of the plane  
                Default: 1.0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def nurbsSelect(*args: str, borderSelection: bool = ..., bottomBorder: bool = ..., growSelection: int = ..., leftBorder: bool = ..., rightBorder: bool = ..., shrinkSelection: int = ..., topBorder: bool = ...) -> bool:
    """Performs selection operations on NURBS objects.If any of the border flags is set, then the appropriate borders are
    selected. Otherwise the current CV selection is used, or all CVs if
    the surfaces is selected as an object.The growSelection, shrinkSelection, borderSelection flags are then applied
    in that order.In practice, it is recommended to use one flag at a time, except for
    the border flags.texture, uv, image
    Args:
        borderSelection (bool?): Extract the border of the current CV selection.  
                Properties: create
        bottomBorder (bool?): Selects the bottom border of the surface (V=0).  
                Properties: create
        growSelection (int?): Grows the CV selection by the given number of CV  
                Properties: create
        leftBorder (bool?): Selects the left border of the surface (U=0).  
                Properties: create
        rightBorder (bool?): Selects the right border of the surface (U=MAX).  
                Properties: create
        shrinkSelection (int?): Shrinks the CV selection by the given number of CV  
                Properties: create
        topBorder (bool?): Selects the top border of the patches (V=MAX).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def nurbsSquare(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., center: Queryable[Tuple[float, float, float]] = ..., centerX: Queryable[float] = ..., centerY: Queryable[float] = ..., centerZ: Queryable[float] = ..., degree: Queryable[int] = ..., nodeState: Queryable[int] = ..., normal: Queryable[Tuple[float, float, float]] = ..., normalX: Queryable[float] = ..., normalY: Queryable[float] = ..., normalZ: Queryable[float] = ..., sideLength1: Queryable[float] = ..., sideLength2: Queryable[float] = ..., spansPerSide: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, Tuple[float, float, float], float, int]:
    """The nurbsSquare command creates a square
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        center (Queryable[Tuple[float, float, float]]?): The center point of the square.  
                Properties: create, query, edit
        centerX (Queryable[float]?): X of the center point.  
                Default: 0  
                Properties: create, query, edit
        centerY (Queryable[float]?): Y of the center point.  
                Default: 0  
                Properties: create, query, edit
        centerZ (Queryable[float]?): Z of the center point.  
                Default: 0  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting circle:  
                1. linear,  
                2. quadratic,  
                3. cubic,  
                5. quintic,  
                7. heptic  
                Default: 3  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normal (Queryable[Tuple[float, float, float]]?): The normal of the plane in which the square will lie.  
                Properties: create, query, edit
        normalX (Queryable[float]?): X of the normal direction.  
                Default: 0  
                Properties: create, query, edit
        normalY (Queryable[float]?): Y of the normal direction.  
                Default: 0  
                Properties: create, query, edit
        normalZ (Queryable[float]?): Z of the normal direction.  
                Default: 1  
                Properties: create, query, edit
        sideLength1 (Queryable[float]?): The length of a side on the square.  
                Default: 1.0  
                Properties: create, query, edit
        sideLength2 (Queryable[float]?): The length of an adjacent side on the square.  
                Default: 1.0  
                Properties: create, query, edit
        spansPerSide (Queryable[int]?): The number of spans per side determines the resolution of the square.  
                Default: 1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def nurbsToPoly(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., curvatureTolerance: Queryable[int] = ..., explicitTessellationAttributes: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., smoothEdge: bool = ..., smoothEdgeRatio: Queryable[float] = ..., uDivisionsFactor: Queryable[float] = ..., vDivisionsFactor: Queryable[float] = ...) -> Union[List[str], bool, int, float]:
    """This command tesselates a NURBS surface and produces a polygonal surface.
    The name of the new polygonal surface is returned.
    If construction history is ON, then the name of the new dependency
    node is returned as well.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curvatureTolerance (Queryable[int]?): Presets for level of secondary criteria curvature tolerance:  
                0 = highest tolerance, 1 = high tolerance, 2 = medium tolerance,  
                3 = no tolerance  
                Default: 2  
                Properties: create, query, edit
        explicitTessellationAttributes (bool?): specify advanced or novice mode for tessellation parameters  
                Default: true  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        smoothEdge (bool?): Specifies if the decision to continue tessellation should be  
                based on the nurbs edge smoothness  
                Default: false  
                Properties: create, query, edit
        smoothEdgeRatio (Queryable[float]?): Specifies the edge smooth ratio.  The higher the value, the  
                smoother the edge will be.  
                Default: 0.99  
                Properties: create, query, edit
        uDivisionsFactor (Queryable[float]?): Specifies the tessellation increase factor in U for novice mode  
                Default: 1.5  
                Properties: create, query, edit
        vDivisionsFactor (Queryable[float]?): Specifies the tessellation increase factor in V for novice mode  
                Default: 1.5  
                Properties: create, query, edit

    Returns:
        List[str]: The polygon and optionally the dependency node name.

    Example:
    """

def nurbsToPolygonsPref(*, query: bool = ..., chordHeight: Queryable[float] = ..., chordHeightRatio: Queryable[float] = ..., delta3D: Queryable[float] = ..., edgeSwap: bool = ..., format: Queryable[int] = ..., fraction: Queryable[float] = ..., matchRenderTessellation: Queryable[int] = ..., merge: Queryable[int] = ..., mergeTolerance: Queryable[float] = ..., minEdgeLen: Queryable[float] = ..., polyCount: Queryable[int] = ..., polyType: Queryable[int] = ..., uNumber: Queryable[int] = ..., uType: Queryable[int] = ..., useChordHeight: bool = ..., useChordHeightRatio: bool = ..., vNumber: Queryable[int] = ..., vType: Queryable[int] = ...) -> Union[bool, float, int]:
    """This command sets the values used by the nurbs-to-polygons
    (or "tesselate") preference.  This preference is used by
    Maya menu items and is saved between Maya sessions.
    To query any of the flags, use the "-query" flag.
    For more information on the flags, see the node documentation for
    the "nurbsTessellate" node.
    Args:
        chordHeight (Queryable[float]?):   
                Properties: create, query
        chordHeightRatio (Queryable[float]?):   
                Properties: create, query
        delta3D (Queryable[float]?):   
                Properties: create, query
        edgeSwap (bool?):   
                Properties: create, query
        format (Queryable[int]?): Valid values are 0, 1 and 2.  
                Properties: create, query
        fraction (Queryable[float]?):   
                Properties: create, query
        matchRenderTessellation (Queryable[int]?):   
                Properties: create, query
        merge (Queryable[int]?):   
                Properties: create, query
        mergeTolerance (Queryable[float]?):   
                Properties: create, query
        minEdgeLen (Queryable[float]?):   
                Properties: create, query
        polyCount (Queryable[int]?):   
                Properties: create, query
        polyType (Queryable[int]?):   
                Properties: create, query
        uNumber (Queryable[int]?):   
                Properties: create, query
        uType (Queryable[int]?):   
                Properties: create, query
        useChordHeight (bool?):   
                Properties: create, query
        useChordHeightRatio (bool?):   
                Properties: create, query
        vNumber (Queryable[int]?):   
                Properties: create, query
        vType (Queryable[int]?):   
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def nurbsToSubdiv(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addUnderTransform: bool = ..., caching: bool = ..., collapsePoles: bool = ..., constructionHistory: bool = ..., matchPeriodic: bool = ..., maxPolyCount: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., reverseNormal: bool = ...) -> Union[List[str], bool, int]:
    """This command converts a NURBS surface and produces a subd surface.
    The name of the new subdivision surface is returned.
    If construction history is ON, then the name of the new dependency
    node is returned as well.
    Args:
        addUnderTransform (bool?): Specify whether the new surface should be added under the old transform or not.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        collapsePoles (bool?): Collapse poles into a single point  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        matchPeriodic (bool?): Match periodic surface texture mapping in the result.  
                Default: false  
                Properties: create, query, edit
        maxPolyCount (Queryable[int]?): The maximum number of base mesh faces in the resulting subdivision surface.  
                Default: 1000  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        reverseNormal (bool?): Reverse the NURBS surface normal in the conversion.  
                Default: true  
                Properties: create, query, edit

    Returns:
        List[str]: The subd surface and optionally the dependency node name

    Example:
    """

def nurbsToSubdivPref(*, query: bool = ..., bridge: Queryable[int] = ..., capType: Queryable[int] = ..., collapsePoles: bool = ..., matchPeriodic: bool = ..., maxPolyCount: Queryable[int] = ..., offset: Queryable[float] = ..., reverseNormal: bool = ..., solidType: Queryable[int] = ..., trans00: Queryable[float] = ..., trans01: Queryable[float] = ..., trans02: Queryable[float] = ..., trans10: Queryable[float] = ..., trans11: Queryable[float] = ..., trans12: Queryable[float] = ..., trans20: Queryable[float] = ..., trans21: Queryable[float] = ..., trans22: Queryable[float] = ..., trans30: Queryable[float] = ..., trans31: Queryable[float] = ..., trans32: Queryable[float] = ...) -> Union[bool, int, float]:
    """This command sets the values used by the nurbs-to-subdivision surface
    preference.  This preference is used by the nurbs creation commands
    and is saved between Maya sessions.To query any of the flags, use the "-query" flag.For more information on the flags, see the node documentation for
    the "nurbsToSubdivProc" node.
    Args:
        bridge (Queryable[int]?): Valid values are 0, 1, 2 or 3.  
                Properties: create, query
        capType (Queryable[int]?): Valid values are 0 or 1.  
                Properties: create, query
        collapsePoles (bool?):   
                Properties: create, query
        matchPeriodic (bool?):   
                Properties: create, query
        maxPolyCount (Queryable[int]?):   
                Properties: create, query
        offset (Queryable[float]?):   
                Properties: create, query
        reverseNormal (bool?):   
                Properties: create, query
        solidType (Queryable[int]?): Valid values are 0, 1 or 2.  
                Properties: create, query
        trans00 (Queryable[float]?):   
                Properties: create, query
        trans01 (Queryable[float]?):   
                Properties: create, query
        trans02 (Queryable[float]?):   
                Properties: create, query
        trans10 (Queryable[float]?):   
                Properties: create, query
        trans11 (Queryable[float]?):   
                Properties: create, query
        trans12 (Queryable[float]?):   
                Properties: create, query
        trans20 (Queryable[float]?):   
                Properties: create, query
        trans21 (Queryable[float]?):   
                Properties: create, query
        trans22 (Queryable[float]?):   
                Properties: create, query
        trans30 (Queryable[float]?):   
                Properties: create, query
        trans31 (Queryable[float]?):   
                Properties: create, query
        trans32 (Queryable[float]?):   
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def nurbsUVSet(*args: str, edit: bool = ..., query: bool = ..., create: bool = ..., useExplicit: bool = ...) -> bool:
    """Allows user to toggle between implicit and explicit UVs on a NURBS object. Also
    provides a facility to create, delete, rename and set the current explicit UVSet.
    An implicit UVSet is non-editable. It uses the parametric make-up of the NURBS object
    to determine the location of UVs (isoparm intersections). NURBS objects also support
    explicit UVSets which are similar to the UVs of a polygonal object. UVs are created
    at the knots (isoparm intersections) of the object and are fully editable. In order
    to access UV editing capabilities on a NURBS object an explicit UVSet must be created
    and set as the current UVSet.nurbs, uvSet, currentUVSet, renameUVSet, deleteUVSet, copyUVSet, createUVSet
    Args:
        create (bool?): Creates an explicit UV set on the specified surface. If the surface already has an  
                explicit UV set this flag will do nothing. Use the -ue/useExplicit flag to set/unset  
                the explicit UV set as the current UV set.  
                Properties: create, query, edit
        useExplicit (bool?): Toggles the usage of explicit/implicit UVs. When true, explicit UVs will be used,  
                otherwise the object will use implicit UVs.  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def objExists(arg0: str = ..., /) -> bool:
    """This command simply returns true or false depending on whether
    an object with the given name exists.
    Returns:
        bool: Command result

    Example:
    """

def objectCenter(arg0: str = ..., /, *, gl: bool = ..., local: bool = ..., x: bool = ..., y: bool = ..., z: bool = ...) -> Union[List[float], float]:
    """This command returns the coordinates of the center of the bounding box
    of the specified object. If one coordinate only is specified, it will
    be returned as a float. If no coordinates are specified, an array of
    floats is returned, containing x, y, and z. If you specify multiple
    coordinates, only one will be returned.
    Args:
        gl (bool?): Return positional values in global coordinates (default).  
                Properties: create
        local (bool?): Return positional values in local coordinates.  
                Properties: create
        x (bool?): Return X value only  
                Properties: create
        y (bool?): Return Y value only  
                Properties: create
        z (bool?): Return Z value only  
                Properties: create

    Returns:
        List[float]: When the asking for the center (default).
        float: When asking for one coordinate only.

    Example:
    """

def objectType(arg0: str = ..., /, *, isAType: str = ..., isType: str = ..., tagFromType: str = ..., typeFromTag: int = ..., typeTag: bool = ...) -> Union[str, bool]:
    """This command returns the type of elements. Warning: This command is
    incomplete and may not be supported by all object types.
    Args:
        isAType (str?): Returns true if the object is the specified type or derives  
                from an object that is of the specified type. This flag will  
                only work with dependency nodes.  
                Properties: create
        isType (str?): Returns true if the object is exactly of the specified type.  
                False otherwise.  
                Properties: create
        tagFromType (str?): Returns the type tag given a type name.  
                Properties: create
        typeFromTag (int?): Returns the type name given an integer type tag.  
                Properties: create
        typeTag (bool?): Returns an integer tag that is unique for that object type.  Not all  
                object types will have tags.  This is the unique 4. byte value that is  
                used to identify nodes of a given type in the binary file format.  
                Properties: create

    Returns:
        str: The type of the specified object
        bool: For "isType": was the object of the specified type?

    Example:
    """

def objectTypeUI(arg0: str = ..., /, *, isType: str = ..., listAll: bool = ..., superClasses: bool = ...) -> str:
    """This command returns the type of UI element such as button, sliders, etc.
    Args:
        isType (str?): Returns true|false if the object is of the specified type.  
                Properties: create
        listAll (bool?): Returns a list of all known UI commands and their respective types.  
                Each entry contains three strings which are the command name, ui type and class name.  
                Note that the class name is internal and is subject to change.  
                Properties: create
        superClasses (bool?): Returns a list of the names of all super classes for the given object.  
                Note that all class names are internal and are subject to change.  
                Properties: create

    Returns:
        str: The type of the specified object.

    Example:
    """

def offsetCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., connectBreaks: Queryable[int] = ..., cutLoop: bool = ..., cutRadius: Queryable[float] = ..., distance: Queryable[float] = ..., nodeState: Queryable[int] = ..., normal: Queryable[Tuple[float, float, float]] = ..., reparameterize: bool = ..., stitch: bool = ..., subdivisionDensity: Queryable[int] = ..., tolerance: Queryable[float] = ..., useGivenNormal: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., range: bool = ...) -> Union[List[str], bool, int, float, Tuple[float, float, float]]:
    """The offset command creates new offset curves from the selected curves.
    The connecting type for breaks in offsets is off (no connection),
    circular (connect with an arc) or linear (connect linearly resulting
    in a sharp corner). If loop cutting is on then any loops in the
    offset curves are trimmed away. For the default cut radius of 0.0 a
    sharp corner is created at each intersection. For values greater than
    0.0 a small arc of that radius is created at each intersection.
    The cut radius value is only valid when loop cutting is on.
    Offsets (for planar curves) are calculated in the plane of that curve
    and 3d curves are offset in 3d. The subdivisionDensity flag is the maximum
    number of times the offset object can be subdivided (i.e. calculate
    the offset until the offset comes within tolerance or the iteration
    reaches this maximum.)
    The reparameterize option allows the offset curve to have a different
    parameterization to the original curve. This avoids uneven parameter
    distributions in the offset curve that can occur with large offsets
    of curves, but is more expensive to compute.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        connectBreaks (Queryable[int]?): Connect breaks method (between gaps):  
                0. off,  
                1. circular,  
                2. linear  
                Default: 2  
                Properties: create, query, edit
        cutLoop (bool?): Do loop cutting.  
                Default: false  
                Properties: create, query, edit
        cutRadius (Queryable[float]?): Loop cut radius. Only used if cutLoop attribute is set true.  
                Default: 0.0  
                Properties: create, query, edit
        distance (Queryable[float]?): Offset distance  
                Default: 1.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normal (Queryable[Tuple[float, float, float]]?): Offset plane normal  
                Properties: create, query, edit
        reparameterize (bool?): Do reparameterization. It is not advisable to change this value.  
                Default: false  
                Properties: create, query, edit
        stitch (bool?): Stitch curve segments together. It is not advisable to change this value.  
                Default: true  
                Properties: create, query, edit
        subdivisionDensity (Queryable[int]?): Maximum subdivision density per span  
                Default: 5  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance  
                Default: 0.01  
                Properties: create, query, edit
        useGivenNormal (bool?): Use the given normal (or, alternativelly, geometry normal)  
                Default: 1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def offsetCurveOnSurface(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., checkPoints: Queryable[int] = ..., connectBreaks: Queryable[int] = ..., cutLoop: bool = ..., distance: Queryable[float] = ..., nodeState: Queryable[int] = ..., stitch: bool = ..., subdivisionDensity: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., range: bool = ...) -> Union[List[str], bool, int, float]:
    """The offsetCurveOnSurface command offsets a curve on surface resulting
    in another curve on surface.
    The connecting type for breaks in offsets is off (no connection),
    circular (connect with an arc) or linear (connect linearly resulting
    in a sharp corner). If loop cutting is on then any loops in the
    offset curves are trimmed away and a sharp corner is created at each
    intersection. The subdivisionDensity flag is the maximum
    number of times the offset object can be subdivided (i.e. calculate
    the offset until the offset comes within tolerance or the iteration
    reaches this maximum.) The checkPoints flag sets the number of points
    per span at which the distance of the offset curve from the original
    curve is determined. The tolerance flag determines how accurately the
    offset curve should satisfy the required offset distance. A satisfactory
    offset curve is one for which all of the checkpoints are within the
    given tolerance of the required offset.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        checkPoints (Queryable[int]?): Checkpoints for fit quality per span. Not advisable to change this value.  
                Default: 3  
                Properties: create, query, edit
        connectBreaks (Queryable[int]?): Connect breaks method (between gaps):  
                0. off,  
                1. circular,  
                2. linear  
                Default: 2  
                Properties: create, query, edit
        cutLoop (bool?): Do loop cutting.  
                Default: false  
                Properties: create, query, edit
        distance (Queryable[float]?): Offset distance  
                Default: 1.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        stitch (bool?): Stitch curve segments together. Not advisable to change this value.  
                Default: true  
                Properties: create, query, edit
        subdivisionDensity (Queryable[int]?): Maximum subdivision density per span  
                Default: 5  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def offsetSurface(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., distance: Queryable[float] = ..., method: Queryable[int] = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, float, int]:
    """The offset command creates new offset surfaces from the
    selected surfaces. The default method is a surface offset,
    which offsets relative to the surface itself. The CV offset
    method offsets the CVs directly rather than the surface, so is
    usually slightly less accurate but is faster. The offset
    surface will always have the same degree, number of CVs and
    knot spacing as the original surface.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        distance (Queryable[float]?): Offset distance  
                Default: 1.0  
                Properties: create, query, edit
        method (Queryable[int]?): Offset method  
                0. Surface Fit  
                1. CV Fit  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def ogs(*, query: bool = ..., deviceInformation: bool = ..., disposeReleasableTextures: bool = ..., dumpTexture: str = ..., enableHardwareInstancing: bool = ..., fragmentEditor: str = ..., fragmentXML: str = ..., gpuMemoryTotal: Queryable[int] = ..., gpuMemoryUsed: bool = ..., isLegacyViewportEnabled: bool = ..., isRemoteGLSessionEnabled: bool = ..., isWinRemoteSession: bool = ..., pause: bool = ..., rebakeTextures: bool = ..., regenerateUVTilePreview: str = ..., reloadTextures: bool = ..., reset: bool = ..., shaderSource: Queryable[str] = ..., toggleTexturePaging: bool = ..., traceRenderPipeline: bool = ...) -> Union[str, int, bool]:
    """OGS is one of the viewport renderers. As there is a lot of effort involved
    in migrating functionality it will evolve over several releases. As it
    evolves it is prudent to provide safeguards to get the database back to a
    known state. That is the function of this command, similar to how
    'dgdirty' is used to restore state to the dependency graph.ogs, debug
    Args:
        deviceInformation (bool?): If used then output the current device information.  
                Properties: create
        disposeReleasableTextures (bool?): Clear up all the releasable file textures in GPU memory that are not required for rendering.  
                Properties: create
        dumpTexture (str?): If used then dump GPU texture memory usage info (in MB), must be used with FLAG gpuMemoryUsed.  
                The final info detail is specified by the string parameter. Current available values are: "full" , "total".  
                Properties: create
        enableHardwareInstancing (bool?): Enables/disables new gpu instancing of instanceable render items in OGS.  
                Properties: create
        fragmentEditor (str?): If used then launch the fragment editor UI.  
                Properties: create
        fragmentXML (str?): Get the fragment XML associated with a shading node.  
                Properties: create
        gpuMemoryTotal (Queryable[int]?): Get or set the total amount of GPU memory which Maya is allowed to use (in MB).  
                Properties: create, query
        gpuMemoryUsed (bool?): If used then output the estimated amount of GPU memory in use (in MB).  
                Properties: create
        isLegacyViewportEnabled (bool?): To query if the legacy viewport is enabled.  
                Properties: query
        isRemoteGLSessionEnabled (bool?): Query if remote gl is allowed  
                Properties: query
        isWinRemoteSession (bool?): Query if this is a remote session.  
                Properties: query
        pause (bool?): Toggle pausing VP2 display update  
                Properties: create, query
        rebakeTextures (bool?): If used then re-bake all baked textures for OGS.  
                Properties: create
        regenerateUVTilePreview (str?): If used then regenerate all UV tiles preview textures for OGS.  
                Properties: create
        reloadTextures (bool?): If used then reload all textures for OGS.  
                Properties: create
        reset (bool?): If used then reset the entire OGS database for all viewports using it.  
                In query mode the number of viewports that would be affected is returned  
                but the reset is not actually done.  If no viewport is using OGS then  
                OGS will stop listening to DG changes.  
                Properties: create, query
        shaderSource (Queryable[str]?): Get the shader source for the specified material.  
                Properties: query
        toggleTexturePaging (bool?): If used then toggle the default OGS Texture paging mechanism.  
                Properties: create
        traceRenderPipeline (bool?): Enable debug tracing of the renderer pipeline.  
                Properties: create

    Returns:
        str: Result of the operation

    Example:
    """

def ogsRender(*args: str, edit: bool = ..., query: bool = ..., activeMultisampleType: Queryable[str] = ..., activeRenderOverride: Queryable[str] = ..., activeRenderTargetFormat: Queryable[str] = ..., availableFloatingPointTargetFormat: bool = ..., availableMultisampleType: bool = ..., availableRenderOverrides: bool = ..., camera: Queryable[str] = ..., currentFrame: bool = ..., currentView: bool = ..., enableFloatingPointRenderTarget: bool = ..., enableMultisample: bool = ..., frame: float = ..., height: Queryable[int] = ..., layer: Queryable[str] = ..., noRenderView: bool = ..., width: Queryable[int] = ...) -> Union[bool, str, int]:
    """Renders an image or a sequence using the OGS rendering engineogs, offline, rendering
    Args:
        activeMultisampleType (Queryable[str]?): Query the current active multisample type.  
                Properties: query, edit
        activeRenderOverride (Queryable[str]?): Set or query the current active render override.  
                Properties: query, edit
        activeRenderTargetFormat (Queryable[str]?): Query the current active floating point target format.  
                Properties: query, edit
        availableFloatingPointTargetFormat (bool?): Returns the names of available floating point render target format.  
                Properties: query
        availableMultisampleType (bool?): Returns the names of available multisample type.  
                Properties: query
        availableRenderOverrides (bool?): Returns the names of available render overrides.  
                Properties: query
        camera (Queryable[str]?): Specify the camera to use.  Use the first available camera if the camera  
                given is not found.  
                Properties: create, query, edit
        currentFrame (bool?): Render the current frame.  
                Properties: create, query, edit
        currentView (bool?): When turned on, only the current view will be rendered.  
                Properties: create, query, edit
        enableFloatingPointRenderTarget (bool?): Enable/disable floating point render target.  
                Properties: query, edit
        enableMultisample (bool?): Enable/disable multisample.  
                Properties: query, edit
        frame (float?): Specify the frame to render.  
                Properties: create, edit
        height (Queryable[int]?): The height flag pass the height to the ogsRender command. If not used,  
                the height is taken from the render globals settings.  
                Properties: create, query, edit
        layer (Queryable[str]?): Render the specified legacy render layer.  
                Only this render layer will be rendered,  
                regardless of the renderable attribute value of the render layer.  
                The layer name will be appended to the output image file name.  
                The specified render layer becomes the current render layer before rendering,  
                and remains as current render layer after the rendering.  
                This argument uses legacy render layers as this command does not recognize the newer  
                renderSetup render layer system introduced in Maya 2016.  
                Properties: create, query, edit
        noRenderView (bool?): When turned on, the render view is not updated after image computation  
                Properties: create, query, edit
        width (Queryable[int]?): The width flag pass the width to the ogsRender command. If not used,  
                the width is taken from the render globals settings.  
                Properties: create, query, edit

    Returns:
        bool: Query result

    Example:
    """

def ogsdebug(*, count: int = ..., debug: str = ..., timing: str = ..., verbose: bool = ...) -> None: ...
def openCLInfo(*args: str, query: bool = ..., limitMinimumVerts: bool = ..., minVertexBuffer: Queryable[int] = ..., supportsDoublePrecision: bool = ..., valid: bool = ...) -> Union[bool, int]:
    """Query OpenCL information.OpenCL, debug
    Args:
        limitMinimumVerts (bool?): Specifies whether the limit on the minimum vert count of the geometry is used or not. The system configuration  
                determines a certain minimum size for geometries to be allowed on GPU.  
                When this flag is on this limit is obeyed. When this flag is off this limit is ignored.  
                This is only used for debugging purposes and is not saved to the file or any preferences.  
                Properties: create, query
        minVertexBuffer (Queryable[int]?): Set the minimum vert count under which the geometry will not be allowed on the GPU (unless in a network  
                with qualifying geometries).  
                This is only used for debugging purposes and is not saved to the file or any preferences.  
                Properties: create, query
        supportsDoublePrecision (bool?): Specifies whether double precision can be used in OpenCL. If the platform can not  
                allow double precision this can not be set to "on".  
                Properties: create, query
        valid (bool?): Valid in query mode only. Checks if OpenCL is initialized.  
                Properties: query

    Returns:
        bool: The state of whether OpenCL is initialized or not (with the 'valid' flag)

    Example:
    """

def openGLExtension(*args: str, extension: str = ..., renderer: bool = ..., vendor: bool = ..., version: bool = ...) -> str:
    """Command returns the extension name depending on whether a given
    OpenGL extension is supported or not. The input is the
    extension string to the -extension flag.
    If the -extension flag is not used, or if
    the string argument to this flag is an empty string
    than all extension names are returned in a single string.
    If the extension exists it is not necessary true that
    the extension is supported.
    This command can only be used when a modeling
    view has been created. Otherwise no extensions
    will have been initialized and the resulting
    string will always be the empty string.OpenGL, GL, extensions
    Args:
        extension (str?): Specifies the OpenGL extension to query.  
                Properties: create
        renderer (bool?): Specifies to query the OpenGL renderer.  
                Properties: create
        vendor (bool?): Specifies to query the company responsible for the OpenGL implementation.  
                Properties: create
        version (bool?): Specifies to query the OpenGL version.  
                Properties: create

    Returns:
        str: The supported string(s)

    Example:
    """

def openMayaPref(*, edit: bool = ..., query: bool = ..., errlog: bool = ..., lazyLoad: bool = ..., oldPluginWarning: bool = ...) -> Union[int, bool]:
    """Set or query API preferences.
    Args:
        errlog (bool?): toggles whether or not an error log of failed API method  
                calls will be created.  When set to true, a file called  
                "OpenMayaErrorLog" will be created in Maya's current working  
                directory.  Each time an API method fails, a detailed  
                description of the error will be written to the file along  
                with a mini-stack trace that indicates the routine that  
                called the failing method.  
                Defaults to false(off).  
                Properties: create, query, edit
        lazyLoad (bool?): toggles whether or not plugins will be loaded with  
                the RTLD_NOW flag or the RTLD_LAZY flag of dlopen(3C).  If  
                set to true, RTLD_LAZY will be used.  In this mode references  
                to functions that cannot be resolved at load time will not be  
                considered an error.  However, if one of these symbols is  
                actually dereferenced by the plug-in at run time, Maya will crash.  
                Defaults to false(off).  
                Properties: create, query, edit
        oldPluginWarning (bool?): toggles whether or not loadPlugin will generate a  
                warning when plug-ins are loaded that were compiled against  
                an older, and possibly incompatible Maya release.  
                Defaults to true(on).  
                Properties: create, query, edit

    Returns:
        int: indicates success or failure

    Example:
    """

def optionMenu(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alwaysCallChangeCommand: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., beforeShowPopup: Callable[..., Any] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., deleteAllItems: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., itemListLong: bool = ..., itemListShort: bool = ..., label: Queryable[str] = ..., manage: bool = ..., maxVisibleItems: Queryable[int] = ..., noBackground: bool = ..., numberOfItems: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., postMenuCommand: Callable[..., Any] = ..., postMenuCommandOnce: bool = ..., preventOverride: bool = ..., select: Queryable[int] = ..., statusBarMessage: str = ..., useTemplate: str = ..., value: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Callable[..., Any]]:
    """This command creates a popup menu control.  The command creates the
    control and provides its menu.  Subsequent calls to the menuItem
    command will place them in the popup.  Note that commands attached
    to menu items will not get called.  Attach any commands via
    the -cc/changedCommand flag.
    Args:
        alwaysCallChangeCommand (bool?): Toggle whether to always call the change command, regardless of the change.  
                Properties: create, query
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        beforeShowPopup (Callable[..., Any]?): Callback that is called just before we show the drop down menu.  
                Properties: create, edit
        changeCommand (Callable[..., Any]?): Adds a callback that is called when a new item is selected.  
              
                The MEL script will have the newly selected item's value substituted for #1.  
              
                For Python, the callback should be a callable object which accepts one argument,  
                which is the newly selected item's value.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteAllItems (bool?): Delete all the items in this menu.  
                Properties: edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        itemListLong (bool?): The long names of the menu items.  
                Properties: query
        itemListShort (bool?): The short names of the menu items.  
                Properties: query
        label (Queryable[str]?): The optional label text to the left of the popup menu.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxVisibleItems (Queryable[int]?): The maximum number of items that are visible in the popup menu.  
                If the popup contains more items than this, a scrollbar is added automatically.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfItems (bool?): The number of menu items.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        postMenuCommand (Callable[..., Any]?): Specify a script to be executed when the popup menu is about  
                to be shown.  
                Properties: create, edit
        postMenuCommandOnce (bool?): Indicate the -pmc/postMenuCommand should only be  
                invoked once.  Default value is false, ie.  
                the -pmc/postMenuCommand is invoked every time the popup menu is  
                shown.  
                Properties: create, query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        select (Queryable[int]?): The current menu item.  The argument and return value  
                is 1. based.  Note that the current menu item can only be set if it  
                is enabled.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[str]?): The text of the current menu item.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def optionMenuGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., deleteAllItems: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., itemListLong: bool = ..., itemListShort: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfItems: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., postMenuCommand: Callable[..., Any] = ..., postMenuCommandOnce: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., select: Queryable[int] = ..., statusBarMessage: str = ..., useTemplate: str = ..., value: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text, option
    menu and an extra label.  Both the label and extra label are optional.
    Subsequent calls to the menuItem command will place them in the option
    menu.  When adding menu items to the option menu after the initialization
    step, use the name of the options menu itself. See the example below for
    more details. Note that commands attached to menu items will not get called.
    Use theflag to be notified when the user
    changes the value of the option menu.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when a new item is selected.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteAllItems (bool?): Delete all the items in this menu.  
                Properties: edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label to the right of the option menu.  Sets the string  
                to be the extra label text.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        itemListLong (bool?): Returns the long names of the items.  
                Properties: query
        itemListShort (bool?): Returns the short names of the items.  
                Properties: query
        label (Queryable[str]?): If present on creation this specifies that there will be  
                a label to the left of the option menu.  Sets the string to be  
                the label text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfItems (bool?): Returns the number of items.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        postMenuCommand (Callable[..., Any]?): Specify a script to be executed when the popup menu is about  
                to be shown.  
                Properties: create, edit
        postMenuCommandOnce (bool?): Indicate the -pmc/postMenuCommand should only be  
                invoked once.  Default value is false, ie.  
                the -pmc/postMenuCommand is invoked every time the popup menu is  
                shown.  
                Properties: create, query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        select (Queryable[int]?): Selects an item by index.  The first item is 1.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[str]?): Select an item by value.  Also, returns the text of the  
                currently selected item.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the control on creation.

    Example:
    """

def optionVar(*, query: str = ..., arraySize: str = ..., category: str = ..., clearArray: Multiuse[str] = ..., clearStash: Multiuse[str] = ..., default: bool = ..., exists: str = ..., floatArray: Multiuse[str] = ..., floatValue: Multiuse[Tuple[str, float]] = ..., floatValue2: Multiuse[Tuple[str, float, float]] = ..., floatValue3: Multiuse[Tuple[str, float, float, float]] = ..., floatValue4: Multiuse[Tuple[str, float, float, float, float]] = ..., floatValueAppend: Multiuse[Tuple[str, float]] = ..., init: bool = ..., intArray: Multiuse[str] = ..., intValue: Multiuse[Tuple[str, int]] = ..., intValue2: Multiuse[Tuple[str, int, int]] = ..., intValue3: Multiuse[Tuple[str, int, int, int]] = ..., intValue4: Multiuse[Tuple[str, int, int, int, int]] = ..., intValueAppend: Multiuse[Tuple[str, int]] = ..., list: bool = ..., listCategories: bool = ..., listModified: bool = ..., prefFile: Queryable[str] = ..., remove: Multiuse[str] = ..., removeFromArray: Multiuse[Tuple[str, int]] = ..., stash: Multiuse[str] = ..., stringArray: Multiuse[str] = ..., stringValue: Multiuse[Tuple[str, str]] = ..., stringValueAppend: Multiuse[Tuple[str, str]] = ..., transient: bool = ..., unstash: Multiuse[str] = ..., version: int = ...) -> Union[int, List[str], None, str]:
    """This command allows you to set and query variables which are
    persistent between different invocations of Maya.  These variables
    are stored as part of the preferences.
    Args:
        arraySize (str?): returns the size of the array named "string".  If no such  
                variable exists, it returns 0.  If the variable is not an  
                array, it returns 1.  
                Properties: create
        category (str?): Set category for the specified variables.  
              
                This flag can also be combined with list/listModified flags to get all the  
                variables in the specified category.  
                Properties: create
        clearArray (Multiuse[str]?): If there is an array named "string", it is set to be empty.  
                Empty arrays are not saved.  
                Properties: create, multiuse
        clearStash (Multiuse[str]?): Clear backup copy of a variable.  
                Properties: create, multiuse
        default (bool?): The variable's current and default values will be set to the specified  
                values.  
              
                This flag can also be combined with the query flag to get the default  
                value or with the exists flag to determine if a default value has been  
                specified.  
              
                It can also be used with list/listModifed flags to  
                list variables with a default value.  
                Properties: create
        exists (str?): Returns 1 if a variable named "string" exists, 0 otherwise.  
                The default/transient flags can be used to list variables  
                that have a default value or are transient.  
                All other flags will be ignored if this is used. (Query has  
                higher precedence)  
                Properties: create
        floatArray (Multiuse[str]?): Creates a new empty float array variable named "string".  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        floatValue (Multiuse[Tuple[str, float]]?): creates a new variable named "string" with float value "float".  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different)  
                Properties: create, multiuse
        floatValue2 (Multiuse[Tuple[str, float, float]]?): Creates a new variable named "string" with a 2 element float array.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        floatValue3 (Multiuse[Tuple[str, float, float, float]]?): Creates a new variable named "string" with a 3 element float array.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        floatValue4 (Multiuse[Tuple[str, float, float, float, float]]?): Creates a new variable named "string" with a 4 element float array.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        floatValueAppend (Multiuse[Tuple[str, float]]?): adds this value to the end of the array of floats named "string".  
                If no such array exists, one is created.  If there was a float  
                value with this name before, it becomes the first element of the  
                array.  If any other kind of value existed, it is overridden.  
                Properties: create, multiuse
        init (bool?): Used to initialize or reset variables. If the flag is set to true or the  
                variable does not exist then the variable's current and default values  
                will be set to the specified values. If the flag if set to false then  
                only the default value will be set and the current value will not be  
                modified.  
                Properties: create
        intArray (Multiuse[str]?): Creates a new empty int array variable named "string".  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        intValue (Multiuse[Tuple[str, int]]?): creates a new variable named "string" with integer value "int".  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        intValue2 (Multiuse[Tuple[str, int, int]]?): Creates a new variable named "string" with a 2 element int array.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        intValue3 (Multiuse[Tuple[str, int, int, int]]?): Creates a new variable named "string" with a 3 element int array.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        intValue4 (Multiuse[Tuple[str, int, int, int, int]]?): Creates a new variable named "string" with a 4 element int array.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        intValueAppend (Multiuse[Tuple[str, int]]?): adds this value to the end of the array of ints named "string".  
                If no such array exists, one is created.  If there was an int  
                value with this name before, it becomes the first element of the  
                array.  If any other kind of value existed, it is overridden.  
                Properties: create, multiuse
        list (bool?): This returns a list of all the defined variable names.  
              
                The category flag can be used to list variables in the specified  
                category and the default/transient flags can be used to list  
                variables that have a default value or are transient.  
              
                All other flags will be ignored if this one is used. (Query and exists  
                flags have a higher precedence).  
                Properties: create
        listCategories (bool?): This returns a list of all the defined variable categories. All other  
                flags will be ignored if this one is used. (Query and exists flags  
                have a higher precedence).  
                Properties: create
        listModified (bool?): This returns a list of all the variables that have been changed from  
                their default value.  
              
                Variables that don't have a default value will also be returned unless  
                the default flag is used to filter the list to variables that have a  
                default value. The category flag can also be used to filter the list by  
                category.  
              
                All other flags will be ignored if this one is used. (Query and exists  
                flags have a higher precedence).  
                Properties: create
        prefFile (Queryable[str]?): Flag need to be used in conjunction with category  
                Specify where the optionVars from specified category need to be saved when saving preferences.  
                Properties: create, query
        remove (Multiuse[str]?): removes the variable named "string", if one exists.  
                Note: all removals are done before any value  
                setting, if both the -r and other (-sv, -iv, -fv) flags are  
                used in the same command.  
                Properties: create, multiuse
        removeFromArray (Multiuse[Tuple[str, int]]?): removes the element numbered "int" in the array named "string".  
                Everything beyond it then gets shuffled down.  
                Properties: create, multiuse
        stash (Multiuse[str]?): Make a backup copy of a variable.  
                Properties: create, multiuse
        stringArray (Multiuse[str]?): Creates a new empty string array variable named "string".  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different).  
                Properties: create, multiuse
        stringValue (Multiuse[Tuple[str, str]]?): creates a new variable named using the first string with value given  
                by the second string.  
                If a variable already exists with this name, it is overridden  
                in favour of the new value (even if the type is different)  
                Properties: create, multiuse
        stringValueAppend (Multiuse[Tuple[str, str]]?): adds the value given by the second string to the end of the array of  
                strings named by the first string.  
                If no such array exists, one is created. If there was a string  
                value with this name before, it becomes the first element of the  
                array. If any other kind of value existed, it is overridden.  
                Properties: create, multiuse
        transient (bool?): Indicates that specified variables will not be persisted across sessions.  
                This flag can also be combined with -exists to determine if a variable is  
                transient.  
                Properties: create
        unstash (Multiuse[str]?): Restore a variable from a backup copy.  
                Properties: create, multiuse
        version (int?): Preferences version number to warn about incompatbile preference  
                files  
                Properties: create

    Returns:
        int: 0 or 1 for the exists option
        List[str]: When the list option is used
        None: otherwise

    Example:
    """

def orbit(arg0: str = ..., /, *, horizontalAngle: float = ..., pivotPoint: Tuple[float, float, float] = ..., rotationAngles: Tuple[float, float] = ..., verticalAngle: float = ...) -> bool:
    """The orbit command revolves the camera(s) horizontally and/or
    vertically in the perspective window. The rotation axis is with
    respect to the camera.To revolve horizontally: the rotation axis is the camera up
    direction vector. To revolve vertically: the rotation axis is the
    camera left direction vector.When both the horizontal and the vertical angles are supplied on
    the command line, the camera is firstly revolved horizontally,
    then revolved vertically.This command may be applied to more than one camera; objects that
    are not cameras are ignored. When no camera name supplied, this command
    is applied to all currently active cameras.
    Args:
        horizontalAngle (float?): Angle to revolve horizontally.  
                Properties: create
        pivotPoint (Tuple[float, float, float]?): Used as the pivot point in the world space.  
                Properties: create
        rotationAngles (Tuple[float, float]?): Angle to revolve horizontally and vertically.  
                Properties: create
        verticalAngle (float?): Angle to revolve vertically.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def orbitCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., localOrbit: bool = ..., name: str = ..., orbitScale: Queryable[float] = ..., toolName: Queryable[str] = ...) -> Union[str, bool, float]:
    """Create, edit, or query an orbit context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        localOrbit (bool?): Orbit around the camera's center of interest.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        orbitScale (Queryable[float]?): In degrees of rotation per 100 pixels of cursor drag.  
                Properties: create, query, edit
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query

    Returns:
        str: The name of the context

    Example:
    """

def orientConstraint(*args: str, edit: bool = ..., query: bool = ..., createCache: Tuple[float, float] = ..., deleteCache: bool = ..., layer: str = ..., maintainOffset: bool = ..., name: Queryable[str] = ..., offset: Queryable[Tuple[float, float, float]] = ..., remove: bool = ..., skip: Multiuse[str] = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[str, Tuple[float, float, float], bool, float]:
    """Constrain an object's orientation to match the orientation of the
    target or the average of a number of targets.An orientConstraint takes as input one or more "target" DAG transform
    nodes to control the orientation of the single "constraint object"
    DAG transform  The orientConstraint orients the constrained object
    to match the weighted average of the target world space orientations.
    Args:
        createCache (Tuple[float, float]?): This flag is used to generate an animation curve that serves as a cache for  
                the constraint. The two arguments define the start and end frames.  
              
                The cache is useful if the constraint has multiple targets and  
                the constraint's interpolation type is set to "no flip". The "no flip"  
                mode prevents flipping during playback, but the result is dependent on  
                the previous frame.  Therefore in order to consistently get the same  
                result on a specific frame, a cache must be generated. This flag  
                creates the cache and sets the constraint's interpolation type to  
                "cache". If a cache exists already, it will be deleted and replaced  
                with a new cache.  
                Properties: edit
        deleteCache (bool?): Delete an existing interpolation cache.  
                Properties: edit
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        maintainOffset (bool?): The offset necessary to preserve the constrained  
                object's initial orientation will be calculated and used as the  
                offset.  
                Properties: create
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        offset (Queryable[Tuple[float, float, float]]?): Sets or queries the value of the offset. Default is 0,0,0.  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        skip (Multiuse[str]?): Specify the axis to be skipped. Valid values are "x", "y", "z" and "none". The default value in create mode is "none". This flag is multi-use.  
                Properties: create, edit, multiuse
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        str: [] ( name of the created constraint node)

    Example:
    """

def outlinerEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowMultiSelection: bool = ..., alwaysToggleSelect: bool = ..., animLayerFilterOptions: Queryable[str] = ..., attrAlphaOrder: Queryable[str] = ..., attrFilter: Queryable[str] = ..., autoExpand: bool = ..., autoExpandAnimatedShapes: bool = ..., autoExpandLayers: bool = ..., autoSelectNewObjects: bool = ..., containersIgnoreFilters: bool = ..., control: bool = ..., defineTemplate: str = ..., directSelect: bool = ..., displayMode: Queryable[str] = ..., doNotSelectNewObjects: bool = ..., docTag: Queryable[str] = ..., dropIsParent: bool = ..., editAttrName: bool = ..., exists: bool = ..., expandAllItems: bool = ..., expandAllSelectedItems: bool = ..., expandAttribute: bool = ..., expandConnections: bool = ..., expandObjects: bool = ..., feedbackItemName: bool = ..., feedbackRowNumber: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., getCurrentSetOfItem: Queryable[int] = ..., highlightActive: bool = ..., highlightConnection: Queryable[str] = ..., highlightSecondary: bool = ..., ignoreDagHierarchy: bool = ..., ignoreHiddenAttribute: bool = ..., ignoreOutlinerColor: bool = ..., isChildSelected: Queryable[str] = ..., isSet: Queryable[int] = ..., isSetMember: Queryable[int] = ..., isUfeItem: Queryable[int] = ..., lockMainConnection: bool = ..., longNames: bool = ..., mainListConnection: Queryable[str] = ..., mapMotionTrails: bool = ..., masterOutliner: Queryable[str] = ..., niceNames: bool = ..., object: Queryable[str] = ..., organizeByClip: bool = ..., organizeByLayer: bool = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., parentObject: bool = ..., pinPlug: Queryable[str] = ..., refresh: bool = ..., removeFromCurrentSet: int = ..., renameItem: int = ..., renameSelectedItem: bool = ..., renderFilterActive: bool = ..., renderFilterIndex: Queryable[int] = ..., renderFilterVisible: bool = ..., selectCommand: Queryable[Callable[..., Any]] = ..., selectionConnection: Queryable[str] = ..., selectionOrder: str = ..., setFilter: Queryable[str] = ..., setsIgnoreFilters: bool = ..., showAnimCurvesOnly: bool = ..., showAnimLayerWeight: bool = ..., showAssets: bool = ..., showAssignedMaterials: bool = ..., showAttrValues: bool = ..., showAttributes: bool = ..., showCompounds: bool = ..., showConnected: bool = ..., showContainedOnly: bool = ..., showContainerContents: bool = ..., showDagOnly: bool = ..., showLeafs: bool = ..., showMuteInfo: bool = ..., showNamespace: bool = ..., showNumericAttrsOnly: bool = ..., showParentContainers: bool = ..., showPinIcons: bool = ..., showPublishedAsConnected: bool = ..., showReferenceMembers: bool = ..., showReferenceNodes: bool = ..., showSelected: bool = ..., showSetMembers: bool = ..., showShapes: bool = ..., showTextureNodesOnly: bool = ..., showTimeEditor: bool = ..., showUVAttrsOnly: bool = ..., showUfeItems: bool = ..., showUnitlessCurves: bool = ..., showUpstreamCurves: bool = ..., sortOrder: Queryable[str] = ..., stateString: bool = ..., transmitFilters: bool = ..., ufeFilter: Queryable[Tuple[str, str]] = ..., ufeFilterValue: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., unpinPlug: str = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool, int, Callable[..., Any], Tuple[str, str]]:
    """This command creates an outliner editor which can be used to display a list
    of objects.WARNING: some flag combinations may not behave as you expect.  The command
    is really intended for internal use for creating the outliner used by
    the various editors.
    Args:
        allowMultiSelection (bool?): If true then multiple selection will be allowed in the outliner.  
                Properties: create, edit
        alwaysToggleSelect (bool?): If true, then clicking on an item in the outliner will select or  
                deselect it without affecting the selection of other items (unless  
                allowMultiSelection is false). If false, clicking on an item in the  
                outliner will replace the current selection with the selected item.  
                Properties: create, edit
        animLayerFilterOptions (Queryable[str]?): Specifies whether a filter is to be applied when displaying animation layers.  
                If so, the options can be "allAffecting" (no filter), "active" (only the active  
                layers on the object will be displayed) and "animLayerEditor" (the settings will  
                be taken from the animation layer editor).  
                Properties: create, query, edit
        attrAlphaOrder (Queryable[str]?): Specify how attributes are to be sorted. Current recognised values  
                are "default" for no sorting and "ascend" to sort attributes from 'a' to ''z' and  
                "descend" to sort from 'z' to 'a'.  
                Notes: a) this only applies to top level attributes.  
                Properties: create, query, edit
        attrFilter (Queryable[str]?): Specifies the name of an itemFilter object to be placed on this editor.  
                This filters the attributes displayed in the editor.  
                Properties: create, query, edit
        autoExpand (bool?): This flag specifies whether or not objects that are loaded  
                in should have their attributes automatically expanded.  
                Properties: create, query, edit
        autoExpandAnimatedShapes (bool?): This flag specifies whether or not DAG objects that have animated  
                shapes should be automatically expanded to show the shape. This flag  
                is enabled by default and has no effect if autoExpand is disabled.  
                Properties: create, query, edit
        autoExpandLayers (bool?): If true then when a node with animation layer is displayed, all  
                the animation layers will show up in expanded form.  
                Properties: create, query, edit
        autoSelectNewObjects (bool?): This flag specifies whether or not new objects added to the outliner  
                should be automatically selected.  
                Properties: create, query, edit
        containersIgnoreFilters (bool?): This flag specifices whether or not filters should be ignored  
                when displaying container contents.  
                Properties: create, query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        directSelect (bool?): If true then clicking on an item in the outliner will add or  
                remove just that item from the selection connection. If false then  
                clicking on an item in the outliner causes the selection connection  
                to be reloaded with the currently selected items in the outliner.  
                Properties: create, edit
        displayMode (Queryable[str]?): Affects how the outliner displays when a filter is applied. List mode  
                is a non-indented flat list. DAG mode indents to represent the  
                hierarchical structure of the model.  
                Properties: create, query, edit
        doNotSelectNewObjects (bool?): If true this flag specifies that new objects added to the outliner  
                will not be selected, even if they are active.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        dropIsParent (bool?): This flag specifies the mode for drag and drop. If the flag is true,  
                dropping items will do a reparent. If it is false, dropping will  
                reorder items. By default, the flag is true (parent).  
                Properties: create, query, edit
        editAttrName (bool?): This flag specifies whether or not attribute names can be edited.  
                By default double-clicking on an attribute will open the expression  
                editor for that attribute.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        expandAllItems (bool?): Expand or collapse all items in the outliner.  
                Properties: create, edit
        expandAllSelectedItems (bool?): Expand or collapse all selected items in the outliner.  
                Properties: create, edit
        expandAttribute (bool?): Force the outliner to fill the selection list with only attributes.  
                Properties: edit
        expandConnections (bool?): This flag specifies whether or not attributes should be  
                expanded to show their input connections.  
                Note: currently the expansion will only show animCurves.  
                Properties: create, query, edit
        expandObjects (bool?): This flag specifies whether or not objects that are loaded  
                in should be automatically expanded.  
                Properties: create, query, edit
        feedbackItemName (bool?): Returns the outliner item name at the current mouse position, if any.  
                Properties: query
        feedbackRowNumber (bool?): Returns the outliner row number at the current mouse position, if any.  
                Properties: query
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        getCurrentSetOfItem (Queryable[int]?): Returns the current set of item at the given row. As an item can belong to number of sets, current set is the set to which the item belongs to currently.  
                Properties: query
        highlightActive (bool?): This flag specifies whether or not the outliner should highlight  
                objects that are active.  
                Note: if the outliner is driving the contents of another editor,  
                setting highlightActive to true may produce unexpected behavior.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        highlightSecondary (bool?): This flag specifies whether or not the outliner should highlight objects  
                that are contained in the highlightConnection.  
                Properties: create, query, edit
        ignoreDagHierarchy (bool?): This flag specifies whether or not DAG objects are displayed  
                in their DAG hierarchy. Warning: using this flag without  
                some other form of sensible filtering will lead to a very  
                confusing outliner.  
                Properties: create, query, edit
        ignoreHiddenAttribute (bool?): Sets whether or not the outliner ignores the 'hidden in outliner' flag on nodes.  
                Properties: create, query, edit
        ignoreOutlinerColor (bool?): Sets whether or not the outliner ignores the 'use outliner color' flag on nodes.  
                Properties: create, query, edit
        isChildSelected (Queryable[str]?): This flag allows you to query if one or more of the children of the  
                specified item is selected in the outliner. The item should be  
                specified using a unique DAG path. Note that if the specified item  
                appears multiple times in the outliner, the result will be true if one  
                or more children of any occurrence of the specified item in the  
                outliner is/are selected.  
                Properties: query
        isSet (Queryable[int]?): Returns true if the item present at the given row is a set.  
                Properties: query
        isSetMember (Queryable[int]?): Returns true if the item present at the given row is a set member.  
                Properties: query
        isUfeItem (Queryable[int]?): Returns true if the item present at the given row is a UFE item.  
                Properties: query
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        longNames (bool?): Controls whether long or short attribute names will be used  
                in the interface.  Note that this flag is ignored if the -niceNames  
                flag is set.  Default is short names. Queried, returns a boolean.  
                Properties: query, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        mapMotionTrails (bool?): Sets whether or not we replace the motion trail in the outliner with the object it is trailing.  
                Properties: create, query, edit
        masterOutliner (Queryable[str]?): This flag is the name of an outliner that this outliner will share the objects  
                and state from. When an outliner is shared, all of its state information  
                comes from, and is applied to, the primary outliner.  
                Properties: create, query, edit
        niceNames (bool?): Controls whether the attribute names will be displayed in  
                a more user-friendly, readable way.  When this is on, the longNames  
                flag is ignored.  When this is off, attribute names will be displayed  
                either long or short, according to the longNames flag.  
                Default is on. Queried, returns a boolean.  
                Properties: query, edit
        object (Queryable[str]?): This flag is used together with the parentObject flag to get  
                the name of the parent object for the specified object.  
                Properties: query
        organizeByClip (bool?): If true then when a node with Time Editor clips is displayed, attributes  
                will be displayed according to the clip(s) it belongs to.  
                eg:  
              
                Clip1  
                Attr1  
                Attr2  
                Clip2  
                Attr1  
              
                If it is false then the outliner will be organized primarily by attributes.  
                eg:  
              
                Attr1  
                Clip1  
                Clip2  
                Attr2  
                Clip1  
                Properties: create, query, edit
        organizeByLayer (bool?): If true then when a node with animation layer is displayed, attributes  
                will be displayed according to the layer(s) it belongs to.  
                eg:  
              
                Layer1  
                Attr1  
                Attr2  
                Layer2  
                Attr1  
              
                If it is false then the outliner will be organized primarily by attributes.  
                eg:  
              
                Attr1  
                Layer1  
                Layer2  
                Attr2  
                Layer1  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        parentObject (bool?):   
                Properties: query
        pinPlug (Queryable[str]?): Pins the named plug, so it always appears in the outliner, irrespective  
                of the incoming selection connection.  
                In query mode, returns a list of the pinned plugs.  
                Properties: create, query, edit
        refresh (bool?): Causes the outliner to refresh itself.  
                Properties: edit
        removeFromCurrentSet (int?): Removes selected members of a set from their current set. Current set is the set to which item at the given row belongs to.  
                If no selected items, the item at the given row is removed from its current set.  
                Properties: edit
        renameItem (int?): Renames the item at the given row index in the outliner.  
                Properties: edit
        renameSelectedItem (bool?): Rename the first selected item in the outliner.  
                Properties: edit
        renderFilterActive (bool?): This is a query only flag which returns true if the render setup filter is Active, i.e one of the four render filters (Inside Selected, Outside Selected, Inside All Layers, Outside All Layers)  
                is applied on the outliner currently, false otherwise.  
                Properties: query
        renderFilterIndex (Queryable[int]?): Sets the Render Setup Filter to the index passed. This only works if the filter is visible in outliner and its selection is not locked.  
                Valid indices are:  
              
                0. Scene  
                2. Inside Selected  
                3. Outside Selected  
                4. Inside All Layers  
                5. Outside All Layers  
              
                Default: Scene  0  
                In query mode returns current index of the filter.  
                Properties: create, query, edit
        renderFilterVisible (bool?): Show/Hide the Render Setup Filter in outliner. In query mode returns whether the Render Setup Filter is visible or not.  
                Properties: create, query, edit
        selectCommand (Queryable[Callable[..., Any]]?): A command to be executed when an item is selected.  
                Only valid Mel commands will be saved when the outlinerEditor  
                will be persisted in a scene or in a JSON layout file.  
                Python commands are never saved.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        selectionOrder (str?): Specify how objects are sorted in selection list. Current recognised values  
                are "chronological" for sorting in selection order and "display" to sort objects in the same order that the outliner does.  
                Properties: edit
        setFilter (Queryable[str]?): Specifies the name of a filter which is used to filter  
                which (if any) sets to display.  
                Properties: create, query, edit
        setsIgnoreFilters (bool?): This flag specifies whether or not the filter should be ignored  
                for expanding sets to show set members (default is true).  
                Properties: create, query, edit
        showAnimCurvesOnly (bool?): This flag modifies the showConnected flag.  If showConnected  
                is set to true then this flag will cause display of only  
                those attributes that are connected to an animCurve. If  
                showConnected is set to false then this flag does nothing.  
                Properties: create, query, edit
        showAnimLayerWeight (bool?): If true then when a node with animation layer is displayed, the  
                weight of the layer will be displayed if it is keyed.  
                Properties: create, query, edit
        showAssets (bool?): This flags specifies whether assets should be shown in the outliner.  
                Properties: create, query, edit
        showAssignedMaterials (bool?): Specifies whether to show assigned materials under shapes.  
                Properties: create, query, edit
        showAttrValues (bool?): This flag specifies whether attribute values or attribute names should  
                be displayed.  
                Note: currently only string attributes can have their values displayed.  
                Properties: create, query, edit
        showAttributes (bool?): Specifies whether to show attributes or not.  
                Properties: create, query, edit
        showCompounds (bool?): This flag specifies whether or not compound attributes should be  
                displayed, or just the leaf attributes.  
                Note: if showConnected is true, and the compound attribute  
                is connected, it will still be displayed.  
                Properties: create, query, edit
        showConnected (bool?): This flag modifies the showAttributes flag.  If showAttributes  
                is set to true then this flag will cause display of only  
                those attributes that are connected in the dependency graph.  
                If showAttributes is set to false then this flag does nothing.  
                Properties: create, query, edit
        showContainedOnly (bool?): This flags specifies whether nodes belonging to containers should be show  
                under the container node only. Otherwise, it will show up under the world  
                as well.  
                Properties: create, query, edit
        showContainerContents (bool?): This flags specifies whether the contents of the container should be  
                shown under the container node in the outliner.  
                Properties: create, query, edit
        showDagOnly (bool?): This flag specifies whether all dependency graph objects will  
                be displayed, or just DAG objects.  
                Properties: create, query, edit
        showLeafs (bool?): This flag specifies whether or not leaf attributes should be  
                displayed, or just the compound attributes.  
                Note: if showConnected is true, and the leaf attribute  
                is connected, it will still be displayed.  
                Properties: create, query, edit
        showMuteInfo (bool?): This flag specifies whether mute information will be displayed  
                Properties: create, query, edit
        showNamespace (bool?): This flag specifies whether all objects will have their  
                namespace displayed, if namespace different than root.  
                Properties: create, query, edit
        showNumericAttrsOnly (bool?): This flag specifies whether or not all attributes should be  
                displayed, or just numeric attributes.  
                Note: if showConnected is true, and the attribute  
                is connected, it will still be displayed.  
                Properties: create, query, edit
        showParentContainers (bool?): This flags specifies whether nodes belonging to containers/assets should show their  
                containers/assets as well in its outliner.  
                Properties: create, query, edit
        showPinIcons (bool?): Sets whether pin icons are shown for unpinned plugs.  
                Properties: create, query, edit
        showPublishedAsConnected (bool?): This flags enables attributes that are published to be displayed in italics.  
                Otherwise, only attributes connected as a destination are shown in italics.  
                Properties: create, query, edit
        showReferenceMembers (bool?): Specifies whether to show reference node members under the reference node in the outliner.  
                Properties: create, query, edit
        showReferenceNodes (bool?): Specifies whether to show reference nodes or not.  
                Properties: create, query, edit
        showSelected (bool?): If true then the selected items are expanded in the outliner.  
                Properties: create, edit
        showSetMembers (bool?): If true then when a set is expanded, the set members  
                will be displayed. If false, then only other sets will be  
                displayed.  
                Properties: create, query, edit
        showShapes (bool?): Specifies whether to show shapes or not.  
                Properties: create, query, edit
        showTextureNodesOnly (bool?): This flag modifies the showConnected flag. If showConnected is set to true then  
                this flag will cause display of only those attributes that are connected to a  
                texture node. If showConnected is set to false then this flag does nothing.  
                Properties: create, query, edit
        showTimeEditor (bool?): If true, all nodes related to the Time Editor will be  
                shown as a hierarchy.  
                Properties: create, query, edit
        showUVAttrsOnly (bool?): This flag specifies whether or not all attributes should be displayed, or  
                just uv attributes.  
                Note: currently the only attribute which will be  
                displayed is Shape.uvSet.uvSetName.  
                Properties: create, query, edit
        showUfeItems (bool?): Specifies whether to show Ufe (non-Maya) items.  
                Properties: create, query, edit
        showUnitlessCurves (bool?): This flag (in combination with -expandConnections) specifies  
                whether or not connection expansion should show unitless  
                animCurves.  
                Properties: create, query, edit
        showUpstreamCurves (bool?): Specifies exactly which attributes are displayed when showAttributes  
                and expandConnections are both true.  
                If true, the dependency graph is searched upstream for all curves  
                that drive the selected plugs (showing multiple curves for example  
                in a typical driven key setup, where first the driven key curve is  
                encountered, followed by the actual animation curve that drives the  
                source object). If false, only the first curves encountered  
                will be shown. Note that, even if false, multiple curves can be shown  
                if e.g. a blendWeighted node is being used to combine multiple curves.  
                Properties: create, query, edit
        sortOrder (Queryable[str]?): Specify how objects are to be sorted.  Current recognised values  
                are "none" for no sorting and "dagName" to sort DAG objects by name.  
                Notes: a) non-DAG objects are always sorted by nodeType and name.  
                b) when sortOrder is set to "dagName", objects cannot be reordered  
                using drag-and-drop, they can however be reparented.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        transmitFilters (bool?): This flag specifies how the selectionConnection is populated  
                when attribute filters are enabled.  If this flag is set to  
                true, then all the attributes that pass the filter will be  
                placed on the selectionConnection.  By default this flag is  
                false.  
                Properties: create, query, edit
        ufeFilter (Queryable[Tuple[str, str]]?): Specifies what UFE filter attributes should be used for display.  
                This flag must used together with the ufeFilterValue flag to get/set  
                the value of the UFE filter.  
                The first string is the UFE run-time name and the second is the child filter name.  
                Properties: query, edit
        ufeFilterValue (bool?): The value of the UFE filter specified with flag ufeFilter.  
                This flag must used together with the ufeFilter flag.  
                Properties: query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        unpinPlug (str?): Unpins the named plug.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: (the name of the editor)

    Example:
    """

def outlinerPanel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., divider: Queryable[int] = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., outlinerEditor: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, int, Callable[..., Any]]:
    """This command creates, edit and queries outliner panels which contain only
    an outliner editor.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        divider (Queryable[int]?): This flag returns the orientation of the divider bar  
                in the outliner.  
              
                0. horizontal  
                1. vertical  
                Properties: query, edit
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        outlinerEditor (bool?): This flag returns the name of the outliner editor  
                contained by the panel.  
                Properties: query
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: (the name of the panel)

    Example:
    """

def outputWindow(*, query: bool = ..., show: bool = ...) -> bool:
    """This command open the output window, if it exists.
    This window shows various diagnostic, status and progress updates.
    This command does nothing on MacOS and Linux as they don't have an output window.
    Args:
        show (bool?): Show or hide the output window.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def overrideModifier(*args: Any, clear: bool = ..., press: Multiuse[str] = ..., release: Multiuse[str] = ...) -> bool:
    """This command allows you to assign modifier key behaviour to other
    parts of the system.  For example you can use a hotkey
    or input device instead of a modifer key to perform the same action.Note that the original modifier key behaviour is not altered in anyway.
    For example, if you've assigned "Ctrl" key behaviour to the "c" key
    then the "Ctrl" key will still work as you expect, all you've done is
    allowed yourself to use the "c" key as an alternative to the "Ctrl" key.
    Args:
        clear (bool?): Don't force any modifier keys.  
                Properties: create
        press (Multiuse[str]?): Force the following modifier to be pressed. Valid values are "Alt",  
                "Ctrl", "Shift".  
                Properties: create, multiuse
        release (Multiuse[str]?): Force the following modifier to be released. Valid values are "Alt",  
                "Ctrl", "Shift".  
                Properties: create, multiuse

    Returns:
        bool:

    Example:
    """

def paint3d(*args: str) -> None: ...
def paintEffectsDisplay(*, query: bool = ..., meshDrawEnable: bool = ...) -> bool:
    """Command to set the global display methods for paint effects itemspaintEffects, stroke, brush, pfxGeometry, pfxHair, pfxToon
    Args:
        meshDrawEnable (bool?): Set whether mesh draw is enabled on objects  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def pairBlend(*args: str, edit: bool = ..., query: bool = ..., attribute: Multiuse[str] = ..., input1: bool = ..., input2: bool = ..., node: str = ...) -> Union[str, bool]:
    """The pairBlend node allows a weighted combinations of 2 inputs to be blended together. It is created automatically when keying or constraining an attribute which is already connected.Alternatively, the pairBlend command can be used to connect a pairBlend node to connected attributes of a node. The previously existing connections are rewired to input1 of the pairBlend node. Additional connections can then be made manually to input2 of the pairBlend node.The pairBlend command can also be used to query the inputs to an existing pairBlend node.blend, animation, constraints
    Args:
        attribute (Multiuse[str]?): The name of the attribute(s) which the blend will drive. This flag is required when creating the blend.  
                Properties: create, multiuse
        input1 (bool?): Returns a string array of the node(s) connected to input 1.  
                Properties: query
        input2 (bool?): Returns a string array of the node(s) connected to input 2.  
                Properties: query
        node (str?): The name of the node which the blend will drive. This flag is required when creating the blend.  
                Properties: create

    Returns:
        str: name of pairBlend node

    Example:
    """

def palettePort(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., actualTotal: Queryable[int] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., colorEditable: bool = ..., colorEdited: Callable[..., Any] = ..., defineTemplate: str = ..., dimensions: Queryable[Tuple[int, int]] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hsvValue: Queryable[Tuple[int, int, float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., redraw: bool = ..., rgbValue: Queryable[Tuple[int, float, float, float]] = ..., setCurCell: Queryable[int] = ..., statusBarMessage: str = ..., topDown: bool = ..., transparent: Queryable[int] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, int, Tuple[float, float, float], bool, Tuple[int, int], Tuple[int, int, float, float, float], Tuple[int, float, float, float], Callable[..., Any]]:
    """This command creates an array of color cells. It could be used to
    to store an retrieve some colors you want to manage during your
    working session.
    Args:
        actualTotal (Queryable[int]?): Set the actual number of palette entries. This number  
                must be greater than zero, but not be greater than maximum  
                number of palette entries defined by the dimensions flag.  
                Properties: create, query
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): This command string will be executed when a color in the  
                palette is changed.  
                Properties: create, edit
        colorEditable (bool?): If true then the user can modify the current index's color.  
                Properties: create, query, edit
        colorEdited (Callable[..., Any]?): This command string will be executed when a color in the  
                palette is edited.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        dimensions (Queryable[Tuple[int, int]]?): Set the dimensions of the array.  
                Properties: create, query
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): If true then the user can change the current color.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hsvValue (Queryable[Tuple[int, int, float, float, float]]?): Set a color for a given cell, using HSV format. On  
                query return the color of the current cell.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        redraw (bool?): Forces a redraw of the array  
                Properties: create, edit
        rgbValue (Queryable[Tuple[int, float, float, float]]?): Set a color for a given cell, using RGB format. On  
                query return the color of the current cell.  
                Properties: create, query, edit
        setCurCell (Queryable[int]?): Set the current cell in the array to the given  
                index. Returns the current cell when queried.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        topDown (bool?): If this flag is true, it indicates that first entry should  
                appear in top left as opposed to the bottom left.  
                Properties: create
        transparent (Queryable[int]?): Set a given cell to be the transparent color.  A cell value  
                of -1 indicates that no cell is transparent.  On query returns the  
                current transparent cell.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the palettePort created

    Example:
    """

def panZoom(arg0: str = ..., /, *, absolute: bool = ..., downDistance: float = ..., leftDistance: float = ..., relative: bool = ..., rightDistance: float = ..., upDistance: float = ..., zoomRatio: float = ...) -> bool:
    """The panZoom command pans/zooms the 2D film.The panZoom command can be applied to either a perspective or an
    orthographic camera.When no camera name is supplied, this command is applied to the
    camera in the active view.
    Args:
        absolute (bool?): This flag modifies the behavior of the distance and zoomRatio  
                flags. If specified, the distance and zoomRatio value will be applied  
                directly.  
                Properties: create
        downDistance (float?): Set the amount of down pan distance in inches  
                Properties: create
        leftDistance (float?): Set the amount of left pan distance in inches  
                Properties: create
        relative (bool?): This flag modifies the behavior of the distance and zoomRatio  
                flags. If specified, the distance or zoomRatio value is used multiply  
                the camera's existing value. By default the relative flag is always on.  
                Properties: create
        rightDistance (float?): Set the amount of right pan distance in inches  
                Properties: create
        upDistance (float?): Set the amount of up pan distance in inches  
                Properties: create
        zoomRatio (float?): Set the amount of zoom ratio  
                Properties: create

    Returns:
        bool:

    Example:
    """

def panZoomCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., buttonDown: bool = ..., buttonUp: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., panMode: bool = ..., toolName: Queryable[str] = ..., zoomMode: bool = ..., zoomScale: Queryable[float] = ...) -> Union[str, bool, float]:
    """This command can be used to create camera 2D pan/zoom context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        buttonDown (bool?): Perform the button down operation  
                Properties: create
        buttonUp (bool?): Perform the button up operation  
                Properties: create
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        panMode (bool?): Specify to create a camera 2D pan context, which is the default.  
                Properties: create
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query
        zoomMode (bool?): Specify to create a camera 2D zoom context.  
                Properties: create
        zoomScale (Queryable[float]?): Scale the zoom. The smaller the scale the slower the drag.  
                Properties: create, query, edit

    Returns:
        str: The name of the context

    Example:
    """

def paneLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeFrameThickness: Queryable[int] = ..., activePane: Queryable[str] = ..., activePaneIndex: Queryable[int] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., configuration: Queryable[str] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., numberOfVisiblePanes: bool = ..., pane1: bool = ..., pane2: bool = ..., pane3: bool = ..., pane4: bool = ..., paneSize: Queryable[Multiuse[Tuple[int, int, int]]] = ..., paneUnderPointer: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., separatorMovedCommand: Callable[..., Any] = ..., separatorThickness: Queryable[int] = ..., setPane: Multiuse[Tuple[str, int]] = ..., staticHeightPane: int = ..., staticWidthPane: int = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, int, Tuple[float, float, float], bool, Multiuse[Tuple[int, int, int]], Callable[..., Any]]:
    """This command creates a pane layout.  A pane layout may have any
    number of children but at any one time only certain children may be
    visible, as determined by the current layout configuration.  For
    example a horizontally split pane shows only two children, one on top
    of the other and a visible separator between the two.  The separator
    may be moved to vary the size of each pane.  Various other pane
    configurations are available and all display a moveable separator
    that define the size of each pane in the layout.
    Args:
        activeFrameThickness (Queryable[int]?): The thickness of the frame drawn around the active frame.  
                Specify an integer value greater than or equal to 0.  
                Properties: create, query, edit
        activePane (Queryable[str]?): The active pane has a colored border surrounding it.  Only  
                one pane may be active at any one time.  Using either of the  
                flags -ap/activePane    or -api/activePaneIndex will  
                automatically deactivate the previously active pane.  The argument  
                is the full or short name of the child control.  
                Properties: create, query, edit
        activePaneIndex (Queryable[int]?): The active pane index.  The active pane has a  
                colored border surrounding it.  Only one pane may be active  
                at any one time.  Using either of the flags -ap/activePane  
                or -api/activePaneIndex will automatically deactivate the  
                previously active pane.  The argument is an integer  
                value ranging from 1 to 4.  Panes for any particular configuration  
                are numbered clockwise beginning with the pane in the top left  
                corner of the layout.  If any other index is specified then the  
                current active pane is deactivated.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        configuration (Queryable[str]?): Set the layout configuration for the panes.  Valid values  
                are:  
                "single", "horizontal2", "vertical2", "horizontal3", "vertical3",  
                "top3", "left3", "bottom3", "right3", "horizontal4", "vertical4",  
                "top4", "left4", "bottom4", "right4", "quad"  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfVisiblePanes (bool?): Return the number of panes visible for the present  
                configuration.  
                Properties: query
        pane1 (bool?):   
                Properties: query
        pane2 (bool?):   
                Properties: query
        pane3 (bool?):   
                Properties: query
        pane4 (bool?): Return the name of the control in the respective pane.  
                Properties: query
        paneSize (Queryable[Multiuse[Tuple[int, int, int]]]?): The size of a pane in the current pane layout  
                configuration.  The first argument specifies the pane index and  
                is an integer value ranging from 1 to 4.  Panes for any particular  
                configuration are numbered clockwise beginning with the pane in  
                the top left corner of the layout.  The width and height of the  
                pane are specified by the last two arguments.  Both are  
                integer values and they indicate the percentage of the total  
                pane layout size rather that the number of pixels.  
                Properties: create, query, edit, multiuse
        paneUnderPointer (bool?): Return the name of the child occupying the  
                pane that the pointer is currently over.  An empty string is  
                returned if the pointer is not over a pane.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        separatorMovedCommand (Callable[..., Any]?): This command executed when the pane separators are moved.  
                Properties: create, edit
        separatorThickness (Queryable[int]?): The thickness of the separators between the panes.  
                Specify an integer value greater than 0. This flag has no effect  
                on Windows systems.  
                Properties: create, query, edit
        setPane (Multiuse[Tuple[str, int]]?): This flag allows you to put a child of this layout in a  
                particular pane.  The first argument is the full or short name of  
                the control.  The second argument is an integer value ranging from  
                1 to 4.  Panes for any particular configuration are numbered  
                clockwise beginning with the pane in the top left corner of the  
                layout.  
                Properties: create, edit, multiuse
        staticHeightPane (int?): Set a pane to have a static height, i.e. its height will not  
                change when the layout is dynamically resized. Only one pane  
                can be set to have a static height at one time. This state  
                will be retained even if another child is switched into the  
                pane. Specify 0 to set a pane back to the default state. Any  
                state will be lost if the pane configuration is changed.  
                Properties: create, edit
        staticWidthPane (int?): Set a pane to have a static width, i.e. its width will not  
                change when the layout is dynamically resized. Only one pane  
                can be set to have a static width at one time. This state  
                will be retained even if another child is switched into the  
                pane. Specify 0 to set a pane back to the default state. Any  
                state will be lost if the pane configuration is changed.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def panel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[bool, str, Callable[..., Any]]:
    """This command allows editing or querying properties of any panels. Not
    all of the common properites of panels can be used with this command.
    Flags such as -tearOff and -replacePanel require that you use the
    explicit panel command. The command 'getPanel -typeOf panelName' will
    return the explicit type of a panel.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def panelConfiguration(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addPanel: Multiuse[Tuple[bool, str, str, str, str]] = ..., configString: Queryable[str] = ..., createStrings: bool = ..., defaultImage: Queryable[str] = ..., defineTemplate: str = ..., editStrings: bool = ..., exists: bool = ..., image: Queryable[str] = ..., isFixedState: bool = ..., label: Queryable[str] = ..., labelStrings: bool = ..., numberOfPanels: bool = ..., removeAllPanels: bool = ..., removeLastPanel: bool = ..., replaceCreateString: Tuple[int, str] = ..., replaceEditString: Tuple[int, str] = ..., replaceFixedState: Tuple[int, bool] = ..., replaceLabel: Tuple[int, str] = ..., replacePanel: Tuple[int, bool, str, str, str, str] = ..., replaceTypeString: Tuple[int, str] = ..., sceneConfig: bool = ..., typeStrings: bool = ..., useTemplate: str = ..., userCreated: bool = ...) -> Union[str, bool]:
    """This command creates a panel configuration object. Typically you would
    not call this method command directly. Instead use the Panel Editor.Once a panel configuration is created you can make it appear in the
    main Maya window by selecting it from any panel's "Panels->Saved Layouts"
    menu.
    Args:
        addPanel (Multiuse[Tuple[bool, str, str, str, str]]?): Adds the specified panel to the configuration.  Arguments are:  
                isFixed, label string, type string, create string, edit string.  
                Properties: create, edit, multiuse
        configString (Queryable[str]?): Specifies the string that arranges the panels.  
                Properties: create, query, edit
        createStrings (bool?): Returns an string array of the panel creation strings.  
                Properties: query
        defaultImage (Queryable[str]?): The default image for this configuration. Once the default image  
                is set it may not be changed. If an image is set with the -i/image  
                flag then it's value will take precedence.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        editStrings (bool?): Returns an string array of the panel edit strings.  
                Properties: query
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        image (Queryable[str]?): The user specified image for this configuration. Use this flag  
                to override the default image.  
                Properties: create, query, edit
        isFixedState (bool?): Returns an integer array of whether the panels have fixed states or not.  
                Properties: query
        label (Queryable[str]?): Configuration label.  
                Properties: create, query, edit
        labelStrings (bool?): Returns an string array of the panel labels.  
                Properties: query
        numberOfPanels (bool?): Returns the number of panels in the configuration.  
                Properties: query
        removeAllPanels (bool?): Removes the last panel in the config.  
                Properties: edit
        removeLastPanel (bool?): Removes the last panel in the config.  
                Properties: edit
        replaceCreateString (Tuple[int, str]?): Replaces the specified create string.  The index is 1 based.  
                Properties: edit
        replaceEditString (Tuple[int, str]?): Replaces the specified edit string.  The index is 1 based.  
                Properties: edit
        replaceFixedState (Tuple[int, bool]?): Replaces the specified fixed state value (true|false).  The index is 1 based.  
                Properties: edit
        replaceLabel (Tuple[int, str]?): Replaces the specified label.  The index is 1 based.  
                Properties: edit
        replacePanel (Tuple[int, bool, str, str, str, str]?): Replaces the specified panel in the configuration.  Arguments are:  
                index, isFixed, label string, type string, create string, edit string.  
                The index is 1 based.  
                Properties: create, edit
        replaceTypeString (Tuple[int, str]?): Replaces the specified type string.  The index is 1 based.  
                Properties: edit
        sceneConfig (bool?): Specifies whether the configuration is associated with the scene.  
                Scene configurations are created when the scene is opened and deleted when  
                the scene is closed.  
                Properties: create, query, edit
        typeStrings (bool?): Returns an string array of the panel types.  
                Properties: query
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        userCreated (bool?): Returns true if the configuration was created by the user. If it is user created, the configuration will show up in the RMB menu in the toolbox's saved layouts.  
                Properties: create, query, edit

    Returns:
        str: The name of the panelConfiguration created.

    Example:
    """

def panelHistory(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., back: bool = ..., clear: bool = ..., defineTemplate: str = ..., exists: bool = ..., forward: bool = ..., historyDepth: Queryable[int] = ..., isEmpty: bool = ..., suspend: bool = ..., targetPane: Queryable[str] = ..., useTemplate: str = ..., wrap: bool = ...) -> Union[str, int, bool]:
    """This command creates a panel history object.  The object is targeted on a
    particular paneLayout and thereafter notes changes in panel configurations
    within that paneLayout, building up a history list.  The list can be stepped
    through backwards or forwards.
    Args:
        back (bool?): Go back one level on the history list.  
                Properties: edit
        clear (bool?): Clear the history stack  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        forward (bool?): Go forward one level on the history list.  
                Properties: edit
        historyDepth (Queryable[int]?): Specifies how many levels of history are maintained.  
                Properties: query, edit
        isEmpty (bool?): Returns true if there is currently no panel history.  
                Properties: query
        suspend (bool?): Specifies whether to suspend or resume updates to the panel history.  
                Useful for chunking a number of changes into one history event.  
                Properties: edit
        targetPane (Queryable[str]?): Specifies which paneLayout the history will be maintained for.  
                Properties: create, query
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        wrap (bool?): Specifies whether the history will wrap at the end and  
                beginning.  This value is true by default.  
                Properties: query, edit

    Returns:
        str: The name of the panelHistory object created.

    Example:
    """

def paramDimContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Command used to register the paramDimCtx tool.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: - name of the context created

    Example:
    """

def paramDimension(*args: str) -> str:
    """This command is used to create a param dimension to display the
    parameter value of a curve/surface at a specified point on the
    curve/surface.
    Returns:
        str: Name of the paramDimension shape node created

    Example:
    """

def paramLocator(*args: str, edit: bool = ..., query: bool = ..., position: bool = ...) -> str:
    """The command creates a locator in the underworld of a NURBS curve or
    NURBS surface at the specified parameter value.  If no object is
    specified, then a locator will be created on the first valid selected item
    (either a curve point or a surface point).
    Args:
        position (bool?): Whether to set the locator position in normalized space.  
                Properties: create

    Returns:
        str: Name for the new locator in the underworld of NURBS shape.

    Example:
    """

def parent(*args: str, absolute: bool = ..., addObject: bool = ..., noConnections: bool = ..., noInvScale: bool = ..., relative: bool = ..., removeObject: bool = ..., shape: bool = ..., world: bool = ...) -> List[str]:
    """This command parents (moves) objects under a new group, removes
    objects from an existing group, or adds/removes parents.If the -w flag is specified all the selected or specified objects
    are parented to the world (unparented first).If the -rm flag is specified then all the selected or specified
    instances are removed.If there are more than two objects specified all the objects are
    parented to the last object specified.If the -add flag is specified, the objects are not reparented but
    also become children of the last object specified.If there is only a single object specified then the selected objects
    are parented to that object.If an object is parented under a different group and there is
    an object in that group with the same name then this command
    will rename the parented object.
    Args:
        absolute (bool?): preserve existing world object transformations  
                (overall object transformation is preserved  
                by modifying the objects local transformation)  
                If the object to parent is a joint, it will  
                alter the translation and joint orientation of  
                the joint to preserve the world object  
                transformation if this suffices. Otherwise, a  
                transform will be inserted between the joint  
                and the parent for this purpose. In this case,  
                the transformation inside the joint is not  
                altered.  
                [default]  
                Properties: create
        addObject (bool?): preserve existing local object transformations  
                but don't reparent, just add the object(s) under  
                the parent. Use -world to add the world as  
                a parent of the given objects.  
                Properties: create
        noConnections (bool?): The parent command will normally generate  
                new instanced set connections when adding instances.  
                (ie. make a connection to the shading engine for  
                new instances) This flag suppresses this behaviour  
                and is primarily used by the file format.  
                Properties: create
        noInvScale (bool?): The parent command will normally connect  
                inverseScale to its parent scale on joints.  
                This is used to compensate scale on joint.  
                The connection of inverseScale will occur if both child and parent are joints and no connection is present on child's inverseScale.  
                In case of a reparenting, the old inverseScale will only get broken if the old parent is a joint. Otherwise connection will remain intact.  
                This flag suppresses this behaviour.  
                Properties: create
        relative (bool?): preserve existing local object transformations  
                (relative to the parent node)  
                Properties: create
        removeObject (bool?): Remove the immediate parent of every object specified. To remove only  
                a single instance of a shape from a parent, the path to the shape  
                should be specified.  
                Note: if there is a single parent then the object is effectively deleted from  
                the scene. Use -world to remove the world as a parent of the given object.  
                Properties: create
        shape (bool?): The parent command usually only operates on  
                transforms.  Using this flags allows a shape  
                that is specified to be directly parented under  
                the given transform.  This is used to instance  
                a shape node. (ie. "parent -add -shape"    is  
                equivalent to the "instance" command).  
                This flag is primarily used by the file format.  
                Properties: create
        world (bool?): unparent given object(s) (parent to world)  
                Properties: create

    Returns:
        List[str]: Names of the objects parented (possibly renamed)

    Example:
    """

def parentConstraint(*args: str, edit: bool = ..., query: bool = ..., createCache: Tuple[float, float] = ..., decompRotationToChild: bool = ..., deleteCache: bool = ..., layer: str = ..., maintainOffset: bool = ..., name: Queryable[str] = ..., remove: bool = ..., skipRotate: Multiuse[str] = ..., skipTranslate: Multiuse[str] = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[List[str], str, bool, float]:
    """Constrain an object's position and rotation so that it behaves as if it
    were a child of the target object(s). In the case of multiple targets,
    the overall position and rotation of the constrained object is the
    weighted average of each target's contribution to the position and
    rotation of the object.A parentConstraint takes as input one or more "target" DAG transform
    nodes at which to position and rotate the single "constraint
    object" DAG transform node.  The parentConstraint positions and rotates
    the constrained object at the weighted average of the world
    space position, rotation and scale target objects.
    Args:
        createCache (Tuple[float, float]?): This flag is used to generate an animation curve that serves as a  
                cache for the constraint. The two arguments define the start and end  
                frames.  
              
                The cache is useful if the constraint has multiple targets and  
                the constraint's interpolation type is set to "no flip". The "no flip"  
                mode prevents flipping during playback, but the result is dependent on  
                the previous frame. Therefore in order to consistently get the same  
                result on a specific frame, a cache must be generated. This flag  
                creates the cache and sets the constraint's interpolation type to  
                "cache". If a cache exists already, it will be deleted and replaced  
                with a new cache.  
                Properties: edit
        decompRotationToChild (bool?): During constraint creation, if the rotation offset between the constrained  
                object and the target object is maintained, this flag indicates close to  
                which object the offset rotation is decomposed. Setting this flag will make  
                the rotation decomposition close to the constrained object instead of the  
                target object, which is the default setting.  
                Properties: create
        deleteCache (bool?): Delete an existing interpolation cache.  
                Properties: edit
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        maintainOffset (bool?): If this flag is specified the position and rotation of the  
                constrained object will be maintained.  
                Properties: create
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        skipRotate (Multiuse[str]?): Causes the axis specified not to be considered when  
                constraining rotation.  Valid arguments are "x", "y", "z" and "none".  
                Properties: create, multiuse
        skipTranslate (Multiuse[str]?): Causes the axis specified not to be considered when  
                constraining translation.  Valid arguments are "x", "y", "z" and "none".  
                Properties: create, multiuse
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def particle(*args: str, edit: bool = ..., query: bool = ..., attribute: str = ..., cache: bool = ..., conserve: Queryable[float] = ..., count: bool = ..., deleteCache: bool = ..., dynamicAttrList: bool = ..., floatValue: float = ..., gridSpacing: Queryable[Multiuse[float]] = ..., inherit: Queryable[float] = ..., jitterBasePoint: Queryable[Multiuse[Tuple[float, float, float]]] = ..., jitterRadius: Queryable[Multiuse[float]] = ..., lowerLeft: Queryable[Multiuse[Tuple[float, float, float]]] = ..., name: Queryable[str] = ..., numJitters: Queryable[Multiuse[int]] = ..., order: int = ..., particleId: int = ..., perParticleDouble: bool = ..., perParticleVector: bool = ..., position: Multiuse[Tuple[float, float, float]] = ..., shapeName: Queryable[str] = ..., upperRight: Queryable[Multiuse[Tuple[float, float, float]]] = ..., vectorValue: Tuple[float, float, float] = ...) -> Union[str, bool, float, Multiuse[float], Multiuse[Tuple[float, float, float]], Multiuse[int]]:
    """The particle command creates a new particle object from a list of
    world space points. If a particle object is created, the command
    returns the names of the new particle shape and its associated particle
    object dependency node. If an object was queried, the results of the
    query are returned. Per particle attributes can be queried using the
    particleId or the order of the particle in the particle array.
    If an object was edited, nothing is returned.
    Args:
        attribute (str?): Used in per particle attribute query and edit. Specifies the  
                name of the attribute being queried or edited.  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        cache (bool?): Turns caching on/off for the particle shape.  
                Properties: create, query, edit
        conserve (Queryable[float]?): Conservation of momentum control (between 0 and 1).  Specifies  
                the fraction of the particle shape's existing momentum which is  
                conserved from frame to frame.  
                A value of 1 (the default) corresponds to true Newtonian physics,  
                in which momentum is conserved.  
                Properties: query, edit
        count (bool?): Returns the number of particles in the object.  
                Properties: query
        deleteCache (bool?): Deletes the particle shapes cache. This command is not undoable.  
                Properties: create
        dynamicAttrList (bool?): Returns a list of the dynamic attributes in the object.  
                Properties: query
        floatValue (float?): Used only in per particle attribute edit.  Specifies that the edit is  
                of a float attribute and must be followed by the new float value.  
                Properties: edit
        gridSpacing (Queryable[Multiuse[float]]?): Spacing between particles in the grid.  
                Properties: create, query, multiuse
        inherit (Queryable[float]?): Inherit this fraction (0. 1) of emitting object's velocity.  
                Properties: query, edit
        jitterBasePoint (Queryable[Multiuse[Tuple[float, float, float]]]?): Base point (center point) for jitters.  The command will create  
                one swatch of jitters for each base point.  It will pair up  
                other flags with base points in the order they are given in the  
                command line.  If not enough instances of the other flags are  
                availble, the last one on the line with be used for all other  
                instances of -jpb.  
                Properties: create, query, multiuse
        jitterRadius (Queryable[Multiuse[float]]?): Max radius from the center to place the particle instances.  
                Properties: create, query, multiuse
        lowerLeft (Queryable[Multiuse[Tuple[float, float, float]]]?): Lower left point of grid.  
                Properties: create, query, multiuse
        name (Queryable[str]?): name of particle object  
                Properties: query, edit
        numJitters (Queryable[Multiuse[int]]?): Number of jitters (instances) per particle.  
                Properties: create, query, multiuse
        order (int?): Used in per particle attribute query and edit. Specifies the  
                zero-based order (index) of the particle whose attribute is being  
                queried  or edited in the  
                particle array. Querying the value of a per particle attribute  
                requires the -attribute and -id or -order flags and their arguments  
                to precede the -q flag.  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        particleId (int?): Used in per particle attribute query and edit. Specifies the  
                id of the particle whose attribute is being queried or edited.  
                Querying the value of a per particle attribute  
                requires the -attribute and -id or -order flags and their arguments  
                to precede the -q flag.  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        perParticleDouble (bool?): Returns a list of the per-particle double attributes,  
                excluding initial-state, cache, and information-only attributes.  
                Properties: query
        perParticleVector (bool?): Returns a list of the per-particle vector attributes,  
                excluding initial-state, cache, and information-only attributes.  
                Properties: query
        position (Multiuse[Tuple[float, float, float]]?): World-space position of each particle.  
                Properties: multiuse
        shapeName (Queryable[str]?): Specify the shape name used for geometry instancing.  
                DO not confuse this with the -n flag which names the particle object.  
                Properties: query, edit
        upperRight (Queryable[Multiuse[Tuple[float, float, float]]]?): Upper right point of grid.  
                Properties: create, query, multiuse
        vectorValue (Tuple[float, float, float]?): Used only in per particle attribute edit.  Specifies that the edit is  
                of a vector attribute and must be followed by all three float values  
                for the vector.  
                Properties: edit

    Returns:
        str: The name of the particle object created

    Example:
    """

def particleExists(*args: str) -> bool:
    """This command is used to query if a particle or soft object with
    the given name exists. Either the transform or shape name can be used
    as well as the name of the soft object.
    Returns:
        bool: True if there is a particle object or soft object by the given
            name, false otherwise.

    Example:
    """

def particleFill(*args: str, closePacking: bool = ..., doubleWalled: bool = ..., maxX: float = ..., maxY: float = ..., maxZ: float = ..., minX: float = ..., minY: float = ..., minZ: float = ..., particleDensity: float = ..., resolution: int = ...) -> bool:
    """This command generates an nParticle system that fills the selected object with a grid of particles.particle
    Args:
        closePacking (bool?): If this is on then the particles are positioned as closely as possible in a hexagonal close packing arrangement.  
                Otherwise particles are packed in a uniform grid lattice.  
                Properties: create
        doubleWalled (bool?): This flag should be used if the thickness of the object to fill has been modeled( for example a mug ).  
                Otherwise the particles will be created inside the wall. Note that doubleWalled will not  
                handle some cases very well. For example a double walled donut shape may get the center  
                region of the donut filled. In cases like this it may be better to make the internal wall a  
                separate mesh then fill that without using doubleWalled.  
                Properties: create
        maxX (float?): The fill max bounds of the particles in X relative to the X bounds of the object.  
                A value of zero is totally empty and one is totally full. The default value is 1, or fully filled.  
                Properties: create
        maxY (float?): The fill max bounds of the particles in Y relative to the Y bounds of the object.  
                A value of zero is totally empty and one is totally full. The default value is 1, or fully filled.  
                Properties: create
        maxZ (float?): The fill max bounds of the particles in Z relative to the Z bounds of the object.  
                A value of zero is totally empty and one is totally full. The default value is 1, or fully filled.  
                Properties: create
        minX (float?): The fill lower bounds of the particles in X relative to the X bounds of the object.  
                A value of zero is totally full and one is totally empty. The default value is 0, or fully filled.  
                Properties: create
        minY (float?): The fill lower bounds of the particles in Y relative to the Y bounds of the object.  
                A value of zero is totally full and one is totally empty. The default value is 0, or fully filled.  
                Properties: create
        minZ (float?): The fill lower bounds of the particles in Z relative to the Z bounds of the object.  
                A value of zero is totally full and one is totally empty. The default value is 0, or fully filled.  
                Properties: create
        particleDensity (float?): This controls the size of the particles. At a value of 1.0 the particle size will exactly match the  
                grid spacing determined by the resolution parameter and the object bounds. Particles which overlap  
                the surface will be rejected even if the center of the particle is inside.  
                Properties: create
        resolution (int?): This determines the total number of particles generated.  
                It represent the resolution along the largest axis of the object's bounding box.  
                For a cube shape the total potential particles will be the cube of the resolution.  
                For other shapes it will be less.  
                The default value for this flag is 10, so 1000 particles could be generated for a cube shape.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def particleInstancer(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addObject: bool = ..., aimAxis: Queryable[str] = ..., aimDirection: Queryable[str] = ..., aimPosition: Queryable[str] = ..., aimUpAxis: Queryable[str] = ..., aimWorldUp: Queryable[str] = ..., attributeMapping: bool = ..., cycle: Queryable[str] = ..., cycleStartObject: Queryable[str] = ..., cycleStep: Queryable[float] = ..., cycleStepUnits: Queryable[str] = ..., index: Queryable[int] = ..., instanceId: Queryable[str] = ..., levelOfDetail: Queryable[str] = ..., name: Queryable[str] = ..., object: Queryable[Multiuse[str]] = ..., objectIndex: Queryable[str] = ..., particleAge: Queryable[str] = ..., position: Queryable[str] = ..., removeObject: bool = ..., rotation: Queryable[str] = ..., rotationOrder: Queryable[str] = ..., rotationType: Queryable[str] = ..., rotationUnits: Queryable[str] = ..., scale: Queryable[str] = ..., shear: Queryable[str] = ..., visibility: Queryable[str] = ...) -> Union[str, bool, float, int, Multiuse[str]]:
    """This command is used to create a particle instancer node and set the proper
    attributes in the particle shape and in the instancer node.  It will
    also create the connections needed between the particle shape and the instancer
    node.particle, instancer
    Args:
        addObject (bool?): This flag indicates that objects specified by the -object flag will be added to  
                the instancer node as instanced objects.  
                Properties: create, edit
        aimAxis (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the aim axis  
                of the instanced objects.  
                Properties: create, query, edit
        aimDirection (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the aim direction  
                of the instanced objects.  
                Properties: create, query, edit
        aimPosition (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the aim position  
                of the instanced objects.  
                Properties: create, query, edit
        aimUpAxis (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the aim up axis  
                of the instanced objects.  
                Properties: create, query, edit
        aimWorldUp (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the aim world up  
                of the instanced objects.  
                Properties: create, query, edit
        attributeMapping (bool?): This flag queries the particle attribute mapping list.  
                Properties: query
        cycle (Queryable[str]?): This flag sets or queries the cycle attribute for the instancer node.  The options are  
                "none", "sequential". The default is "none".  
                Properties: create, query, edit
        cycleStartObject (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the cycle start object  
                of the instanced objects.  
                Properties: create, query, edit
        cycleStep (Queryable[float]?): This flag sets or queries the cycle step attribute for the instancer node.  This attribute  
                indicates the size of the step in frames or seconds (see cycleStepUnits).  
                Properties: create, query, edit
        cycleStepUnits (Queryable[str]?): This flag sets or queries the cycle step unit attribute for the instancer node.  
                The options are "frames" or "seconds".  The default is "frames".  
                Properties: create, query, edit
        index (Queryable[int]?): This flag is used to query the name of the ith instanced object.  
                Properties: query
        instanceId (Queryable[str]?): This flag queries the particle attribute name to be used for the id of the instanced objects.  
                Properties: query
        levelOfDetail (Queryable[str]?): This flag sets or queries the level of detail of the instanced objects.  The options are  
                "geometry", "boundingBox" or "boundingBoxes".  The default is "geometry".  
                Properties: create, query, edit
        name (Queryable[str]?): This flag sets or queries the name of the instancer node.  
                Properties: create, query
        object (Queryable[Multiuse[str]]?): This flag indicates which objects will be add/removed from the list of instanced  
                objects.  The flag is used in conjuction with the -addObject and -remove flags.  If  
                neither of these flags is specified on the command line then -addObject is assumed.  
                Properties: create, query, edit, multiuse
        objectIndex (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the object index  
                of the instanced objects.  
                Properties: create, query, edit
        particleAge (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the age  
                of the instanced objects.  
                Properties: create, query, edit
        position (Queryable[str]?): DEFAULT "worldPosition"  
                This flag sets or queries the particle attribute name to be used for the positions  
                of the instanced objects.  By default the attribute is worldPosition.  
                Properties: create, query, edit
        removeObject (bool?): This flag indicates that objects specified by the -object flag will be  
                removed from the instancer node as instanced objects.  
                Properties: edit
        rotation (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the rotation  
                of the instanced objects.  
                Properties: create, query, edit
        rotationOrder (Queryable[str]?): This flag specifies the rotation order associated with the rotation flag.  The options are  
                XYZ, XZY, YXZ, YZX, ZXY, or ZYX.  By default the attribute is XYZ.  
                Properties: create, query, edit
        rotationType (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the rotation type  
                of the instanced objects.  
                Properties: create, query, edit
        rotationUnits (Queryable[str]?): This flag specifies the rotation units associated with the rotation flag.  The options are  
                degrees or radians.  By default the attribute is degrees.  
                Properties: create, query, edit
        scale (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the scale  
                of the instanced objects.  
                Properties: create, query, edit
        shear (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the shear  
                of the instanced objects.  
                Properties: create, query, edit
        visibility (Queryable[str]?): This flag sets or queries the particle attribute name to be used for the visibility  
                of the instanced objects.  
                Properties: create, query, edit

    Returns:
        str: Command result

    Example:
    """

def particleRenderInfo(*, query: bool = ..., attrList: Queryable[int] = ..., attrListAll: bool = ..., name: Queryable[int] = ..., renderTypeCount: bool = ...) -> Union[bool, int]:
    """This action provides information access to the particle
    render subclasses. These are derived from TdynRenderBase.
    This action is used primarily by the Attribute Editor to
    gather information about attributes used for rendering.
    Args:
        attrList (Queryable[int]?): Return the list of attributes used by this render type.  
                Properties: query
        attrListAll (bool?): Return a complete list of all render attributes used by the  
                particle object. This also includes the per particle attributes.  
                Properties: query
        name (Queryable[int]?): Return the name of the render subclass using the render type.  
                Properties: query
        renderTypeCount (bool?): Return the count of registered render classes for particle.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def partition(*args: str, edit: bool = ..., query: bool = ..., addSet: str = ..., name: str = ..., removeSet: str = ..., render: bool = ...) -> Union[str, bool]:
    """This command is used to create, query or add/remove sets to a
    partition. If a partition name needs to be specified, it is the first
    argument, other arguments represent the set names.Without any flags, the command will create a
    partition with a default name.  Any sets which are arguments
    to the command will be added to the partition.A set can be added to a partition only if none of its members
    are in any of the other sets in the partition. If the -re/render
    flag is specified when the partition is created, only 'renderable'
    sets can be added to the partition.Sets can be added and removed from a partition by using the
    -addSet or -removeSet flags.If a set is already selected, and the partition command is
    executed, the set will be added to the created partition.
    Args:
        addSet (str?): Adds the list of sets to the named partition.  
                Properties: create
        name (str?): Assigns the given name to new partition. Valid only for create mode.  
                Properties: create
        removeSet (str?): Removes the list of sets from the named partition.  
                Properties: create
        render (bool?): New partition can contain render sets.  
                For use in creation mode only. Default is false.  Can also  
                be used with query flag - returns boolean.  
                Properties: create, query

    Returns:
        str: Name of the partition that was created or edited

    Example:
    """

def pasteKey(*args: str, edit: bool = ..., query: bool = ..., animLayer: str = ..., animation: str = ..., attribute: Multiuse[str] = ..., clipboard: str = ..., connect: bool = ..., copies: int = ..., float: Range[float] = ..., floatOffset: float = ..., includeUpperBound: bool = ..., index: int = ..., matchByName: bool = ..., option: str = ..., time: NullableRange[float] = ..., timeOffset: int = ..., valueOffset: float = ...) -> int:
    """The pasteKey command pastes curve segment hierarchies from the
    clipboard onto other objects or curves. If the object hierarchy
    from which the curve segments were copied or cut does not match
    the object hierarchy being pasted to, pasteKey will paste as much
    as it can match in the hierarchy.  If animation from only one object
    is on the clipboard, it will be pasted to each of the target objects.
    If animation from more than one object is on the clipboard, selection
    list order determines what animation is pasted to which object.Valid operations include:TbaseKeySetCmd.hThe way the keyset clipboard will be pasted to the specified object's
    attributes depends on the paste "-option" specified. Each of these
    options below will be explained using an example. For all the
    explanations, let us assume that there is a curve segment
    with 20 frames of animation on the keyset clipboard (you can put
    curve segments onto the clipboard using theorcommands). We will call the animation curve that
    we are pasting to the
    Args:
        animLayer (str?): Specifies that the keys getting pasted should be pasted onto  
                curves on the specified animation layer.If that layer doesn't  
                exist for the specified objects or attributes then the keys  
                won't get pasted.  
                Properties: create
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        clipboard (str?): Specifies the clipboard from which animation is pasted.  
                Valid clipboards are "api" and "anim".  The default clipboard  
                is: anim  
                Properties: create
        connect (bool?): When true, connect the source curve with the  
                destination curve's value at the paste time.  
                (This has the effect of shifting the clipboard curve  
                in value to connect with the destination curve.)  
                False preserves the source curve's original keyframe  
                values. Default is false.  
                Properties: create
        copies (int?): The number of times to paste the source curve.  
                Properties: create
        float (Range[float]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create
        floatOffset (float?): How much to offset the pasted keys in time (for non-time-input  
                animation curves).  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (int?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create
        matchByName (bool?): When true, we will only paste onto items in the scene whose  
                node and attribute names match up exactly with a corresponding  
                item in the clipboard. No hierarchy information is used.  
                Default is false, and in this case the usual matching by  
                hierarchy occurs.  
                Properties: create
        option (str?): Valid values are "insert", "replace",  
                "replaceCompletely", "merge", "scaleInsert,"  
                "scaleReplace", "scaleMerge", "fitInsert",  
                "fitReplace", and "fitMerge". The default paste  
                option is: "insert".  
                Properties: create
        time (NullableRange[float]?): time uniquely representing a key (or key  
                range) on a time-based animCurve.  See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create
        timeOffset (int?): How much to offset the pasted keys in time (for time-input  
                animation curves).  
                Properties: create
        valueOffset (float?): How much to offset the pasted keys in value.  
                Properties: create

    Returns:
        int: The number of curves pasted

    Example:
    """

def pathAnimation(*args: str, edit: bool = ..., query: bool = ..., bank: bool = ..., bankScale: Queryable[float] = ..., bankThreshold: Queryable[float] = ..., curve: Queryable[str] = ..., endTimeU: Queryable[Multiuse[int]] = ..., endU: Queryable[float] = ..., follow: bool = ..., followAxis: Queryable[str] = ..., fractionMode: bool = ..., inverseFront: bool = ..., inverseUp: bool = ..., name: Queryable[str] = ..., startTimeU: Queryable[Multiuse[int]] = ..., startU: Queryable[float] = ..., upAxis: Queryable[str] = ..., useNormal: bool = ..., worldUpObject: Queryable[str] = ..., worldUpType: Queryable[str] = ..., worldUpVector: Queryable[Tuple[float, float, float]] = ...) -> Union[str, bool, float, Multiuse[int], Tuple[float, float, float]]:
    """The pathAnimation command constructs the necessary graph nodes
    and their interconnections for a motion path animation. Motion path
    animation requires a curve and one or more other objects.
    During the animation, the objects will be moved along the 3D curve
    or the curveOnSurface.There are two ways to specify the moving objects:Likewise, there are two ways to specify a motion curve:When the end time is not specified: only one keyframe
    will be created either at the current time, or at the specified
    start time.
    Args:
        bank (bool?): If on, enable alignment of the up axis of the moving  
                object(s) to the curvature of the path geometry.  
                Default is false.  
                When queried, this flag returns a boolean.  
                Properties: query
        bankScale (Queryable[float]?): This flag specifies a factor to scale the amount of  
                bank angle.  
                Default is 1.0  
                When queried, this flag returns a float.  
                Properties: query
        bankThreshold (Queryable[float]?): This flag specifies the limit of the bank angle.  
                Default is 90 degrees  
                When queried, this flag returns an angle.  
                Properties: query
        curve (Queryable[str]?): This flag specifies the name of the curve for the path.  
                Default is NONE  
                When queried, this flag returns a string.  
                Properties: query
        endTimeU (Queryable[Multiuse[int]]?): This flag specifies the ending time of the animation  
                for the u parameter.  
                Default is NONE.  
                When queried, this flag returns a time.  
                Properties: query, multiuse
        endU (Queryable[float]?): This flag specifies the ending value of the u  
                parameterization for the animation.  
                Default is the end parameterization value of the curve.  
                When queried, this flag returns a linear.  
                Properties: query
        follow (bool?): If on, enable alignment of the front axis of the moving object(s).  
                Default is false.  
                When queried, this flag returns a boolean.  
                Properties: query
        followAxis (Queryable[str]?): This flag specifies which object local axis to be  
                aligned to the tangent of the path curve.  
                Default is y  
                When queried, this flag returns a string.  
                Properties: query
        fractionMode (bool?): If on, evaluation on the path is based on the fraction  
                of length of the path curve.  
                Default is false.  
                When queried, this flag returns a boolean.  
                Properties: query
        inverseFront (bool?): This flag specifies whether or not to align  
                the front axis of the moving object(s) to the opposite direction  
                of the tangent vector of the path geometry.  
                Default is false.  
                When queried, this flag returns a boolean.  
                Properties: query
        inverseUp (bool?): This flag specifies whether or not to align  
                the up axis of the moving object(s) to the opposite direction  
                of the normal vector of the path geometry.  
                Default is false.  
                When queried, this flag returns a boolean.  
                Properties: query
        name (Queryable[str]?): This flag specifies the name for the new motion path node.  
                (instead of the default name)  
                When queried, this flag returns a string.  
                Properties: query
        startTimeU (Queryable[Multiuse[int]]?): This flag specifies the starting time of the animation  
                for the u parameter.  
                Default is the the current time.  
                When queried, this flag returns a time.  
                Properties: query, multiuse
        startU (Queryable[float]?): This flag specifies the starting value of the u  
                parameterization for the animation.  
                Default is the start parameterization value of the curve.  
                When queried, this flag returns a linear.  
                Properties: query
        upAxis (Queryable[str]?): This flag specifies which object local axis to be  
                aligned a computed up direction.  
                Default is z  
                When queried, this flag returns a string.  
                Properties: query
        useNormal (bool?): This flag is now obsolete. Use -wut/worldUpType instead.  
                Properties: create, query, edit
        worldUpObject (Queryable[str]?): Set the DAG object to use for worldUpType "object" and  
                "objectrotation". See -wut/worldUpType for greater detail.  
                The default value is no up object, which is interpreted  
                as world space.  
                Properties: create, query, edit
        worldUpType (Queryable[str]?): Set the type of the world up vector computation.  
                The worldUpType can have one of 5 values: "scene",  
                "object", "objectrotation", "vector", or "normal".  
                If the value is "scene", the upVector is  
                aligned with the up axis of the scene and  
                worldUpVector and worldUpObject are ignored.  
                If the value is "object", the upVector is  
                aimed as closely as possible to the  
                origin of the space of the worldUpObject and  
                the worldUpVector is ignored.  
                If the value is "objectrotation" then the  
                worldUpVector is interpreted as being in  
                the coordinate space of the worldUpObject, transformed into  
                world space and the upVector is aligned as  
                closely as possible to the result.  
                If the value is "vector", the upVector  
                is aligned with worldUpVector as closely as  
                possible and worldUpObject is ignored.  
                Finally, if the value is "normal" the upVector is aligned to  
                the path geometry.  
                The default worldUpType is "vector".  
                Properties: create, query, edit
        worldUpVector (Queryable[Tuple[float, float, float]]?): Set world up vector.  This is the vector in world  
                coordinates that up vector should align with.  
                See -wut/worldUpType for greater detail.  
                If not given at creation time, the default  
                value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit

    Returns:
        str: (name of the created motionPath node)

    Example:
    """

def pause(*, seconds: int = ...) -> bool:
    """Pause for a specified number of seconds for canned demos or
    for test scripts to allow user to view results.
    Args:
        seconds (int?): Pause for the specified number of seconds.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def perCameraVisibility(*args: str, query: bool = ..., camera: Queryable[str] = ..., exclusive: bool = ..., hide: bool = ..., remove: bool = ..., removeAll: bool = ..., removeCamera: bool = ...) -> Union[List[str], str, bool]:
    """The perCameraVisibility command creates, queries and removes
    visibility relationships between DAG objects and cameras.
    These relationships are applied in any viewport that uses the cameras
    involved. (They are not used e.g. in rendering.)
    Objects can be set to be exclusive to a camera (meaning they will only
    be displayed in viewports using that camera; they will be hidden in other
    viewports) or hidden from a camera (meaning they will be not visible
    in any viewport using the camera).viewport, visibility
    Args:
        camera (Queryable[str]?): Specify the camera for the operation.  
                Properties: create, query
        exclusive (bool?): Set objects as being exclusive to the given camera.  
                Properties: create, query
        hide (bool?): Set objects as being hidden from the given camera.  
                Properties: create, query
        remove (bool?): Used with exclusive or hide, removes the objects instead of adding them.  
                Properties: create
        removeAll (bool?): Remove all exclusivity/hidden objects for all cameras.  
                Properties: create
        removeCamera (bool?): Remove all exclusivity/hidden objects for the given camera.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def percent(arg0: str = ..., /, *args: str, query: bool = ..., addPercent: bool = ..., dropoffAxis: Tuple[float, float, float] = ..., dropoffCurve: str = ..., dropoffDistance: float = ..., dropoffPosition: Tuple[float, float, float] = ..., dropoffType: str = ..., multiplyPercent: bool = ..., value: Queryable[float] = ...) -> Union[bool, float]:
    """This command sets percent values on members of a weighted node such as
    a cluster or a jointCluster. With no flags specified the command sets
    the percent value for selected components of the specified node to the
    specified percent value. A dropoff from the specified percent value to
    0 can be specified from a point, plane or curve using a dropoff
    distance around that shape. The percent value can also be added or
    multiplied with existing percent values of the node components.
    Args:
        addPercent (bool?): Add the percent value specified with the -v flag to the existing percent values  
                Properties: create
        dropoffAxis (Tuple[float, float, float]?): Specifies the axis along which to dropoff the percent value,  
                starting from the dropoffPosition.  
                Properties: create
        dropoffCurve (str?): Specifies the curve around which to dropoff the percent value.  
                Properties: create
        dropoffDistance (float?): Specifies the dropoff distance from the point, plane or curve  
                that was specified using the -dp -dax or -dc flags.  
                Properties: create
        dropoffPosition (Tuple[float, float, float]?): Specifies the point around which to dropoff the percent value.  
                Properties: create
        dropoffType (str?): Specifies the type of dropoff. Used in conjunction with  
                the -dp, -dax or -dc flags. Default is linear.  
                Valid values are: linear, sine, exponential, linearSquared, none.  
                Properties: create
        multiplyPercent (bool?): Multiply the percent value specified with the -v flag with existing percent values  
                Properties: create
        value (Queryable[float]?): The percent value to be applied. The default is 1. In query mode,  
                returns an array of doubles corresponding to the weights of the  
                selected object components.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def performanceOptions(*, query: bool = ..., clusterResolution: Queryable[float] = ..., disableStitch: Queryable[str] = ..., disableTrimBoundaryDisplay: Queryable[str] = ..., disableTrimDisplay: Queryable[str] = ..., latticeResolution: Queryable[float] = ..., passThroughBindSkinAndFlexors: Queryable[str] = ..., passThroughBlendShape: Queryable[str] = ..., passThroughCluster: Queryable[str] = ..., passThroughDeltaMush: Queryable[str] = ..., passThroughFlexors: Queryable[str] = ..., passThroughLattice: Queryable[str] = ..., passThroughMeshBoolean: Queryable[str] = ..., passThroughPaintEffects: Queryable[str] = ..., passThroughSculpt: Queryable[str] = ..., passThroughWire: Queryable[str] = ..., regionOfEffect: Queryable[str] = ..., skipHierarchyTraversal: bool = ..., useClusterResolution: Queryable[str] = ..., useLatticeResolution: Queryable[str] = ...) -> Union[str, float, bool]:
    """Sets the global performance options for the application.  The options allow
    the disabling of features such as stitch surfaces or deformers to
    cut down on computation time in the scene.Performance options that are in effect may be on all the time, or they can be
    turned on only for interaction.  In the latter case, the options will only
    take effect during UI interaction or playback.Note that none of these performance options will affect rendering.
    Args:
        clusterResolution (Queryable[float]?): Sets the global cluster resolution.  This value may range between  
                0.0 (exact calculation) and 10.0 (rough approximation)  
                Properties: query
        disableStitch (Queryable[str]?): Sets the state of stitch surface disablement.  Setting this  
                to "on" suppresses the generation of stitch surfaces.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        disableTrimBoundaryDisplay (Queryable[str]?): Sets the state of trim boundary drawing disablement.  Setting this  
                to "on" suppresses the drawing of surface trim boundaries.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        disableTrimDisplay (Queryable[str]?): Sets the state of trim drawing disablement.  Setting this  
                to "on" suppresses the drawing of surface trims.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        latticeResolution (Queryable[float]?): Sets the global lattice resolution.  This value may range between  
                0.0 (exact calculation) and 1.0 (rough approximation)  
                Properties: query
        passThroughBindSkinAndFlexors (Queryable[str]?): Sets the state of bind skin and all flexors pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughBlendShape (Queryable[str]?): Sets the state of blend shape deformer pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughCluster (Queryable[str]?): Sets the state of cluster deformer pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughDeltaMush (Queryable[str]?): Sets the state of delta mush deformer pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughFlexors (Queryable[str]?): Sets the state of flexor pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughLattice (Queryable[str]?): Sets the state of lattice deformer pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughMeshBoolean (Queryable[str]?): Sets the state of mesh booleans pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughPaintEffects (Queryable[str]?): Sets the state of paint effects pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughSculpt (Queryable[str]?): Sets the state of sculpt deformer pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        passThroughWire (Queryable[str]?): Sets the state of wire deformer pass through.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        regionOfEffect (Queryable[str]?): When enabled, an interactive update of translation commands will attempt to  
                determine which components are being changed and only update effected components  
                as a performance optimization while dragging a manip.  
                Properties: query
        skipHierarchyTraversal (bool?): When enabled, hierarchy traversal of invisible objects in the scene will be  
                disabled in order to increase performance however this has a side effect of  
                performing redundant viewport refreshes on certain actions such as manipulations,  
                start/end of playback, idle refresh calls, etc.  
                Properties: query
        useClusterResolution (Queryable[str]?): Sets the state of cluster deformer global resolution.  This  
                allows clusters to be calculated at a lower resolution.  
                Valid values are "on", "off", "interactive".  
                Properties: query
        useLatticeResolution (Queryable[str]?): Sets the state of lattice deformer global resolution.  This  
                allows lattices to be calculated at a lower resolution.  
                Valid values are "on", "off", "interactive".  
                Properties: query

    Returns:
        str: One of "on", "off", or "interactive" giving the state of the option
        float: Global resolution value

    Example:
    """

def pfxstrokes(*, filename: str = ..., postCallback: bool = ..., selected: bool = ...) -> bool:
    """This command will loop through all the Paint Effects strokes, including pfxHair nodes, and write
    the current state of all the tubes to a file. For normal stroke nodes tubes must be ON in the brush or
    there will be no output. For pfxHair nodes there will always be output, but the format is different than
    for stroke nodes(however one can assign a brush with tubes = ON to a pfxHair node, in which case it
    will output the same format as strokes). The general file format is ASCII, using commas to separate numerical
    values and newlines between blocks of data. The format used for pfxHair nodes presents the hair curves points
    in order from root to tip of the hair. The hairs follow sequentially in the following fashion:
    NumCvs
    pointX,pointY,pointZ, normalX,normalY,normalZ, width, colorR,colorG,colorB, paramU
    pointX,pointY,pointZ, normalX,normalY,normalZ, width, colorR,colorG,colorB, paramU
    etc...
    NumCvs
    pointX,pointY,pointZ, normalX,normalY,normalZ, width, colorR,colorG,colorB, paramU
    etc..
    The format used to output files for brushes with tubes=ON is more complex. The tubes can branch and the order
    the segments are written is the same order they are drawn in. Slowly drawing a tall grass brush in the paint
    effects panel can help to illustrate the order the segments will appear in the file. New tubes can start "growing"
    before others are finished. There is no line for "NumCvs". Instead all data for each segment appears on each line.
    The data on each line is the same as passed into the paint effects runtime function. See the argument list of
    paintRuntimeFunc.mel for the order and a description of these parameters. The parameters match up exactly in
    the order they appear on a line of the output file with the order of arguments to this function. If one wishes to
    parse the output file and connect the segments together into curves the branchId, parentId and siblingCnt
    parameters can help when sorting which segment connects to which line.
    Using the -postCallback option will write out the tubes data after it has been proessed by the runTime callback.paint, effects, strokes, callback
    Args:
        filename (str?): The output file.  
                Properties: create
        postCallback (bool?): Output information to the file after the Runtime Callback MEL function has been invoked. The default  
                is to output the information prior to the callback.  
                Properties: create
        selected (bool?): Only loop through the selected strokes.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def pickWalk(*args: str, direction: str = ..., recurse: bool = ..., type: str = ...) -> List[str]:
    """The pickWalk command allows you to quickly change the selection list
    relative to the nodes that are currently selected. It is called
    pickWalk, because it walks from one selection list to another
    by unselecting what's currently selected, and selecting nodes that
    are in the specified direction from the currently selected list.
    If you specify objects on the command line, the pickWalk command
    will walk from those objects instead of the selected list.If the -type flag is instances, then the left and right direction will
    walk to the previous or next instance of the same selected dag node.
    Args:
        direction (str?): The direction to walk from the node. The choices are  
                up | down | left | right | in | out. up walks to the parent node,  
                down to the child node, and left and right to the sibling nodes.  
                If a CV on a surface is selected, the left and right directions walk  
                in the U parameter direction of the surface, and the up and down directions  
                walk in the V parameter direction.  
                In and out are only used if the type flag is 'latticepoints'.  
                Default is right.  
                Properties: create
        recurse (bool?): If specified then recurse down when walking  
                Properties: create
        type (str?): The choices are nodes | instances | edgeloop | edgering | faceloop | keys | latticepoints | motiontrailpoints.  
                If type is nodes, then the left and right direction walk to the next dag siblings.  
                If type is instances, the left and right direction walk to the previous or next  
                instance of the same dag node.  
                If type is edgeloop, then the edge loop starting at the first selected edge will  
                be selected.  
                If type is edgering, then the edge ring starting at the first selected edge will  
                be selected.  
                If type is faceloop, and there are two connected quad faces selected which define  
                a face loop, then that face loop will be selected.  
              
                edgeloop, edgering and faceloop all remember which was the first edge or faces  
                selected for as long as consecutive selections are made by this command.  They  
                use this information to determine what the "next" loop or ring selection should  
                be.  Users can make selections forwards and backwards by using the direction  
                flag with "left" or "right".  
              
                If type is motiontrailpoints, then the left and right direction walk to the previous  
                or next motion trail points respectively.  
              
                Default is nodes.  
                Properties: create

    Returns:
        List[str]: A list of the newly selected items

    Example:
    """

def picture(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., tile: bool = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a static image.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): Sets the image given the .xpm file name.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        tile (bool?): If true, the picture is tiled to fill the picture area. False  
                by default. (Windows only flag)  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the picture control created.

    Example:
    """

def pixelMove(arg0: int = ..., arg1: int = ..., /) -> bool:
    """The pixelMove command moves objects by what appears as pixel units
    based on the current view. It takes two integer arguments which
    specify the direction in screen space an object should appear to
    move. The vector between the center pixel of the view and the
    specified offset is mapped to some world space vector which defines
    the relative amount to move the selected objects. The mapping is
    dependent upon the view.
    Returns:
        bool:

    Example:
    """

def planarSrf(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., degree: Queryable[int] = ..., keepOutside: bool = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., range: bool = ...) -> Union[List[str], bool, int, float]:
    """This command computes a planar trimmed surface given
    planar boundary curves that form a closed region.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface:  
                1. linear,  
                3. cubic  
                Default: 3  
                Properties: create, query, edit
        keepOutside (bool?): If true, keep the regions outside the given curves.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The distance tolerance for the cvs of the curves to be in the same plane.  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def plane(*, length: float = ..., name: str = ..., position: Tuple[float, float, float] = ..., rotation: Tuple[float, float, float] = ..., size: float = ..., width: float = ...) -> str:
    """The command creates a sketch plane (also known as a "construction plane")
    in space.  To create an object (such as a NURBS curve, joint chain or
    polygon) on a construction plane, you need to first make the plane live.
    See also the makeLive command.
    Args:
        length (float?): The length of plane.  
                "linear" means that this flag can handle values with units.  
                Properties: create
        name (str?): Name the resulting object.  
                Properties: create
        position (Tuple[float, float, float]?): 3D position where the centre of the plane is positioned.  
                "linear" means that this flag can handle values with units.  
                Properties: create
        rotation (Tuple[float, float, float]?): The rotation of plane.  
                "angle" means that this flag can handle values with units.  
                Properties: create
        size (float?): The combined size (size x size) of plane.  
                "linear" means that this flag can handle values with units.  
                Properties: create
        width (float?): The width of plane.  
                "linear" means that this flag can handle values with units.  
                Properties: create

    Returns:
        str: (name of the new plane)

    Example:
    """

def play(*, query: bool = ..., forward: bool = ..., playSound: bool = ..., record: bool = ..., sound: Queryable[str] = ..., state: bool = ..., wait: bool = ...) -> Union[bool, str]:
    """This command starts and stops playback.
    In order to change the frame range of playback,
    see the playbackOptions command.
    Args:
        forward (bool?): When true, play back the animation from the  
                currentTime to the maximum of the playback range.  
                When false, play back from the currentTime to the  
                minimum of the playback range.  When queried,  
                returns an int.  
                Properties: create, query
        playSound (bool?): Specify whether or not sound should be used during playback  
                Properties: create, query
        record (bool?): enable the recording system and start one playback loop  
                Properties: create, query
        sound (Queryable[str]?): Specify the sound node to be used during playback  
                Properties: create, query
        state (bool?): start or stop playing back  
                Properties: create, query
        wait (bool?): Wait till completion before returning control to  
                command Window.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def playbackOptions(*, edit: bool = ..., query: bool = ..., animationEndTime: Queryable[int] = ..., animationStartTime: Queryable[int] = ..., blockingAnim: bool = ..., by: Queryable[float] = ..., framesPerSecond: bool = ..., loop: Queryable[str] = ..., maxPlaybackSpeed: Queryable[float] = ..., maxTime: Queryable[int] = ..., minTime: Queryable[int] = ..., playbackSpeed: Queryable[float] = ..., selectionEndTime: Queryable[int] = ..., selectionStartTime: Queryable[int] = ..., selectionVisible: bool = ..., stepLoop: bool = ..., view: Queryable[str] = ...) -> Union[str, int, bool, float]:
    """This command sets/queries certain values associated
    with playback: looping style, start/end times, etc.
    Only commands modifying the -minTime/maxTime,
    the -animationStartTime/animationEndTime,
    the -selectionStartTime/selectionEndTime/selectionVisible
    or the -by value are undoable.
    Args:
        animationEndTime (Queryable[int]?): Sets the end time of the animation.  Query returns a float.  
                Properties: create, query, edit
        animationStartTime (Queryable[int]?): Sets the start time of the animation.  Query returns a float.  
                Properties: create, query, edit
        blockingAnim (bool?): All tangents playback as stepped so that animation can be viewed in pure pose-to-pose form  
                Properties: create, query
        by (Queryable[float]?): Increment between times viewed during playback. (Default 1.0)  
                Properties: create, query, edit
        framesPerSecond (bool?): Queries the actual playback rate.  Query returns a float.  
                Properties: create, query
        loop (Queryable[str]?): Controls if and how playback repeats.  Valid values are  
                "once," "continuous," and "oscillate."  Query returns string.  
                Properties: create, query, edit
        maxPlaybackSpeed (Queryable[float]?): Sets the desired maximum playback speed.  Query returns a float. The  
                maxPlaybackSpeed is only used by Maya when your playbackSpeed is 0  
                (play every frame). The maxPlaybackSpeed will clamp the maximum  
                playback rate to prevent it from going more than a certain amount. A  
                maxPlaybackSpeed of 0 will give free (unclamped) playback.  
                Properties: create, query, edit
        maxTime (Queryable[int]?): Sets the end of the playback time range.  Query returns a float.  
                Properties: create, query, edit
        minTime (Queryable[int]?): Sets the start of the playback time range.  Query returns a float.  
                Properties: create, query, edit
        playbackSpeed (Queryable[float]?): Sets the desired playback speed.  Query returns a float.  
                Properties: create, query, edit
        selectionEndTime (Queryable[int]?): Sets the end time of the selection.  Query returns a float.  
                Properties: create, query, edit
        selectionStartTime (Queryable[int]?): Sets the start time of the selection.  Query returns a float.  
                Properties: create, query, edit
        selectionVisible (bool?): Sets the selection visibility. Query returns current visibility.  
                Properties: create, query, edit
        stepLoop (bool?): Turns on/off looping back to the start or end of the play range for step forward/backward one frame and step forward/backward one key.  
                Properties: create, query
        view (Queryable[str]?): Controls how many modelling views update during playback.  
                Valid values are "all" and "active".  Query returns a string.  
                Properties: create, query, edit

    Returns:
        str: or float
            Query of edited option.

    Example:
    """

def playblast(*, activeEditor: bool = ..., cameraSetup: Multiuse[Tuple[str, str]] = ..., clearCache: bool = ..., codecOptions: bool = ..., combineSound: bool = ..., completeFilename: str = ..., compression: str = ..., editorPanelName: str = ..., endTime: int = ..., filename: str = ..., forceOverwrite: bool = ..., format: str = ..., frame: Multiuse[int] = ..., framePadding: int = ..., height: int = ..., indexFromZero: bool = ..., offScreen: bool = ..., offScreenViewportUpdate: bool = ..., options: bool = ..., percent: int = ..., quality: int = ..., rawFrameNumbers: bool = ..., replaceAudioOnly: bool = ..., replaceEndTime: int = ..., replaceFilename: str = ..., replaceStartTime: int = ..., sequenceTime: bool = ..., showOrnaments: bool = ..., sound: str = ..., startTime: int = ..., throwOnError: bool = ..., useTraxSounds: bool = ..., viewer: bool = ..., width: int = ..., widthHeight: Tuple[int, int] = ...) -> str:
    """This command playblasts the current playback range.
    Sound is optional.Note that the playblast command registers a condition called "playblasting"
    so that users can monitor whether playblasting is occurring. You may monitor the
    condition using the API (MConditionMessage) or a script (scriptJob and condition
    commands).
    Args:
        activeEditor (bool?): This flag will return the current model editor that would be used  
                for playblast. It does not invoke playblast itself.  
                Properties: create
        cameraSetup (Multiuse[Tuple[str, str]]?): Information about camera setup. The first string defines a camera setup MEL procedure.  
                The camera setup procedure will be invoked before executing a playblast.  
                The second string argument which is used as a camera identifier and is  
                appended to the root file name to specify the final output file name(s).  
                The command will fail there is not a pair of strings supplied to the argument.  
                Properties: create, multiuse
        clearCache (bool?): When true, all previous temporary playblast files will be deleted  
                before the new playblast files are created and the remaining temporary  
                playblast files will be deleted when the application quits.  
                Any playblast files that were explicitly given a name by the user will not be deleted.  
                Properties: create
        codecOptions (bool?): Brings up the OS specific dialog for setting playblast codec options, and  
                does not run the playblast.  
                Properties: create
        combineSound (bool?): Combine the trax sounds into a single track. This might force a  
                resampling of the sound if the sound paramters don't match up.  
                Properties: create
        completeFilename (str?): When set, this string specifies the exact name of the output image.  
                In contrast with the -f/filename flag, -cf/completeFilename does not  
                append any frame number or extension string at the end of the filename.  
                Additionally, playblast will not delete the image from disk after it is  
                displayed. This flag should not be used in conjunction with -f/filename.  
                Properties: create
        compression (str?): Specify the compression to use for the movie file.  To determine which settings are available on your system, use the  
                `playblast -options` command. This will display a system-specific dialog with supported compression formats.  
                When the 'format' flag is 'image', this flag is used to pass in the  
                desired image format. If the format is 'image' and the compression flag is ommitted,  
                the output format specified via the Render Globals preference (see -format) will be used.  
                If compression is set to 'none', the iff image format will be used.  
                Properties: create
        editorPanelName (str?): This optional flag specifies the name of the model editor or panel, which is to  
                be used for playblast. The current model editor or panel won't be used for  
                playblast unless its name is specified. Flag usage is specific to invoking  
                playblast.  
                Properties: create
        endTime (int?): Specify the end time of the playblast.  Default  
                is the end time of the playback range displayed in  
                the Time Slider. Overridden by -frame.  
                Properties: create
        filename (str?): The filename to use for the output of this playblast.  
                If the file already exists, a confirmation box will be  
                displayed if playblast is performed interactively.  If  
                playblast is executed from the command line and the file  
                already exists, it will abort.  
                Properties: create
        forceOverwrite (bool?): Overwrite existing playblast files which may have the  
                the same name as the one specified with the "-f" flag  
                Properties: create
        format (str?): The format for the playblast output.  
              
              
              
                ValueDescription  
              
              
                "movie"  
                This option selects a platform-specific default movie format.  
                On Linux and Mac OSX the default movie format is Quicktime.  
                On Windows the default movie format is Audio Video Interleave.  
              
              
              
                "avi"  
                Set the format to Audio Video Interleave (Windows only)  
              
              
                "qt"  
                Set the format to QuickTime (all platforms).  
              
              
                "avfoundation"  
                Write movie by AVFoundation (Mac only).  
              
              
                "image"  
                Outputs a sequence of image files.  
                The image format will be the Output Format specified using Window > RenderEditors > RenderSettings > CommonTab.  
                The resulting files use the value of the "-f" flag as a prefix, with an  
                appended frame number, as in "myFile.0007.iff"  
              
              
                "iff"  
                Same as "image"  
              
              
              
                The default value of the -fmt/format flag is "movie".  
                Depending on the selected format, a platform-specific default application will be used to view results.  
                For image sequences, the default application is "fcheck".  
                For movies, the default application is Windows Media Player (on Windows),  
                Quicktime Player (on Mac OSX), and Lqtplay (on Linux).  
                Users can specify different applications via Maya's application preferences.  
                Properties: create
        frame (Multiuse[int]?): List of frames to blast. One frame specified per flag.  
                The frames can be specified in any order but will be output  
                in an ordered sequence. When specified this flag will override any  
                start/end range  
                Properties: create, multiuse
        framePadding (int?): Number of zeros used to pad file name. Typically set to 4 to support fcheck.  
                Properties: create
        height (int?): Height of the final image. This value will be clamped if larger  
                than the width of the active window.  
                Windows: If not using fcheck, the width and height must each be divisible  
                by 4.  
                Properties: create
        indexFromZero (bool?): Output frames starting with file.0000.ext and incrementing by one. Typically  
                frames use the Maya time as their frame number. This option can only be used  
                for frame based output formats.  
                Properties: create
        offScreen (bool?): When set, this toggle allow playblast to use an offscreen buffer  
                to render the view. This allows playblast to work when the application  
                is iconified, or obscured.  
                Properties: create
        offScreenViewportUpdate (bool?): When set, this toggle allows playblast to update the viewport  
                while rendering with the offscreen buffer.  
                Properties: create
        options (bool?): Brings up a dialog for setting playblast options, and  
                does not run the playblast.  
                Properties: create
        percent (int?): Percentage of current view size  to use during blasting.  
                Accepted values are integers between 10 and 100.  All other  
                values are clamped to be within this range.  A value of 25  
                means 1/4 of the  current view size; a  value of 50  means  
                half the current view size; a value of 100 means full  
                size.  (Default is 50.)  
                Properties: create
        quality (int?): Specify the compression quality factor to use for the movie file.  
                Value should be in the 0. 100 range  
                Properties: create
        rawFrameNumbers (bool?): Playblast typically numbers its frames sequentially, starting at zero.  
                This flag will override the default action and frames will be numbered using the  
                actual frames specified by the -frame or -startFrame/-endFrame flags.  
                Properties: create
        replaceAudioOnly (bool?): When set, this string dictates that only the audio will be replaced when  
                the scene is re-playblasted.  
                Properties: create
        replaceEndTime (int?): Specify the end time of a replayblast of an existing  
                playblast.  Default is the start time of the playback  
                range displayed in the Time Slider. Overridden by -frame.  
                Properties: create
        replaceFilename (str?): When set, this string specifies the name of an input playblast file which  
                will have frames replaced according to the replace start and end times.  
                Properties: create
        replaceStartTime (int?): Specify the start time of a replayblast of an existing  
                playblast.  Default is the start time of the playback  
                range displayed in the Time Slider. Overridden by -frame.  
                Properties: create
        sequenceTime (bool?): Use sequence time  
                Properties: create
        showOrnaments (bool?): Sets whether or not model view ornaments (e.g. the axis icon)  
                should be displayed  
                Properties: create
        sound (str?): Specify the sound node to be used during playblast  
                Properties: create
        startTime (int?): Specify the start time of the playblast.  Default  
                is the start time of the playback range displayed in  
                the Time Slider. Overridden by -frame.  
                Properties: create
        throwOnError (bool?): Playblast is tolerant of failures in most situations. When set,  
                this toggle allows playblast to throw an error on these failures.  
                Properties: create
        useTraxSounds (bool?): Use sounds from TRAX.  
                Properties: create
        viewer (bool?): Specify whether a viewer should be launched for the  
                playblast.  Default is "true".  Runs "fcheck" when -fmt is "image".  
                The player for movie files depends on the OS: Windows uses Microsoft Media  
                Player, Irix uses movieplayer, OSX uses QuickTime.  
                Properties: create
        width (int?): Width of the final image. This value will be clamped if larger than  
                the width of the active window.  
                Windows: If not using fcheck, the width and height must each be divisible  
                by 4.  
                Properties: create
        widthHeight (Tuple[int, int]?): Final image's width and height.  
                Values larger than the dimensions of the active window are clamped.  
                A width and height of 0 means to use the window's current  
                size.  
                Windows: If not using fcheck, the width and height must each be divisible  
                by 4.  
                Properties: create

    Returns:
        str: Name of moviefile created.

    Example:
    """

def pluginDisplayFilter(arg0: str = ..., /, *, query: bool = ..., classification: Queryable[str] = ..., deregister: bool = ..., exists: bool = ..., label: Queryable[str] = ..., listFilters: bool = ..., register: bool = ...) -> Union[str, bool]:
    """Register, deregister or query a plugin display filter.
    Plug-ins can use this command to register their own display filters which
    will appear in the 'Show' menus on Maya's model panels.displayfilter, modeleditor, modelpanel
    Args:
        classification (Queryable[str]?): The classification used to filter objects in Viewport 2.0.  
                This classification is the same as MFnPlugin::registerNode().  
                If the node was registered with multiple classifications, use the one beginning with "drawdb".  
                The default value of this flag is an empty string (""). It will not  
                filter any objects in Viewport 2.0.  
                Properties: create, query
        deregister (bool?): Deregister a plugin display filter.  
                Properties: create
        exists (bool?): Returns true if the specified filter exists, false otherwise.  
                Other flags are ignored.  
                Properties: create
        label (Queryable[str]?): The string to be displayed for this filter in the UI. E.g. in the 'Show' menu of a model panel.  
                The default value of this flag is the same as the plugin display filter name.  
                Properties: create, query
        listFilters (bool?): Returns an array of all plugin display filters.  
                Properties: query
        register (bool?): Register a plugin display filter.  
                The -register is implied if both -register and -deregister flags are missing in create mode.  
                You are responsible for deregistering any filters which you register.  
                Filters are reference counted, meaning that if you register the same filter twice  
                then you will have to deregister it twice as well.  
                Properties: create

    Returns:
        str: string[]

    Example:
    """

def pluginInfo(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeFile: bool = ..., allEvaluators: bool = ..., animCurveInterp: Queryable[str] = ..., apiVersion: bool = ..., autoload: bool = ..., cacheFormat: bool = ..., changedCommand: Callable[..., Any] = ..., command: Queryable[Multiuse[str]] = ..., constraintCommand: bool = ..., controlCommand: bool = ..., data: Queryable[Multiuse[Tuple[str, str]]] = ..., dependNode: Queryable[Multiuse[bool]] = ..., dependNodeByType: Queryable[str] = ..., dependNodeId: Queryable[str] = ..., device: bool = ..., dragAndDropBehavior: bool = ..., evaluator: bool = ..., iksolver: bool = ..., listPlugins: bool = ..., listPluginsPath: bool = ..., loadPluginPrefs: bool = ..., loaded: bool = ..., modelEditorCommand: bool = ..., name: Queryable[str] = ..., path: Queryable[str] = ..., pluginsInUse: bool = ..., referenceTranslators: bool = ..., registered: bool = ..., remove: bool = ..., renderer: bool = ..., savePluginPrefs: bool = ..., serviceDescriptions: bool = ..., settings: bool = ..., tool: Queryable[Multiuse[str]] = ..., translator: bool = ..., unloadOk: bool = ..., userNamed: bool = ..., vendor: Queryable[str] = ..., version: bool = ..., writeRequires: bool = ...) -> Union[Any, bool, str, Multiuse[str], Multiuse[Tuple[str, str]], Multiuse[bool]]:
    """This command provides access to the plug-in registry of the
    application. It is used mainly to query the characteristics of
    registered plug-ins. Plugins automatically become registered the first
    time that they are loaded.The argument is either the internal name of the plug-in or the path to
    access it.
    Args:
        activeFile (bool?): Restricts the command to the active file only, not the entire scene.  
                This only affects the dependNode/dn and pluginsInUse/pu flags.  
                For use during export selected.  
                Properties: query
        allEvaluators (bool?): Returns a string array containing the names of all of the  
                evaluator types registered to any plug-in.  
                Properties: query
        animCurveInterp (Queryable[str]?): Returns a string array containing the names of all of the  
                animation curve interpolators registered by this plug-in.  
                Properties: query
        apiVersion (bool?): Returns a string containing the version of the API that this  
                plug-in was compiled with.  See the comments in MTypes.h for the  
                details on how to interpret this value.  
                Properties: query
        autoload (bool?): Sets whether or not this plug-in should be loaded every  
                time the application starts up. Returns a boolean in query mode.  
                Properties: create, query, edit
        cacheFormat (bool?): Returns a string array containing the names of all of the  
                registered geometry cache formats  
                Properties: query
        changedCommand (Callable[..., Any]?): Adds a callback that will get executed every time the plug-in  
                registry changes. Any other previously registered callbacks will  
                also get called.  
                Properties: create
        command (Queryable[Multiuse[str]]?): Returns a string array containing the names of all of the  
                normal commands registered by this plug-in.  
                Constraint, control, context and model editor commands are not included.  
                Properties: query, multiuse
        constraintCommand (bool?): Returns a string array containing the names of all of the  
                constraint commands registered by this plug-in.  
                Properties: query
        controlCommand (bool?): Returns a string array containing the names of all of the  
                control commands registered by this plug-in.  
                Properties: query
        data (Queryable[Multiuse[Tuple[str, str]]]?): Returns a string array containing the names of all of the  
                data types registered by this plug-in.  
                Properties: query, multiuse
        dependNode (Queryable[Multiuse[bool]]?): Returns a string array containing the names of all of the  
                custom nodes types registered by this plug-in.  
                Properties: query, multiuse
        dependNodeByType (Queryable[str]?): Returns a string array of all registered node types within a specified  
                class of nodes.  Each custom node type registered by a plug-in belongs  
                to a more general class of node types as specified by its  
                MPxNode::Type. The flag's argument is an MPxNode::Type as a string.  For  
                example, if you want to list all registered Locator nodes, you should  
                specify kLocatorNode as a argument to this flag.  
                Properties: query
        dependNodeId (Queryable[str]?): Returns an integer array containing the ids of all of the  
                custom node types registered by this plug-in.  
                Properties: query
        device (bool?): Returns a string array containing the names of all of the  
                devices registered by this plug-in.  
                Properties: query
        dragAndDropBehavior (bool?): Returns a string array containing the names of all of the  
                drag and drop behaviors registered by this plug-in.  
                Properties: query
        evaluator (bool?): Returns a string array containing the names of all of the  
                evaluator types registered by this plug-in.  
                Properties: query
        iksolver (bool?): Returns a string array containing the names of all of the  
                ik solvers registered by this plug-in.  
                Properties: query
        listPlugins (bool?): Returns a string array containing all the plug-ins that are  
                currently loaded.  
                Properties: query
        listPluginsPath (bool?): Returns a string array containing the full paths of all the plug-ins that are  
                currently loaded.  
                Properties: query
        loadPluginPrefs (bool?): Loads the plug-in preferences (ie. autoload) from pluginPrefs.mel into Maya.  
                Properties: create
        loaded (bool?): Returns a boolean specifying whether or not the plug-in is loaded.  
                Properties: query
        modelEditorCommand (bool?): Returns a string array containing the names of all of the  
                model editor commands registered by this plug-in.  
                Properties: query
        name (Queryable[str]?): Returns a string containing the internal name by which the  
                plug-in is registered.  
                Properties: query
        path (Queryable[str]?): Returns a string containing the absolute path name to the plug-in.  
                Properties: query
        pluginsInUse (bool?): Returns a string array containing all the plug-ins that are  
                currently being used in the scene.  
                Properties: query
        referenceTranslators (bool?): If this flag is used in conjunction with the pluginsInUse/pu flag  
                then it will modify the output. When true it will only show plug-ins currently in use  
                containing translators that are used to load referenced files. When false it  
                will only show plug-ins not containing such translators.  
                Properties: query
        registered (bool?): Returns a boolean specifying whether or not plug-in is currently  
                registered with the system.  
                Properties: query
        remove (bool?): Removes the given plug-in's record from the registry.  
                There is no return value.  
                Properties: edit
        renderer (bool?): Returns a string array containing the names of all of the  
                renderers registered by this plug-in.  
                Properties: query
        savePluginPrefs (bool?): Saves the plug-in preferences (ie. autoload) out to pluginPrefs.mel  
                Properties: create
        serviceDescriptions (bool?): If there are services in use, then this flag will return a string  
                array containing short descriptions saying what those services are.  
                Properties: query
        settings (bool?): Returns an array of values with the loaded, autoload, registered flags  
                Properties: query
        tool (Queryable[Multiuse[str]]?): Returns a string array containing the names of all of the  
                tool contexts registered by this plug-in.  
                Properties: query, multiuse
        translator (bool?): Returns a string array containing the names of all of the  
                file translators registered by this plug-in.  
                Properties: query
        unloadOk (bool?): Returns a boolean that specifies whether or not the plug-in can  
                be safely unloaded.  It will return false if the plug-in is currently  
                in use.  For example, if the plug-in adds a new dependency node type,  
                and an instance of that node type is present in the scene, then this  
                query will return false.  
                Properties: query
        userNamed (bool?): Returns a boolean specifying whether or not the plug-in has  
                been assigned a name by the user.  
                Properties: query
        vendor (Queryable[str]?): Returns a string containing the vendor of the plug-in.  
                Properties: query
        version (bool?): Returns a string containing the version the plug-in.  
                Properties: query
        writeRequires (bool?): Sets whether or not this plug-in should write "requires" command  
                into the saved file. "requires" command could autoload  
                the plug-in when you open or import that saved file.  
                This way, Maya will load the plug-in  
                when a file is being loaded for some specified reason,  
                such as to create a customized UI or to load some plug-in data  
                that is not saved in any node or attributes.  
                For example, "stereoCamera" is using this flag for its customized UI.  
                Properties: create, query, edit

    Returns:
        Any: Dependent upon the action requested.

    Example:
    """

def pointConstraint(*args: str, edit: bool = ..., query: bool = ..., layer: str = ..., maintainOffset: bool = ..., name: Queryable[str] = ..., offset: Queryable[Tuple[float, float, float]] = ..., remove: bool = ..., skip: Multiuse[str] = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[List[str], str, Tuple[float, float, float], bool, float]:
    """Constrain an object's position to the position of the target object or
    to the average position of a number of targets.A pointConstraint takes as input one or more "target" DAG transform
    nodes at which to position the single "constraint object" DAG
    transform node.  The pointConstraint positions the constrained object
    at the weighted average of the world space position target
    objects.
    Args:
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        maintainOffset (bool?): The offset necessary to preserve the constrained  
                object's initial position will be calculated and used as the  
                offset.  
                Properties: create
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        offset (Queryable[Tuple[float, float, float]]?): Sets or queries the value of the offset. Default is 0,0,0.  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        skip (Multiuse[str]?): Specify the axis to be skipped. Valid values are "x", "y", "z" and "none". During creation, "none" is the default. This flag is multi-use.  
                Properties: create, edit, multiuse
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def pointCurveConstraint(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., pointConstraintUVW: Queryable[Tuple[float, float, float]] = ..., pointWeight: Queryable[float] = ..., position: Tuple[float, float, float] = ..., weight: float = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, Tuple[float, float, float], float]:
    """The command enables direct manipulation of a NURBS curve. It does so
    by apply a position constraint at the specified parameter location on
    the NURBS curve.If construction history for the cmd is enabled, a locator is created
    to enable subsequent interactive manipulation of the curve. The
    locator position may be key framed or transformed and the "curve1"
    will try to match the position of the locator.The argument is a curve location
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pointConstraintUVW (Queryable[Tuple[float, float, float]]?): Point constraint parameter space location on input NURBS Object  
                Properties: create, query, edit
        pointWeight (Queryable[float]?): Point constraint weight. Determines how strong an influence the constraint has on the input NURBS object.  
                Default: 1.0  
                Properties: create, query, edit
        position (Tuple[float, float, float]?): The new desired position in space for the nurbs object  
                at the specified parameter space component. If not specified,  
                the position is taken to be the one evaluated at the parameter  
                space component on the nurbs object.  
                Properties: create
        weight (float?): weight of the lsq constraint. The larger the weight,  
                the least squares constraint is strictly met.  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object Name(s), node name.

    Example:
    """

def pointLight(*args: str, edit: bool = ..., query: bool = ..., decayRate: Queryable[int] = ..., discRadius: Queryable[float] = ..., exclusive: bool = ..., intensity: Queryable[float] = ..., name: Queryable[str] = ..., position: Queryable[Tuple[float, float, float]] = ..., rgb: Queryable[Tuple[float, float, float]] = ..., rotation: Queryable[Tuple[float, float, float]] = ..., shadowColor: Queryable[Tuple[float, float, float]] = ..., shadowDither: Queryable[float] = ..., shadowSamples: Queryable[int] = ..., softShadow: bool = ..., useRayTraceShadows: bool = ...) -> Union[str, int, float, bool, Tuple[float, float, float]]:
    """The pointLight command is used to edit the parameters of
    existing pointLights, or to create new ones. The default
    behaviour is to create a new pointlight.
    Args:
        decayRate (Queryable[int]?): decay rate of the light (0. no decay, 1. slow, 2. realistic, 3. fast)  
                Properties: create, query, edit
        discRadius (Queryable[float]?): radius of the disc around the light  
                Properties: create, query, edit
        exclusive (bool?): This flag is obsolete.  
                Properties: create, query, edit
        intensity (Queryable[float]?): intensity of the light (expressed as a percentage)  
                Properties: create, query, edit
        name (Queryable[str]?): specify the name of the light  
                Properties: create, query, edit
        position (Queryable[Tuple[float, float, float]]?): This flag is obsolete.  
                Properties: create, query, edit
        rgb (Queryable[Tuple[float, float, float]]?): color of the light (0. 1)  
                Properties: create, query, edit
        rotation (Queryable[Tuple[float, float, float]]?): This flag is obsolete.  
                Properties: create, query, edit
        shadowColor (Queryable[Tuple[float, float, float]]?): the shadow color  
                Properties: create, query, edit
        shadowDither (Queryable[float]?): dither the shadow  
                Properties: create, query, edit
        shadowSamples (Queryable[int]?): number of shadow samples.  
                Properties: create, query, edit
        softShadow (bool?): soft shadow  
                Properties: create, query, edit
        useRayTraceShadows (bool?): ray trace shadows  
                Properties: create, query, edit

    Returns:
        str: Light shape name

    Example:
    """

def pointOnCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., curvatureCenter: bool = ..., curvatureRadius: bool = ..., nodeState: Queryable[int] = ..., normal: bool = ..., normalizedNormal: bool = ..., normalizedTangent: bool = ..., parameter: Queryable[float] = ..., position: bool = ..., tangent: bool = ..., turnOnPercentage: bool = ...) -> Union[Tuple[float, float, float], float, str, bool, int]:
    """This command returns information for a point on a NURBS curve.
    If no flag is specified, it assumes p/position by default.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curvatureCenter (bool?): Returns the (x,y,z) center of curvature of the specified point  
                on the curve  
                Properties: create
        curvatureRadius (bool?): Returns the radius of curvature of the specified point  
                on the curve  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normal (bool?): Returns the (x,y,z) normal of the specified point on the curve  
                Properties: create
        normalizedNormal (bool?): Returns the (x,y,z) normalized normal of the specified point  
                on the curve  
                Properties: create
        normalizedTangent (bool?): Returns the (x,y,z) normalized tangent of the specified point  
                on the curve  
                Properties: create
        parameter (Queryable[float]?): The parameter value on curve  
                Default: 0.0  
                Properties: query, edit
        position (bool?): Returns the (x,y,z) position of the specified point on the curve  
                Properties: create
        tangent (bool?): Returns the (x,y,z) tangent of the specified point on the curve  
                Properties: create
        turnOnPercentage (bool?): Whether the parameter is normalized (0,1) or not  
                Default: false  
                Properties: query, edit

    Returns:
        Tuple[float, float, float]: Vector query result
        float: Single float query result
        str: String query result

    Example:
    """

def pointOnPolyConstraint(*args: str, edit: bool = ..., query: bool = ..., layer: str = ..., maintainOffset: bool = ..., name: Queryable[str] = ..., offset: Queryable[Tuple[float, float, float]] = ..., remove: bool = ..., skip: Multiuse[str] = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[List[str], str, Tuple[float, float, float], bool, float]:
    """Constrain an object's position to the position of the target object or
    to the average position of a number of targets.A pointOnPolyConstraint takes as input one or more "target" DAG transform
    nodes at which to position the single "constraint object" DAG
    transform node.  The pointOnPolyConstraint positions the constrained object
    at the weighted average of the world space position target
    objects.
    Args:
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        maintainOffset (bool?): The offset necessary to preserve the constrained  
                object's initial position will be calculated and used as the  
                offset.  
                Properties: create
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        offset (Queryable[Tuple[float, float, float]]?): Sets or queries the value of the offset. Default is 0,0,0.  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        skip (Multiuse[str]?): Specify the axis to be skipped. Valid values are "x", "y", "z" and "none". During creation, "none" is the default. This flag is multi-use.  
                Properties: create, edit, multiuse
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def pointOnSurface(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., nodeState: Queryable[int] = ..., normal: bool = ..., normalizedNormal: bool = ..., normalizedTangentU: bool = ..., normalizedTangentV: bool = ..., parameterU: Queryable[float] = ..., parameterV: Queryable[float] = ..., position: bool = ..., tangentU: bool = ..., tangentV: bool = ..., turnOnPercentage: bool = ...) -> Union[Tuple[float, float, float], str, bool, int, float]:
    """This command returns information for a point on a surface.
    If no flag is specified, this command assumes p/position by default.
    If more than one flag is specifed, then a string array is returned.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normal (bool?): Returns the (x,y,z) normal of the specified point on the surface  
                Properties: create, query, edit
        normalizedNormal (bool?): Returns the (x,y,z) normalized normal of the specified point  
                on the surface  
                Properties: create, query, edit
        normalizedTangentU (bool?): Returns the (x,y,z) normalized U tangent of the specified point  
                on the surface  
                Properties: create, query, edit
        normalizedTangentV (bool?): Returns the (x,y,z) normalized V tangent of the specified point  
                on the surface  
                Properties: create, query, edit
        parameterU (Queryable[float]?): The U parameter value on surface  
                Default: 0.0  
                Properties: query, edit
        parameterV (Queryable[float]?): The V parameter value on surface  
                Default: 0.0  
                Properties: query, edit
        position (bool?): Returns the (x,y,z) positon of the specified point on the surface  
                Properties: create, query, edit
        tangentU (bool?): Returns the (x,y,z) U tangent of the specified point on the surface  
                Properties: create, query, edit
        tangentV (bool?): Returns the (x,y,z) V tangent of the specified point on the surface  
                Properties: create, query, edit
        turnOnPercentage (bool?): Whether the parameter is normalized (0,1) or not  
                Default: false  
                Properties: query, edit

    Returns:
        Tuple[float, float, float]: Vector query result
        str: String query result

    Example:
    """

def pointPosition(arg0: str = ..., /, *, local: bool = ..., world: bool = ...) -> List[float]:
    """This command returns the world or local space position for any type of
    point object. Valid selection items are:
    - curve and surface CVs
    - poly vertices
    - lattice points
    - particles
    - curve and surface edit points
    - curve and surface parameter points
    - poly uvs
    - rotate/scale/joint pivots
    - selection handles
    - locators, param locators and arc length locatorsIt works on the selected object or you can specify the object in
    the command. By default, if no flag is specified then the world
    position is returned.
    Args:
        local (bool?): Return the point in local space coordinates.  
                Properties: create
        world (bool?): Return the point in world space coordinates.  
                Properties: create

    Returns:
        List[float]: Command result

    Example:
    """

def poleVectorConstraint(*args: str, edit: bool = ..., query: bool = ..., layer: str = ..., name: Queryable[str] = ..., remove: bool = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[List[str], str, bool, float]:
    """Constrains the poleVector of an ikRPsolve handle to point at a
    target object or at the average position of a number of targets.An poleVectorConstraint takes as input one or more "target" DAG
    transform nodes at which to aim pole vector for an IK handle using
    the rotate plane solver.  The pole vector is adjust such that
    the in weighted average of the world space position target
    objects lies is the "rotate plane" of the handle.
    Args:
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        List[str]: name of the created constraint node

    Example:
    """

def polyAppend(*args: str, edit: bool = ..., query: bool = ..., append: Multiuse[Union[Tuple[()], Tuple[float, float, float]]] = ..., constructionHistory: bool = ..., edge: Multiuse[int] = ..., hole: Multiuse[bool] = ..., name: str = ..., point: Multiuse[Tuple[float, float, float]] = ..., subdivision: Queryable[int] = ..., texture: Queryable[int] = ...) -> Union[str, bool, int]:
    """Appends a new face to the selected polygonal object.
    The first argument must be a border edge.
    The new face will be automatically closed.Only works with one object selected.
    Args:
        append (Multiuse[Union[Tuple[()], Tuple[float, float, float]]]?): Appends to the given polygon object.  The append flag should be used  
                multiple times to specify the edges, points, and holes that make up the new  
                face that is being added.  
              
                You may specify an edge by passing a single argument which will be the edges  
                index.  A point is specified with three arguments which are the coordinates  
                of the point in the objects local space.  Pass no arguments indicates that  
                the values which follow shall specify a hole.  In Python, pass an empty  
                tuple to specify no arguments.  
                Properties: create, multiuse
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        edge (Multiuse[int]?): Adds the given edge of the selected object to the new face.  
                This edge must be a border, which will be then shared by the  
                new face and the neighboring one. The new face is oriented according  
                to the orientation of the given edge(s).  
              
                Note that this flag should be avoided in Python.  You may use the "append"  
                flag instead and pass one argument.  
                Properties: create, multiuse
        hole (Multiuse[bool]?): Add a hole. The following points and edges will define a hole.  
              
                Note that this flag should be avoided in Python.  You may use the "append"  
                flag instead and pass an empty tuple ().  
                Properties: create, multiuse
        name (str?): Give a name to the resulting node.  
                Properties: create
        point (Multiuse[Tuple[float, float, float]]?): Adds a new point to the new face.  
                Coordinates of free points are given in the local object reference.  
              
                Note that this flag should be avoided in Python.  You may use the "append"  
                flag instead and pass three arguments.  
                Properties: create, multiuse
        subdivision (Queryable[int]?): This flag specifies the level of subdivisions.  
                Automatically subdivides new edges into the given number of edges.  
                Existing edges cannot be subdivided.  
                C : Default is 1 (no subdivision).  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (Queryable[int]?): Specifies how new faces are mapped.  
                 0. None; 1. Normalize; 2. Unitize  
                C: Default is 0 (no mapping).  
                Q: When queried, this flag returns an int  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyAppendFacetCtx(*args: Any, edit: bool = ..., query: bool = ..., append: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., isRotateAvailable: bool = ..., maximumNumberOfPoints: Queryable[int] = ..., planarConstraint: bool = ..., rotate: Queryable[float] = ..., subdivision: Queryable[int] = ..., texture: Queryable[int] = ...) -> Union[bool, str, int, float]:
    """Create a new context to append facets on polygonal objects
    Args:
        append (bool?): Allows to switch to polyCreateFacetCtx tool  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        isRotateAvailable (bool?): Tells if the control associated to rotate flag is available.  
                If several edges are already selected and they are not aligned  
                (thus there is no "rotation axis") the rotation is no longer available.  
                Properties: query
        maximumNumberOfPoints (Queryable[int]?): Allows the ability to set a upper bound on the number of  
                points in interactively place before polygon is  
                created. A value less than 2 will mean that there is no  
                upper bound.  
                Properties: create, query, edit
        planarConstraint (bool?): Allows/avoid new facet to be non-planar.  
                If on, all new points will be projected onto  
                current facet plane. Selected edges will be checked as well.  
                Properties: create, query, edit
        rotate (Queryable[float]?): Rotate current facet around the first edge selected.  
                Properties: create, query, edit
        subdivision (Queryable[int]?): Number of sub-edges created for each new edge. Default is 1.  
                Properties: create, query, edit
        texture (Queryable[int]?): Number of textures. Default is 1.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyAppendVertex(*args: str, edit: bool = ..., query: bool = ..., append: Multiuse[Union[Tuple[()], Tuple[float, float, float]]] = ..., constructionHistory: bool = ..., hole: Multiuse[bool] = ..., name: str = ..., point: Multiuse[Tuple[float, float, float]] = ..., texture: Queryable[int] = ..., vertex: Multiuse[int] = ...) -> Union[str, bool, int]:
    """Appends a new face to the selected polygonal object. The direction
    of the normal is given by the vertex order: the face normal points
    towards the user when the vertices rotate counter clockwise. Note
    that holes must be described in the opposite direction.Only works with one object selected.
    Args:
        append (Multiuse[Union[Tuple[()], Tuple[float, float, float]]]?): Append a vertex or a point to the selected object, or mark the start of a  
                hole.  
              
                This flag may also be used in place of the "hole", "vertex" and "point" flags.  
                If no argument is passed to the "append" flag, then it marks the beginning of a  
                hole (use an empty tuple in Python '()').  If one argument is passed, then the  
                argument is considered to be an index into the vertices of the selected  
                object, as with the "vertex" flag.  If three arguments are passed, then it is  
                interpreted as the coordinates of a new point which will be inserted, as with  
                the "point" flag.  
                Properties: create, multiuse
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        hole (Multiuse[bool]?): Add a hole. The following points and edges will define a hole.  
              
                Note that this flag should be avoided in Python.  You may use the "append"  
                flag instead and pass an empty tuple '()' to specify the start of a hole.  
                Properties: create, multiuse
        name (str?): Give a name to the resulting node.  
                Properties: create
        point (Multiuse[Tuple[float, float, float]]?): Adds a new point to the new face.  
                Coordinates of free points are given in the local object reference.  
              
                Note that this flag should be avoided in Python.  You may use the "append"  
                flag instead and pass three arguments.  
                Properties: create, multiuse
        texture (Queryable[int]?): Specifies how new faces are mapped.  
                0. None; 1. Normalize; 2. Unitize  
                C: Default is 0 (no mapping).  
                Q: When queried, this flag returns an int  
                Properties: create, query, edit
        vertex (Multiuse[int]?): Adds the given vertex of the selected object to the new face.  
              
                Note that this flag should be avoided in Python.  You may use the "append"  
                flag instead and pass one argument.  
                Properties: create, multiuse

    Returns:
        str: The node name.

    Example:
    """

def polyAutoProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., insertBeforeDeformers: bool = ..., layout: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., optimize: Queryable[int] = ..., percentageSpace: Queryable[float] = ..., planes: Queryable[int] = ..., projectBothDirections: bool = ..., scaleMode: Queryable[int] = ..., skipIntersect: bool = ..., uvSetName: str = ..., worldSpace: bool = ..., layoutMethod: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ...) -> Union[str, bool, int, float, Tuple[float, float, float]]:
    """Projects a map onto an object, using several orthogonal projections
    simultaneously.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): Set to true if a new map should be created  
                Properties: create
        insertBeforeDeformers (bool?): Set to true if the new node created should inserted before any deformer nodes.  
                Properties: create
        layout (Queryable[int]?): What layout algorithm should be used:  
                0 UV pieces are set to no layout.  
                1 UV pieces are aligned along the U axis.  
                2 UV pieces are moved in a square shape.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        optimize (Queryable[int]?): Use two different flavors for the cut generation.  
                0 Every face is assigned to the best plane. This optimizes the  
                map distortion.  
                1 Small UV pieces are incorporated into larger ones, when the  
                extra distortion introduced is reasonable. This tends to produce fewer  
                UV pieces.  
                Properties: create, query, edit
        percentageSpace (Queryable[float]?): When layout is set to square, this value is a percentage of  
                the texture area which is added around each UV piece. It can be  
                used to ensure each UV piece uses different pixels in the texture.  
                Maximum value is 5 percent.  
                Properties: create, query, edit
        planes (Queryable[int]?): Number of intermediate projections used. Valid numbers  
                are 4, 5, 6, 8, and 12.  
                C: Default is 6.  
                Properties: create, query, edit
        projectBothDirections (bool?): This flag specifies which reference to use.  
                If "on" : projections are mirrored on directly opposite faces.  
                If "off" : projections are not mirrored on opposite faces.  
                C: Default is "off".  
                Q: When queried, this flag returns an integer.  
                Properties: create, query, edit
        scaleMode (Queryable[int]?): How to scale the pieces, after projections:  
                0 No scale is applied.  
                1 Uniform scale to fit in unit square.  
                2 Non proportional scale to fit in unit square.  
                Properties: create, query, edit
        skipIntersect (bool?): When on, self intersection of UV pieces are not  
                tested. This makes the projection faster and produces fewer pieces,  
                but may lead to overlaps in UV space.  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        layoutMethod (Queryable[int]?): Set which layout method to use:  
                0 Block Stacking.  
                1 Shape Stacking.  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): This flag specifies the pivot for scaling and rotation.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        pivotX (Queryable[float]?): This flag specifies the X pivot for scaling and rotation.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): This flag specifies the Y pivot for scaling and rotation.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): This flag specifies the Z pivot for scaling and rotation.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): This flag specifies the rotation angles around X, Y, Z.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        rotateX (Queryable[float]?): This flag specifies the rotation angle around X.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): This flag specifies the rotation angle around Y.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): This flag specifies the rotation angle around Z.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): This flag specifies the scaling vector.  
                C: Default is 1.0 1.0 1.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        scaleX (Queryable[float]?): This flag specifies X for scaling vector.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): This flag specifies Y for scaling vector.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): This flag specifies Z for scaling vector.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): This flag specifies the translation vector.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        translateX (Queryable[float]?): This flag specifies the X translation vector.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        translateY (Queryable[float]?): This flag specifies the Y translation vector.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): This flag specifies the Z translation vector.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyAverageNormal(*args: str, allowZeroNormal: bool = ..., distance: float = ..., postnormalize: bool = ..., prenormalize: bool = ..., replaceNormalXYZ: Tuple[float, float, float] = ...) -> str:
    """Set normals of vertices or vertex-faces to an average value when the vertices
    within a given threshold.
    First, it sorts out the containing edges, and set them to be soft, if it is
    possible, so to let the normals appear to be "merged". The remained components
    then are sorted into lumps where vertices in each lump are within the given
    threshold. For all vertices and vertex-faces, set their normals to the average
    normal in the lump.
    Selected vertices may or may not on the same object.
    If objects are selected, it is assumed that all vertices are selected.
    If edges or faces are selected, it is assumed that the related vertex-faces
    are selected.poly, userNormals, polyNormals, averageNormal, setNormal, vertexNormal
    Args:
        allowZeroNormal (bool?): Specifies whether to allow zero normals to be created.  
                By default it is false. If it is false, replaceNormal is needed.  
                Properties: create
        distance (float?): Specifies the distance threshold. All vertices within  
                the threshold are considered when computing an average  
                normal. By default it is 0.0.  
                Properties: create
        postnormalize (bool?): Specifies whether to normalize the resulting normals.  
                By default it is true.  
                Properties: create
        prenormalize (bool?): Specifies whether to normalize the normals before averaging.  
                By default it is true.  
                Properties: create
        replaceNormalXYZ (Tuple[float, float, float]?): If the allowZeroNormal is false, this value is used to  
                replace the zero normals. By default it is (1, 0, 0).  
                Properties: create

    Returns:
        str: of the node name.

    Example:
    """

def polyAverageVertex(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., iterations: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """Moves the selected vertices of a polygonal object to round its shape.
    Translate, move, rotate or scale vertices.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        iterations (Queryable[int]?): Number of rounding steps.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyAxis(*args: str, edit: bool = ..., query: bool = ..., arrowType: Queryable[int] = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., frameType: Queryable[int] = ..., lengthX: Queryable[float] = ..., lengthY: Queryable[float] = ..., lengthZ: Queryable[float] = ..., materialTemplate: str = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., rightHanded: bool = ..., scale: Queryable[float] = ..., subdivisionsAxis: Queryable[int] = ...) -> Union[List[str], int, Tuple[float, float, float], bool, float]:
    """The polyAxis command creates a new polygonal shape representing a coordinate system.
    Args:
        arrowType (Queryable[int]?): This flag specifies the shape at the ends of the axis  
                The valid values are 0, 1 and 2.  
                0 means a flat end shape.  
                1 means a rounded end shape.  
                2 means a cone end shape.  
              
                C: Default is the cone end shape  
                Properties: create, query, edit
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the frame. This is the axis that will point up.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        frameType (Queryable[int]?): This flag allows a specific frame type to be created  
                The valid values are 0 and 1.  
                0 implies an axis shape will be created.  
                1 implies an wedge shape will be created.  
              
                C: Default is the axis shape  
                Properties: create, query, edit
        lengthX (Queryable[float]?): This flag specifies the length of the x-axis.  
                Properties: create, query, edit
        lengthY (Queryable[float]?): This flag specifies the length of the y-axis.  
                Properties: create, query, edit
        lengthZ (Queryable[float]?): This flag specifies the length of the z-axis.  
                Properties: create, query, edit
        materialTemplate (str?): Assign the specified material template to geoemtry. If it does  
                not exist one will be created with materials assigned to each  
                axis  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): This flag specifies the radius of the axis.  
                Properties: create, query, edit
        rightHanded (bool?): When this is set to true the result will be a shape representing a right handed coordinate system  
                Properties: create, query, edit
        scale (Queryable[float]?): This flag specifies the overall scale of the frame shape.  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): This specifies the number of subdivisions for the axis.  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyBevel(*args: str, edit: bool = ..., query: bool = ..., angleTolerance: Queryable[float] = ..., autoFit: bool = ..., caching: bool = ..., constructionHistory: bool = ..., mergeVertexTolerance: Queryable[float] = ..., mergeVertices: bool = ..., miteringAngle: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset: Queryable[float] = ..., offsetAsFraction: bool = ..., roundness: Queryable[float] = ..., segments: Queryable[int] = ..., smoothingAngle: Queryable[float] = ..., subdivideNgons: bool = ..., useLegacyBevelAlgorithm: bool = ..., uvAssignment: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, float, bool, int]:
    """Bevel edges.
    Args:
        angleTolerance (Queryable[float]?): Angular tolerance for creation of extra triangles  
                Note this attribute is for compatability only and should not be modified in Maya 7.0 files  
                Default: 20.0  
                Properties: create, query, edit
        autoFit (bool?): If autoFit is on, it computes a smooth roundness :  new facets round off a smooth angle.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        mergeVertexTolerance (Queryable[float]?): Tolerance within which to merge vertices  
                Default: 0.0  
                Properties: create, query, edit
        mergeVertices (bool?): Merge vertices within a tolerance  
                Default: false  
                Properties: create, query, edit
        miteringAngle (Queryable[float]?): Miter faces that have angles less than this value  
                Default: 0.0  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset (Queryable[float]?): The offset for bevel.  
                Default: 0.2  
                Properties: create, query, edit
        offsetAsFraction (bool?): If on, the offset value is treated as a fraction between zero and one.  
                Default: false  
                Properties: create, query, edit
        roundness (Queryable[float]?): The roundness of bevel, it is taken into account when autoFit is off.  
                Default: 0.5  
                Properties: create, query, edit
        segments (Queryable[int]?): The number of segments used for beveling.  
                Default: 1  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Create new edges as hard edges if the angle between adjacent faces exceeds this value  
                Default: 0.0  
                Properties: create, query, edit
        subdivideNgons (bool?): Subdivide new faces with more than 4 edges  
                Default: false  
                Properties: create, query, edit
        useLegacyBevelAlgorithm (bool?): If on, bevel is done the way maya 2014 did  
                Default: false  
                Properties: create, query, edit
        uvAssignment (Queryable[int]?): Technique used to compute UVs on new faces  
                0 computes new UVs by projecting along surface normal of original mesh onto new mesh  
                1 computes new UVs by projecting along surface normal of new mesh onto original mesh  
                Default: 0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyBevel3(*args: str, edit: bool = ..., query: bool = ..., angleTolerance: Queryable[float] = ..., autoFit: bool = ..., caching: bool = ..., chamfer: bool = ..., constructionHistory: bool = ..., depth: Queryable[float] = ..., fillNgons: bool = ..., mergeVertexTolerance: Queryable[float] = ..., mergeVertices: bool = ..., miterAlong: Queryable[int] = ..., mitering: Queryable[int] = ..., miteringAngle: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset: Queryable[float] = ..., offsetAsFraction: bool = ..., roundness: Queryable[float] = ..., segments: Queryable[int] = ..., smoothingAngle: Queryable[float] = ..., uvAssignment: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, float, bool, int]:
    """Bevel edges.
    Args:
        angleTolerance (Queryable[float]?): Angular tolerance for creation of extra triangles  
                Note this attribute is for compatability only and should not be modified in Maya 7.0 files  
                Default: 20.0  
                Properties: create, query, edit
        autoFit (bool?): If autoFit is on, it computes a smooth roundness :  new facets round off a smooth angle.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        chamfer (bool?): If chamfer is on, the surface is smoothed out at bevels. When it is off, the shape of the surface remains the same.  
                Default: true  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        depth (Queryable[float]?): The depth of bevel. One means a smooth surface, -1 means maximum depth.  
                Default: 1.0  
                Properties: create, query, edit
        fillNgons (bool?): Subdivide new faces with more than 4 edges  
                Default: false  
                Properties: create, query, edit
        mergeVertexTolerance (Queryable[float]?): Tolerance within which to merge vertices  
                Default: 0.0  
                Properties: create, query, edit
        mergeVertices (bool?): Merge vertices within a tolerance  
                Default: false  
                Properties: create, query, edit
        miterAlong (Queryable[int]?): Controls in which direction new vertices should we offseted.  
                Default: 0  
                Properties: create, query, edit
        mitering (Queryable[int]?): Controls how the topology should look like at corners.  
                Default: 0  
                Properties: create, query, edit
        miteringAngle (Queryable[float]?): Miter faces that have angles less than this value  
                Default: 0.0  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset (Queryable[float]?): The offset for bevel.  
                Default: 0.2  
                Properties: create, query, edit
        offsetAsFraction (bool?): If on, the offset value is treated as a fraction between zero and one.  
                Default: false  
                Properties: create, query, edit
        roundness (Queryable[float]?): The roundness of bevel, it is taken into account when autoFit is off.  
                Default: 0.5  
                Properties: create, query, edit
        segments (Queryable[int]?): The number of segments used for beveling.  
                Default: 1  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Create new edges as hard edges if the angle between adjacent faces exceeds this value  
                Default: 0.0  
                Properties: create, query, edit
        uvAssignment (Queryable[int]?): Technique used to compute UVs on new faces  
                0 computes new UVs by projecting along surface normal of original mesh onto new mesh  
                1 computes new UVs by projecting along surface normal of new mesh onto original mesh  
                Default: 0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyBlendColor(*args: str, edit: bool = ..., query: bool = ..., baseColorName: Queryable[str] = ..., blendFunc: Queryable[int] = ..., blendWeightA: Queryable[float] = ..., blendWeightB: Queryable[float] = ..., blendWeightC: Queryable[float] = ..., blendWeightD: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., dstColorName: Queryable[str] = ..., name: str = ..., nodeState: Queryable[int] = ..., srcColorName: Queryable[str] = ...) -> Union[str, int, float, bool]:
    """Takes two color sets and blends them together into a third specified color set.
    Args:
        baseColorName (Queryable[str]?): Name of the color set to blend from  
                Properties: query, edit
        blendFunc (Queryable[int]?): Type of blending function to use  
                Properties: query, edit
        blendWeightA (Queryable[float]?): Blend weight for linear and bilinear blending functions  
                Properties: query, edit
        blendWeightB (Queryable[float]?): Blend weight for bilinear and channel blending functions  
                Properties: query, edit
        blendWeightC (Queryable[float]?): Blend weight for channel functions  
                Properties: query, edit
        blendWeightD (Queryable[float]?): Blend weight for channel functions  
                Properties: query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        dstColorName (Queryable[str]?): Name of the color set to copy to  
                Properties: query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        srcColorName (Queryable[str]?): Name of the color set to copy from  
                Properties: query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyBlindData(*args: str, edit: bool = ..., associationType: str = ..., binaryData: Multiuse[str] = ..., booleanData: Multiuse[bool] = ..., delete: bool = ..., doubleData: Multiuse[float] = ..., int64Data: Multiuse[int] = ..., intData: Multiuse[int] = ..., longDataName: Multiuse[str] = ..., rescan: bool = ..., reset: bool = ..., shape: bool = ..., shortDataName: Multiuse[str] = ..., stringData: Multiuse[str] = ..., typeId: int = ...) -> str:
    """Command creates blindData types (basically creates an instance of
    TdnPolyBlindData). When used with the query flag, it returns the data
    types that define this blindData type.
    This command is to be used create a blindData node *and* to edit the same..
    The associationType flag *has* to be specified at all times.. This is
    because if an instance of the specified BD typeId exists in the history
    chain but if the associationType is not the same, then a new polyBlindData
    node is created..
    For object level blind data, only the object itself must be specified.
    A new compound attribute BlindDataNNNN will be created on the object.
    Blind data attribute names must be unique across types for object level
    blind data.
    So, the command will require the following to be specified:
        - typeId,
        - associationType
        - longDataName or shortDataName of data being edited.
        - The actual data being specified.
        - The components that this data is to be attached to.Polygon, blinddata, assign, command
    Args:
        associationType (str?): Specifies the dataTypes that are part of BlindData node being created.  
                Allowable associations are "object" for any object, and "vertex" "edge" and  
                "face" for mesh objects. Other associations for other geometry types may  
                be added.  
                Properties: create, edit
        binaryData (Multiuse[str]?): Specifies the data type is a binary data value  
                Properties: create, edit, multiuse
        booleanData (Multiuse[bool]?): Specifies the data type is a boolean logic value  
                Properties: create, edit, multiuse
        delete (bool?): Specifies that this will remove the blind data if found  
                Properties: create, edit
        doubleData (Multiuse[float]?): Specifies the data type is a floating point double value  
                Properties: create, edit, multiuse
        int64Data (Multiuse[int]?): Specifies the data type is an 64. bit integer value  
                Properties: create, edit, multiuse
        intData (Multiuse[int]?): Specifies the data type is an integer value  
                Properties: create, edit, multiuse
        longDataName (Multiuse[str]?): Specifies the long name of the data that is being modified by this command.  
                Properties: create, edit, multiuse
        rescan (bool?): Enables a rescan of blind data nodes for cached information  
                Properties: create, edit
        reset (bool?): Specifies that this command will reset the given attribute to default value  
                Properties: create, edit
        shape (bool?): For object association only, apply blind data to the shape(s) below  
                this node instead of the node itself  
                Properties: create, edit
        shortDataName (Multiuse[str]?): Specifies the short name of the data that is being modified by this command.  
                Properties: create, edit, multiuse
        stringData (Multiuse[str]?): Specifies the data type is a string value  
                Properties: create, edit, multiuse
        typeId (int?): Specifies the typeId of the BlindData type being created  
                Properties: create, edit

    Returns:
        str: Name of nodes created

    Example:
    """

def polyBoolOp(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., faceAreaThreshold: Queryable[float] = ..., operation: Queryable[int] = ..., preserveColor: bool = ..., useThresholds: bool = ..., vertexDistanceThreshold: Queryable[float] = ..., caching: bool = ..., mergeUVSets: Queryable[int] = ..., nodeState: Queryable[int] = ...) -> Union[List[str], float, int, bool]:
    """This command creates a new poly as the result of a boolean
    operation on input polys : union, intersection, difference.Only for difference, the order of the selected objects is
    important :result = object1 - object2.If no objects are specified in the command line, then the
    objects from the active list are used.
    Args:
        faceAreaThreshold (Queryable[float]?): Area threshold to determine whether faces should  
                be collapsed before boolean. Attribute is ignored unless  
                useThresholds is set to true  
                Default: 0.0001  
                Properties: create, query, edit
        operation (Queryable[int]?): Boolean operation type. 1=union, 2=difference, 3=intersection.  
                Default type is union.  
                Default: kBoolOpUnion  
                Properties: create, query, edit
        preserveColor (bool?): If true, boolean op will compute color for the  
                new mesh. If false, the new mesh won't have any color  
                set.  
                Default: false  
                Properties: create, query, edit
        useThresholds (bool?): If true, merge vertices with separations less then  
                vertexDistanceThreshold and collapse faces with areas  
                less then faceAreaThreshold. If false, do not merge  
                vertices or collapse faces  
                Default: false  
                Properties: create, query, edit
        vertexDistanceThreshold (Queryable[float]?): Tolerance to determine whether vertices (and edges) should  
                be merged before boolean operation is applied. Attribute is  
                ignored unless useThresholds is set to true  
                Default: 0.001  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        mergeUVSets (Queryable[int]?): Specify how UV sets will be merged on the output mesh.  
              
                0 = "No Merge": Each UV set on each mesh will become a new UV set in the output.  
                1 = "Merge By Name": UV sets with the same name will be merged.  
                2 = "Merge By UV Links": UV sets will be merged so that UV linking on the input meshes continues to work.  
              
                The default is merge by name.  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyBridgeEdge(*args: str, edit: bool = ..., query: bool = ..., bridgeOffset: Queryable[int] = ..., caching: bool = ..., constructionHistory: bool = ..., curveType: Queryable[int] = ..., divisions: Queryable[int] = ..., inputCurve: str = ..., name: str = ..., nodeState: Queryable[int] = ..., smoothingAngle: Queryable[float] = ..., startVert1: Queryable[int] = ..., startVert2: Queryable[int] = ..., taper: Queryable[float] = ..., taperCurve_FloatValue: Queryable[float] = ..., taperCurve_Interp: Queryable[int] = ..., taperCurve_Position: Queryable[float] = ..., twist: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, int, bool, float]:
    """Bridges two sets of edges.
    Args:
        bridgeOffset (Queryable[int]?): Add offset to which vertices are connected.  
                Default: 0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        curveType (Queryable[int]?): Format: 0. Linear, 1. Blend, 2. Curve  
                Default: TdnpolyBridgeEdge::Linear  
                Properties: create, query, edit
        divisions (Queryable[int]?): The number of subdivisions in the bridging faces  
                (resulting in (divisions+1) row of faces).  
                Default: 1  
                Properties: create, query, edit
        inputCurve (str?): This flag specifies the name of the curve to be used as input for the operation.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Angle below which new edges will be smoothed  
                Default: kPi/6.0  
                Properties: create, query, edit
        startVert1 (Queryable[int]?): The start vertex from the first set of edges  
                Default: -1  
                Properties: create, query, edit
        startVert2 (Queryable[int]?): The start vertex from the second set of edges  
                Default: -1  
                Properties: create, query, edit
        taper (Queryable[float]?): Taper or Scale along the extrusion path  
                Default: 1.0  
                Properties: create, query, edit
        taperCurve_FloatValue (Queryable[float]?): Value for taperCurve;  
                Curve control for taper along extrusion  
                Using this curve, the taper along extrusion  
                can be changed from a simple linear scaling to  
                custom scaling along the extrusion path.  
                Properties: create, query, edit
        taperCurve_Interp (Queryable[int]?): Interpolation type for taperCurve;  
                Curve control for taper along extrusion  
                Using this curve, the taper along extrusion  
                can be changed from a simple linear scaling to  
                custom scaling along the extrusion path.  
                Properties: create, query, edit
        taperCurve_Position (Queryable[float]?): Position for taperCurve;  
                Curve control for taper along extrusion  
                Using this curve, the taper along extrusion  
                can be changed from a simple linear scaling to  
                custom scaling along the extrusion path.  
                Properties: create, query, edit
        twist (Queryable[float]?): Twist or Rotation along the extrusion path  
                Default: 0.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCBoolOp(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., classification: Queryable[int] = ..., faceAreaThreshold: Queryable[float] = ..., operation: Queryable[int] = ..., preserveColor: bool = ..., useCarveBooleans: bool = ..., useThresholds: bool = ..., vertexDistanceThreshold: Queryable[float] = ..., caching: bool = ..., mergeUVSets: Queryable[int] = ..., nodeState: Queryable[int] = ..., tagIntersection: bool = ...) -> Union[List[str], int, float, bool]:
    """This command creates a new poly as the result of a boolean
    operation on input polys : union, intersection, difference.Only for difference, the order of the selected objects is
    important :result = object1 - object2.If no objects are specified in the command line, then the
    objects from the active list are used.
    Args:
        classification (Queryable[int]?): Changes how intersections of open and closed manifolds are treated.  
                1 for "Edge", 2 for "Normal".  
                Properties: create, query, edit
        faceAreaThreshold (Queryable[float]?): Area threshold to determine whether faces should  
                be collapsed before boolean. Attribute is ignored unless  
                useThresholds is set to true  
                Default: 0.0001  
                Properties: create, query, edit
        operation (Queryable[int]?): Boolean operation type. 1=union, 2=difference, 3=intersection.  
                Default type is union.  
                Default: kBoolOpUnion  
                Properties: create, query, edit
        preserveColor (bool?): If true, boolean op will compute color for the  
                new mesh. If false, the new mesh won't have any color  
                set.  
                Default: false  
                Properties: create, query, edit
        useCarveBooleans (bool?): If true, use the Carve Boolean library  
                Properties: create, query, edit
        useThresholds (bool?): If true, merge vertices with separations less then  
                vertexDistanceThreshold and collapse faces with areas  
                less then faceAreaThreshold. If false, do not merge  
                vertices or collapse faces  
                Default: false  
                Properties: create, query, edit
        vertexDistanceThreshold (Queryable[float]?): Tolerance to determine whether vertices (and edges) should  
                be merged before boolean operation is applied. Attribute is  
                ignored unless useThresholds is set to true  
                Default: 0.001  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        mergeUVSets (Queryable[int]?): Specify how UV sets will be merged on the output mesh.  
              
                0 = "No Merge": Each UV set on each mesh will become a new UV set in the output.  
                1 = "Merge By Name": UV sets with the same name will be merged.  
                2 = "Merge By UV Links": UV sets will be merged so that UV linking on the input meshes continues to work.  
              
                The default is merge by name.  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tagIntersection (bool?): If set the operation creates custom component tags that contain  
                vertices on the intersection.  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyCacheMonitor(*, cacheValue: bool = ..., nodeName: str = ...) -> bool:
    """When the cacheInput attribute has a positive value the midModifier node caches the output mesh
    improving performance in computations of downstream nodes.
    When the counter has a zero value the midModifier releases the cached data.poly, cache
    Args:
        cacheValue (bool?): Flag to indicate whether the node's cache counter should be incremented or decremented.  
                True increments the counter, false decrements the counter.  
                Properties: create
        nodeName (str?): Name of the node whose cache counter needs to be changed.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def polyCanBridgeEdge(*args: str) -> bool:
    """Returns true if the specified poly edges can be bridged using polyBridgeEdge.
    Returns:
        bool: Success or Failure.

    Example:
    """

def polyCheck(*args: str, edge: bool = ..., face: bool = ..., faceOffset: bool = ..., openFile: str = ...) -> int:
    """Dumps a description of internal memory representation of poly objects.If no objects are specified in the command line, the
    objects from the active list are used.Default behaviour is to print only a summary. Use the flags
    above to get more details on a specific part of the object.
    Args:
        edge (bool?): Check edge descriptions.  
                If no flag is set, a complete check is performed.  
                Properties: create
        face (bool?): Check face descriptions.  
                If no flag is set, a complete check is performed.  
                Properties: create
        faceOffset (bool?): Check face offset descriptions.  
                If no flag is set, a complete check is performed.  
                Properties: create
        openFile (str?): Opens a file that contains a poly description,  
                as dumped out by the debug commands.  
                Properties: create

    Returns:
        int: The number of errors.

    Example:
    """

def polyChipOff(*args: str, edit: bool = ..., query: bool = ..., attraction: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., duplicate: bool = ..., gain: Queryable[Multiuse[float]] = ..., gravity: Queryable[Tuple[float, float, float]] = ..., gravityX: Queryable[float] = ..., gravityY: Queryable[float] = ..., gravityZ: Queryable[float] = ..., keepFacesTogether: bool = ..., keepFacetTogether: bool = ..., localCenter: Queryable[int] = ..., localDirection: Queryable[Tuple[float, float, float]] = ..., localDirectionX: Queryable[float] = ..., localDirectionY: Queryable[float] = ..., localDirectionZ: Queryable[float] = ..., localRotate: Queryable[Tuple[float, float, float]] = ..., localRotateX: Queryable[float] = ..., localRotateY: Queryable[float] = ..., localRotateZ: Queryable[float] = ..., localScale: Queryable[Tuple[float, float, float]] = ..., localScaleX: Queryable[float] = ..., localScaleY: Queryable[float] = ..., localScaleZ: Queryable[float] = ..., localTranslate: Queryable[Tuple[float, float, float]] = ..., localTranslateX: Queryable[float] = ..., localTranslateY: Queryable[float] = ..., localTranslateZ: Queryable[float] = ..., magnX: Queryable[float] = ..., magnY: Queryable[float] = ..., magnZ: Queryable[float] = ..., magnet: Queryable[Tuple[float, float, float]] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset: Queryable[float] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., random: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ..., weight: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, float, bool, Multiuse[float], Tuple[float, float, float], int]:
    """Extract facets. Faces can be extracted separately or together, and
    manipulations can be performed either in world or object space.
    Args:
        attraction (Queryable[float]?): Attraction, related to magnet.  
                The range is [-2.0, 2.0].  
                Default: 0.0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        duplicate (bool?): If "on", facets are duplicated, otherwise original facets are removed.  
                C: Default is "on".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        gain (Queryable[Multiuse[float]]?): Gain factor per component. Can be painted using Artisan.  
                Default: 1.0  
                Properties: create, query, edit, multiuse
        gravity (Queryable[Tuple[float, float, float]]?): The gravity vector.  
                Default: 0.0, -1.0, 0.0  
                Properties: create, query, edit
        gravityX (Queryable[float]?): Gravity X coord.  
                Properties: create, query, edit
        gravityY (Queryable[float]?): Gravity Y coord.  
                Properties: create, query, edit
        gravityZ (Queryable[float]?): Gravity Z coord.  
                Properties: create, query, edit
        keepFacesTogether (bool?): How to extrude edges.  
                If "on", extruded faces produced from the edges being extruded  
                will be kept together. Otherwise they are pulled independently.  
                Default: true  
                Properties: create, query, edit
        keepFacetTogether (bool?): How to extrude edges.  
                If "on", extruded faces produced from the edges being extruded  
                will be kept together. Otherwise they are pulled independently.  
                Default: true  
                Properties: create, query, edit
        localCenter (Queryable[int]?): Local center on the edge : 0=Middle point, 1=Start point, 2=End point.  
                Default: 0  
                Properties: create, query, edit
        localDirection (Queryable[Tuple[float, float, float]]?): Direction to determine X axis for local space.  
                Default: 1.0, 0.0, 0.0  
                Properties: create, query, edit
        localDirectionX (Queryable[float]?): X coord of the X axis.  
                Properties: create, query, edit
        localDirectionY (Queryable[float]?): Y coord of the X axis.  
                Properties: create, query, edit
        localDirectionZ (Queryable[float]?): Z coord of the X axis.  
                Properties: create, query, edit
        localRotate (Queryable[Tuple[float, float, float]]?): The local rotations.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localRotateX (Queryable[float]?): Local rotate X coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateY (Queryable[float]?): Local rotate Y coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateZ (Queryable[float]?): Local rotate Z coord : Rotation along the normal.  
                The range is [0, 360].  
                Properties: create, query, edit
        localScale (Queryable[Tuple[float, float, float]]?): Local Scale.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        localScaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        localScaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        localScaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        localTranslate (Queryable[Tuple[float, float, float]]?): Local translate.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localTranslateX (Queryable[float]?): Local translation X coord.  
                Properties: create, query, edit
        localTranslateY (Queryable[float]?): Local translation Y coord.  
                Properties: create, query, edit
        localTranslateZ (Queryable[float]?): Local translation Z coord : Move along the normal.  
                Properties: create, query, edit
        magnX (Queryable[float]?): Magnet X coord.  
                Properties: create, query, edit
        magnY (Queryable[float]?): Magnet Y coord.  
                Properties: create, query, edit
        magnZ (Queryable[float]?): Magnet Z coord.  
                Properties: create, query, edit
        magnet (Queryable[Tuple[float, float, float]]?): The magnet vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset (Queryable[float]?): Local offset. Faces are moved this distance towards the inside of the face.  
                Default: 0.0  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot for scaling and rotation.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Pivot X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Pivot Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Pivot Z coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value for all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scaling vector.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        scaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): Translation vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        translateX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        translateY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        weight (Queryable[float]?): The weight, related to gravity.  
                Default: 0.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCircularize(*args: str, edit: bool = ..., query: bool = ..., alignment: Queryable[int] = ..., caching: bool = ..., constructionHistory: bool = ..., createCurve: bool = ..., evenlyDistribute: bool = ..., inputCurve: str = ..., name: str = ..., nodeState: Queryable[int] = ..., normalOrientation: Queryable[int] = ..., radialOffset: Queryable[float] = ..., smoothingAngle: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, int, bool, float]:
    """Mirror all the faces of the selected object.
    Args:
        alignment (Queryable[int]?): How the circle should be  oriented relative to the surface  
                Default: 0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createCurve (bool?): If true then the operation can create a curve.  
                Properties: create
        evenlyDistribute (bool?): Should the point be evenly distributed around the circle  
                Default: true  
                Properties: create, query, edit
        inputCurve (str?): This flag specifies the name of the curve to be used as input for the operation.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normalOrientation (Queryable[int]?): What calculation to use to get circle plane normal  
                Default: 0  
                Properties: create, query, edit
        radialOffset (Queryable[float]?): The amount the circle points should be translated along radius  
                Default: 0.0  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): The angle that decides which resulting faces are hard or soft  
                Default: 30.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCircularizeEdge(*args: str, edit: bool = ..., query: bool = ..., alignment: Queryable[int] = ..., caching: bool = ..., constructionHistory: bool = ..., createCurve: bool = ..., evenlyDistribute: bool = ..., inputCurve: str = ..., name: str = ..., nodeState: Queryable[int] = ..., normalOrientation: Queryable[int] = ..., radialOffset: Queryable[float] = ..., smoothingAngle: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, int, bool, float]:
    """Mirror all the faces of the selected object.
    Args:
        alignment (Queryable[int]?): How the circle should be  oriented relative to the surface  
                Default: 0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createCurve (bool?): If true then the operation can create a curve.  
                Properties: create
        evenlyDistribute (bool?): Should the point be evenly distributed around the circle  
                Default: true  
                Properties: create, query, edit
        inputCurve (str?): This flag specifies the name of the curve to be used as input for the operation.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normalOrientation (Queryable[int]?): What calculation to use to get circle plane normal  
                Default: 0  
                Properties: create, query, edit
        radialOffset (Queryable[float]?): The amount the circle points should be translated along radius  
                Default: 0.0  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): The angle that decides which resulting faces are hard or soft  
                Default: 30.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCircularizeFace(*args: str, edit: bool = ..., query: bool = ..., alignment: Queryable[int] = ..., caching: bool = ..., constructionHistory: bool = ..., createCurve: bool = ..., evenlyDistribute: bool = ..., inputCurve: str = ..., name: str = ..., nodeState: Queryable[int] = ..., normalOrientation: Queryable[int] = ..., radialOffset: Queryable[float] = ..., smoothingAngle: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, int, bool, float]:
    """Mirror all the faces of the selected object.
    Args:
        alignment (Queryable[int]?): How the circle should be  oriented relative to the surface  
                Default: 0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createCurve (bool?): If true then the operation can create a curve.  
                Properties: create
        evenlyDistribute (bool?): Should the point be evenly distributed around the circle  
                Default: true  
                Properties: create, query, edit
        inputCurve (str?): This flag specifies the name of the curve to be used as input for the operation.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normalOrientation (Queryable[int]?): What calculation to use to get circle plane normal  
                Default: 0  
                Properties: create, query, edit
        radialOffset (Queryable[float]?): The amount the circle points should be translated along radius  
                Default: 0.0  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): The angle that decides which resulting faces are hard or soft  
                Default: 30.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyClean(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., cleanEdges: bool = ..., cleanPartialUVMapping: bool = ..., cleanUVs: bool = ..., cleanVertices: bool = ..., constructionHistory: bool = ..., frozen: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """polyClean will attempt to remove components that are invalid in the description of a poly mesh.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        cleanEdges (bool?): If true, the operation will look for and delete edges that are  
                not associated with any face in the mesh.  
                Properties: create, query, edit
        cleanPartialUVMapping (bool?): If true, the operation will look for any faces on the mesh that do  
                not have complete UV mapping.  Maya requires that all vertices that  
                make up a mesh face have valid UV data associated with them, or that  
                none of the vertices withing the face have associated UVs.  
                Properties: create, query, edit
        cleanUVs (bool?): If true, the operation will look for and delete UVs that are  
                not associated with any face in the mesh.  
                Properties: create, query, edit
        cleanVertices (bool?): If true, the operation will look for and delete vertices that are  
                not associated with any face in the mesh.  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        frozen (bool?): Toggle frozen state for a particular node to keep current evaluation  
                state and prevent any other indirect changes to it.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyClipboard(*args: str, clear: bool = ..., color: bool = ..., copy: bool = ..., paste: bool = ..., shader: bool = ..., uvCoordinates: bool = ...) -> bool:
    """The command allows the user to copy and paste certain polygonal
    attributes to a clipboard. These attributes are:
     1) Shader (shading engine) assignment.
     2) Texture coordinate (UV) assignment.
     3) Color value assignment.
    Any combination of attributes can be chosen for the copy or
    paste operation. If the attribute has not been copied
    to the clipboard, then naturally it cannot be pasted from
    the clipboard.
    The copy option will copy the attribute assignments from
    a single source polygonal dag object or polygon component.
    If the source does not have the either UV or color attributes,
    then nothing will be copied to the clipboard.
    The paste option will paste the attribute assignments to
    one or more polygon components or polygonal dag objects.
    If the destination does not have either UV or color attributes,
    then new values will be assigned as needed.
    Additionally, there is the option to clear the clipboard
    contentspoly, clipboard, uv, color, shaders
    Args:
        clear (bool?): When used, will mean to clear the specified attribute argument(s).  
                Properties: create
        color (bool?): When used, will be to copy or paste color attributes  
                Properties: create
        copy (bool?): When used, will mean to copy the specified attribute argument(s).  
                Properties: create
        paste (bool?): When used, will mean to paste the specified attribute argument(s).  
                Properties: create
        shader (bool?): When used, will be to copy or paste shader attributes  
                Properties: create
        uvCoordinates (bool?): When used, will be to copy or paste texture coordinate attributes  
                Properties: create

    Returns:
        bool: Success or Failure

    Example:
    """

def polyCloseBorder(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Closes open borders of objects. For each border edge given,
    a face is created to fill the hole the edge lies on.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCollapseEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Turns each selected edge into a point.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCollapseFacet(*args: str, edit: bool = ..., query: bool = ..., areaThreshold: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., useAreaThreshold: bool = ...) -> Union[str, float, bool, int]:
    """Turns each selected facet into a point.
    Args:
        areaThreshold (Queryable[float]?): Area threshold to determine whether faces should  
                be collapsed. Attribute is ignored unless useAreaThreshold is  
                set to true.  
                Default: 0.1  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        useAreaThreshold (bool?): If true only collapse faces with area less than the area threshold,  
                otherwise collapse all faces regardless of area  
                Default: false  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCollapseTweaks(arg0: str = ..., /, *, query: bool = ..., hasVertexTweaks: bool = ...) -> bool:
    """A command that updates a mesh's vertex tweaks by applying its tweak data
    (stored on the mesh node) onto its respective vertex data.This command is only useful in cases where no construction history is associated
    with the shape node.If a mesh name is not specified as input, a singly selected mesh (if any) will
    have its tweaked vertices baked.
    Args:
        hasVertexTweaks (bool?): Determines whether an individual mesh has vertex tweaks.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyColorBlindData(*args: Any, aboveMaxColorBlue: Multiuse[float] = ..., aboveMaxColorGreen: Multiuse[float] = ..., aboveMaxColorRed: Multiuse[float] = ..., attrName: Multiuse[str] = ..., belowMinColorBlue: Multiuse[float] = ..., belowMinColorGreen: Multiuse[float] = ..., belowMinColorRed: Multiuse[float] = ..., clashColorBlue: float = ..., clashColorGreen: float = ..., clashColorRed: float = ..., colorBlue: Multiuse[float] = ..., colorGreen: Multiuse[float] = ..., colorRed: Multiuse[float] = ..., dataType: Multiuse[str] = ..., enableFalseColor: bool = ..., maxColorBlue: Multiuse[float] = ..., maxColorGreen: Multiuse[float] = ..., maxColorRed: Multiuse[float] = ..., maxValue: Multiuse[float] = ..., minColorBlue: Multiuse[float] = ..., minColorGreen: Multiuse[float] = ..., minColorRed: Multiuse[float] = ..., minValue: Multiuse[float] = ..., mode: Multiuse[int] = ..., noColorBlue: float = ..., noColorGreen: float = ..., noColorRed: float = ..., numIdTypes: Multiuse[int] = ..., queryMode: bool = ..., typeId: Multiuse[int] = ..., useMax: Multiuse[bool] = ..., useMin: Multiuse[bool] = ..., value: Multiuse[str] = ...) -> List[str]:
    """This command applies false color to the selected polygonal components
    and objects, depending on whether or not blind data exists for the
    selected components (or, in the case of poly objects, dynamic
    attributes), and, depending on the color mode indicated, what the
    values are. It is possible to color objects based on whether or not
    the data exists, if the data matches a specific value or range of
    values, or grayscale color the data according to what the actual value
    is in relation to the specified min and max. This command also has a
    query mode in which the components and/or objects are returned in a
    string array to allow for selection filtering.color, query, blind, data
    Args:
        aboveMaxColorBlue (Multiuse[float]?): Specifies blue component of color to use for data that is above max  
                Properties: create, multiuse
        aboveMaxColorGreen (Multiuse[float]?): Specifies green component of color to use for data that is above max  
                Properties: create, multiuse
        aboveMaxColorRed (Multiuse[float]?): Specifies red component of color to use for data that is above max  
                Properties: create, multiuse
        attrName (Multiuse[str]?): Specifies the name of the data that is being examined by this command.  
                Properties: create, multiuse
        belowMinColorBlue (Multiuse[float]?): Specifies blue component of color to use for data that is below min  
                Properties: create, multiuse
        belowMinColorGreen (Multiuse[float]?): Specifies green component of color to use for data that is below min  
                Properties: create, multiuse
        belowMinColorRed (Multiuse[float]?): Specifies red component of color to use for data that is below min  
                Properties: create, multiuse
        clashColorBlue (float?): Specifies blue component color to use for data which clashes  
                Properties: create
        clashColorGreen (float?): Specifies green component color to use for data which clashes  
                Properties: create
        clashColorRed (float?): Specifies red component color to use for data which clashes  
                Properties: create
        colorBlue (Multiuse[float]?): Specifies blue component of color to use for given data  
                Properties: create, multiuse
        colorGreen (Multiuse[float]?): Specifies green component of color to use for given data  
                Properties: create, multiuse
        colorRed (Multiuse[float]?): Specifies red component of color to use for given data  
                Properties: create, multiuse
        dataType (Multiuse[str]?): Specifies the type for this id  
                Properties: create, multiuse
        enableFalseColor (bool?): Turns false coloring on or off for all poly objects in the scene  
                Properties: create
        maxColorBlue (Multiuse[float]?): Specifies blue component of color to use for max value for grayscale  
                Properties: create, multiuse
        maxColorGreen (Multiuse[float]?): Specifies green component of color to use for max value for grayscale  
                Properties: create, multiuse
        maxColorRed (Multiuse[float]?): Specifies red component of color to use for max value for grayscale  
                Properties: create, multiuse
        maxValue (Multiuse[float]?): Specifies the max value for grayscale or discrete range data  
                Properties: create, multiuse
        minColorBlue (Multiuse[float]?): Specifies blue component of color to use for min value for grayscale  
                Properties: create, multiuse
        minColorGreen (Multiuse[float]?): Specifies green component of color to use for min value for grayscale  
                Properties: create, multiuse
        minColorRed (Multiuse[float]?): Specifies red component of color to use for min value for grayscale  
                Properties: create, multiuse
        minValue (Multiuse[float]?): Specifies the min value for grayscale or discrete range data  
                Properties: create, multiuse
        mode (Multiuse[int]?): Specifies the mode:  
              
                0. binary - only components and objects that have the data will be colored  
                1. discrete value - a value is specified. Data that matches this value will be colored  
                2. discrete range - values that fall within the given range will be colored  
                3. unsigned set mode - if ( givenValue & actualValue ) then data will be colored  
                4. unsigned not set mode - if ( !(givenValue & actualValue) ) then data will be colored  
                5. unsigned equal mode - if ( givenValue == actualValue ) then data will be colored  
                6. grayscale mode - a min value, max value, min color, max color, below min color, and  
                    above max color are given. Data is colored according to how it relates to these values.  
                7. as color mode - if the blind data consists of 3 doubles, ranged 0. 1, the components are colored as the data specifies  
                Properties: create, multiuse
        noColorBlue (float?): Specifies blue component of color to use for no data assigned  
                Properties: create
        noColorGreen (float?): Specifies green component of color to use for no data assigned  
                Properties: create
        noColorRed (float?): Specifies red component of color to use for no data assigned  
                Properties: create
        numIdTypes (Multiuse[int]?): Specifies how many attrs are in this id type  
                Properties: create, multiuse
        queryMode (bool?): If on, do not color and return selection as string array instead.  
                Any data that would be colored normally (except for 'no color' and  
                out of range colors) is returned  
                Properties: create
        typeId (Multiuse[int]?): Specifies the typeId of the BlindData type being created  
                Properties: create, multiuse
        useMax (Multiuse[bool]?): Specifies whether the max should be used for discrete ranges  
                Properties: create, multiuse
        useMin (Multiuse[bool]?): Specifies whether the min should be used for discrete ranges  
                Properties: create, multiuse
        value (Multiuse[str]?): The value of the data  
                Properties: create, multiuse

    Returns:
        List[str]: Command result

    Example:
    """

def polyColorDel(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., colorSetName: Queryable[str] = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Deletes color from selected components.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        colorSetName (Queryable[str]?): The name of the color set to work on  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyColorMod(*args: str, edit: bool = ..., query: bool = ..., alphaScale_FloatValue: Queryable[float] = ..., alphaScale_Interp: Queryable[int] = ..., alphaScale_Position: Queryable[float] = ..., baseColorName: str = ..., blueScale_FloatValue: Queryable[float] = ..., blueScale_Interp: Queryable[int] = ..., blueScale_Position: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., greenScale_FloatValue: Queryable[float] = ..., greenScale_Interp: Queryable[int] = ..., greenScale_Position: Queryable[float] = ..., huev: Queryable[float] = ..., intensityScale_FloatValue: Queryable[float] = ..., intensityScale_Interp: Queryable[int] = ..., intensityScale_Position: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., redScale_FloatValue: Queryable[float] = ..., redScale_Interp: Queryable[int] = ..., redScale_Position: Queryable[float] = ..., satv: Queryable[float] = ..., value: Queryable[float] = ...) -> Union[str, float, int, bool]:
    """Modifies the attributes of a poly color set.
    Args:
        alphaScale_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        alphaScale_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        alphaScale_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        baseColorName (str?): The name of the color set to be modified.  
                Properties: create
        blueScale_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        blueScale_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        blueScale_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        greenScale_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        greenScale_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        greenScale_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        huev (Queryable[float]?): Hue  rotates hue value of the final color.  
                Default: 0.0  
                Properties: create, query, edit
        intensityScale_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        intensityScale_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        intensityScale_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        redScale_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        redScale_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        redScale_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        satv (Queryable[float]?): Sat scales the staturation of the final color.  
                Default: 1.0  
                Properties: create, query, edit
        value (Queryable[float]?): Value scales the final color value.  
                Default: 1.0  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyColorPerVertex(*args: str, edit: bool = ..., query: bool = ..., alpha: Queryable[float] = ..., clamped: bool = ..., colorB: Queryable[float] = ..., colorDisplayOption: bool = ..., colorG: Queryable[float] = ..., colorR: Queryable[float] = ..., colorRGB: Queryable[Tuple[float, float, float]] = ..., notUndoable: bool = ..., relative: bool = ..., remove: bool = ..., representation: Queryable[int] = ...) -> Union[bool, float, Tuple[float, float, float], int]:
    """Command associates color(rgb and alpha) with vertices on polygonal objects.
    When used with the query flag, it returns the color associated with the
    specified components.poly, color, colorPerVertex, vertexColor
    Args:
        alpha (Queryable[float]?): Specifies the alpha channel of color  
                Properties: create, query, edit
        clamped (bool?): This flag specifies if the color set will truncate any value that is  
                outside 0 to 1 range.  
                Properties: create, query, edit
        colorB (Queryable[float]?): Specifies the B channel of color  
                Properties: create, query, edit
        colorDisplayOption (bool?): Change the display options on the mesh to display the vertex colors.  
                Properties: create, query, edit
        colorG (Queryable[float]?): Specifies the G channel of color  
                Properties: create, query, edit
        colorR (Queryable[float]?): Specifies the R channel of color  
                Properties: create, query, edit
        colorRGB (Queryable[Tuple[float, float, float]]?): Specifies the RGB channels of color  
                Properties: create, query, edit
        notUndoable (bool?): Execute the command, but without having the command  
                be undoable. This option will greatly improve performance  
                for large numbers of object. This will make the command  
                not undoable regardless of whether undo has been  
                enabled or not.  
                Properties: create, query, edit
        relative (bool?): When used, the color values specified are added relative to the current values.  
                Properties: create, query, edit
        remove (bool?): When used, the color values are removed from the selected or specified objects  
                or components. This option only supports meshes with no construction history, or meshes  
                whose construction history includes a recent polyColorPerVertexNode. For meshes whose construction  
                history includes a polgon operation the polyColorPerVertexNode, consider using the polyColorDel command instead  
                Properties: create, query, edit
        representation (Queryable[int]?): This flag corresponds to the color channels to used, for example  
                A(alpha only), RGB, and RGBA.  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyColorSet(*args: str, edit: bool = ..., query: bool = ..., allColorSets: bool = ..., clamped: bool = ..., colorSet: Queryable[str] = ..., copy: bool = ..., create: bool = ..., currentColorSet: bool = ..., currentPerInstanceSet: bool = ..., delete: bool = ..., newColorSet: Queryable[str] = ..., perInstance: bool = ..., rename: bool = ..., representation: Queryable[str] = ..., shareInstances: bool = ..., unshared: bool = ...) -> Union[bool, str]:
    """Command to do the following to color sets:poly, colorSet, currentColorSet, renameColorSet, deleteColorSet, copyColorSet, createColorSet
    Args:
        allColorSets (bool?): This flag when used in a query will return a list of all  
                of the color set names  
                Properties: create, query, edit
        clamped (bool?): This flag specifies if the color set will truncate any value that is  
                outside 0 to 1 range.  
                Properties: create, query, edit
        colorSet (Queryable[str]?): Specifies the name of the color set that this command needs to work on.  
                This flag has to be specified for this command to do anything meaningful  
                other than query the current color set.  
                Properties: create, query, edit
        copy (bool?): This flag when used will result in the copying of the color set corresponding  
                to name specified with the colorSet flag to the colorSet corresponding  
                to the name specified with the newcolorSet flag  
                Properties: create, query, edit
        create (bool?): This flag when used will result in the creation of an empty color set  
                corresponding to the name specified with the colorSet flag. If  
                a color set with that name already exists, then no new color set will  
                be created.  
                Properties: create, query, edit
        currentColorSet (bool?): This flag when used will set the current color set that the object needs to  
                work on, to be the color set corresponding to the name specified with the  
                colorSet flag. This does require that a colorSet with the specified name exist.  
                When queried, this returns the current color set.  
                Properties: create, query, edit
        currentPerInstanceSet (bool?): This is a query-only flag for use when the current color set is a per-instance  
                color set family. This returns the member of the set family that corresponds  
                to the currently select instance.  
                Properties: query, edit
        delete (bool?): This flag when used will result in the deletion of the color set corresponding  
                to the name specified with the colorSet flag.  
                Properties: create, query, edit
        newColorSet (Queryable[str]?): Specifies the name that the color set corresponding to the name specified with  
                the colorSet flag, needs to be renamed to.  
                Properties: create, query, edit
        perInstance (bool?): This flag can be used in conjunction with the create flag to indicate  
                whether or not the color set is per-instance. When you create a per-instance  
                color set, the set will be applied as shared between all selected instances  
                of the shape unless the unshared flag is used. The perInstance flag can  
                be used in query mode with the currentColorSet or allColorSets flag to indicate  
                that the set family names (i.e. not containing instance identifiers) will  
                be returned by the query.  
                			In query mode, this flag can accept a value.  
                Properties: create, query, edit
        rename (bool?): This flag when used will result in the renaming of the color set corresponding  
                to the name specified with the colorSet flag to the name specified using the  
                newColorSet flag.  
                Properties: create, query, edit
        representation (Queryable[str]?): This flag corresponds to the color channels to used, for example  
                A(alpha only), RGB, and RGBA.  
                Properties: create, query, edit
        shareInstances (bool?): This flag is used to modify the sharing of per-instance color sets within  
                a given color set family so that all selected instances share the specified  
                set. In query mode, it returns a list of the instances that share the  
                set specified by the colorSet flag.  
                Properties: create, query, edit
        unshared (bool?): This flag can be used in conjunction with the create and perInstance flags  
                to indicate that the newly created per-instance set should be created with  
                a separate set per instance.  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyColorSetCmdWrapper(*args: Any, **kwargs: Any) -> None: ...
def polyCompare(*args: str, colorSetIndices: bool = ..., colorSets: bool = ..., edges: bool = ..., faceDesc: bool = ..., userNormals: bool = ..., uvSetIndices: bool = ..., uvSets: bool = ..., vertices: bool = ...) -> int:
    """Compares two Polygonal Geometry objects with a fine control on what to compare.If no objects are specified in the command line, then the
    objects from the active list are used.Default behaviour is to compare all flags.Use MEL script polyCompareTwoObjects.mel to get formatted output from this command.
    Args:
        colorSetIndices (bool?): Compare poly1, poly2 for matching Color Indices.  
                Properties: create
        colorSets (bool?): Compare poly1, poly2 for matching Color Sets.  
                Properties: create
        edges (bool?): Compare poly1, poly2 for matching Edges.  
                Properties: create
        faceDesc (bool?): Compare poly1, poly2 for matching Face Descriptions. Face descriptions describe the topology of a face, for example number and orientation of edges, number of topology of any holes in the face etc.  
                Properties: create
        userNormals (bool?): Compare poly1, poly2 for matching User Normals.  
                Properties: create
        uvSetIndices (bool?): Compare poly1, poly2 for matching UV Indices.  
                Properties: create
        uvSets (bool?): Compare poly1, poly2 for matching UV Sets.  
                Properties: create
        vertices (bool?): Compare poly1, poly2 for matching Vertices.  
                Properties: create

    Returns:
        int: 0 if successful, non-zero if poly1 and poly2 are not determined to be equal based on requested flags.
            The non-zero value depends on which attributes are different:
            
            Vertices = 1          
            Edges = 2             
            Face Descriptions = 4 
            UV Sets = 8           
            UV Indices = 16       
            Color Sets = 32       
            Color Indices = 64    
            User Normals = 128    
            
            So a return value of 3, for example, indicates both vertices and edges are different.

    Example:
    """

def polyCone(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: Queryable[int] = ..., height: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., roundCap: bool = ..., subdivisionsAxis: Queryable[int] = ..., subdivisionsCap: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., subdivisionsX: Queryable[int] = ..., subdivisionsY: Queryable[int] = ..., subdivisionsZ: Queryable[int] = ..., texture: bool = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The cone command creates a new polygonal cone.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the cone.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize  
                3. Normalize and Preserve Aspect Ratio  
                Default: 2  
                Properties: create, query, edit
        height (Queryable[float]?): Height of the cone.  
                Default: 2.0  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): Radius of the cone.  
                Default: 1.0  
                Properties: create, query, edit
        roundCap (bool?): To indicate whether we need a round cap  
                Default: false  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): Subdivisions around the axis.  
                Default: 20  
                Properties: create, query, edit
        subdivisionsCap (Queryable[int]?): Subdivisions on the bottom cap.  
                Default: 0  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height.  
                Default: 1  
                Properties: create, query, edit
        subdivisionsX (Queryable[int]?): This specifies the number of subdivisions in the X direction for the cone.  
                C: Default is 20.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsY (Queryable[int]?): This flag specifies the number of subdivisions in the Y direction for the cone.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsZ (Queryable[int]?): This flag specifies the number of subdivisions in the Z direction for the cone.  
                C: Default is 0.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (bool?): Apply texture or not.  
                Default: true  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyConnectComponents(*args: str, edit: bool = ..., query: bool = ..., adjustEdgeFlow: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., insertWithEdgeFlow: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, float, bool, int]:
    """Splits polygon edges according to the selected components.
    The selected components are gathered into connected 'paths' that define continuous splits.
    Mixed components (vertices, edges and faces) can be used at once.
    The connection rules are:
    * Edges can connect to other edges in the same face
    or to vertices in the same face (that are not in the edge itself)
    or to faces connected to other edges in the same face.
    * Vertices can connect to edges (as above)
    or to vertices in the same face (that are not joined to the first vertex by an edge)
    or to faces adjacent to a face that uses the vertex (except those that also use the vertex).
    * Faces can connect to vertices or edges (as above)
    or to adjacent faces.
    Args:
        adjustEdgeFlow (Queryable[float]?): The weight value of the edge vertices to be positioned.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        insertWithEdgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyContourProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., flipRails: bool = ..., insertBeforeDeformers: bool = ..., method: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset0: Queryable[float] = ..., offset1: Queryable[float] = ..., offset2: Queryable[float] = ..., offset3: Queryable[float] = ..., reduceShear: Queryable[float] = ..., smoothness0: Queryable[float] = ..., smoothness1: Queryable[float] = ..., smoothness2: Queryable[float] = ..., smoothness3: Queryable[float] = ..., userDefinedCorners: bool = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Performs a contour stretch UV projection onto an object.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): Set to true if a new map should be created  
                Properties: create
        flipRails (bool?): If true, flip which curves are the rails of the birail surface.  
                Properties: create, query, edit
        insertBeforeDeformers (bool?): Set to true if the new node created should inserted before any deformer nodes.  
                Properties: create
        method (Queryable[int]?): Sets which projection method to use. Valid values are  
                0. Walk Contours  
                1. NURBS Projection  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset0 (Queryable[float]?): Sets the offset on edge 0 of the NURBS surface.  
                Properties: create, query, edit
        offset1 (Queryable[float]?): Sets the offset on edge 1 of the NURBS surface.  
                Properties: create, query, edit
        offset2 (Queryable[float]?): Sets the offset on edge 2 of the NURBS surface.  
                Properties: create, query, edit
        offset3 (Queryable[float]?): Sets the offset on edge 3 of the NURBS surface.  
                Properties: create, query, edit
        reduceShear (Queryable[float]?): Sets the 'reduce shear' parameter of the projection.  
                Properties: create, query, edit
        smoothness0 (Queryable[float]?): Sets the smoothness of edge 0 of the NURBS surface.  
                Properties: create, query, edit
        smoothness1 (Queryable[float]?): Sets the smoothness of edge 1 of the NURBS surface.  
                Properties: create, query, edit
        smoothness2 (Queryable[float]?): Sets the smoothness of edge 2 of the NURBS surface.  
                Properties: create, query, edit
        smoothness3 (Queryable[float]?): Sets the smoothness of edge 3 of the NURBS surface.  
                Properties: create, query, edit
        userDefinedCorners (bool?): If true, the four vertices specified by user will be taken as corners to do the projection.  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCopyUV(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., uvSetName: str = ..., uvSetNameInput: Queryable[str] = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """Copy some UVs from a UV set into another.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): Set to true if a new map should be created  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        uvSetNameInput (Queryable[str]?): Specifies name of the input uv set to  
                read the UV description from. Default is the current UV set.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCrease(*args: str, edit: bool = ..., query: bool = ..., createHistory: bool = ..., operation: Queryable[int] = ..., relativeValue: Queryable[float] = ..., value: Queryable[Multiuse[float]] = ..., vertexValue: Queryable[Multiuse[float]] = ...) -> Union[bool, int, float, Multiuse[float]]:
    """Command to set the crease values on the edges or vertices
    of a poly.  The crease values are used by the smoothing
    algorithm.poly, crease, smooth, subdiv
    Args:
        createHistory (bool?): For objects that have no construction history, this flag can be used  
                to force the creation of construction history for creasing.  By default,  
                history is not created if the object has no history.  Regardless of this  
                flag, history is always created if the object already has history.  
                Properties: create, query, edit
        operation (Queryable[int]?): Operation to perform.  Valid values are:  
                0. Crease the specified components.  
                1. Remove the crease values for the specified components.  
                2. Remove all crease values from the mesh.  
                Default is 0.  
                Properties: create, query, edit
        relativeValue (Queryable[float]?): Specifies a new relative value for all selected vertex and edge components.  
                This flag can not be used at the same time as either the value or vertexValue  
                flags.  
                Properties: create, query, edit
        value (Queryable[Multiuse[float]]?): Specifies the crease value for the selected edge components.  
                When specified multiple times, the values are assigned respectively to  
                the specified edges.  
                Properties: create, query, edit, multiuse
        vertexValue (Queryable[Multiuse[float]]?): Specifies the crease value for the selected vertex components.  
                When specified multiple times, the values are assigned respectively to  
                the specified vertices.  
                Properties: create, query, edit, multiuse

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyCreaseCtx(*args: Any, edit: bool = ..., query: bool = ..., createSet: str = ..., exists: bool = ..., extendSelection: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., relative: bool = ...) -> Union[bool, str]:
    """Create a new context to crease components on polygonal objects
    Args:
        createSet (str?): Creates a set for the selected components.  
                Properties: edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        extendSelection (bool?): Enable/disable extending selection to all connected creased components.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        relative (bool?): Enable/disable applying value relative to existing crease value.  
                If disabled, absolute value is applied.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyCreateFacet(*args: str, edit: bool = ..., query: bool = ..., constructionHistory: bool = ..., hole: Multiuse[bool] = ..., name: str = ..., point: Multiuse[Union[Tuple[()], Tuple[float, float, float]]] = ..., subdivision: Queryable[int] = ..., texture: Queryable[int] = ...) -> Union[List[str], bool, int]:
    """Create a new polygonal object with the specified face, which will be closed.
    List of arguments must have at least 3 points.
    Args:
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        hole (Multiuse[bool]?): Add a hole. The following points will define a hole.  
                Holes can be defined either clockwise or counterclockwise.  
              
                Note that this flag is not recommended for use in Python.  When specifying facets  
                with the point flag in Python, pass in an empty point "()" when you want to  
                start specifying a hole.  
                Properties: create, multiuse
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        point (Multiuse[Union[Tuple[()], Tuple[float, float, float]]]?): Adds a new point to the face.  
                Coordinates of points are given in world reference.  
              
                The point flag may also be passed with no arguments.  That indicates that the  
                following points will specify a hole.  Passing the point flag with no  
                arguments is the same as using the "hole" flag, except that it will work  
                in Python.  
                Properties: create, multiuse
        subdivision (Queryable[int]?): This flag specifies the level of subdivision.  
                Subdivides edges into the given number of edges.  
                C: Default is 1 (no subdivision).  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (Queryable[int]?): Specifies how the face is mapped.  
                 0. None; 1. Normalize; 2. Unitize  
                C: Default is 0 (no mapping).  
                Q: When queried, this flag returns an int  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyCreateFacetCtx(*args: Any, edit: bool = ..., query: bool = ..., append: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., maximumNumberOfPoints: Queryable[int] = ..., planarConstraint: bool = ..., subdivision: Queryable[int] = ..., texture: Queryable[int] = ...) -> Union[bool, str, int]:
    """Create a new context to create polygonal objects
    Args:
        append (bool?): Allows to switch to polyAppendFacetCtx tool  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        maximumNumberOfPoints (Queryable[int]?): Allows the ability to set a upper bound on the number of  
                points in interactively place before polygon is  
                created. A value less than 2 will mean that there is no  
                upper bound.  
                Properties: create, query, edit
        planarConstraint (bool?): allows/avoid new facet to be non-planar.  
                If on, all new points will be projected onto  
                current facet plane.  
                Properties: create, query, edit
        subdivision (Queryable[int]?): Number of subdivisions for each edge.  
                Default: 1  
                Properties: create, query, edit
        texture (Queryable[int]?): What texture mechanism to be applied  
                0=No textures, 1=Normalized, Undistorted textures  
                2=Unitized textures  
                Default: 0  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyCube(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: Queryable[int] = ..., depth: Queryable[float] = ..., height: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., subdivisionsDepth: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., subdivisionsWidth: Queryable[int] = ..., subdivisionsX: Queryable[int] = ..., subdivisionsY: Queryable[int] = ..., subdivisionsZ: Queryable[int] = ..., texture: Queryable[int] = ..., width: Queryable[float] = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The cube command creates a new polygonal cube.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the cube.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize Each Face Separately  
                3. Normalize Collectively  
                4. Normalize and Preserve Aspect Ratio  
                Default: 3  
                Properties: create, query, edit
        depth (Queryable[float]?): Depth of the cube.  
                Default: 1.0  
                Properties: create, query, edit
        height (Queryable[float]?): Height of the cube.  
                Default: 1.0  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        subdivisionsDepth (Queryable[int]?): Subdivisions along the depth of the cube.  
                Default: 1  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height of the cube.  
                Default: 1  
                Properties: create, query, edit
        subdivisionsWidth (Queryable[int]?): Subdivisions along the width of the cube.  
                Default: 1  
                Properties: create, query, edit
        subdivisionsX (Queryable[int]?): This specifies the number of subdivisions in the X direction for the cube.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsY (Queryable[int]?): This flag specifies the number of subdivisions in the Y direction for the cube.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsZ (Queryable[int]?): This flag specifies the number of subdivisions in the Z direction for the cube.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (Queryable[int]?): What texture mechanism to be applied  
                0=No textures; 1=Object; 2=Faces  
                Default: 1  
                Properties: create, query, edit
        width (Queryable[float]?): Width of the cube.  
                Default: 1.0  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyCut(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., cutPlaneCenter: Queryable[Tuple[float, float, float]] = ..., cutPlaneCenterX: Queryable[float] = ..., cutPlaneCenterY: Queryable[float] = ..., cutPlaneCenterZ: Queryable[float] = ..., cutPlaneHeight: Queryable[float] = ..., cutPlaneRotate: Queryable[Tuple[float, float, float]] = ..., cutPlaneRotateX: Queryable[float] = ..., cutPlaneRotateY: Queryable[float] = ..., cutPlaneRotateZ: Queryable[float] = ..., cutPlaneSize: Queryable[Tuple[float, float]] = ..., cutPlaneWidth: Queryable[float] = ..., cuttingDirection: str = ..., deleteFaces: bool = ..., extractFaces: bool = ..., extractOffset: Queryable[Tuple[float, float, float]] = ..., extractOffsetX: Queryable[float] = ..., extractOffsetY: Queryable[float] = ..., extractOffsetZ: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., onObject: bool = ..., worldSpace: bool = ...) -> Union[str, bool, Tuple[float, float, float], float, Tuple[float, float], int]:
    """This command splits a mesh, or a set of poly faces, along a plane.
    The position and orientation of the plane can be adjusted using the
    appropriate flags listed above.  In addition, the cut operation can
    also delete the faces lying on one side of the cutting plane, or
    extract those faces by an offset amount.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        cutPlaneCenter (Queryable[Tuple[float, float, float]]?): The position of the cutting plane.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        cutPlaneCenterX (Queryable[float]?): Cutting plane center X coord.  
                Properties: create, query, edit
        cutPlaneCenterY (Queryable[float]?): Cutting plane center Y coord.  
                Properties: create, query, edit
        cutPlaneCenterZ (Queryable[float]?): Cutting plane center Z coord.  
                Properties: create, query, edit
        cutPlaneHeight (Queryable[float]?): The height of the cutting plane  
                Properties: create, query, edit
        cutPlaneRotate (Queryable[Tuple[float, float, float]]?): The orientation of the cutting plane.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        cutPlaneRotateX (Queryable[float]?): cutting plane X rotate angle.  
                Properties: create, query, edit
        cutPlaneRotateY (Queryable[float]?): cutting plane Y rotate angle.  
                Properties: create, query, edit
        cutPlaneRotateZ (Queryable[float]?): cutting plane Z rotate angle.  
                Properties: create, query, edit
        cutPlaneSize (Queryable[Tuple[float, float]]?): The width and the height of the cutting plane  
                Default: 1.0, 1.0  
                Properties: create, query, edit
        cutPlaneWidth (Queryable[float]?): The width of the cutting plane  
                Properties: create, query, edit
        cuttingDirection (str?): This flag specifies the direction of the cutting plane.  
                Valid values are "x", "y", "z"  
                A value of "x" will cut the object along the YZ plane  
                cutting through the center of the bounding box.  
                A value of "y" will cut the object along the ZX plane  
                cutting through the center of the bounding box.  
                A value of "z" will cut the object along the XY plane  
                cutting through the center of the bounding box.  
                Properties: create
        deleteFaces (bool?): whether to delete the one-half of the cut-faces  
                of the poly.  If true, they are deleted.  
                Default: false  
                Properties: create, query, edit
        extractFaces (bool?): whether to extract the cut-faces of the poly  
                into a separate shell.  If true, they are extracted.  
                Default: false  
                Properties: create, query, edit
        extractOffset (Queryable[Tuple[float, float, float]]?): The displacement offset of the cut faces.  
                Default: 0.5, 0.5, 0.5  
                Properties: create, query, edit
        extractOffsetX (Queryable[float]?): The X-displacement offset of the cut faces.  
                Properties: create, query, edit
        extractOffsetY (Queryable[float]?): The Y-displacement offset of the cut faces.  
                Properties: create, query, edit
        extractOffsetZ (Queryable[float]?): The Z-displacement offset of the cut faces.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        onObject (bool?): whether to act on the entire polyObject  
                or its selected face components  
                Default: true  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyCutCtx(*args: Any, edit: bool = ..., query: bool = ..., deleteFaces: bool = ..., exists: bool = ..., extractFaces: bool = ..., extractOffset: Queryable[Tuple[float, float, float]] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> Union[bool, Tuple[float, float, float], str]:
    """Create a new context to cut facets on polygonal objects
    Args:
        deleteFaces (bool?): whether to delete the one-half of the cut-faces  
                of the poly.  If true, they are deleted.  
                Default: false  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        extractFaces (bool?): whether to extract the cut-faces of the poly  
                into a separate shell.  If true, they are extracted.  
                Default: false  
                Properties: create, query, edit
        extractOffset (Queryable[Tuple[float, float, float]]?): The displacement offset of the cut faces.  
                Default: 0.5, 0.5, 0.5  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyCutUVCtx(*args: Any, edit: bool = ..., query: bool = ..., loopSpeed: Queryable[int] = ..., mapBordersColor: Queryable[Tuple[float, float, float]] = ..., showCheckerMap: bool = ..., showTextureBorders: bool = ..., showUVShellColoring: bool = ..., steadyStroke: bool = ..., steadyStrokeDistance: Queryable[float] = ..., symmetry: Queryable[int] = ...) -> Union[bool, float, int, Tuple[float, float, float]]:
    """Create a new context to cut UVs on polygonal objects
    Args:
        loopSpeed (Queryable[int]?): Edit the speed of loop cutting.  
                Properties: query, edit
        mapBordersColor (Queryable[Tuple[float, float, float]]?): Color of UV map border edges in 3d view.  
                Properties: query, edit
        showCheckerMap (bool?): Display checker map.  
                Properties: query, edit
        showTextureBorders (bool?): Display texture border edges.  
                Properties: query, edit
        showUVShellColoring (bool?): Turn on UV shell coloring or not.  
                Properties: query, edit
        steadyStroke (bool?): Turn on steady stroke or not.  
                Properties: query, edit
        steadyStrokeDistance (Queryable[float]?): The distance for steady stroke.  
                Properties: query, edit
        symmetry (Queryable[int]?): Symmetric modeling.  
                Properties: query, edit

    Returns:
        bool: Whether steady stroke is on or not, when querying the steadyStroke flag.
        float: The distance for a steady stroke, when querying the steadyStrokeDistance flag.

    Example:
    """

def polyCylinder(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: Queryable[int] = ..., height: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., roundCap: bool = ..., subdivisionsAxis: Queryable[int] = ..., subdivisionsCaps: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., subdivisionsX: Queryable[int] = ..., subdivisionsY: Queryable[int] = ..., subdivisionsZ: Queryable[int] = ..., texture: Queryable[int] = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The cylinder command creates a new polygonal cylinder.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the cylinder.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize  
                3. Normalize and Preserve Aspect Ratio  
                Default: 2  
                Properties: create, query, edit
        height (Queryable[float]?): Height of the cylinder.  
                Default: 2.0  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): Radius of the cylinder.  
                Default: 1.0  
                Properties: create, query, edit
        roundCap (bool?): To indicate whether we need a round cap  
                Default: false  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): Subdivisions around the axis.  
                Default: 20  
                Properties: create, query, edit
        subdivisionsCaps (Queryable[int]?): Subdivisions on the caps  
                Default: 0  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height.  
                Default: 1  
                Properties: create, query, edit
        subdivisionsX (Queryable[int]?): This specifies the number of subdivisions in the X direction for the cylinder.  
                C: Default is 20.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsY (Queryable[int]?): This flag specifies the number of subdivisions in the Y direction for the cylinder.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsZ (Queryable[int]?): This flag specifies the number of subdivisions in the Z direction for the cylinder.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (Queryable[int]?): What texture mechanism to be applied  
                0=No textures, 1=Object, 2=Faces  
                Default: 2  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyCylindricalProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., imageCenter: Queryable[Tuple[float, float]] = ..., imageCenterX: Queryable[float] = ..., imageCenterY: Queryable[float] = ..., imageScale: Queryable[Tuple[float, float]] = ..., imageScaleU: Queryable[float] = ..., imageScaleV: Queryable[float] = ..., insertBeforeDeformers: bool = ..., keepImageRatio: bool = ..., mapDirection: str = ..., name: str = ..., nodeState: Queryable[int] = ..., perInstance: bool = ..., projectionCenter: Queryable[Tuple[float, float, float]] = ..., projectionCenterX: Queryable[float] = ..., projectionCenterY: Queryable[float] = ..., projectionCenterZ: Queryable[float] = ..., projectionHeight: Queryable[float] = ..., projectionHorizontalSweep: Queryable[float] = ..., projectionScale: Queryable[Tuple[float, float]] = ..., projectionScaleU: Queryable[float] = ..., projectionScaleV: Queryable[float] = ..., radius: Queryable[float] = ..., rotationAngle: Queryable[float] = ..., seamCorrect: bool = ..., smartFit: bool = ..., worldSpace: bool = ...) -> Union[str, bool, Tuple[float, float], float, int, Tuple[float, float, float]]:
    """TpolyProjCmdBase is a base class for the command to create a mapping on the selected polygonal faces.
    Projects a cylindrical map onto an object.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): This flag when set true will create a new map with  
                a the name passed in, if the map does not already exist.  
                Properties: create, query
        imageCenter (Queryable[Tuple[float, float]]?): The center point of the 2D model layout.  
                Default: 0.5, 0.5  
                Properties: create, query, edit
        imageCenterX (Queryable[float]?): Image center X coord.  
                Properties: create, query, edit
        imageCenterY (Queryable[float]?): Image center Y coord.  
                Properties: create, query, edit
        imageScale (Queryable[Tuple[float, float]]?): Specifies the UV scale : Enlarges or reduces the 2D version of the  
                model in U or V space relative to the 2D centerpoint.  
                Default: 1.0, 1.0  
                Properties: create, query, edit
        imageScaleU (Queryable[float]?): Specifies the UV scale : Enlarges or reduces the 2D version of the  
                model in U or V space relative to the 2D centerpoint.  
                Properties: create, query, edit
        imageScaleV (Queryable[float]?): The V scale : Enlarges or reduces the 2D version of the model  
                in V space relative to the 2D centerpoint.  
                Properties: create, query, edit
        insertBeforeDeformers (bool?): This flag specifies if the projection node should be inserted before  
                or after deformer nodes already applied to the shape. Inserting the  
                projection after the deformer leads to texture swimming during  
                animation and is most often undesirable.  
                C: Default is on.  
                Properties: create
        keepImageRatio (bool?): True means keep any image ratio  
                Properties: create
        mapDirection (str?): This flag specifies the mapping direction.  
                'x', 'y' and 'z' projects the map along the corresponding axis.  
                'c' projects along the current camera viewing direction.  
                'p' does perspective projection if current camera is perspective.  
                'b' projects along the best plane fitting the objects selected.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        perInstance (bool?): True if the new map is per-instance, otherwise it is shared.  
                Properties: create
        projectionCenter (Queryable[Tuple[float, float, float]]?): The origin point from which the map is projected.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        projectionCenterX (Queryable[float]?): Projection center X coord.  
                Properties: create, query, edit
        projectionCenterY (Queryable[float]?): Projection center Y coord.  
                Properties: create, query, edit
        projectionCenterZ (Queryable[float]?): Projection center Z coord.  
                Properties: create, query, edit
        projectionHeight (Queryable[float]?): The height of the map relative to the 3D projection axis  
                Properties: create, query, edit
        projectionHorizontalSweep (Queryable[float]?): The angle swept by the 3D projection axis  
                Properties: create, query, edit
        projectionScale (Queryable[Tuple[float, float]]?): The width and the height of the map relative to the 3D projection axis.  
                Default: 180.0, 1.0  
                Properties: create, query, edit
        projectionScaleU (Queryable[float]?): The width of the map relative to the 3D projection axis.  
                Properties: create, query, edit
        projectionScaleV (Queryable[float]?): The height of the map relative to the 3D projection axis.  
                Properties: create, query, edit
        radius (Queryable[float]?): Used by the UI : Manipulator.  
                Default: 10.0  
                Properties: create, query, edit
        rotationAngle (Queryable[float]?): The for the rotation.  
                When the angle is positive, then the map rotates counterclockwise on  
                the mapped model, whereas when it is negative then the map rotates  
                lockwise on the mapped model.  
                Default: 0.0  
                Properties: create, query, edit
        seamCorrect (bool?): Used to indicate fixing UV seams.  
                Default: false  
                Properties: create, query, edit
        smartFit (bool?): True means use the smart fit algorithm  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyDelEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., cleanVertices: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Deletes selected edges, and merges neighboring faces.
    If deletion leaves winged vertices, they may be deleted as well.Notice : only non border edges can be deleted.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        cleanVertices (bool?): If on : delete resulting winged vertices.  
                C: Default is "off".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyDelFacet(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Deletes faces.
    If the result is split into disconnected pieces,
    the pieces (so-called shells) are still
    considered to be one object.Notice : The last face cannot be deleted.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyDelVertex(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Deletes vertices.
    Joins two edges which have a common vertex.
    The vertices must be connected to exactly two edges (so-called "winged").
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyDuplicateAndConnect(*args: str, removeOriginalFromShaders: bool = ..., renameChildren: bool = ...) -> bool:
    """This command duplicates the input polygonal object, connects
    up the outMesh attribute of the original polygonal shape to
    the inMesh attribute of the newly created duplicate shape and
    copies over the shader assignments from the original shape
    to the new duplicated shape.The command will fail if no objects are selected or sent as
    argument or if the object sent as argument is not a polygonal
    object.
    Args:
        removeOriginalFromShaders (bool?): Used to specify if the original object should be removed from  
                the shaders (shadingGroups) that it is a member of. The shader  
                associations will get transferred to the duplicated object, before  
                they are removed from the original. If this flag is specified  
                then the original polygonal object will be drawn in wireframe  
                mode even if all objects are being drawn in shaded mode.  
                Properties: create
        renameChildren (bool?): rename the children nodes of the hierarchy, to make them unique.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def polyDuplicateEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., adjustEdgeFlow: Queryable[float] = ..., deleteEdge: bool = ..., endVertexOffset: Queryable[float] = ..., insertWithEdgeFlow: bool = ..., offset: float = ..., smoothingAngle: Queryable[float] = ..., splitType: Queryable[int] = ..., startVertexOffset: Queryable[float] = ...) -> Union[str, bool, int, float]:
    """Duplicates a series of connected edges (edgeLoop)
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        adjustEdgeFlow (Queryable[float]?): The weight value of the edge vertices to be positioned.  
                Properties: create, query, edit
        deleteEdge (bool?): When true, the end edges are deleted so the end triangles are converted to quads.  
                Properties: create, query, edit
        endVertexOffset (Queryable[float]?): Weight value controlling the offset of the end vertex of the edgeloop.  
                Properties: create, query, edit
        insertWithEdgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Properties: create, query, edit
        offset (float?): Weight value controlling the relative positioning of the new  
                edges. The range of values is [0.0, 1.0].  
                Properties: create
        smoothingAngle (Queryable[float]?): Angle below which new edges will be smoothed  
                Properties: create, query, edit
        splitType (Queryable[int]?): Format: 0. Absolute, 1. Relative, 2. Multi  
                Properties: create, query, edit
        startVertexOffset (Queryable[float]?): Weight value controlling the offset of the start vertex of the edgeloop.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyEditEdgeFlow(*args: str, edit: bool = ..., query: bool = ..., adjustEdgeFlow: float = ..., caching: bool = ..., constructionHistory: bool = ..., edgeFlow: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Edit edges of a polygonal object to respect surface curvature.
    Args:
        adjustEdgeFlow (float?): The weight value of the edge vertices to be positioned.  
                <0. Concave  
                0.  Middle point  
                1.  Surface continuity  
                >1. Convex  
                Default is 1.0  
                Properties: create
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        edgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Default is true.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyEditUV(*args: str, query: bool = ..., angle: Queryable[float] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., relative: bool = ..., rotateRatio: Queryable[float] = ..., rotation: bool = ..., scale: bool = ..., scaleU: Queryable[float] = ..., scaleV: Queryable[float] = ..., uValue: Queryable[float] = ..., uvSetName: Queryable[str] = ..., vValue: Queryable[float] = ...) -> Union[bool, float, str]:
    """Command edits uvs on polygonal objects. When used with the query flag, it
    returns the uv values associated with the specified components.poly, editUV, tweakUV, uvEditing
    Args:
        angle (Queryable[float]?): Specifies the angle value (in degrees) that the uv values are to be rotated  
                by.  
                Properties: create, query
        pivotU (Queryable[float]?): Specifies the pivot value, in the u direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        pivotV (Queryable[float]?): Specifies the pivot value, in the v direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        relative (bool?): Specifies whether this command is editing the values relative to the currently  
                existing values. Default is true;  
                Properties: create, query
        rotateRatio (Queryable[float]?): Specifies the ratio value that the uv values are to be rotated by  
                Default is 1.0  
                Properties: create, query
        rotation (bool?): Specifies whether this command is editing the values with rotation values  
                Properties: create, query
        scale (bool?): Specifies whether this command is editing the values with scale values  
                Properties: create, query
        scaleU (Queryable[float]?): Specifies the scale value in the u direction.  
                Properties: create, query
        scaleV (Queryable[float]?): Specifies the scale value in the v direction.  
                Properties: create, query
        uValue (Queryable[float]?): Specifies the value, in the u direction - absolute if relative flag is false..  
                Properties: create, query
        uvSetName (Queryable[str]?): Specifies the name of the uv set to edit uvs on. If not specified  
                will use the current uv set if it exists.  
                Properties: create, query
        vValue (Queryable[float]?): Specifies the value, in the v direction - absolute if relative flag is false..  
                Properties: create, query

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyEditUVShell(*args: str, query: bool = ..., angle: Queryable[float] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., relative: bool = ..., rotateRatio: Queryable[float] = ..., rotation: bool = ..., scale: bool = ..., scaleU: Queryable[float] = ..., scaleV: Queryable[float] = ..., uValue: Queryable[float] = ..., uvSetName: Queryable[str] = ..., vValue: Queryable[float] = ...) -> Union[bool, float, str]:
    """Command edits uv shells on polygonal objects. When used with the query flag, it
    returns the transformation values associated with the specified components.poly, editUV, tweakUV, uvEditing, uvShells
    Args:
        angle (Queryable[float]?): Specifies the angle value (in degrees) that the uv values are to be rotated  
                by.  
                Properties: create, query
        pivotU (Queryable[float]?): Specifies the pivot value, in the u direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        pivotV (Queryable[float]?): Specifies the pivot value, in the v direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        relative (bool?): Specifies whether this command is editing the values relative to the currently  
                existing values. Default is true;  
                Properties: create, query
        rotateRatio (Queryable[float]?): Specifies the ratio value that the uv values are to be rotated by  
                Default is 1.0  
                Properties: create, query
        rotation (bool?): Specifies whether this command is editing the values with rotation values  
                Properties: create, query
        scale (bool?): Specifies whether this command is editing the values with scale values  
                Properties: create, query
        scaleU (Queryable[float]?): Specifies the scale value in the u direction.  
                Properties: create, query
        scaleV (Queryable[float]?): Specifies the scale value in the v direction.  
                Properties: create, query
        uValue (Queryable[float]?): Specifies the value, in the u direction - absolute if relative flag is false..  
                Properties: create, query
        uvSetName (Queryable[str]?): Specifies the name of the uv set to edit uvs on. If not specified  
                will use the current uv set if it exists.  
                Properties: create, query
        vValue (Queryable[float]?): Specifies the value, in the v direction - absolute if relative flag is false..  
                Properties: create, query

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyEvaluate(*args: str, accurateEvaluation: bool = ..., activeShells: bool = ..., activeUVShells: bool = ..., area: bool = ..., boundingBox: bool = ..., boundingBox2d: bool = ..., boundingBoxComponent: bool = ..., boundingBoxComponent2d: bool = ..., displayStats: bool = ..., edge: bool = ..., edgeComponent: bool = ..., face: bool = ..., faceArea: bool = ..., faceComponent: bool = ..., format: bool = ..., shell: bool = ..., triangle: bool = ..., triangleComponent: bool = ..., uvArea: bool = ..., uvComponent: bool = ..., uvEdgePairs: bool = ..., uvFaceArea: bool = ..., uvSetName: str = ..., uvShell: bool = ..., uvShellIds: bool = ..., uvcoord: bool = ..., uvsInShell: int = ..., vertex: bool = ..., vertexComponent: bool = ..., worldArea: bool = ..., worldFaceArea: bool = ...) -> Any:
    """Returns the required counts on the specified objects.If no objects are specified in the command line, then the
    objects from the active list are used.In MEL, the values are returned in the same order as the flags are set.
    Under Python, there is no concept of argument ordering, so the items are
    returned in a dictionary keyed by the name of the flag.  In Python, if only
    one item is requested, then it will not be returned in a dictionary.For user convenience, if no flag is set, then all values are echoed.All flags (except -fmt/format) are in fact query-flags. For
    user convenience, the -q flag may be ommitted.Some comments for non-formatted output :
    Args:
        accurateEvaluation (bool?): used to get accurate results for the bounding box computation  
                For objects with large vertex counts, accurate evaluation takes more time  
                Properties: create
        activeShells (bool?): returns the indices of active shells as an array of int  
                Properties: create
        activeUVShells (bool?): returns the indices of active UV shells (for the current map if one  
                is not specified) as an array of int  
                Properties: create
        area (bool?): returns the surface area of the object's faces in local space as a float  
                Properties: create
        boundingBox (bool?): returns the object's bounding box in 3d space  
                as 6 floats in MEL: xmin xmax ymin ymax zmin zmax, or as  
                a tuple of three pairs in Python: ((xmin,xmax), (ymin,ymax), (zmin,zmax))  
                Properties: create
        boundingBox2d (bool?): returns the object's uv bounding box (for the current map if one is not specified) in 2d space  
                as 4 floats in MEL : xmin xmax ymin ymax, or as  
                a tuple of three pairs in Python: ((xmin,xmax), (ymin,ymax), (zmin,zmax))  
                Properties: create
        boundingBoxComponent (bool?): returns the bounding box of selected components in 3d space  
                as 6 floats in MEL : xmin xmax ymin ymax zmin zmax, or as  
                a tuple of three pairs in Python: ((xmin,xmax), (ymin,ymax), (zmin,zmax))  
                Properties: create
        boundingBoxComponent2d (bool?): returns the bounding box of selected/specified components uv coordinates in 2d space  
                as 4 floats in MEL : xmin xmax ymin ymax, or as  
                a tuple of two pairs in Python: ((xmin,xmax), (ymin,ymax))  
                Properties: create
        displayStats (bool?): toggles the display of poly statistics for the active View.  
                All other flags are ignored if this flag is specified (Obsolete  
                - refer to the headsUpDisplay command)  
                Properties: create
        edge (bool?): returns the number of edges as an int  
                Properties: create
        edgeComponent (bool?): returns the object's number of selected edges as an int  
                Properties: create
        face (bool?): returns the number of faces as an int  
                Properties: create
        faceArea (bool?): returns the surface area of selected/specified faces in local space as an array of float  
                Properties: create
        faceComponent (bool?): returns the object's number of selected faces as an int  
                Properties: create
        format (bool?): used to display the results as an explicit sentence  
                Properties: create
        shell (bool?): returns the number of shells (disconnected pieces) as an int  
                Properties: create
        triangle (bool?): returns the number of triangles as an int  
                Properties: create
        triangleComponent (bool?): returns the number of triangles of selected components as an int  
                Properties: create
        uvArea (bool?): returns the UV area of the object's faces in 2d space as a float  
                Properties: create
        uvComponent (bool?): returns the object's number of selected uv coordinates as an int  
                Properties: create
        uvEdgePairs (bool?): returns the pairs of UVs that are on the selected/specified edges  
                Properties: create
        uvFaceArea (bool?): returns the UV area of selected/specified faces in 2d space as an array of float  
                Properties: create
        uvSetName (str?): used when querying texture vertices to specify the uv set.  If a uv set  
                is not specified then the current map for the object will be used  
                Properties: create
        uvShell (bool?): returns the number of UV shells (for the current map if one is not  
                specified) as an int  
                Properties: create
        uvShellIds (bool?): returns the UV shell indices for selected/specified faces or UVs as an array of int  
                (for the current map if one is not specified), one shell index per each face/UV.  
                Properties: create
        uvcoord (bool?): returns the number of uv coordinates (for the current map if one is  
                not specified) as an int  
                Properties: create
        uvsInShell (int?): returns all UVs inside specified shell(for the current map if one is not specified), use activeUVShells  
                to get shell indices for current selection, use uvShellIds to get shell indices for specified faces or UVs  
                Properties: create
        vertex (bool?): returns the number of vertices as an int  
                Properties: create
        vertexComponent (bool?): returns the object's number of selected vertices as an int  
                Properties: create
        worldArea (bool?): returns the surface area of the object's faces in world space as a float  
                Properties: create
        worldFaceArea (bool?): returns the surface area of selected/specified faces in world space as an array of float  
                Properties: create

    Returns:
        Any: a MEL array of values, a Python dictionary, or a string, depending on
            the format requested and the language called from.

    Example:
    """

def polyExtrudeEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createCurve: bool = ..., divisions: Queryable[int] = ..., gain: Queryable[Multiuse[float]] = ..., inputCurve: str = ..., keepFacesTogether: bool = ..., localCenter: Queryable[int] = ..., localDirection: Queryable[Tuple[float, float, float]] = ..., localDirectionX: Queryable[float] = ..., localDirectionY: Queryable[float] = ..., localDirectionZ: Queryable[float] = ..., localRotate: Queryable[Tuple[float, float, float]] = ..., localRotateX: Queryable[float] = ..., localRotateY: Queryable[float] = ..., localRotateZ: Queryable[float] = ..., localScale: Queryable[Tuple[float, float, float]] = ..., localScaleX: Queryable[float] = ..., localScaleY: Queryable[float] = ..., localScaleZ: Queryable[float] = ..., localTranslate: Queryable[Tuple[float, float, float]] = ..., localTranslateX: Queryable[float] = ..., localTranslateY: Queryable[float] = ..., localTranslateZ: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset: Queryable[float] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., random: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., smoothingAngle: Queryable[float] = ..., taper: Queryable[float] = ..., taperCurve_FloatValue: Queryable[float] = ..., taperCurve_Interp: Queryable[int] = ..., taperCurve_Position: Queryable[float] = ..., thickness: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ..., twist: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, bool, int, Multiuse[float], Tuple[float, float, float], float]:
    """Extrude edges separately or together.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createCurve (bool?): If true then the operation can create a curve.  
                Properties: create
        divisions (Queryable[int]?): How many internal edges are creating when pulling.  
                Default: 1  
                Properties: create, query, edit
        gain (Queryable[Multiuse[float]]?): Gain factor per component. Can be painted using Artisan.  
                Default: 1.0  
                Properties: create, query, edit, multiuse
        inputCurve (str?): This flag specifies the name of the curve to be used as input for the operation.  
                Properties: create
        keepFacesTogether (bool?): How to extrude edges.  
                If "on", extruded faces produced from the edges being extruded  
                will be kept together. Otherwise they are pulled independently.  
                Default: true  
                Properties: create, query, edit
        localCenter (Queryable[int]?): Local center on the edge : 0=Middle point, 1=Start point, 2=End point.  
                Default: 0  
                Properties: create, query, edit
        localDirection (Queryable[Tuple[float, float, float]]?): Direction to determine X axis for local space.  
                Default: 1.0, 0.0, 0.0  
                Properties: create, query, edit
        localDirectionX (Queryable[float]?): X coord of the X axis.  
                Properties: create, query, edit
        localDirectionY (Queryable[float]?): Y coord of the X axis.  
                Properties: create, query, edit
        localDirectionZ (Queryable[float]?): Z coord of the X axis.  
                Properties: create, query, edit
        localRotate (Queryable[Tuple[float, float, float]]?): The local rotations.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localRotateX (Queryable[float]?): Local rotate X coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateY (Queryable[float]?): Local rotate Y coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateZ (Queryable[float]?): Local rotate Z coord : Rotation along the normal.  
                The range is [0, 360].  
                Properties: create, query, edit
        localScale (Queryable[Tuple[float, float, float]]?): Local Scale.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        localScaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        localScaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        localScaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        localTranslate (Queryable[Tuple[float, float, float]]?): Local translate.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localTranslateX (Queryable[float]?): Local translation X coord.  
                Properties: create, query, edit
        localTranslateY (Queryable[float]?): Local translation Y coord.  
                Properties: create, query, edit
        localTranslateZ (Queryable[float]?): Local translation Z coord : Move along the normal.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset (Queryable[float]?): Edges are moved this distance in the opposite direction of the edge.  
                Default: 0.0  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot for scaling and rotation.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Pivot X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Pivot Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Pivot Z coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value for all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): Rotation angles around X, Y, Z.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        rotateX (Queryable[float]?): Rotation angle around X.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): Rotation angle around Y.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): Rotation angle around Z.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scaling vector.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        scaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Angle below which new edges will be smoothed  
                Default: kPi/6.0  
                Properties: create, query, edit
        taper (Queryable[float]?): Taper or Scale along the extrusion path  
                Default: 1.0  
                Properties: create, query, edit
        taperCurve_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        taperCurve_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        taperCurve_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        thickness (Queryable[float]?): Edges are moved this distance in the direction of the connected face normals.  
                Default: 0.0f  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): Translation vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        translateX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        translateY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        twist (Queryable[float]?): Twist or Rotation along the extrusion path  
                Default: 0.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyExtrudeFacet(*args: str, edit: bool = ..., query: bool = ..., attraction: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., createCurve: bool = ..., divisions: Queryable[int] = ..., gain: Queryable[Multiuse[float]] = ..., gravity: Queryable[Tuple[float, float, float]] = ..., gravityX: Queryable[float] = ..., gravityY: Queryable[float] = ..., gravityZ: Queryable[float] = ..., inputCurve: str = ..., keepFacesTogether: bool = ..., keepFacetTogether: bool = ..., localCenter: Queryable[int] = ..., localDirection: Queryable[Tuple[float, float, float]] = ..., localDirectionX: Queryable[float] = ..., localDirectionY: Queryable[float] = ..., localDirectionZ: Queryable[float] = ..., localRotate: Queryable[Tuple[float, float, float]] = ..., localRotateX: Queryable[float] = ..., localRotateY: Queryable[float] = ..., localRotateZ: Queryable[float] = ..., localScale: Queryable[Tuple[float, float, float]] = ..., localScaleX: Queryable[float] = ..., localScaleY: Queryable[float] = ..., localScaleZ: Queryable[float] = ..., localTranslate: Queryable[Tuple[float, float, float]] = ..., localTranslateX: Queryable[float] = ..., localTranslateY: Queryable[float] = ..., localTranslateZ: Queryable[float] = ..., magnX: Queryable[float] = ..., magnY: Queryable[float] = ..., magnZ: Queryable[float] = ..., magnet: Queryable[Tuple[float, float, float]] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset: Queryable[float] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., random: Queryable[float] = ..., reverseAllFaces: bool = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., smoothingAngle: Queryable[float] = ..., taper: Queryable[float] = ..., taperCurve_FloatValue: Queryable[float] = ..., taperCurve_Interp: Queryable[int] = ..., taperCurve_Position: Queryable[float] = ..., thickness: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ..., twist: Queryable[float] = ..., weight: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, float, bool, int, Multiuse[float], Tuple[float, float, float]]:
    """Extrude faces. Faces can be extruded separately or together, and
    manipulations can be performed either in world or object space.
    Args:
        attraction (Queryable[float]?): Attraction, related to magnet.  
                The range is [-2.0, 2.0].  
                Default: 0.0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createCurve (bool?): If true then the operation can create a curve.  
                Properties: create
        divisions (Queryable[int]?): How many divisions should the extrusion be broken-up into.  
                Default: 1  
                Properties: create, query, edit
        gain (Queryable[Multiuse[float]]?): Gain factor per component. Can be painted using Artisan.  
                Default: 1.0  
                Properties: create, query, edit, multiuse
        gravity (Queryable[Tuple[float, float, float]]?): The gravity vector.  
                Default: 0.0, -1.0, 0.0  
                Properties: create, query, edit
        gravityX (Queryable[float]?): Gravity X coord.  
                Properties: create, query, edit
        gravityY (Queryable[float]?): Gravity Y coord.  
                Properties: create, query, edit
        gravityZ (Queryable[float]?): Gravity Z coord.  
                Properties: create, query, edit
        inputCurve (str?): This flag specifies the name of the curve to be used as input for the operation.  
                Properties: create
        keepFacesTogether (bool?): How to extrude faces.  
                If "on", faces are pulled together (connected ones stay connected),  
                otherwise they are pulled independently.  
                Default: true  
                Properties: create, query, edit
        keepFacetTogether (bool?): How to extrude edges.  
                If "on", extruded faces produced from the edges being extruded  
                will be kept together. Otherwise they are pulled independently.  
                Default: true  
                Properties: create, query, edit
        localCenter (Queryable[int]?): Local center on the edge : 0=Middle point, 1=Start point, 2=End point.  
                Default: 0  
                Properties: create, query, edit
        localDirection (Queryable[Tuple[float, float, float]]?): Direction to determine X axis for local space.  
                Default: 1.0, 0.0, 0.0  
                Properties: create, query, edit
        localDirectionX (Queryable[float]?): X coord of the X axis.  
                Properties: create, query, edit
        localDirectionY (Queryable[float]?): Y coord of the X axis.  
                Properties: create, query, edit
        localDirectionZ (Queryable[float]?): Z coord of the X axis.  
                Properties: create, query, edit
        localRotate (Queryable[Tuple[float, float, float]]?): The local rotations.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localRotateX (Queryable[float]?): Local rotate X coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateY (Queryable[float]?): Local rotate Y coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateZ (Queryable[float]?): Local rotate Z coord : Rotation along the normal.  
                The range is [0, 360].  
                Properties: create, query, edit
        localScale (Queryable[Tuple[float, float, float]]?): Local Scale.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        localScaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        localScaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        localScaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        localTranslate (Queryable[Tuple[float, float, float]]?): Local translate.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localTranslateX (Queryable[float]?): Local translation X coord.  
                Properties: create, query, edit
        localTranslateY (Queryable[float]?): Local translation Y coord.  
                Properties: create, query, edit
        localTranslateZ (Queryable[float]?): Local translation Z coord : Move along the normal.  
                Properties: create, query, edit
        magnX (Queryable[float]?): Magnet X coord.  
                Properties: create, query, edit
        magnY (Queryable[float]?): Magnet Y coord.  
                Properties: create, query, edit
        magnZ (Queryable[float]?): Magnet Z coord.  
                Properties: create, query, edit
        magnet (Queryable[Tuple[float, float, float]]?): The magnet vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset (Queryable[float]?): Local offset. Faces are moved this distance towards the inside of the face.  
                Default: 0.0  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot for scaling and rotation.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Pivot X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Pivot Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Pivot Z coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value for all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        reverseAllFaces (bool?): If "on", original faces are reversed in case  
                of extruding all faces.  
                Default: true  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): Rotation angles around X, Y, Z.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        rotateX (Queryable[float]?): Rotation angle around X.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): Rotation angle around Y.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): Rotation angle around Z.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scaling vector.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        scaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Angle below which new edges will be smoothed  
                Default: kPi/6.0  
                Properties: create, query, edit
        taper (Queryable[float]?): Taper or Scale along the extrusion path  
                Default: 1.0  
                Properties: create, query, edit
        taperCurve_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        taperCurve_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        taperCurve_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        thickness (Queryable[float]?): Faces are moved outwards from their original position to give  
                the object a consistent thickess.  
                Default: 0.0f  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): Translation vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        translateX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        translateY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        twist (Queryable[float]?): Twist or Rotation along the extrusion path  
                Default: 0.0  
                Properties: create, query, edit
        weight (Queryable[float]?): The weight, related to gravity.  
                Default: 0.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyExtrudeVertex(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., divisions: Queryable[int] = ..., length: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., width: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Command that extrudes selected vertices outwards.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        divisions (Queryable[int]?): This flag specifies the number of subdivisions.  
                C: Default is 1  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        length (Queryable[float]?): This flag specifies the length of the vertex extrusion.  
                C: Default is 0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        width (Queryable[float]?): This flag specifies the width of the vertex extrusion.  
                C: Default is 0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyFlipEdge(*args: str) -> bool:
    """Command to flip the edges shared by 2 adjacent triangles.
    When used with the edit flag, new edges can be added to the
    same node, instead of creating a separate node in the chain.poly, flip, turn, edge
    Returns:
        bool: Success or Failure.

    Example:
    """

def polyFlipUV(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., cutUV: bool = ..., flipType: Queryable[int] = ..., insertBeforeDeformers: bool = ..., local: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., usePivot: bool = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Flip (mirror) the UVs (in texture space) of input polyFaces, about either
    the U or V axis..
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): Set to true if a new map should be created  
                Properties: create
        cutUV (bool?): Cut UV edges when flipping some components on a UV shell  
                C: Default is on.  
                Q: When queried, returns an int.  
                Properties: create, query, edit
        flipType (Queryable[int]?): Flip along U or V direction.  
              
              
                0 Horizontal  
              
              
                1 Vertical  
              
              
                C: Default is 0.  
                Q: When queried, returns an int.  
                Properties: create, query, edit
        insertBeforeDeformers (bool?): Set to true if the new node created should inserted before any deformer nodes.  
                Properties: create
        local (bool?): Flips in the local space of the input faces.  
                C: Default is on.  
                Q: When queried, returns an int.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivotU (Queryable[float]?): Specifies the pivot value, in the U direction.  
                Properties: create, query, edit
        pivotV (Queryable[float]?): Specifies the pivot value, in the V direction.  
                Properties: create, query, edit
        usePivot (bool?): Flip using pivot or not.  
                C: Default is off.  
                Q: When queried, returns an int.  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyForceUV(*args: str, cameraProjection: bool = ..., createNewMap: bool = ..., flipHorizontal: bool = ..., flipVertical: bool = ..., g: bool = ..., local: bool = ..., normalize: str = ..., numItems: int = ..., preserveAspectRatio: bool = ..., unitize: bool = ..., unshare: bool = ..., uvSetName: str = ...) -> bool:
    """A set of functionalities can be called through this command.  The input for
    this command is a set of faces.  Based on the arguments passed, the UVs for
    these selected faces can be created.Based on the current view direction/orientation, the UVs are generated and
    assigned to the faces.  Any previously assigned UV information will be lost.The UVs are computed based on the plane defined by the user, and is applied
    to the selected faces.  This tool has 2 phases.  In the first phase,
    the faces to be mapped (faces to which UVs are to be created) are selected.
    In the second phase, the points (vertices, CVs) that define the
    projecting plane are selected.  Any previously assigned UV information will
    be lost.A new set of unitized UVs are generated and assigned to the faces.
            Any previously assigned UV information will be lost.Force the specified UV to be unshared by possibly creating new UVs.  Any previously assigned UV information will be lost.poly, uv, normalize, unitize, flip, bestPlane
    Args:
        cameraProjection (bool?): Project the UVs based on the camera position/orientation  
                Properties: create
        createNewMap (bool?): Create new map if it does not exist.  
                Properties: create
        flipHorizontal (bool?): OBSOLETE flag.  Use polyFlipUV instead.  
                Properties: create
        flipVertical (bool?): OBSOLETE flag.  Use polyFlipUV instead.  
                Properties: create
        g (bool?): OBSOLETE flag.  
                Properties: create
        local (bool?): OBSOLETE flag.  
                Properties: create
        normalize (str?): OBSOLETE flag.  Use polyNormalizeUV instead.  
                Properties: create
        numItems (int?): This flag is only used for the best plane texturing  
                        of polygonal faces.  This flag should be followed by a  
                        selection list. If not specified, the selected objects will  
                        be used (in the order they were selected).   
                        This flag specifies the number of items (leading) in the  
                        selection list that should be used for the mapping.  
                        The trailing items will be used for computing the  
                        plane (See example below).  The best plane texturing  
                        is better suited for using interactively from within its context.  
                        You can type "BestPlaneTexturingTool"  
                        in the command window OR (EditPolygons->Texture->BestPlaneTexturing  
                        from the Menu) to enter its context.  
                Properties: create
        preserveAspectRatio (bool?): OBSOLETE flag.  
                Properties: create
        unitize (bool?): To unitize the UVs of the selected faces  
                Properties: create
        unshare (bool?): To unshare tye specified UV  
                Properties: create
        uvSetName (str?): Specifies name of the uv set to work on  
                Properties: create

    Returns:
        bool: true/false

    Example:
    """

def polyGeoSampler(*args: Any, edit: bool = ..., alphaBlend: str = ..., averageColor: bool = ..., clampAlphaMax: float = ..., clampAlphaMin: float = ..., clampRGBMax: Tuple[float, float, float] = ..., clampRGBMin: Tuple[float, float, float] = ..., colorBlend: str = ..., colorDisplayOption: bool = ..., computeShadows: bool = ..., displaceGeometry: bool = ..., flatShading: bool = ..., ignoreDoubleSided: bool = ..., lightingOnly: bool = ..., reuseShadows: bool = ..., sampleByFace: bool = ..., scaleFactor: float = ..., shareUV: bool = ..., useLightShadows: bool = ...) -> bool:
    """This command performs a render sampling of surface color and transparency
    for each selected vertex or face and stores the sampled data
    as either the color value, or uses the sampled data to displace
    the affected vertices or faces by a sampled data value.
    Transparency is not used for displacement, and displacement
    is performed along vertex normals.
    The sampled data value used can be pre-scaled by a user defined
    amount.
    Additionally, the normals chosen for sampling can be overridden
    using a "flat" shading option. This option basically means
    to always use the normals of the faces when computing
    sampling values. This may be a desired if the user
    wishes to override an edge smoothness factor. Basically
    with the "flat" shading option on, edges are always
    considered to be hard.
    Note that displacement sampling will result
    in the -sampleByFace option to be turned
    off, since a displacement of a vertex
    always affects the faces the vertex
    is connected to.
    Finally, it is possible to force the storage of shared
    colors per vertex, and / or force the usage of unshared
    UV values.
    The computation of the resulting color is as follows:The analogous computation is done for computing the resulting alpha
    value.
    The command requires that there be a camera selected in your scene in
    order to work properly in -batch or -prompt mode.poly, sampling, GeoSampler
    Args:
        alphaBlend (str?): When specified, indicates the type of alpha blend to  
                be applied. Options are: "none", "overwrite", "add",  
                "subtract", "multiply", "divide", "average".  
                This option only applies when colors are being  
                set. The default if this argument is not  
                specified is "overwrite".  
                The "none" options  
                to not overwrite the existing value.  
                Properties: create, edit
        averageColor (bool?): When used, will mean to force the storage of shared colors  
                for vertex level sampling. By default vertex level sampling  
                stores unshared colors.  
                Properties: create, edit
        clampAlphaMax (float?): When used, will mean to clamp the storage of alpha  
                to a maximum  
                Properties: create, edit
        clampAlphaMin (float?): When used, will mean to clamp the storage of alpha  
                to a minimum  
                Properties: create, edit
        clampRGBMax (Tuple[float, float, float]?): When used, will mean to clamp the storage of RGB  
                color to a maximum  
                Properties: create, edit
        clampRGBMin (Tuple[float, float, float]?): When used, will mean to clamp the storage of RGB  
                color to a minimum  
                Properties: create, edit
        colorBlend (str?): When specified, indicates the type of color blend to  
                be applied. Options are: "none", "overwrite", "add",  
                "subtract", "multiply", "divide", "average".  
                This option only applies when colors are being  
                set. The default if this argument is not  
                specified is "overwrite".  
                The "none" options  
                to not overwrite the existing value.  
                Properties: create, edit
        colorDisplayOption (bool?): Change the display options on the mesh to display the vertex colors.  
                Properties: create, edit
        computeShadows (bool?): When used, shadow maps will be computed, saved, and reused during the sampling  
                process.  
                Properties: create, edit
        displaceGeometry (bool?): When used, geometry will be displaced along the normals at  
                the sampling positions, as opposed to storing color values. The  
                default is to store colors.  
                Properties: create, edit
        flatShading (bool?): When used, flat shaded sampling will be computed. The default  
                is smooth shading.  
                Properties: create, edit
        ignoreDoubleSided (bool?): When specified, the double sided flag will be ignored  
                for prelighting.  
                Properties: create, edit
        lightingOnly (bool?): When used, incoming illumination will be computed as opposed to  
                surface color an tranparency  
                Properties: create, edit
        reuseShadows (bool?): When used, if shadow maps were previosly computed and saved, then  
                they will be reused during the sampling process. The computeShadows  
                option must be enabled for this option to apply.  
                Properties: create, edit
        sampleByFace (bool?): When used, sample will occur at a per face level versus a per  
                vertex level, which is the default behaviour  
                Properties: create, edit
        scaleFactor (float?): When used, will scale the sampled value by the specified amount.  
                The default scale factor is 1.0. Negative values are acceptable  
                for displacement, but not for color values.  
                Properties: create, edit
        shareUV (bool?): When used, UVs are shared at a vertex when sampled.  
                By default UVs are forced to be unshared.  
                Properties: create, edit
        useLightShadows (bool?): When used, will use each lights shadow map options. Otherwise  
                these options will be overrridden when the computeShadows, and/or  
                reusedShadows option is enabled.  
                Properties: create, edit

    Returns:
        bool: Success or Failure

    Example:
    """

def polyHelix(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., coils: Queryable[float] = ..., constructionHistory: bool = ..., createUVs: Queryable[int] = ..., direction: Queryable[int] = ..., height: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., roundCap: bool = ..., subdivisionsAxis: Queryable[int] = ..., subdivisionsCaps: Queryable[int] = ..., subdivisionsCoil: Queryable[int] = ..., texture: Queryable[int] = ..., useOldInitBehaviour: bool = ..., width: Queryable[float] = ...) -> Union[List[str], bool, float, int]:
    """The polyHelix command creates a new polygonal helix.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        coils (Queryable[float]?): Number of coils.  
                Default: 3  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize  
                3. Normalize and Preserve Aspect Ratio  
                Default: 2  
                Properties: create, query, edit
        direction (Queryable[int]?): What should be the direction of the coil.  
                0=Clockwise; 1=Counterclockwise  
                Default: 1  
                Properties: create, query, edit
        height (Queryable[float]?): Height of the helix.  
                Default: 2.0  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): Radius of tube.  
                Default: 0.4  
                Properties: create, query, edit
        roundCap (bool?): To indicate whether we need a round cap  
                Default: false  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): Subdivisions around the axis.  
                Default: 8  
                Properties: create, query, edit
        subdivisionsCaps (Queryable[int]?): Subdivisions along the thickness caps.  
                Default: 0  
                Properties: create, query, edit
        subdivisionsCoil (Queryable[int]?): Subdivisions along the coil.  
                Default: 50  
                Properties: create, query, edit
        texture (Queryable[int]?): What texture mechanism to be applied  
                0=No textures; 1=Object; 2=Faces  
                Default: 2  
                Properties: create, query, edit
        useOldInitBehaviour (bool?): Create the helix with base on the origin as in Maya V8.0 and below  
                Otherwise create helix centred at origin  
                Default: false  
                Properties: create, query, edit
        width (Queryable[float]?): Width of the helix.  
                Default: 2.0  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyHole(*args: str, edit: bool = ..., query: bool = ..., assignHole: bool = ..., createHistory: bool = ...) -> bool:
    """Command to set and clear holes on given faces.poly, hole, smooth, subdiv
    Args:
        assignHole (bool?): Assign the selected faces to be hole or unassign the hole faces to be non-hole. By default, the command will  
                assign faces to be hole.  
                Properties: create, query, edit
        createHistory (bool?): For objects that have no construction history, this flag can be used  
                to force the creation of construction history for hole.  By default,  
                history is not created if the object has no history.  Regardless of this  
                flag, history is always created if the object already has history.  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyInfo(*args: str, edgeToFace: bool = ..., edgeToVertex: bool = ..., faceNormals: bool = ..., faceToEdge: bool = ..., faceToVertex: bool = ..., invalidEdges: bool = ..., invalidVertices: bool = ..., laminaFaces: bool = ..., nonManifoldEdges: bool = ..., nonManifoldUVEdges: bool = ..., nonManifoldUVs: bool = ..., nonManifoldVertices: bool = ..., vertexToEdge: bool = ..., vertexToFace: bool = ...) -> str:
    """Command queries topological information on polygonal objects and components.
    So, the command will require the following to be specified:
            - selection list to queryquery, polygons, information, topology
    Args:
        edgeToFace (bool?): Returns the faces that share the specified edge. Requires edges to be selected.  
                Properties: create
        edgeToVertex (bool?): Returns the vertices defining an edge. Requires edges to be selected.  
                Properties: create
        faceNormals (bool?): Returns face normals of the specified object. If faces are selected the command  
                returns the face normals of selected faces. Else it returns the face normals  
                of all the faces of the object.  
                Properties: create
        faceToEdge (bool?): Returns the edges defining a face. Requires faces to be selected.  
                Properties: create
        faceToVertex (bool?): Returns the vertices defining a face. Requires faces to be selected.  
                Properties: create
        invalidEdges (bool?): Find all edges that are not associated with any face in the mesh.  
                Properties: create
        invalidVertices (bool?): Find all vertices that are not associated with any face in the mesh.  
                Properties: create
        laminaFaces (bool?): Find all lamina faces in the specified objects.  
                Properties: create
        nonManifoldEdges (bool?): Find all non-manifold edges in the specified objects.  
                Properties: create
        nonManifoldUVEdges (bool?): Find all non-manifold UV edges in the specified objects.  
                Properties: create
        nonManifoldUVs (bool?): Find all non-manifold UVs in the specified objects.  
                Properties: create
        nonManifoldVertices (bool?): Find all non-manifold vertices in the specified objects.  
                Properties: create
        vertexToEdge (bool?): Returns the Edges connected to a vertex. Requires vertices to be selected.  
                Properties: create
        vertexToFace (bool?): Returns the faces that share the specified vertex. Requires vertices to  
                be selected.  
                Properties: create

    Returns:
        str: Components

    Example:
    """

def polyInstallAction(*args: Any, query: bool = ..., commandName: bool = ..., convertSelection: bool = ..., installConstraint: bool = ..., installDisplay: bool = ..., keepInstances: bool = ..., uninstallConstraint: bool = ..., uninstallDisplay: bool = ...) -> Union[List[str], bool]:
    """Installs/uninstalls several things to help the user to perform the
    specified action :
    Args:
        commandName (bool?): return as a string the name of the command previously installed  
                Properties: query
        convertSelection (bool?): convert all polys selected in object mode  
                into their full matching component selection. For example : if a polyMesh is selected,  
                polyInstallAction -cs polyCloseBorder  
                will select all border edges.  
                Properties: create
        installConstraint (bool?): C: install selection pickmask and internal constraints for actionname  
                Q: returns 1 if any internal constraint is set for current action  
                Properties: create, query
        installDisplay (bool?): C: install display attributes for actionname  
                Q: returns 1 if any display is set for current action  
                Properties: create, query
        keepInstances (bool?): Convert components for all selected instances rather than only the first selected instance.  
                Properties: create
        uninstallConstraint (bool?): uninstall internal constraints previously installed  
                Properties: create
        uninstallDisplay (bool?): uninstall display attributes previously installed  
                Properties: create

    Returns:
        List[str]: When installing constraint, returns as an array of strings the
            items on which the installed command will act on. otherwise, returns nothing

    Example:
    """

def polyIterOnPoly(*args: Any, **kwargs: Any) -> None: ...
def polyLayoutUV(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., flipReversed: bool = ..., layout: Queryable[int] = ..., layoutMethod: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., percentageSpace: Queryable[float] = ..., rotateForBestFit: Queryable[int] = ..., scale: Queryable[int] = ..., separate: Queryable[int] = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Move UVs in the texture plane to avoid overlaps.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        flipReversed (bool?): If this flag is turned on, the reversed UV pieces are fliped.  
                Properties: create, query, edit
        layout (Queryable[int]?): How to move the UV pieces, after cuts are applied:  
                0 No move is applied.  
                1 Layout the pieces along the U axis.  
                2 Layout the pieces in a square shape.  
                Properties: create, query, edit
        layoutMethod (Queryable[int]?): Which layout method to use:  
                0 Block Stacking.  
                1 Shape Stacking.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        percentageSpace (Queryable[float]?): When layout is set to square, this value is a percentage of  
                the texture area which is added around each UV piece. It can be  
                used to ensure each UV piece uses different pixels in the texture.  
                Maximum value is 5 percent.  
                Properties: create, query, edit
        rotateForBestFit (Queryable[int]?): 0 No rotation is applied.  
                1 Only allow 90 degree rotations.  
                2 Allow free rotations.  
                Properties: create, query, edit
        scale (Queryable[int]?): How to scale the pieces, after move and cuts:  
                0 No scale is applied.  
                1 Uniform scale to fit in unit square.  
                2 Non proportional scale to fit in unit square.  
                Properties: create, query, edit
        separate (Queryable[int]?): Which UV edges should be cut:  
                0 No cuts.  
                1 Cut only along folds.  
                2 Make all necessary cuts to avoid all intersections.  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyListComponentConversion(*args: str, border: bool = ..., fromEdge: bool = ..., fromFace: bool = ..., fromUV: bool = ..., fromVertex: bool = ..., fromVertexFace: bool = ..., internal: bool = ..., toEdge: bool = ..., toFace: bool = ..., toUV: bool = ..., toVertex: bool = ..., toVertexFace: bool = ..., uvShell: bool = ..., vertexFaceAllEdges: bool = ...) -> List[str]:
    """This command converts poly components from one or more types
    to another one or more types, and returns the list of the
    conversion. It does not change anything of the current database.
    Args:
        border (bool?): Indicates that the converted components must  
                be on the border of the selection. If it is not provided, the  
                converted components will be the related ones.  
                Properties: create
        fromEdge (bool?):   
                Properties: create
        fromFace (bool?):   
                Properties: create
        fromUV (bool?):   
                Properties: create
        fromVertex (bool?):   
                Properties: create
        fromVertexFace (bool?): Indicates the component type to convert from.  
                If none of them is provided, it is assumed to be  
                all of them, including poly objects.  
                Properties: create
        internal (bool?): Indicates that the converted components must  
                be totally envolved by the source components. E.g.  
                a converted face must have all of its surrounding  
                vertices being given. If it is not provided, the  
                converted components will be the related ones.  
                Properties: create
        toEdge (bool?):   
                Properties: create
        toFace (bool?):   
                Properties: create
        toUV (bool?):   
                Properties: create
        toVertex (bool?):   
                Properties: create
        toVertexFace (bool?): Indicates the component type to convert to.  
                If none of them is provided, it is assumed to  
                the object.  
                Properties: create
        uvShell (bool?): Will return UV components within the same UV shell. Only works with -tuv and -fuv flags.  
                Properties: create
        vertexFaceAllEdges (bool?): When converting from face vertices to edges, indicates  
                that all edges with an end at the face vertex should be included.  
                Without this flag, the default behaviour is to only include  
                one edge per face vertex.  
                Properties: create

    Returns:
        List[str]: List of poly components

    Example:
    """

def polyMapCut(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., moveratio: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, float, int]:
    """Cut along edges of the texture mapping. The cut edges become map borders.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        moveratio (Queryable[float]?): Cut open ratio related to the neighbor edge length of cut edge.  
                Properties: query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMapDel(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Deletes texture coordinates (UVs) from selected faces.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMapSew(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Sew border edges in texture space. Selected edges must be map borders.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMapSewMove(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., limitPieceSize: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., numberFaces: Queryable[int] = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """This command can be used to Move and Sew together separate UV pieces
    along geometric edges. UV pieces that correspond to the same geometric
    edge, are merged together by moving the smaller piece to the larger
    one.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        limitPieceSize (bool?): When on, this flag specifies that the face number limit  
                described above should be used.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        numberFaces (Queryable[int]?): Maximum number of faces in a UV piece. When trying to  
                combine two UV pieces into a single one, the merge operation is  
                rejected if the smaller piece has more faces than the number specified  
                by this flag.  
                This flag is only used when limitPieceSize is set to on.  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMergeEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., firstEdge: Queryable[int] = ..., mergeMode: Queryable[int] = ..., mergeTexture: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., secondEdge: Queryable[int] = ...) -> Union[str, bool, int]:
    """Sews two border edges together.The new edge is located either on the first, last,
    or between both selected edges, depending on the mode.Both edges must belong to the same object, and orientations must match
    (i.e. normals on corresponding faces must point in the same direction).Edge flags are mandatory.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        firstEdge (Queryable[int]?): First edge to merge.  
                Invalid default value to force the value to be set.  
                Default: -1  
                Properties: create, query, edit
        mergeMode (Queryable[int]?): Merge mode : 0=first, 1=halfway between both edges, 2=second.  
                Default: 1  
                Properties: create, query, edit
        mergeTexture (bool?): Boolean which is used to decide if uv coordinates should be  
                merged or not - along with the geometry.  
                Default: false  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        secondEdge (Queryable[int]?): Second edge to merge.  
                Invalid default value to force the value to be set.  
                Default: -1  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMergeEdgeCtx(*args: Any, edit: bool = ..., query: bool = ..., activeNodes: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., immediate: bool = ..., name: str = ..., previous: bool = ..., reset: bool = ..., toolNode: bool = ..., caching: bool = ..., constructionHistory: bool = ..., firstEdge: Queryable[int] = ..., mergeMode: Queryable[int] = ..., mergeTexture: bool = ..., nodeState: Queryable[int] = ..., secondEdge: Queryable[int] = ...) -> Union[str, bool, int]:
    """Sews two border edges together.The new edge is located either on the first, last,
    or between both selected edges, depending on the mode.Both edges must belong to the same object, and orientations must match
    (i.e. normals on corresponding faces must point in the same direction).Edge flags are mandatory.Create a new context to merge edges on polygonal objects
    Args:
        activeNodes (bool?): Return the active nodes in the tool  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        immediate (bool?): Acts on the object not the tool defaults  
                Properties: edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        previous (bool?): Reset to previously stored values  
                Properties: edit
        reset (bool?): Reset to default values  
                Properties: edit
        toolNode (bool?): Return the node used for tool defaults  
                Properties: query
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        firstEdge (Queryable[int]?): First edge to merge.  
                Invalid default value to force the value to be set.  
                Default: -1  
                Properties: create, query, edit
        mergeMode (Queryable[int]?): Merge mode : 0=first, 1=halfway between both edges, 2=second.  
                Default: 1  
                Properties: create, query, edit
        mergeTexture (bool?): Boolean which is used to decide if uv coordinates should be  
                merged or not - along with the geometry.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        secondEdge (Queryable[int]?): Second edge to merge.  
                Invalid default value to force the value to be set.  
                Default: -1  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMergeFacet(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., firstFacet: Queryable[int] = ..., mergeMode: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., secondFacet: Queryable[int] = ...) -> Union[str, bool, int]:
    """The second face becomes a hole in the first face.The new holed face is located either on the first, last,
    or between both selected faces, depending on the mode.Both faces must belong to the same object.Facet flags are mandatory.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        firstFacet (Queryable[int]?): The number of the first (outer) face to merge.  
                Properties: create, query, edit
        mergeMode (Queryable[int]?): This flag specifies how faces are merged:  
                0. moves second face to first one  
                1. moves both faces to average  
                2. moves first face to second one  
                3, 4, 5. same as above, except faces are projected but not centred  
                6. Nothing moves.  
                C: Default is None (6).  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        secondFacet (Queryable[int]?): The number of the second (hole) face to merge.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMergeFacetCtx(*args: Any, edit: bool = ..., query: bool = ..., activeNodes: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., immediate: bool = ..., name: str = ..., previous: bool = ..., reset: bool = ..., toolNode: bool = ..., caching: bool = ..., constructionHistory: bool = ..., firstFacet: Queryable[int] = ..., mergeMode: Queryable[int] = ..., nodeState: Queryable[int] = ..., secondFacet: Queryable[int] = ...) -> Union[str, bool, int]:
    """The second face becomes a hole in the first face.The new holed face is located either on the first, last,
    or between both selected faces, depending on the mode.Both faces must belong to the same object.Facet flags are mandatory.Create a new context to merge facets on polygonal objects
    Args:
        activeNodes (bool?): Return the active nodes in the tool  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        immediate (bool?): Acts on the object not the tool defaults  
                Properties: edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        previous (bool?): Reset to previously stored values  
                Properties: edit
        reset (bool?): Reset to default values  
                Properties: edit
        toolNode (bool?): Return the node used for tool defaults  
                Properties: query
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        firstFacet (Queryable[int]?): The number of the first (outer) face to merge.  
                Properties: create, query, edit
        mergeMode (Queryable[int]?): This flag specifies how faces are merged:  
                0. moves second face to first one  
                1. moves both faces to average  
                2. moves first face to second one  
                3, 4, 5. same as above, except faces are projected but not centred  
                6. Nothing moves.  
                C: Default is None (6).  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        secondFacet (Queryable[int]?): The number of the second (hole) face to merge.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMergeUV(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., distance: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, bool, float, int]:
    """Merge UVs of an object based on their distance. UVs are merge only
    if they belong to the same 3D vertex.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        distance (Queryable[float]?): This flag specifies the maximum distance to merge UVs.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a double.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMergeVertex(*args: str, edit: bool = ..., query: bool = ..., alwaysMergeTwoVertices: bool = ..., caching: bool = ..., constructionHistory: bool = ..., distance: Queryable[float] = ..., mergeToComponents: Queryable[str] = ..., name: str = ..., nodeState: Queryable[int] = ..., texture: bool = ..., worldSpace: bool = ...) -> Union[str, bool, float, int]:
    """Merge vertices within a given threshold.Since this allows merging any vertices that lie on the same object it
    is possible for the resulting geometry to be non-manifold.First, perform comparison of pairs of selected vertices.
    Pairs that lie within given distance of one another are merged,
    along with the edge between them.Second, any selected vertices which share an edge are merged if
    the distance between them is within the specified distance.Unlike Merge Edges, Merge Vertices will perform the merge even if the
    edges adjoining the vertices do not have matching orientation (i.e.
    normals of adjacent faces do not point in the same direction). As this
    restriction is not enforced while merging vertices, resulting geometry
    can be non-manifold.If alwaysMergeTwoVertices is set and there are only two vertices, tolerance
    is ignored and the vertices will be merged.Resulting mesh may have extra vertices or edges to ensure
    geometry is valid.
    Args:
        alwaysMergeTwoVertices (bool?): This flag specifies whether to always merge if only two vertices are  
                selected regardless of distance.  
                C: Default is false.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        distance (Queryable[float]?): This flag specifies the distance within which vertices will be merged.  
                C: Default is 0.0 (i.e. vertices are coincident).  
                Q: When queried, this flag returns a double.  
                Properties: create, query, edit
        mergeToComponents (Queryable[str]?): Optionally defines the position to merge all of the vertices to.  If set, the distance  
                flag will be ignored, and instead the center point of the set components will be  
                calculated and all vertices will be merged to that location.  
                C: Default is empty string.  
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        texture (bool?): This flag specifies whether the texture is sewn in addition to the 3d edge  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMirrorFace(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[int] = ..., axisDirection: Queryable[int] = ..., caching: bool = ..., constructionHistory: bool = ..., direction: Queryable[int] = ..., mergeMode: Queryable[int] = ..., mergeThreshold: Queryable[float] = ..., mergeThresholdType: Queryable[int] = ..., mirrorAxis: Queryable[int] = ..., mirrorPosition: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, int, bool, float, Tuple[float, float, float]]:
    """Mirror all the faces of the selected object.
    Args:
        axis (Queryable[int]?): Axis to mirror the object along  
                Default: 0  
                Properties: create, query, edit
        axisDirection (Queryable[int]?): Direction to mirror the object along  
                Default: 1  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        direction (Queryable[int]?): Direction to mirror the object along  
                Default: 0  
                Properties: create, query, edit
        mergeMode (Queryable[int]?): Merge mode to apply  
                Default: 1  
                Properties: create, query, edit
        mergeThreshold (Queryable[float]?): Tolerance to determine whether vertices should  
                be merged.  
                Default: 0.001  
                Properties: create, query, edit
        mergeThresholdType (Queryable[int]?): Merge mode to apply  
                Default: 0  
                Properties: create, query, edit
        mirrorAxis (Queryable[int]?): Mirror axis type selection  
                Default: 2  
                Properties: create, query, edit
        mirrorPosition (Queryable[float]?): Custom mirror axis position  
                Default: 0.0  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): Pivot point of the mirror plane.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMoveEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., gain: Queryable[Multiuse[float]] = ..., localCenter: Queryable[int] = ..., localDirection: Queryable[Tuple[float, float, float]] = ..., localDirectionX: Queryable[float] = ..., localDirectionY: Queryable[float] = ..., localDirectionZ: Queryable[float] = ..., localRotate: Queryable[Tuple[float, float, float]] = ..., localRotateX: Queryable[float] = ..., localRotateY: Queryable[float] = ..., localRotateZ: Queryable[float] = ..., localScale: Queryable[Tuple[float, float, float]] = ..., localScaleX: Queryable[float] = ..., localScaleY: Queryable[float] = ..., localScaleZ: Queryable[float] = ..., localTranslate: Queryable[Tuple[float, float, float]] = ..., localTranslateX: Queryable[float] = ..., localTranslateY: Queryable[float] = ..., localTranslateZ: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., random: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, bool, Multiuse[float], int, Tuple[float, float, float], float]:
    """Modifies edges of a polygonal object.
    Translate, move, rotate or scale edges.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        gain (Queryable[Multiuse[float]]?): Gain factor per component. Can be painted using Artisan.  
                Default: 1.0  
                Properties: create, query, edit, multiuse
        localCenter (Queryable[int]?): Local center on the edge : 0=Middle point, 1=Start point, 2=End point.  
                Default: 0  
                Properties: create, query, edit
        localDirection (Queryable[Tuple[float, float, float]]?): Direction to determine X axis for local space.  
                Default: 1.0, 0.0, 0.0  
                Properties: create, query, edit
        localDirectionX (Queryable[float]?): X coord of the X axis.  
                Properties: create, query, edit
        localDirectionY (Queryable[float]?): Y coord of the X axis.  
                Properties: create, query, edit
        localDirectionZ (Queryable[float]?): Z coord of the X axis.  
                Properties: create, query, edit
        localRotate (Queryable[Tuple[float, float, float]]?): The local rotations.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localRotateX (Queryable[float]?): Local rotate X coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateY (Queryable[float]?): Local rotate Y coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateZ (Queryable[float]?): Local rotate Z coord : Rotation along the normal.  
                The range is [0, 360].  
                Properties: create, query, edit
        localScale (Queryable[Tuple[float, float, float]]?): Local Scale.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        localScaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        localScaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        localScaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        localTranslate (Queryable[Tuple[float, float, float]]?): Local translate.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localTranslateX (Queryable[float]?): Local translation X coord.  
                Properties: create, query, edit
        localTranslateY (Queryable[float]?): Local translation Y coord.  
                Properties: create, query, edit
        localTranslateZ (Queryable[float]?): Local translation Z coord : Move along the normal.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot for scaling and rotation.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Pivot X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Pivot Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Pivot Z coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value for all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): Rotation angles around X, Y, Z.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        rotateX (Queryable[float]?): Rotation angle around X.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): Rotation angle around Y.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): Rotation angle around Z.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scaling vector.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        scaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): Translation vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        translateX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        translateY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMoveFacet(*args: str, edit: bool = ..., query: bool = ..., attraction: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., gain: Queryable[Multiuse[float]] = ..., gravity: Queryable[Tuple[float, float, float]] = ..., gravityX: Queryable[float] = ..., gravityY: Queryable[float] = ..., gravityZ: Queryable[float] = ..., localCenter: Queryable[int] = ..., localDirection: Queryable[Tuple[float, float, float]] = ..., localDirectionX: Queryable[float] = ..., localDirectionY: Queryable[float] = ..., localDirectionZ: Queryable[float] = ..., localRotate: Queryable[Tuple[float, float, float]] = ..., localRotateX: Queryable[float] = ..., localRotateY: Queryable[float] = ..., localRotateZ: Queryable[float] = ..., localScale: Queryable[Tuple[float, float, float]] = ..., localScaleX: Queryable[float] = ..., localScaleY: Queryable[float] = ..., localScaleZ: Queryable[float] = ..., localTranslate: Queryable[Tuple[float, float, float]] = ..., localTranslateX: Queryable[float] = ..., localTranslateY: Queryable[float] = ..., localTranslateZ: Queryable[float] = ..., magnX: Queryable[float] = ..., magnY: Queryable[float] = ..., magnZ: Queryable[float] = ..., magnet: Queryable[Tuple[float, float, float]] = ..., name: str = ..., nodeState: Queryable[int] = ..., offset: Queryable[float] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., random: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ..., weight: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, float, bool, Multiuse[float], Tuple[float, float, float], int]:
    """Modifies facet of a polygonal object.
    Translate, move, rotate or scale facets.
    Args:
        attraction (Queryable[float]?): Attraction, related to magnet.  
                The range is [-2.0, 2.0].  
                Default: 0.0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        gain (Queryable[Multiuse[float]]?): Gain factor per component. Can be painted using Artisan.  
                Default: 1.0  
                Properties: create, query, edit, multiuse
        gravity (Queryable[Tuple[float, float, float]]?): The gravity vector.  
                Default: 0.0, -1.0, 0.0  
                Properties: create, query, edit
        gravityX (Queryable[float]?): Gravity X coord.  
                Properties: create, query, edit
        gravityY (Queryable[float]?): Gravity Y coord.  
                Properties: create, query, edit
        gravityZ (Queryable[float]?): Gravity Z coord.  
                Properties: create, query, edit
        localCenter (Queryable[int]?): Local center on the edge : 0=Middle point, 1=Start point, 2=End point.  
                Default: 0  
                Properties: create, query, edit
        localDirection (Queryable[Tuple[float, float, float]]?): Direction to determine X axis for local space.  
                Default: 1.0, 0.0, 0.0  
                Properties: create, query, edit
        localDirectionX (Queryable[float]?): X coord of the X axis.  
                Properties: create, query, edit
        localDirectionY (Queryable[float]?): Y coord of the X axis.  
                Properties: create, query, edit
        localDirectionZ (Queryable[float]?): Z coord of the X axis.  
                Properties: create, query, edit
        localRotate (Queryable[Tuple[float, float, float]]?): The local rotations.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localRotateX (Queryable[float]?): Local rotate X coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateY (Queryable[float]?): Local rotate Y coord.  
                The range is [0, 360].  
                Properties: create, query, edit
        localRotateZ (Queryable[float]?): Local rotate Z coord : Rotation along the normal.  
                The range is [0, 360].  
                Properties: create, query, edit
        localScale (Queryable[Tuple[float, float, float]]?): Local Scale.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        localScaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        localScaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        localScaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        localTranslate (Queryable[Tuple[float, float, float]]?): Local translate.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localTranslateX (Queryable[float]?): Local translation X coord.  
                Properties: create, query, edit
        localTranslateY (Queryable[float]?): Local translation Y coord.  
                Properties: create, query, edit
        localTranslateZ (Queryable[float]?): Local translation Z coord : Move along the normal.  
                Properties: create, query, edit
        magnX (Queryable[float]?): Magnet X coord.  
                Properties: create, query, edit
        magnY (Queryable[float]?): Magnet Y coord.  
                Properties: create, query, edit
        magnZ (Queryable[float]?): Magnet Z coord.  
                Properties: create, query, edit
        magnet (Queryable[Tuple[float, float, float]]?): The magnet vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        offset (Queryable[float]?): Local offset. Faces are moved this distance towards the inside of the face.  
                Default: 0.0  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot for scaling and rotation.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Pivot X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Pivot Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Pivot Z coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value for all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): Rotation angles around X, Y, Z.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        rotateX (Queryable[float]?): Rotation angle around X.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): Rotation angle around Y.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): Rotation angle around Z.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scaling vector.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        scaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): Translation vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        translateX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        translateY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        weight (Queryable[float]?): The weight, related to gravity.  
                Default: 0.0  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMoveFacetUV(*args: str, edit: bool = ..., query: bool = ..., axisLen: Queryable[Tuple[float, float]] = ..., axisLenX: Queryable[float] = ..., axisLenY: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float]] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., random: Queryable[float] = ..., rotationAngle: Queryable[float] = ..., scale: Queryable[Tuple[float, float]] = ..., scaleU: Queryable[float] = ..., scaleV: Queryable[float] = ..., translate: Queryable[Tuple[float, float]] = ..., translateU: Queryable[float] = ..., translateV: Queryable[float] = ...) -> Union[str, Tuple[float, float], float, bool, int]:
    """Modifies the map by moving all UV values associated with
    the selected face(s).The UV coordinates of the model are manipulated without
    changing the vertices of the 3D object.
    Args:
        axisLen (Queryable[Tuple[float, float]]?): Axis Length vector, used to draw the manip handles.  
                C: Default is 1.0, 1.0  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        axisLenX (Queryable[float]?): Axis Length in X, used to draw the manip handles.  
                C: Default is 1.0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        axisLenY (Queryable[float]?): Axis Length in Y, used to draw the manip handles.  
                C: Default is 1.0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float]]?): This flag specifies the pivot for scaling and rotation.  
                C: Default is 0.0 0.0.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        pivotU (Queryable[float]?): This flag specifies U for the pivot for scaling and rotation.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        pivotV (Queryable[float]?): This flag specifies V for the pivot for scaling and rotation.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        random (Queryable[float]?): This flag specifies the random value for all parameters.  
                C: Default is 0.0. The range is [-10.0, 10.0].  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotationAngle (Queryable[float]?): Angle of rotation.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float]]?): This flag specifies the scaling vector.  
                C: Default is 1.0 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        scaleU (Queryable[float]?): This flag specifies U for the scaling vector.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        scaleV (Queryable[float]?): This flag specifies V for the scaling vector.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float]]?): This flag specifies the translation vector.  
                C: Default is 0.0 0.0.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        translateU (Queryable[float]?): This flag specifies the U translation vector.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        translateV (Queryable[float]?): This flag specifies the V translation vector.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMoveUV(*args: str, edit: bool = ..., query: bool = ..., axisLen: Queryable[Tuple[float, float]] = ..., axisLenX: Queryable[float] = ..., axisLenY: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float]] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., random: Queryable[float] = ..., rotationAngle: Queryable[float] = ..., scale: Queryable[Tuple[float, float]] = ..., scaleU: Queryable[float] = ..., scaleV: Queryable[float] = ..., translate: Queryable[Tuple[float, float]] = ..., translateU: Queryable[float] = ..., translateV: Queryable[float] = ...) -> Union[str, Tuple[float, float], float, bool, int]:
    """Moves selected UV coordinates in 2D space.
    As the selected UVs are adjusted, the way the image is
    mapped onto the object changes accordingly.
    This command manipulates the UV values without changing
    the 3D geometry of the object.
    Args:
        axisLen (Queryable[Tuple[float, float]]?): AxisLen vector, used to draw the manip handles.  
                Default: 1.0, 1.0  
                Properties: create, query, edit
        axisLenX (Queryable[float]?): AxisLen X coord.  
                Properties: create, query, edit
        axisLenY (Queryable[float]?): AxisLen Y coord.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float]]?): The pivot for scaling and rotation.  
                Default: 0.5, 0.5  
                Properties: create, query, edit
        pivotU (Queryable[float]?): Pivot U coord.  
                Properties: create, query, edit
        pivotV (Queryable[float]?): Pivot V coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value, added to all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        rotationAngle (Queryable[float]?): Angle of rotation.  
                Default: 0.0  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float]]?): Scaling vector.  
                Default: 1.0, 1.0  
                Properties: create, query, edit
        scaleU (Queryable[float]?): Scaling U coord.  
                Properties: create, query, edit
        scaleV (Queryable[float]?): Scaling V coord.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float]]?): Translation vector.  
                Default: 0.0, 0.0  
                Properties: create, query, edit
        translateU (Queryable[float]?): Translation U coord.  
                Properties: create, query, edit
        translateV (Queryable[float]?): Translation V coord.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMoveVertex(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., gain: Queryable[Multiuse[float]] = ..., localDirection: Queryable[Tuple[float, float, float]] = ..., localDirectionX: Queryable[float] = ..., localDirectionY: Queryable[float] = ..., localDirectionZ: Queryable[float] = ..., localTranslate: Queryable[Tuple[float, float, float]] = ..., localTranslateX: Queryable[float] = ..., localTranslateY: Queryable[float] = ..., localTranslateZ: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., random: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scaleX: Queryable[float] = ..., scaleY: Queryable[float] = ..., scaleZ: Queryable[float] = ..., translate: Queryable[Tuple[float, float, float]] = ..., translateX: Queryable[float] = ..., translateY: Queryable[float] = ..., translateZ: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, bool, Multiuse[float], Tuple[float, float, float], float, int]:
    """Modifies vertices of a polygonal object.
    Translate, rotate or scale vertices in local or world space.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        gain (Queryable[Multiuse[float]]?): Gain factor per component. Can be painted using Artisan.  
                Default: 1.0  
                Properties: create, query, edit, multiuse
        localDirection (Queryable[Tuple[float, float, float]]?): Direction to determine X axis for local space.  
                Default: 1.0, 0.0, 0.0  
                Properties: create, query, edit
        localDirectionX (Queryable[float]?): X coord of the X axis.  
                Properties: create, query, edit
        localDirectionY (Queryable[float]?): Y coord of the X axis.  
                Properties: create, query, edit
        localDirectionZ (Queryable[float]?): Z coord of the X axis.  
                Properties: create, query, edit
        localTranslate (Queryable[Tuple[float, float, float]]?): Local translate.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        localTranslateX (Queryable[float]?): Local translation X coord.  
                Properties: create, query, edit
        localTranslateY (Queryable[float]?): Local translation Y coord.  
                Properties: create, query, edit
        localTranslateZ (Queryable[float]?): Local translation Z coord : Move along the normal.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The pivot for scaling and rotation.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        pivotX (Queryable[float]?): Pivot X coord.  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Pivot Y coord.  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Pivot Z coord.  
                Properties: create, query, edit
        random (Queryable[float]?): Random value for all parameters.  
                Default: 0.0  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): Rotation angles around X, Y, Z.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        rotateX (Queryable[float]?): Rotation angle around X.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): Rotation angle around Y.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): Rotation angle around Z.  
                Properties: create, query, edit
        scale (Queryable[Tuple[float, float, float]]?): Scaling vector.  
                Default: 1.0, 1.0, 1.0  
                Properties: create, query, edit
        scaleX (Queryable[float]?): Scale X coord.  
                Properties: create, query, edit
        scaleY (Queryable[float]?): Scale Y coord.  
                Properties: create, query, edit
        scaleZ (Queryable[float]?): Scale Z coord.  
                Properties: create, query, edit
        translate (Queryable[Tuple[float, float, float]]?): Translation vector.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        translateX (Queryable[float]?): Translation X coord.  
                Properties: create, query, edit
        translateY (Queryable[float]?): Translation Y coord.  
                Properties: create, query, edit
        translateZ (Queryable[float]?): Translation Z coord.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyMultiLayoutUV(*args: str, flipReversed: bool = ..., gridU: int = ..., gridV: int = ..., layout: int = ..., layoutMethod: int = ..., offsetU: float = ..., offsetV: float = ..., percentageSpace: float = ..., prescale: int = ..., rotateForBestFit: int = ..., scale: int = ..., sizeU: float = ..., sizeV: float = ..., uvSetName: str = ...) -> bool:
    """place the UVs of the selected polygonal objects so that they do not overlap.poly, uv, map, placement
    Args:
        flipReversed (bool?): If this flag is turned on, the reversed UV pieces are fliped.  
                Properties: create
        gridU (int?): The U size of the grids.  
                Properties: create
        gridV (int?): The V size of the grids.  
                Properties: create
        layout (int?): How to move the UV pieces, after cuts are applied:  
                0 No move is applied.  
                1 Layout the pieces along the U axis.  
                2 Layout the pieces in a square shape.  
                3 Layout the pieces in grids.  
                4 Layout the pieces in nearest regions.  
                Properties: create
        layoutMethod (int?): // -lm/layoutMethod     layoutMethod  integer  
                //      (C, E, Q) Which layout method to use:  
                //              0 Block Stacking.  
                //              1 Shape Stacking.  
                Properties: create
        offsetU (float?): Offset the layout in the U direction by the given value.  
                Properties: create
        offsetV (float?): Offset the layout in the V direction by the given value.  
                Properties: create
        percentageSpace (float?): When layout is set to square, this value is a percentage of  
                the texture area which is added around each UV piece. It can be  
                used to ensure each UV piece uses different pixels in the texture.  
                Maximum value is 5 percent.  
                Properties: create
        prescale (int?): Prescale the shell before laying it out.  
                0 No scale is applied.  
                1 Object space scaling applied.  
                2 World space scaling applied.  
                Properties: create
        rotateForBestFit (int?): How to rotate the pieces, before move:  
                0 No rotation is applied.  
                1 Only allow 90 degree rotations.  
                2 Allow free rotations.  
                Properties: create
        scale (int?): How to scale the pieces, after move:  
                0 No scale is applied.  
                1 Uniform scale to fit in unit square.  
                2 Non proportional scale to fit in unit square.  
                Properties: create
        sizeU (float?): Scale the layout in the U direction by the given value.  
                Properties: create
        sizeV (float?): Scale the layout in the V direction by the given value.  
                Properties: create
        uvSetName (str?): Specifies the name of the uv set to edit uvs on. If not  
                specified will use the current uv set if it exists.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def polyNormal(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., normalMode: Queryable[int] = ..., userNormalMode: bool = ...) -> Union[str, bool, int]:
    """Control the normals of an object. This command works on faces
    or polygonal objects.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        normalMode (Queryable[int]?): Normal mode     : 0=reverse, 1=propagate, 2=conform,  
                3=reverseAndCut, 4=reverseAndPropagate  
                Default: 0  
                Properties: create, query, edit
        userNormalMode (bool?): Determines if user normals needs to be reversed as well.  
                Default: true  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyNormalPerVertex(*args: str, edit: bool = ..., query: bool = ..., allLocked: bool = ..., deformable: bool = ..., freezeNormal: bool = ..., normalX: Queryable[float] = ..., normalXYZ: Queryable[Multiuse[Tuple[float, float, float]]] = ..., normalY: Queryable[float] = ..., normalZ: Queryable[float] = ..., relative: bool = ..., unFreezeNormal: bool = ...) -> Union[bool, float, Multiuse[Tuple[float, float, float]]]:
    """Command associates normal(x, y, z) with vertices on polygonal objects.
    When used with the query flag, it returns the normal associated with the
    specified components. However, when queried, the command returns all
    normals (all vtx-face combinations) on the vertex, regardless of whether
    they are shared or not.poly, userNormals, polyNormals, setNormal, vertexNormal, vertex
    Args:
        allLocked (bool?): Queries if all normals on the selected vertices are locked (frozen) or not  
                Properties: create, query, edit
        deformable (bool?): DEFAULT  true  
                OBSOLETE flag. This flag will be removed in the next release.  
                Properties: create, query, edit
        freezeNormal (bool?): Specifies that the normal values be frozen (locked) at the current value.  
                Properties: create, query, edit
        normalX (Queryable[float]?): Specifies the x value normal  
                Properties: create, query, edit
        normalXYZ (Queryable[Multiuse[Tuple[float, float, float]]]?): Specifies the xyz values normal  
                If this flag is used singly, the specified normal xyz values are  
                used for all selected components.  
                If the flag is used multiple times, the number of uses must match  
                the number of selected components, and each use specifies  
                the normal of one component.  
                Properties: create, query, edit, multiuse
        normalY (Queryable[float]?): Specifies the y value normal  
                Properties: create, query, edit
        normalZ (Queryable[float]?): Specifies the z value normal  
                Properties: create, query, edit
        relative (bool?): When used, the normal values specified are added relative to the current value.  
                Properties: create, query, edit
        unFreezeNormal (bool?): Specifies that the normal values that were frozen at the current value be  
                un-frozen (un-locked).  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyNormalizeUV(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., insertBeforeDeformers: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., uvSetName: str = ..., worldSpace: bool = ..., centerOnTile: bool = ..., normalizeDirection: Queryable[int] = ..., normalizeType: Queryable[int] = ..., preserveAspectRatio: bool = ...) -> Union[str, bool, int]:
    """Normalizes the UVs of input polyFaces. The existing UVs of the faces
    are normalized between 0 and 1.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): Set to true if a new map should be created  
                Properties: create
        insertBeforeDeformers (bool?): Set to true if the new node created should inserted before any deformer nodes.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        centerOnTile (bool?): If true, will center UV's on the UV tile they are most over.  
                If false, will center UV's in the 0. 1 region.  
                Properties: create, query, edit
        normalizeDirection (Queryable[int]?): Scale along U or V or both.  
              
              
                0 UV  
              
              
                1 U  
              
              
                2 V  
              
              
                C:  Default is 0.  
                Q:  When queried, returns an int.  
                Properties: create, query, edit
        normalizeType (Queryable[int]?): Options for normalize.  
              
              
                0 Separate  
              
              
                1 Collective  
              
              
                C:  Default is 1.  
                Q:  When queried, returns an int.  
                Properties: create, query, edit
        preserveAspectRatio (bool?): Scale uniform along u and v.  
                C: Default is on.  
                Q: When queried, returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyOptUvs(*args: str, edit: bool = ..., query: bool = ..., applyToShell: bool = ..., areaWeight: float = ..., caching: bool = ..., constructionHistory: bool = ..., globalBlend: float = ..., globalMethodBlend: float = ..., iterations: int = ..., name: str = ..., nodeState: Queryable[int] = ..., optimizeAxis: int = ..., pinSelected: bool = ..., pinUvBorder: bool = ..., scale: float = ..., stoppingThreshold: float = ..., useScale: bool = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """Optimizes selected UVs.
    Args:
        applyToShell (bool?): Specifies where the whole object or just shells that are selected  
                or pinned should be affected.  
                Properties: create
        areaWeight (float?): Surface driven importance. 0 treat all faces equal. 1 gives more  
                importance to large ones.  
                Properties: create
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        globalBlend (float?): This allows the user to blend between a local optimization method  
                (globalBlend = 0.0) and a global optimization method  
                (globalBlend = 1.0). The local optimization method looks at the  
                ratio between the triangles on the object and the triangles in UV  
                space.  It has a side affect that it can sometimes introduce tapering  
                problems.  The global optimization is much slower, but takes into  
                consideration the entire object when optimizing uv placement.  
                Properties: create
        globalMethodBlend (float?): The global optimization method uses two functions to compute  
                a minimization.  The first function controls edge  
                stretch by using edges lengths between xyz and uv.  The second  
                function penalizes the first function by preventing  
                configurations where triangles would overlap.  For every surface  
                there is a mix between these two functions that will give the  
                appropriate response. Values closer to 1.0 give more weight to  
                the edge length function. Values closer to 0.0 give more weight to  
                surface area.  The default value of '0.5' is a even mix  
                between these two values.  
                Properties: create
        iterations (int?): Maximum number of iterations for each connected UV piece.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        optimizeAxis (int?): Degree of freedom for optimization:  
                0=Optimize freely, 1=Move vertically only, 2=Move horzontally only  
                Properties: create
        pinSelected (bool?): Specifies that the selected components should be pinned  
                instead of the unselected components.  
                Properties: create
        pinUvBorder (bool?): Specifies that the UV border should be pinned when doing the  
                solve. By default only unselected components are pinned.  
                Properties: create
        scale (float?): Ratio between 2d and 3d space.  
                Properties: create
        stoppingThreshold (float?): Minimum distorsion improvement between two steps in %.  
                Properties: create
        useScale (bool?): Adjust the scale or not.  
                Properties: create
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyOptions(*args: Any, query: bool = ..., activeObjects: bool = ..., allEdges: bool = ..., backCullVertex: bool = ..., backCulling: bool = ..., colorMaterialChannel: Queryable[str] = ..., colorShadedDisplay: bool = ..., displayAlphaAsGreyScale: bool = ..., displayBlueChannel: bool = ..., displayBorder: bool = ..., displayCenter: bool = ..., displayColorAsGreyScale: bool = ..., displayCreaseEdge: bool = ..., displayCreaseVertex: bool = ..., displayGeometry: bool = ..., displayGreenChannel: bool = ..., displayInvisibleFaces: bool = ..., displayItemNumbers: Queryable[Tuple[bool, bool, bool, bool]] = ..., displayMapBorder: bool = ..., displayMetadata: Queryable[Tuple[bool, bool, bool]] = ..., displayNormal: bool = ..., displayRedChannel: bool = ..., displaySubdComps: bool = ..., displayTangent: bool = ..., displayTriangle: bool = ..., displayUVTopology: bool = ..., displayUVs: bool = ..., displayVertex: bool = ..., displayWarp: bool = ..., facet: bool = ..., fullBack: bool = ..., gl: bool = ..., hardBack: bool = ..., hardEdge: bool = ..., hardEdgeColor: bool = ..., materialBlend: Queryable[str] = ..., newPolymesh: bool = ..., point: bool = ..., pointFacet: bool = ..., relative: bool = ..., reuseTriangles: bool = ..., sizeBorder: Queryable[float] = ..., sizeNormal: Queryable[float] = ..., sizeUV: Queryable[float] = ..., sizeVertex: Queryable[float] = ..., smoothDrawType: Queryable[int] = ..., softEdge: bool = ..., vertexNormalMethod: Queryable[int] = ..., wireBackCulling: bool = ...) -> Union[bool, str, Tuple[bool, bool, bool, bool], Tuple[bool, bool, bool], float, int]:
    """Changes the global display polygonal attributes.
    Args:
        activeObjects (bool?): Apply user choices for all active objects.  
                Properties: create, query
        allEdges (bool?): Display all edges in solid line.  
                Properties: create, query
        backCullVertex (bool?): BackCull vertices.  
                Properties: create, query
        backCulling (bool?): Display with no back culling.  
                Properties: create, query
        colorMaterialChannel (Queryable[str]?): If colorShadedDisplay is true, then determines which  
                material channel to display color per vertex in.  
                The options are:  
              
                "none" : disable material shading  
                "ambient" : ambient material channel  
                "ambientDiffuse" :  ambient and diffuse material channel  
                "diffuse" :  diffuse material channel  
                "specular" :  specular material channel  
                "emission" :  emission material channel  
                Properties: create, query
        colorShadedDisplay (bool?): Use color per vertex display in shaded mode.  
                Properties: create, query
        displayAlphaAsGreyScale (bool?): Display alpha as greyscale.  
                Properties: create, query
        displayBlueChannel (bool?): Display Blue channel.  
                Properties: create, query
        displayBorder (bool?): Highlight border edge.  
                Properties: create, query
        displayCenter (bool?): Display facet centers.  
                Properties: create, query
        displayColorAsGreyScale (bool?): Display color channels as greyscale.  
                Properties: create, query
        displayCreaseEdge (bool?): Highlight creased edges  
                Properties: create, query
        displayCreaseVertex (bool?): Highlight creased vertices  
                Properties: create, query
        displayGeometry (bool?): Display geometry.  
                Properties: create, query
        displayGreenChannel (bool?): Display Green channel.  
                Properties: create, query
        displayInvisibleFaces (bool?): Highlight invisible faces  
                Properties: create, query
        displayItemNumbers (Queryable[Tuple[bool, bool, bool, bool]]?): Displays item numbers (vertices edges facets uvs)  
                Properties: create, query
        displayMapBorder (bool?): Highlight map border edge.  
                Properties: create, query
        displayMetadata (Queryable[Tuple[bool, bool, bool]]?): Displays component metadata (vertices edges facets vertexFaces)  
                Properties: create, query
        displayNormal (bool?): Display normals.  
                Properties: create, query
        displayRedChannel (bool?): Display Red channel.  
                Properties: create, query
        displaySubdComps (bool?): Display subdivided components when in Smooth Mesh Preview mode.  
                Properties: create, query
        displayTangent (bool?): Display tangent.  
                Properties: create, query
        displayTriangle (bool?): Display triangulation.  
                Properties: create, query
        displayUVTopology (bool?): Option on UV display to display UVs topologically.  
                Properties: create, query
        displayUVs (bool?): Display UVs.  
                Properties: create, query
        displayVertex (bool?): Display vertices.  
                Properties: create, query
        displayWarp (bool?): Highlight warped facets.  
                Properties: create, query
        facet (bool?): For use with -dn flag. Set the normal display style to facet display.  
                Properties: create, query
        fullBack (bool?): Display with full back culling.  
                Properties: create, query
        gl (bool?): Apply user choices for all objects.  
                Properties: create, query
        hardBack (bool?): Backculled hard edges only for backculled faces.  
                Properties: create, query
        hardEdge (bool?): Display only hard edges.  
                Properties: create, query
        hardEdgeColor (bool?): Display hard edges as separate color.  
                Properties: create, query
        materialBlend (Queryable[str]?): The options are:  
                "overwrite"  
                "add"  
                "subtract"  
                "multiply"  
                "divide"  
                "average"  
                "modulate2x"  
                Properties: create, query
        newPolymesh (bool?): Set component display state of new polymesh objects.  
                Properties: create, query
        point (bool?): For use with -dn flag. Set the normal display style to vertex display.  
                Properties: create, query
        pointFacet (bool?): For use with -dn flag. Set the normal display style to vertex and face display.  
                Properties: create, query
        relative (bool?): When this flag is used with flags dealing with size,  
                the value (size) is a multiplication factor :  
                i.e for flags : -sizeNormal, -sizeBorder.  
                When this flag is used with flags dealing with a boolean value,  
                the boolean value is toggled :  
                i.e for flags : displayVertex, displayCenter, displayTriangle,  
                displayBorder, backCullVertex, displayWarp, displayItemNumbers.  
                Properties: create, query
        reuseTriangles (bool?): Avoid regenerating triangles, by reusing the old triangles upstream  
                in the construction history.  The construction history is searched  
                upstream and downstream for other mesh nodes, and the given boolean  
                value is set on those mesh nodes.  Note, that this command does not  
                set the value on the given mesh node.  That has to be done using  
                the setAttr command.  
                This option would affect only the interactive 3d viewport.  
                The batch-rendering would use the properly computed triangles.  
                This is useful only for interactive performance such as skinning  
                playback, when the display mode is shaded (or wireframe with  
                triangles displayed)  Using this option for wireframe display mode  
                is not recomended.  
                Properties: create, query
        sizeBorder (Queryable[float]?): Set the size of the polygonal border edges.  
                Properties: create, query
        sizeNormal (Queryable[float]?): Set the size of the polygonal normals.  
                Properties: create, query
        sizeUV (Queryable[float]?): Set the size of the polygonal UV.  
                Properties: create, query
        sizeVertex (Queryable[float]?): Set the size of the polygonal vertex.  
                Properties: create, query
        smoothDrawType (Queryable[int]?): This setting only works with the newPolymesh flag.  
                Sets a new default attribute value for the smoothDrawType attribute on a polymesh object.  
                Options are:  
                0. Catmull-Clark  
                1. Linear  
                2. OpenSubdiv Catmull-Clark Uniform  
                3. OpenSubdiv Catmull-Clark Adaptive  
                Properties: create, query
        softEdge (bool?): Display soft edges in dotted lines.  
                Properties: create, query
        vertexNormalMethod (Queryable[int]?): This setting only works with the newPolymesh flag.  
                Sets a new default attribute value for the vertexNormalMethod attribute on a polymesh object.  
                Options are:  
                0. Unweighted  
                1. Angle Weighted  
                2. Area Weighted  
                3. Angle And Area Weighted  
                Properties: create, query
        wireBackCulling (bool?): Backculled faces are in wireframe.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyOutput(*args: str, allValues: bool = ..., color: bool = ..., colorDesc: bool = ..., edge: bool = ..., edgeFace: bool = ..., face: bool = ..., faceNorm: bool = ..., force: bool = ..., group: bool = ..., noOutput: bool = ..., normDesc: bool = ..., outputFile: str = ..., triangle: bool = ..., uvDesc: bool = ..., uvValue: bool = ..., vert: bool = ..., vertEdge: bool = ..., vertNorm: bool = ...) -> bool:
    """Dumps a description of internal memory representation of poly objects.
    If no objects are specified in the command line, then the
    objects from the active list are used.
    If information on the geometry in the history of a poly shape is desired,
    then the plug of interest needs to be specified in the command line.
    Default behaviour is to print only a summary. Use the flags
    above to get more details on a specific part of the object.
    Args:
        allValues (bool?): Shortcut for setting all the flags above  
                Properties: create
        color (bool?): Prints the color per vertex. In case of multiple sets,  
                all sets are printed.  
                Properties: create
        colorDesc (bool?): Print the color per vertex description. Each integer  
                is an entry in the color array.  
                Properties: create
        edge (bool?): Print the edge description.  
                Properties: create
        edgeFace (bool?): Prints the edge to face adjascency list. Only  
                available if the information is already computed on  
                the object.  
                Properties: create
        face (bool?): Print the faces description  
                Properties: create
        faceNorm (bool?): Prints the normals per face. Only available if the  
                information is already computed on the object.  
                Properties: create
        force (bool?): Force evaluation of missing pieces before printing.  
                Properties: create
        group (bool?): Print the groups of the object.  
                Properties: create
        noOutput (bool?): Dont output any data.  Would be useful if you want to  
                just evaluate the data, for testing purposes.  
                Properties: create
        normDesc (bool?): Prints the normals per vertex description. Each  
                integer is an entry in the vertNorm array. Only  
                available if the information is already computed on  
                the object.  
                Properties: create
        outputFile (str?): Location of the output file.  
                Properties: create
        triangle (bool?): Prints the triangles per face. Only available if the  
                information is already computed on the object.  
                Properties: create
        uvDesc (bool?): Print the UV description. Each integer is an entry in  
                the uvValue array.  
                Properties: create
        uvValue (bool?): Prints the UV positions. In case of multiple UV sets,  
                all sets are printed.  
                Properties: create
        vert (bool?): Prints the vertex positions.  
                Properties: create
        vertEdge (bool?): Prints the vertex to edge adjascency list. Only  
                available if the information is already computed on  
                the object.  
                Properties: create
        vertNorm (bool?): Prints the normals per vertex. Only available if the  
                information is already computed on the object.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def polyPinUV(*args: str, edit: bool = ..., query: bool = ..., createHistory: bool = ..., operation: Queryable[int] = ..., unpinned: bool = ..., uvSetName: Queryable[str] = ..., value: Queryable[Multiuse[float]] = ...) -> Union[bool, int, str, Multiuse[float]]:
    """This command is used to pin and unpin UVs. A "pinned" UV is one which should not be modified.Each UV has an associated pin weight, that defaults to 0.0 meaning that the UV is not pinned. If pin weight is set to 1.0 then it becomes fully pinned and UV tools should not modify that UV.
    If the pin weight is set to a value between 0.0 and 1.0 then UV tools should weight their changes to that UV accordingly.UV pinning is not enforced by the shape node: it is up to each tool to decide whether it will obey the pin weights.uv, pin
    Args:
        createHistory (bool?): For objects that have no construction history, this flag can be used  
                to force the creation of construction history for pinning.  By default,  
                history is not created if the object has no history.  Regardless of this  
                flag, history is always created if the object already has history.  
                Properties: create, query, edit
        operation (Queryable[int]?): Operation to perform.  Valid values are:  
                0. Set pin weights on the selected UVs.  
                1. Set pin weights to zero for the selected UVs.  
                2. Remove pin weights from the entire mesh.  
                3. Invert pin weights of the entire mesh.  
                Default is 0.  
                Properties: create, query, edit
        unpinned (bool?): List all selected UVs which are not pinned.  
                Properties: query, edit
        uvSetName (Queryable[str]?): Specifies the name of the UV set to edit UVs on. If not  
                specified the current UV set will be used if it exists.  
                Properties: create, query, edit
        value (Queryable[Multiuse[float]]?): Specifies the pin value for the selected UV components.  
                When specified multiple times, the values are assigned respectively to  
                the specified UVs.  
                Properties: create, query, edit, multiuse

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyPipe(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: bool = ..., height: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., roundCap: bool = ..., subdivisionsAxis: Queryable[int] = ..., subdivisionsCaps: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., texture: bool = ..., thickness: Queryable[float] = ...) -> Union[List[str], Tuple[float, float, float], bool, float, int]:
    """The polyPipe command creates a new polygonal pipe.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the pipe.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (bool?): Create UVs or not.  
                Default: true  
                Properties: create, query, edit
        height (Queryable[float]?): Height of the pipe.  
                Default: 2.0  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): Radius of the pipe.  
                Default: 1.0  
                Properties: create, query, edit
        roundCap (bool?): To indicate whether we need a round cap  
                Default: false  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): Subdivisions around the axis.  
                Default: 20  
                Properties: create, query, edit
        subdivisionsCaps (Queryable[int]?): Subdivisions along the thickness caps.  
                Default: 1  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height.  
                Default: 1  
                Properties: create, query, edit
        texture (bool?): Apply texture or not. this is an old attribute.  
                This is unsupported and would be removed in a future release.  
                Default: true  
                Properties: create, query, edit
        thickness (Queryable[float]?): Thickness of the pipe.  
                Default: 0.5  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyPlanarProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., imageCenter: Queryable[Tuple[float, float]] = ..., imageCenterX: Queryable[float] = ..., imageCenterY: Queryable[float] = ..., imageScale: Queryable[Tuple[float, float]] = ..., imageScaleU: Queryable[float] = ..., imageScaleV: Queryable[float] = ..., insertBeforeDeformers: bool = ..., keepImageRatio: bool = ..., mapDirection: str = ..., name: str = ..., nodeState: Queryable[int] = ..., perInstance: bool = ..., projectionCenter: Queryable[Tuple[float, float, float]] = ..., projectionCenterX: Queryable[float] = ..., projectionCenterY: Queryable[float] = ..., projectionCenterZ: Queryable[float] = ..., projectionHeight: Queryable[float] = ..., projectionScale: Queryable[Tuple[float, float]] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., rotationAngle: Queryable[float] = ..., smartFit: bool = ..., worldSpace: bool = ..., projectionHorizontalSweep: Queryable[float] = ..., seamCorrect: bool = ...) -> Union[str, bool, Tuple[float, float], float, int, Tuple[float, float, float]]:
    """TpolyProjCmdBase is a base class for the command to create a mapping on the selected polygonal faces.
    Projects a map onto an object, using an orthogonal projection. The
    piece of the map defined from isu, isv, icx, icy area, is placed at
    pcx, pcy, pcz location.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): This flag when set true will create a new map with  
                a the name passed in, if the map does not already exist.  
                Properties: create, query
        imageCenter (Queryable[Tuple[float, float]]?): The center point of the 2D model layout.  
                Default: 0.5, 0.5  
                Properties: create, query, edit
        imageCenterX (Queryable[float]?): Image center X coord.  
                Properties: create, query, edit
        imageCenterY (Queryable[float]?): Image center Y coord.  
                Properties: create, query, edit
        imageScale (Queryable[Tuple[float, float]]?): Specifies the UV scale : Enlarges or reduces the 2D version of the  
                model in U or V space relative to the 2D centerpoint.  
                Default: 1.0, 1.0  
                Properties: create, query, edit
        imageScaleU (Queryable[float]?): The the U scale : Enlarges or reduces the 2D version of the model  
                in U space relative to the 2D centerpoint.  
                Properties: create, query, edit
        imageScaleV (Queryable[float]?): The V scale : Enlarges or reduces the 2D version of the model  
                in V space relative to the 2D centerpoint.  
                Properties: create, query, edit
        insertBeforeDeformers (bool?): This flag specifies if the projection node should be inserted before  
                or after deformer nodes already applied to the shape. Inserting the  
                projection after the deformer leads to texture swimming during  
                animation and is most often undesirable.  
                C: Default is on.  
                Properties: create
        keepImageRatio (bool?): True means keep any image ratio  
                Properties: create
        mapDirection (str?): This flag specifies the mapping direction.  
                'x', 'y' and 'z' projects the map along the corresponding axis.  
                'c' projects along the current camera viewing direction.  
                'p' does perspective projection if current camera is perspective.  
                'b' projects along the best plane fitting the objects selected.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        perInstance (bool?): True if the new map is per-instance, otherwise it is shared.  
                Properties: create
        projectionCenter (Queryable[Tuple[float, float, float]]?): The point on the object that will be the center of the projection.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        projectionCenterX (Queryable[float]?): Projection center X coord.  
                Properties: create, query, edit
        projectionCenterY (Queryable[float]?): Projection center Y coord.  
                Properties: create, query, edit
        projectionCenterZ (Queryable[float]?): Projection center Z coord.  
                Properties: create, query, edit
        projectionHeight (Queryable[float]?): The height of the map relative to the 3D projection axis.  
                Properties: create, query, edit
        projectionScale (Queryable[Tuple[float, float]]?): The width and the height of the map relative to the 3D projection axis.  
                Default: 1.0, 1.0  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): The mapping rotate angles.  
                Default: 0.0, 0.0, 0.0  
                Properties: create, query, edit
        rotateX (Queryable[float]?): X mapping rotate angle.  
                Properties: create, query, edit
        rotateY (Queryable[float]?): Y mapping rotate angle.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): Z mapping rotate angle.  
                Properties: create, query, edit
        rotationAngle (Queryable[float]?): The angle for the rotation.  
                When the angle is positive, then the map rotates counterclockwise on  
                the mapped model; if negative, the map rotates clockwise.  
                Default: 0.0  
                Properties: create, query, edit
        smartFit (bool?): True means use the smart fit algorithm  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        projectionHorizontalSweep (Queryable[float]?): The angle swept horizontally by the projection.  The range is [0, 360].  
                Properties: create, query, edit
        seamCorrect (bool?): This flag specifies to perform a seam correction  
                on the mapped faces.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyPlane(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., createUVs: Queryable[int] = ..., height: Queryable[float] = ..., subdivisionsHeight: Queryable[int] = ..., subdivisionsWidth: Queryable[int] = ..., subdivisionsX: Queryable[int] = ..., subdivisionsY: Queryable[int] = ..., texture: Queryable[int] = ..., width: Queryable[float] = ...) -> Union[List[str], bool, int, Tuple[float, float, float], float]:
    """Create a new polygonal plane.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the plane.  
                Properties: create, query, edit
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize and Preserve Aspect Ratio  
                Default: 1  
                Properties: create, query, edit
        height (Queryable[float]?): Height of the plane.  
                Default: 1.0  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height of the sphere.  
                Properties: create, query, edit
        subdivisionsWidth (Queryable[int]?): Subdivisions along the width of the plane.  
                Default: 10  
                Properties: create, query, edit
        subdivisionsX (Queryable[int]?): This specifies the number of subdivisions in the X direction for the plane.  
                Default is 5.  
                Properties: create, query, edit
        subdivisionsY (Queryable[int]?): This flag specifies the number of subdivisions in the Y direction for the plane.  
                Default is 5.  
                Properties: create, query, edit
        texture (Queryable[int]?): What texture mechanism to be applied.  
                0=No textures; 1=stretch to fit;  
                2=preserve aspect ratio  
                Default: 1  
                Properties: create, query, edit
        width (Queryable[float]?): Width of the plane.  
                Default: 1.0  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyPlatonicSolid(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: int = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., sideLength: Queryable[float] = ..., solidType: int = ..., texture: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The polyPlatonicSolid command creates a new polygonal platonic solid.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the platonic solid.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (int?): This flag alows a specific UV mechanism to be selected, while creating.  
                The valid values are 0, 1,  2 ,3 or 4.  
                0 implies that no UVs will be generated (No texture to be applied).  
              
                1 implies UVs should be created for the object as a whole without any normalization.  
                 The solid will be unwrapped and then the texture will be applied  
                 without any distortion.  
                 In the unwrapped solid, the shared edges will have shared UVs.  
              
                2 implies UVs are created separately for each of the faces of the solid.  
              
                3 implies the UVs should be normalized. This will normalize the  
                 U and V direction separately, thereby resulting in distortion of textures.  
              
                4 implies UVs are created so that the texture will not be distorted when applied.  
                 The texture lying outside the UV range will be truncated (since that cannot be  
                 squeezed in, without distorting the texture.  
              
                  For better understanding of these options, you may have to open the  
                     texture view window  
              
                C: Default is 4  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): This flag specifies the radius of the platonic solid.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        sideLength (Queryable[float]?): This flag specifies the side length of platonic solid.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        solidType (int?): This flag allows a specific platonic solid to be selected for creation of mesh,  
                The valid values are 0, 1, 2 and 3.  
                0 implies dodecahedron to be created.  
                1 implies icosahedron to be created.  
                2 implies octahedron to be created.  
                3 implies tertrahedron to be created.  
              
                C: Default is 0  
                Properties: create
        texture (int?): This flag is obsolete and will be removed in the next release.  
                The -cuv/createUVs flag should be used instead.  
                Properties: create

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyPoke(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., localTranslate: Tuple[float, float, float] = ..., localTranslateX: float = ..., localTranslateY: float = ..., localTranslateZ: float = ..., name: str = ..., nodeState: Queryable[int] = ..., translate: Tuple[float, float, float] = ..., translateX: float = ..., translateY: float = ..., translateZ: float = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """Introduces a new vertex in the middle of the selected face,
    and connects it to the rest of the vertices of the face.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        localTranslate (Tuple[float, float, float]?): Translate the new vertex in the local face coordinate.  
                Properties: create
        localTranslateX (float?): Translate the new vertex in the local face coordinate along X.  
                Properties: create
        localTranslateY (float?): Translate the new vertex in the local face coordinate along Y.  
                Properties: create
        localTranslateZ (float?): Translate the new vertex in the local face coordinate along Z.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        translate (Tuple[float, float, float]?): Translate the new vertex in the world space.  
                Properties: create
        translateX (float?): Translate the new vertex in the world space along X.  
                Properties: create
        translateY (float?): Translate the new vertex in the world space along Y.  
                Properties: create
        translateZ (float?): Translate the new vertex in the world space along Z.  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name

    Example:
    """

def polyPrimitive(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., createUVs: Queryable[int] = ..., polyType: int = ..., radius: Queryable[float] = ..., sideLength: Queryable[float] = ..., texture: Queryable[int] = ...) -> Union[List[str], bool, int, Tuple[float, float, float], float]:
    """Create a polygon primative
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the primitive polygon.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize Each Face Separately  
                3. Normalize Collectively  
                4. Normalize and Preserve Aspect Ratio  
                Properties: create, query, edit
        polyType (int?): This flag allows a specific primitive poly to be selected for creation of mesh,  
                The valid values is 0  
                0 implies soccer ball to be created.  
                C: Default is 0  
                Properties: create
        radius (Queryable[float]?): This flag specifies the radius of the primitive polygon.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        sideLength (Queryable[float]?): This flag specifies the side length of primitive polygon.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        texture (Queryable[int]?): What texture mechanism to be applied  
                0=No textures, 1=Object, 2=Faces  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyPrimitiveMisc(*args: Any, **kwargs: Any) -> None: ...
def polyPrism(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: int = ..., length: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., numberOfSides: Queryable[int] = ..., numderOfSides: Queryable[int] = ..., object: bool = ..., sideLength: Queryable[float] = ..., subdivisionsCaps: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., texture: int = ...) -> Union[List[str], Tuple[float, float, float], bool, float, int]:
    """The prism command creates a new polygonal prism.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the prism.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (int?): This flag alows a specific UV mechanism to be selected, while creating the primitive.  
                The valid values are 0, 1,  2 or 3.  
                0 implies that no UVs will be generated (No texture to be applied).  
              
                1 implies UVs should be created for the object as a whole without any normalization.  
                 The primitive will be unwrapped and then the texture will be applied  
                 without any distortion.  
                 In the unwrapped primitive, the shared edges will have shared UVs.  
              
                2 implies the UVs should be normalized. This will normalize the  
                 U and V direction separately, thereby resulting in distortion of textures.  
              
                3 implies UVs are created so that the texture will not be distorted when applied.  
                 The texture lying outside the UV range will be truncated (since that cannot be  
                 squeezed in, without distorting the texture.  
              
                  For better understanding of these options, you may have to open the  
                     texture view window  
              
                C: Default is 2.  
                Properties: create
        length (Queryable[float]?): This flag specifies the length of the prism.  
                C: Default is 2.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        numberOfSides (Queryable[int]?): This specifies the number of sides for the prism.  
                C: Default is 3.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        numderOfSides (Queryable[int]?): This specifies the number of sides for the prism.  
                C: Default is 3.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        sideLength (Queryable[float]?): This flag specifies the edge length of the prism.  
                C: Default is 2.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        subdivisionsCaps (Queryable[int]?): This flag specifies the subdivisions on the caps for the prism.  
                C: Default is 2.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): This specifies the subdivisions along the height for the prism.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (int?): This flag is obsolete and will be removed in the next release.  
                The -cuv/createUVs flag should be used instead.  
                Properties: create

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyProjectCurve(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., addUnderTransform: bool = ..., caching: bool = ..., direction: Queryable[Tuple[float, float, float]] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ...) -> Union[List[str], bool, Tuple[float, float, float], float, int]:
    """The polyProjectCurve command creates curves by projecting a selected
    curve onto a selected poly mesh.  The direction of projection will be
    the current view direction unless the direction vector is specified
    with the -direction/-d flag.
    Args:
        addUnderTransform (bool?): True if the resulting curve should be added under the source transform  
                Properties: create
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[Tuple[float, float, float]]?): Direction of projection.  
                Properties: create, query, edit
        directionX (Queryable[float]?): X direction of projection.  
                Properties: create, query, edit
        directionY (Queryable[float]?): Y direction of projection.  
                Properties: create, query, edit
        directionZ (Queryable[float]?): Z direction of projection.  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance to fit to.  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name

    Example:
    """

def polyProjection(*args: str, constructionHistory: bool = ..., createNewMap: bool = ..., imageCenterX: float = ..., imageCenterY: float = ..., imageScaleU: float = ..., imageScaleV: float = ..., insertBeforeDeformers: bool = ..., keepImageRatio: bool = ..., mapDirection: str = ..., projectionCenterX: float = ..., projectionCenterY: float = ..., projectionCenterZ: float = ..., projectionScaleU: float = ..., projectionScaleV: float = ..., rotateX: float = ..., rotateY: float = ..., rotateZ: float = ..., rotationAngle: float = ..., seamCorrect: bool = ..., smartFit: bool = ..., type: str = ..., uvSetName: str = ...) -> str:
    """Creates a mapping on the selected polygonal faces.  When construction
            history is created, the name of the new node is returned.  In other cases,
            the command returns nothing.poly, mapping, projection, planar, cylindrical, spherical
    Args:
        constructionHistory (bool?): Turn the construction history on or off (where applicable).  
                Properties: create
        createNewMap (bool?): Create new map if it does not exist.  
                Properties: create
        imageCenterX (float?): Specifies the X (U) translation of the projected UVs.  
                        Default is 0.5.  
                Properties: create
        imageCenterY (float?): Specifies the Y (V) translation of the projected UVs.  
                        Default is 0.5.  
                Properties: create
        imageScaleU (float?): Specifies the U scale factor of the projected UVs.  
                        Default is 1.  
                Properties: create
        imageScaleV (float?): Specifies the V scale factor of the projected UVs.  
                        Default is 1.  
                Properties: create
        insertBeforeDeformers (bool?): Specifies if the projection node should be inserted  
                        before or after deformer nodes already applied to the shape.  
                        Inserting the projection after the deformer leads to texture  
                        swimming during animation and is most often undesirable.  
                        Default is on.  
                Properties: create
        keepImageRatio (bool?): Specifies if the xy scaling in the planar projection has to be  
                        uniform.  By setting this flag, the texture aspect ratio is  
                        preserved.  This flag is ignored for cylindrical and spherical  
                        projections.  
                Properties: create
        mapDirection (str?): Specifies the direction of the projection.  By specifying this flag, the  
                        projection placement values (pcx, pcy, pcz, rx, ry, rz, psu, psv) are  
                        internally computed.  If both this flag and the projection values are  
                        specified, the projection values are ignored.  
                        Valid Values are :  
                                X                       Projects along the X Axis  
                                Y                       Projects along the Y Axis  
                                Z                       Projects along the Z Axis  
                                bestPlane       Projects on the best plane fitting the object  
                                camera          Projects along the viewing direction  
                                perspective Creates perspective projection if current camera is perspective  
                        Default is bestPlane.  
                Properties: create
        projectionCenterX (float?): Specifies the X coordinate of the center of the projection manipulator.  
                Properties: create
        projectionCenterY (float?): Specifies the Y coordinate of the center of the projection manipulator.  
                Properties: create
        projectionCenterZ (float?): Specifies the Z coordinate of the center of the projection manipulator.  
                Properties: create
        projectionScaleU (float?): Specifies the U scale component of the projection manipulator.  
                Properties: create
        projectionScaleV (float?): Specifies the V scale component of the projection manipulator.  
                Properties: create
        rotateX (float?): Specifies the X-axis rotation of the projection manipulator.  
                Properties: create
        rotateY (float?): Specifies the Y-axis rotation of the projection manipulator.  
                Properties: create
        rotateZ (float?): Specifies the Z-axis rotation of the projection manipulator.  
                Properties: create
        rotationAngle (float?): Specifies the rotation of the projected UVs in the UV space.  
                        Default is 0.  
                Properties: create
        seamCorrect (bool?): Specifies if seam correction has to be done for spherical  
                        and cylindrical projections.  This flag is ignored, if the  
                        planar projection is specified.  
                Properties: create
        smartFit (bool?): Specifies if the projection manipulator has to be placed  
                        fitting the object.  Used for cylindrical and spherical  
                        projections.  For smart fitting the planar projection, the  
                        mapDirection flag has to be used, since there are several  
                        options for smart fitting a planar projection.  
                Properties: create
        type (str?): Specify the type of mapping to be performed.  
                        Valid values for the STRING are  
                         "planar"  
                         "cylindrical"  
                         "spherical"  
                        Default is planar.  
                Properties: create
        uvSetName (str?): Specifies name of the uv set to work on.  
                Properties: create

    Returns:
        str: Name of node created

    Example:
    """

def polyPyramid(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., numberOfSides: Queryable[int] = ..., numderOfSides: Queryable[int] = ..., object: bool = ..., sideLength: Queryable[float] = ..., subdivisionsCaps: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., texture: bool = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The pyramid command creates a new polygonal pyramid.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the pyramid.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (Queryable[int]?): Create UVs or not.  
                0. No UVs  
                1. No Normalization  
                2. Normalize  
                3. Normalize and Preserve Aspect Ratio  
                Default: 2  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        numberOfSides (Queryable[int]?): Number of sides of Pyramid.  
                Default: 4  
                Properties: create, query, edit
        numderOfSides (Queryable[int]?): Number of sides of Pyramid.  
                Default: 4  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        sideLength (Queryable[float]?): Side length of the Pyramid.  
                Default: 1.0  
                Properties: create, query, edit
        subdivisionsCaps (Queryable[int]?): Subdivisions on bottom cap  
                Default: 0  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height.  
                Default: 1  
                Properties: create, query, edit
        texture (bool?): Apply texture or not.  
                Default: true  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyQuad(*args: str, edit: bool = ..., query: bool = ..., angle: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., keepGroupBorder: bool = ..., keepHardEdges: bool = ..., keepTextureBorders: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, float, bool, int]:
    """Merges selected triangles of a polygonal object into four-sided
    faces.
    Args:
        angle (Queryable[float]?): Angle threshold above which two triangles are not merged.  
                C: Default is 30 degrees. The range is [0.0, 180.0].  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        keepGroupBorder (bool?): Keep facet group border :  
                If "on", the borders of selected faces are maintained,  
                otherwise the borders of selected facets may be modified.  
                C: Default is "on".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        keepHardEdges (bool?): Keep hard edges :  
                If "on", the hard edges of selected faces are maintained,  
                otherwise they may be deleted between two triangles.  
                C: Default is "on".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        keepTextureBorders (bool?): Keep texture border :  
                If "on", the borders of texture maps are maintained,  
                otherwise the boreders of texture maps may be modified.  
                C: Default is "on".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyQueryBlindData(*args: str, associationType: str = ..., binaryData: str = ..., booleanData: bool = ..., doubleData: float = ..., intData: int = ..., longDataName: Multiuse[str] = ..., maxValue: float = ..., minValue: float = ..., shortDataName: Multiuse[str] = ..., showComp: bool = ..., stringData: str = ..., subString: str = ..., typeId: int = ...) -> str:
    """Command query's blindData associated with particular polygonal components.
    So, the command will require the following to be specified:
            - selection list to query
    Optional are the:
            - typeId
            - associationType
            - longDataName or shortDataName of data being queried.
            - The actual data being specified.
            - showComponent flag
    Note that for object level blind data, the showComponent flag will be ignored.
    If no components are selected, the assocation flag will be ignored and
    object level data will be queried.query, blind, data
    Args:
        associationType (str?): Specifies the dataTypes that are part of BlindData node being queried.  
                Allowable associations are "object" for any object, and "vertex" "edge" and  
                "face" for mesh objects.  
                Properties: create
        binaryData (str?): Specifies the binary string value to search for  
                Properties: create
        booleanData (bool?): Specifies the string value to search for  
                Properties: create
        doubleData (float?): Specifies the double/float value to search for  
                Properties: create
        intData (int?): Specifies the integer value to search for  
                Properties: create
        longDataName (Multiuse[str]?): Specifies the long name of the data that is being queried by this command.  
                Properties: create, multiuse
        maxValue (float?): Specifies the maximum value to search for.  This option will query float,  
                double, and integer types of blind data.  
                Properties: create
        minValue (float?): Specifies the minimum value to search for.  This option will query float,  
                double and integer types of blind data.  
                Properties: create
        shortDataName (Multiuse[str]?): Specifies the short name of the data that is being queried by this command.  
                Properties: create, multiuse
        showComp (bool?): The showComponent option controls whether the object.[component].attribute  
                name is output preceeding the actual value.  If the showComponent option  
                is used then the restriction of only returning 1 type of blind data (i.e.  
                one of integer, float, double... is removed, as the return for all are  
                strings.  
                If the association is object and not component, then this option will  
                still cause all the attribute names to be printed  
                Properties: create
        stringData (str?): Specifies the string value to search for  
                Properties: create
        subString (str?): Specifies the substring that should be checked against a STRING type blind  
                data.  If the sub string is found query is successful.  Will not look at non  
                String type blind data elements.  
                Properties: create
        typeId (int?): Specifies the typeId of the BlindData type being queried.  If the typeId  
                is not specified, then all of the components that match the query will be  
                output.  The typeId of the elements found will be output if the ShowComponents  
                option is used.  Will be in the format "object.component.attribute::typeId".  
                If the typeId is specifed then the "::typeId" portion will not be output with  
                the ShowComponents option.  
                Properties: create

    Returns:
        str: Blind data

    Example:
    """

def polyReduce(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., cachingReduce: bool = ..., colorWeights: Queryable[float] = ..., compactness: Queryable[float] = ..., constructionHistory: bool = ..., geomWeights: Queryable[float] = ..., invertVertexWeights: bool = ..., keepBorder: bool = ..., keepBorderWeight: Queryable[float] = ..., keepColorBorder: bool = ..., keepColorBorderWeight: Queryable[float] = ..., keepCreaseEdge: bool = ..., keepCreaseEdgeWeight: Queryable[float] = ..., keepFaceGroupBorder: bool = ..., keepFaceGroupBorderWeight: Queryable[float] = ..., keepHardEdge: bool = ..., keepHardEdgeWeight: Queryable[float] = ..., keepMapBorder: bool = ..., keepMapBorderWeight: Queryable[float] = ..., keepOriginalVertices: bool = ..., keepQuadsWeight: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., percentage: Queryable[float] = ..., preserveLocation: bool = ..., preserveTopology: bool = ..., replaceOriginal: bool = ..., sharpness: Queryable[float] = ..., symmetryPlaneW: Queryable[float] = ..., symmetryPlaneX: Queryable[float] = ..., symmetryPlaneY: Queryable[float] = ..., symmetryPlaneZ: Queryable[float] = ..., symmetryTolerance: Queryable[float] = ..., termination: Queryable[int] = ..., triangleCount: Queryable[int] = ..., triangulate: bool = ..., useVirtualSymmetry: Queryable[int] = ..., uvWeights: Queryable[float] = ..., version: Queryable[int] = ..., vertexCount: Queryable[int] = ..., vertexMapName: Queryable[str] = ..., vertexWeightCoefficient: Queryable[float] = ..., weightCoefficient: Queryable[float] = ...) -> Union[str, bool, float, int]:
    """Simplify a polygonal object by reducing geometry while preserving the
    overall shape of the mesh.The algorithm for polyReduce was changed in 2014 to use a new algorithm derived
    from Softimage. However, the command still defaults to using the old algorithm
    for backwards compatibility.  Therefore, we recommend setting the version flag
    to 1 for best results as the new algorithm is better at preserving geometry
    features.  Additionally, some flags only apply to a specific algorithm and
    this is documented for each flag.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        cachingReduce (bool?): Cache intermediate reductions for speed at the expense of memory.  
                It is recommended that caching be enabled when using the new  
                algorithm. (-version 1)  However, caching is not recommended  
                when using then old algorithm because it can cause stability  
                issues.  
                C: Default is false.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        colorWeights (Queryable[float]?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                How much consideration vertex color is given in the reduction  
                algorithm. A higher weight means the reduction will try  
                harder to preserve vertex coloring.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        compactness (Queryable[float]?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                Tolerance for compactness for the generated triangles  
                A value of 0 will accept all triangles during decimation  
                A value close to 0 will attempt to eliminate triangles  
                that have collinear edges (zero area triangles)  
                A value closer to 1 will attempt to eliminate triangles  
                that are not strictly equilateral (of equal lengths)  
                The closer to 1.0, the more expensive the computation  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        geomWeights (Queryable[float]?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                How much consideration vertex positions are given in the  
                reduction algorithm.  A higher weight means the reduction  
                will try harder to preserve geometry.  
                C: Default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        invertVertexWeights (bool?): This flag controls how weight map values are interpreted.  
                If true, a vertex weight of 1.0 means a vertex is unlikely to be reduced.  
                If false, a vertex weight of 0.0 means a vertex is unlikely to be reduced.  
                This flag only applies when using the new algorithm. (-version 1)  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepBorder (bool?): If true, reduction will try to retain geometric borders and  
                the border of the selection.  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepBorderWeight (Queryable[float]?): If keepBorder is on, this flag specifies the weight to assign  
                to borders.  Setting this value to 0 will disable border preservation  
                and a value of 1 will exactly preserve all border vertices which is  
                useful for matching adjacent meshes.  This flag only applies  
                when using the new algorithm. (-version 1)  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        keepColorBorder (bool?): If true, reduction will try to retain color borders.  These are  
                determined according to color Ids.  This flag only applies  
                when using the new algorithm. (-version 1)  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepColorBorderWeight (Queryable[float]?): If keepColorBorder is on, this flag specifies the weight to  
                assign to color borders.  Setting this value to 0 will disable  
                color border preservation and a value of 1 will exactly preserve  
                all color borders.  This flag only applies when using the new  
                algorithm. (-version 1)  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        keepCreaseEdge (bool?): If true, reduction will try to retain crease edges.  
                C: Default is true.  This flag only applies  
                when using the new algorithm. (-version 1)  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepCreaseEdgeWeight (Queryable[float]?): If keepCreaseEdge is on, this flag specifies the weight to assign  
                to crease edges.  Setting this value to 0 will disable crease  
                edge preservation and a value of 1 will exactly preserve all crease edges.  
                This flag only applies when using the new algorithm. (-version 1)  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        keepFaceGroupBorder (bool?): If true, reduction will try to retain borders of face groups,  
                which are mostly used to define material assignments.  This  
                flag only applies when using the new algorithm. (-version 1)  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepFaceGroupBorderWeight (Queryable[float]?): If keepFaceGroupBorder is on, this flag specifies the weight to  
                assign to material borders.  Setting this value to 0 will disable  
                group border preservation and a value of 1 will exactly preserve all  
                group borders.  This flag only applies when using the new  
                algorithm. (-version 1)  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        keepHardEdge (bool?): If true, reduction will try to retain hard edges.  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepHardEdgeWeight (Queryable[float]?): If keepHardEdge is on, this flag specifies the weight to assign  
                to hard edges.  Setting this value to 0 will disable hard  
                edge preservation and a value of 1 will exactly preserve all hard edges.  
                This flag only applies when using the new algorithm. (-version 1)  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        keepMapBorder (bool?): If true, reduction will try to retain UV borders.  A UV border  
                is present if the faces on either side of the edge do not share  
                UV Ids.  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepMapBorderWeight (Queryable[float]?): If keepMapBorder is on, this flag specifies the weight to assign  
                to UV map borders.  Setting this value to 0 will disable UV map  
                border preservation and a value of 1 will exactly preserve all UV borders.  
                This flag only applies when using the new algorithm. (-version 1)  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        keepOriginalVertices (bool?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                If true, vertices will try to retain their original positions  
                and will not be repositioned for optimal shape.  
                NOTE: In the newer algorithm vertices always retain  
                their exact original positions. (though the Ids will change)  
                C: Default is false.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepQuadsWeight (Queryable[float]?): This flag controls how much consideration is given to  
                oreserving quad faces during reduction.  A higher  
                weight means the reduction will try harder to keep quad  
                faces and avoid creation of triangles. If the version  
                flag is set to 1 (-version 1) and the keepQuadsWeight  
                flag is set to 1.0 then a special quad reduction algorithm  
                is used that does a better job of preserving quads.  
                Howver, this special quad reduction algorithm does  
                not support symmetry so those flags will be ignored  
                when the keepQuadsWeight flag is set to 1.0.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        percentage (Queryable[float]?): This flag specifies how many vertices to remove during reduction as a  
                percentage of the original mesh.  This flag only applies if the termination  
                flag is set to 0 or when using the old algorithm.  
                C: Default is 0. 100 will remove every possible vertex, 0 will remove none.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        preserveLocation (bool?): This flag guarantees that if the original geometry is preserved, the new  
                geometry will have the same location.  
                C: Default is false.  
                Properties: create
        preserveTopology (bool?): this flag guarantees that the topological type will be preserved during  
                reduction.  In particular, if the input is manifold then the output will be  
                manifold.  This option also prevents holes in the mesh from being closed off.  
                This flag only applies when using the new algorithm. (-version 1)  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        replaceOriginal (bool?): Create "in place" (i.e., replace) (not available in all commands). NOTE:  
                This flag is intended for use by the "Reduce" menu item. If  
                'polyReduce -rpo 0' is executed from the command line, Shader information will  
                not be copied from the original mesh to the result.  
                Properties: create
        sharpness (Queryable[float]?): Sharpness controls the balance between preserving small, sharp  
                details versus larger shapes.  At low values, details that are  
                small relative to the general shape of the object are more  
                likely to be collapsed.  At high values, they are more likely  
                to be kept.  This flag only applies when using the new  
                algorithm. (-version 1)  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        symmetryPlaneW (Queryable[float]?): W value of the symmetry plane.  This flag only applies  
                when using the new algorithm (-version 1) and the  
                useVirtualSymmetry flag is set to 2.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        symmetryPlaneX (Queryable[float]?): X value of the symmetry plane.  This flag only applies  
                when using the new algorithm (-version 1) and the  
                useVirtualSymmetry flag is set to 2.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        symmetryPlaneY (Queryable[float]?): Y value of the symmetry plane.  This flag only applies  
                when using the new algorithm (-version 1) and the  
                useVirtualSymmetry flag is set to 2.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        symmetryPlaneZ (Queryable[float]?): Z value of the symmetry plane.  This flag only applies  
                when using the new algorithm (-version 1) and the  
                useVirtualSymmetry flag is set to 2.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        symmetryTolerance (Queryable[float]?): Tolerance to use when applying symmetry.  
                For each vertex of the mesh, we find its exact symmetric point,  
                then we look for the closest vertex to the exact symmetry up to  
                the tolerance distance.  Higher values risk finding more  
                spurious symmetries, lower values might miss symmetries.  
                The value is distance in object space.  This flag only applies  
                when using the new algorithm (-version 1) and the  
                useVirtualSymmetry flag is not set to 0.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        termination (Queryable[int]?): This flag specifies the termination condition to use  
                when reducing the mesh.  This flag only applies to the  
                new algorithm. (-version 1)  
                0 Percentage  
                1 Vertex count  
                2 Triangle count  
                C: Default is 0.  
                Q: When queried, this flag returns an integer.  
                Properties: create, query, edit
        triangleCount (Queryable[int]?): This flag specifies a target number of triangles to retain after reduction.  
                Note that other factors such as quad and feature preservation  
                may take precendence and cause the actual number of triangles to be different.  
                This flag only applies when using the new algorithm (-version 1)  
                and the termination flag is set to 2.  
                C: Default is 0.  
                Q: When queried, this flag returns an integer.  
                Properties: create, query, edit
        triangulate (bool?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                This attribute specifies if the geometry  
                or the selected faces has to be triangulated,  
                before performing reduction.  
                C: Default is true.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        useVirtualSymmetry (Queryable[int]?): This flag controls whether symmetry is preserved during the  
                reduction. This flag only applies when using the new  
                algorithm (-version 1) and the keepQuadsWeight flag is less  
                than 1.0.  
                0 No symmetry preservation  
                1 Automatic. Try to find suitable symmetry during reduction.  
                2 Plane.  Specify a symmetry plane to use during reduction.  
                C: Default is 0.  
                Q: When queried, this flag returns an integer.  
                Properties: create, query, edit
        uvWeights (Queryable[float]?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                How much consideration uv positions are given in the  
                reduction algorithm. A higher weight means the  
                reduction will try harder to preserve uv positions.  
                C: Default is 0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        version (Queryable[int]?): Version of the poly reduce algorithm to use.  
                0 Old algorithm used in Maya 2013 and prior for backwards compatibility  
                1 New algorithm derived from Softimage and used in Maya 2014 and later  
                The default is 0 for backwards compatibility but for best results  
                it is recommended that the new algorithm is used as it is better at  
                preserving mesh details. Some flags only apply to a specific algorithm  
                and this is documented for each flag.  
                C: Default is 0 for backwards compatibility.  
                Q: When queried, this flag returns an integer.  
                Properties: create, query, edit
        vertexCount (Queryable[int]?): This flag specifies a target number of vertices to retain after reduction.  
                Note that other factors such as quad and feature preservation  
                may take precendence and cause the actual number of vertices to be different.  
                This flag only applies when using the new algorithm (-version 1)  
                and the termination flag is set to 1.  
                C: Default is 0.  
                Q: When queried, this flag returns an integer.  
                Properties: create, query, edit
        vertexMapName (Queryable[str]?): Name of a color set to be added to the output mesh that stores  
                a mapping from vertices in the output mesh to vertices in the  
                input mesh.  The color set is RGB.  The original vertex Id that  
                maps to an output vertex is of a vertex is 65536*r + g where r  
                and g are the red and green channel at a vertex. The blue  
                channel is always zero.  Each vertex in the output mesh has a  
                shared color. This flag only applies when using the new  
                algorithm. (-version 1)  
                Q: When queried, this flag returns a string.  
                Properties: create, query
        vertexWeightCoefficient (Queryable[float]?): This flag specifies a constant value to multiply to each weight map value.  
                A value of zero turns off the weight map.  This flag only applies  
                when using the new algorithm. (-version 1)  
                C: Default is 1.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        weightCoefficient (Queryable[float]?): This flag only applies when using the old algorithm and  
                is provided for backwards compatibility.  
                The weight of each vertex is multiplied with this coefficient  
                when the reduction is performed.  This value does not have  
                to be edited, normally.  It gives finer control over the  
                weighted reduction. This attribute is replaced by  
                vertexWeightCoefficient in the new algorithm when the version  
                flag is set to 1.  
                C: Default is 10000.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyRemesh(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., collapseThreshold: Queryable[float] = ..., constructionHistory: bool = ..., interpolationType: Queryable[int] = ..., maxEdgeLength: Queryable[float] = ..., name: str = ..., nodeState: Queryable[int] = ..., smoothStrength: Queryable[float] = ..., tessellateBorders: bool = ..., useRelativeValues: bool = ...) -> Union[str, bool, float, int]:
    """Triangulates, then remeshes the given mesh through edge splitting and collapsing.
    Edges longer than the specified max edge length are split, and edges shorter
    than the collapse threshold are collapsed.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        collapseThreshold (Queryable[float]?): A percentage of the maxEdgeLength. Edges shorter than this percentage will be reduced to a single vertex.  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        interpolationType (Queryable[int]?): Algorithm used for interpolating new vertices  
                Properties: create, query, edit
        maxEdgeLength (Queryable[float]?): Triangle edges longer than this value will be split into two edges.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        smoothStrength (Queryable[float]?): Amount of smoothing applied to the vertices after remeshing.  
                Properties: create, query, edit
        tessellateBorders (bool?): Specifies if the borders of the selected region are allowed to be remeshed.  
                Properties: create, query, edit
        useRelativeValues (bool?): Specifies if the refine threshold value is relative to the average edge length of the input mesh.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyRetopo(*args: str) -> str:
    """Retopologize a polygonial surface.
    Returns:
        str: The node name.

    Example:
    """

def polyRetopoCtx(*args: Any, **kwargs: Any) -> None: ...
def polySelect(*args: str, query: bool = ..., add: bool = ..., addFirst: bool = ..., asSelectString: bool = ..., deselect: bool = ..., edgeBorder: Multiuse[int] = ..., edgeBorderPath: Multiuse[Tuple[int, int]] = ..., edgeBorderPattern: Multiuse[Tuple[int, int]] = ..., edgeLoop: Multiuse[int] = ..., edgeLoopOrBorder: Multiuse[int] = ..., edgeLoopOrBorderPattern: Multiuse[Tuple[int, int]] = ..., edgeLoopPath: Multiuse[Tuple[int, int]] = ..., edgeLoopPattern: Multiuse[Tuple[int, int]] = ..., edgeRing: Multiuse[int] = ..., edgeRingPath: Multiuse[Tuple[int, int]] = ..., edgeRingPattern: Multiuse[Tuple[int, int]] = ..., edgeUVLoopOrBorder: Multiuse[int] = ..., everyN: int = ..., extendToShell: Multiuse[int] = ..., noSelection: bool = ..., replace: bool = ..., shortestEdgePath: Multiuse[Tuple[int, int]] = ..., shortestEdgePathUV: Multiuse[Tuple[int, int]] = ..., shortestFacePath: Multiuse[Tuple[int, int]] = ..., toggle: bool = ...) -> Union[List[int], bool]:
    """This command makes different types of poly component selections.  The return value
    is an integer array containing the id's of the components in the selection in order.
    If a given type of selection loops back on itself then this is indicated by the start id
    appearing twice, once at the start and once at the end.
    Args:
        add (bool?): Indicates that the specified items should be  
                added to the active list without removing existing  
                items from the active list.  
                Properties: create, query
        addFirst (bool?): Indicates that the specified items should be  
                added to the front of the active list without  
                removing existing items from the active list.  
                Properties: create, query
        asSelectString (bool?): Changes the return type from an integer array to  
                a string array which can be used as a selection string.  
                Properties: create, query
        deselect (bool?): Indicates that the specified items should  
                be removed from the active list if they are on the  
                active list.  
                Properties: create, query
        edgeBorder (Multiuse[int]?): Select all conected border edges starting at the given edge.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeBorderPath (Multiuse[Tuple[int, int]]?): Given two edges on the same border, this will select  
                the edges on the border in the path between them.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeBorderPattern (Multiuse[Tuple[int, int]]?): Given two edges on the same border, this will check how  
                many edges there are between the given edges and then  
                continue that pattern of selection around the border.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeLoop (Multiuse[int]?): Select an edge loop starting at the given edge.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeLoopOrBorder (Multiuse[int]?): Select an edge loop or all conected border edges,  
                depending on whether the edge is on a border or not,  
                starting at the given edge.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeLoopOrBorderPattern (Multiuse[Tuple[int, int]]?): Given two edges either on the same edge loop or on the  
                same edge border, this will check how many edges there  
                are between the given edges and then continue that pattern  
                of selection around the edge loop or edge border.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeLoopPath (Multiuse[Tuple[int, int]]?): Given two edges that are on the same edge loop, this  
                will select the shortest path between them on the loop.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeLoopPattern (Multiuse[Tuple[int, int]]?): Given two edges on the same edge loop, this will check how  
                many edges there are between the given edges and then  
                continue that pattern of selection around the edge loop.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeRing (Multiuse[int]?): Select an edge ring starting at the given edge.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeRingPath (Multiuse[Tuple[int, int]]?): Given two edges that are on the same edge ring, this  
                will select the shortest path between them on the ring.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeRingPattern (Multiuse[Tuple[int, int]]?): Given two edges on the same edge ring, this will check how  
                many edges there are between the given edges and then  
                continue that pattern of selection around the edge ring.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        edgeUVLoopOrBorder (Multiuse[int]?): Select an edge loop or border, terminating at UV borders.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        everyN (int?): Number of elements to stride over. If less than 1 then  
                use 1, meaning every element. 2 means every second one, etc.  
                Properties: create
        extendToShell (Multiuse[int]?): Select the poly shell given a face id.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        noSelection (bool?): If this flag is used then the selection is not  
                changed at all.  
                Properties: create, query
        replace (bool?): Indicates that the specified items should  
                replace the existing items on the active list.  
                Properties: create, query
        shortestEdgePath (Multiuse[Tuple[int, int]]?): Given two vertices, this will select the shortest path  
                between them in the 3d object space.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        shortestEdgePathUV (Multiuse[Tuple[int, int]]?): Given two UVs, this will select the shortest path  
                between them in the 2d texture space.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        shortestFacePath (Multiuse[Tuple[int, int]]?): Given two faces, this will select the shortest path  
                between them in the 3d object space.  
                      In query mode, this flag needs a value.  
                Properties: create, query, multiuse
        toggle (bool?): Indicates that those items on the given list which  
                are on the active list should be removed from the active  
                list and those items on the given list which are not on  
                the active list should be added to the active list.  
                Properties: create, query

    Returns:
        List[int]: List of selected components.

    Example:
    """

def polySelectConstraint(*, query: bool = ..., angle: Queryable[int] = ..., anglePropagation: bool = ..., angleTolerance: Queryable[float] = ..., anglebound: Queryable[Tuple[float, float]] = ..., border: bool = ..., borderPropagation: bool = ..., convexity: Queryable[int] = ..., crease: bool = ..., disable: bool = ..., dist: Queryable[int] = ..., distaxis: Queryable[Tuple[float, float, float]] = ..., distbound: Queryable[Tuple[float, float]] = ..., distpoint: Queryable[Tuple[float, float, float]] = ..., edgeDistance: int = ..., geometricarea: Queryable[int] = ..., geometricareabound: Queryable[Tuple[float, float]] = ..., holes: Queryable[int] = ..., length: Queryable[int] = ..., lengthbound: Queryable[Tuple[float, float]] = ..., loopPropagation: bool = ..., max2dAngle: float = ..., max3dAngle: float = ..., mode: Queryable[int] = ..., nonmanifold: Queryable[int] = ..., oppositeEdges: bool = ..., order: Queryable[int] = ..., orderbound: Queryable[Tuple[int, int]] = ..., orient: Queryable[int] = ..., orientaxis: Queryable[Tuple[float, float, float]] = ..., orientbound: Queryable[Tuple[float, float]] = ..., planarity: Queryable[int] = ..., propagate: Queryable[int] = ..., random: Queryable[int] = ..., randomratio: Queryable[float] = ..., returnSelection: bool = ..., ringPropagation: bool = ..., shell: bool = ..., size: Queryable[int] = ..., smoothness: Queryable[int] = ..., stateString: bool = ..., textured: Queryable[int] = ..., texturedarea: Queryable[int] = ..., texturedareabound: Queryable[Tuple[float, float]] = ..., textureshared: Queryable[int] = ..., topology: Queryable[int] = ..., type: Queryable[int] = ..., uvBorderSelection: bool = ..., uvConstraint: bool = ..., uvEdgeLoopPropagation: bool = ..., uvEdgeRingPropagation: bool = ..., uvFaceOrientation: Queryable[int] = ..., uvShell: bool = ..., visibility: Queryable[int] = ..., visibilityangle: Queryable[float] = ..., visibilitypoint: Queryable[Tuple[float, float, float]] = ..., where: Queryable[int] = ..., wholeSensitive: bool = ...) -> Union[bool, int, float, Tuple[float, float], Tuple[float, float, float], Tuple[int, int]]:
    """Changes the global polygonal selection constraints.
    Args:
        angle (Queryable[int]?): 0(off) 1(on).  
                Properties: create, query
        anglePropagation (bool?): If true, selection will be extended to all connected components whose normal  
                is close to any of the normals of the original selection (see angleTolerance)  
                Properties: create, query
        angleTolerance (Queryable[float]?): When angle propagation is turned on, this controls what is the maximum  
                difference of the normal vectors where the selection propagates.  
                Properties: create, query
        anglebound (Queryable[Tuple[float, float]]?): min and max angles.  The given value should be in the current units that  
                Maya is using.  See the examples for how to check the current unit.  
                For vertices :    angle between the 2 edges owning the vertex.  
                For edges :        angle between the 2 faces owning the edge.  
                Properties: create, query
        border (bool?): Use "-uvConstraint true" to edit/query UV view constraint.  
                If true, selection will be extended to all connected border components  
                so that the whole "loop" is selected. It also removes all nonborder components  
                from the existing selection (compatibility mode)  
                Properties: create, query
        borderPropagation (bool?): If true, selection will be extended to all connected border components  
                so that the whole "loop" is selected.  
                Properties: create, query
        convexity (Queryable[int]?): 0(off) 1(concave) 2(convex).  
                Properties: create, query
        crease (bool?): If true, selection will be extended to all connected creased components.  
                Properties: create, query
        disable (bool?): Toggles off all constraints for all component types, but  
                leaves the other constraint parameters.   
                This flag may be used together with other ones toggling some  
                constraints on : if so, all constraints are  
                disabled first (no matter the position of the -disable flag in  
                the command line) then the specified ones are activated.  
                Properties: create
        dist (Queryable[int]?): 0(off) 1(to point) 2(to axis) 3(to plane).  
                Properties: create, query
        distaxis (Queryable[Tuple[float, float, float]]?): axis. (Normal to the plane in case of distance to plane).  
                Properties: create, query
        distbound (Queryable[Tuple[float, float]]?): min and max distances.  
                Properties: create, query
        distpoint (Queryable[Tuple[float, float, float]]?): point. (Axis/plane origin in case of distance to axis/plane).  
                Properties: create, query
        edgeDistance (int?): Maximum distance (number of edges) to extend the edge selection for "Contiguous Edges" propagate mode. 0 means to ignore the distance constraint.  
                Properties: create
        geometricarea (Queryable[int]?): 0(off) 1(on).  
                Properties: create, query
        geometricareabound (Queryable[Tuple[float, float]]?): min and max areas.  
                Properties: create, query
        holes (Queryable[int]?): 0(off) 1(holed) 2(non holed).  
                Properties: create, query
        length (Queryable[int]?): 0(off) 1(on).  
                Properties: create, query
        lengthbound (Queryable[Tuple[float, float]]?): min and max lengths.  
                Properties: create, query
        loopPropagation (bool?): If true, edge selection will be extended to a loop.  
                Properties: create, query
        max2dAngle (float?): Maximum angle between two consecutive edges in the 2d tangent plane for "Contiguous Edges" propagate mode.  
                Properties: create
        max3dAngle (float?): Maximum angle between two consecutive edges in 3d space for "Contiguous Edges" propagate mode.  
                Properties: create
        mode (Queryable[int]?): 0(Off) 1(Next) 2(Current and Next) 3(All and Next).  
                Off :             no constraints are used at all.  
                Next :             constraints will be used to filter next selections.  
                Current and Next :    constraints will be aplied on current selection  
                and then used to filter next selections.  
                All and Next :        all items satisfying constraints are selected.  
                Properties: create, query
        nonmanifold (Queryable[int]?): 0(off) 1(on)  
                Properties: create, query
        oppositeEdges (bool?): Use the opposite edges  
                Properties: create
        order (Queryable[int]?): 0(off) 1(on).  
                Properties: create, query
        orderbound (Queryable[Tuple[int, int]]?): min and max orders.  
                number of owning edges.  
                Properties: create, query
        orient (Queryable[int]?): 0(off) 1(orientation) 2(direction).  
                Properties: create, query
        orientaxis (Queryable[Tuple[float, float, float]]?): axis.  
                Properties: create, query
        orientbound (Queryable[Tuple[float, float]]?): min and max angles.  The given value should be in the current units that  
                Maya is using.  See the examples for how to check the current unit.  
                Properties: create, query
        planarity (Queryable[int]?): 0(off) 1(non planar) 2(planar).  
                Properties: create, query
        propagate (Queryable[int]?): 0(Off) 1(More) 2(Less) 3(Border) 4(Contiguous Edges) 5(Grow Along Loop) 6(Shrink Along Loop).  
                More :        will add current selection border to current selection.  
                Less :        will remove current selection border from current selection.  
                Border :    will keep only current selection border.  
                Contiguous Edges :    Add edges aligned with the current  
                edges selected. The direction and number of edges selected is  
                controlled by the -m2a, -m3a, and -ed flags.  
                Grow Along Loop:    Will grow current selection along loop, support face, edge, vertex and UV.  
                Shrink Along Loop:    Will shrink current selection along loop, support face, edge, vertex and UV.  
                Properties: create, query
        random (Queryable[int]?): 0(off) 1(on).  
                Properties: create, query
        randomratio (Queryable[float]?): ratio [0,1].  
                Properties: create, query
        returnSelection (bool?): If true, current selection will not be modified, instead the new selection will be returned as result.  
                Properties: create
        ringPropagation (bool?): If true, edge selection will be extended to a ring.  
                Properties: create, query
        shell (bool?): If true, selection will be extended to all connected components  
                so that the whole piece of object is selected.  
                Properties: create, query
        size (Queryable[int]?): 0(off) 1(triangles) 2(quads) 3(nsided).  
                Properties: create, query
        smoothness (Queryable[int]?): 0(off) 1(hard) 2(smooth).  
                Properties: create, query
        stateString (bool?): Query only flag. Returns the MEL command that would restore all  
                the current settings.  
                Properties: query
        textured (Queryable[int]?): 0(off) 1(mapped) 2(unmapped).  
                Properties: create, query
        texturedarea (Queryable[int]?): 0(off) 1(Area specified is unsigned) 2(Area specified is signed).  
                Properties: create, query
        texturedareabound (Queryable[Tuple[float, float]]?): min and max areas.  
                Properties: create, query
        textureshared (Queryable[int]?): 0(off) 1(on).  
                This option will select any UVs on the currentMap which are shared  
                by more than one vertex  
                Properties: create, query
        topology (Queryable[int]?): 0(off) 1(non triangulatable) 2(lamina) 3(non triangulatable and lamina)  
                Properties: create, query
        type (Queryable[int]?): 0x0000(none)  
                0x0001(vertex)  
                0x8000(edge)  
                0x0008(face)  
                0x0010(texture coordinates)  
                Properties: create, query
        uvBorderSelection (bool?): This flag only works on UV view  
                If true, selection will be extended to all UV border components  
                It also removes all components not on UV border from the existing selection  
                Properties: create, query
        uvConstraint (bool?): If true, applicable constraint flags will work on UV view.  
                      In query mode, this flag can accept a value.  
                Properties: create
        uvEdgeLoopPropagation (bool?): Use "-uvConstraint true" to edit/query UV view constraint.  
                If true, UV edge selection will be extended to a loop.  
                Properties: create, query
        uvEdgeRingPropagation (bool?): This flag only works on UV view  
                If true, UV edge selection will be extended to a ring.  
                Properties: create, query
        uvFaceOrientation (Queryable[int]?): This flag only works on UV view  
                0(Off) 1(Front Face) 2(Back Face).  
                Properties: create, query
        uvShell (bool?): If true, selection will be extended to all connected components in UV space  
                Properties: create, query
        visibility (Queryable[int]?): 0(off) 1(on).  
                Properties: create, query
        visibilityangle (Queryable[float]?): angle [0,360].  
                Properties: create, query
        visibilitypoint (Queryable[Tuple[float, float, float]]?): point.  
                Properties: create, query
        where (Queryable[int]?): 0(off) 1(on border) 2(inside).  
                Properties: create, query
        wholeSensitive (bool?): Tells how to select faces : either  
                 by picking anywhere inside the face (if true)  
                 or by picking on the face center marker (if false).  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polySelectConstraintMonitor(*args: Any, changeCommand: Tuple[str, str] = ..., create: bool = ..., delete: bool = ...) -> bool:
    """Manage the window to display/edit the polygonal selection constraint
    parameters
    Args:
        changeCommand (Tuple[str, str]?): Specifies the mel callback to refresh the window. First argument is  
                the callback, second is the window name.  
                Properties: create
        create (bool?): Specifies the Monitor should be created  
                Properties: create
        delete (bool?): Specifies that the Monitor should be removed  
                Properties: create

    Returns:
        bool:

    Example:
    """

def polySelectCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., mode: Queryable[int] = ...) -> Union[bool, str, int]:
    """Create a new context to select polygon components
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        mode (Queryable[int]?): Edge loop or Edge ring or Border edge mode  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polySelectEditCtx(*args: Any, edit: bool = ..., query: bool = ..., adjustEdgeFlow: Queryable[float] = ..., divisions: Queryable[int] = ..., exists: bool = ..., fixQuads: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., insertWithEdgeFlow: bool = ..., smoothingAngle: Queryable[float] = ..., splitType: Queryable[int] = ..., useEqualMultiplier: bool = ..., absoluteOffset: bool = ..., autoComplete: bool = ..., deleteEdge: bool = ..., endVertexOffset: Queryable[float] = ..., mode: Queryable[int] = ..., startVertexOffset: Queryable[float] = ...) -> Union[str, float, int, bool]:
    """Create a new context to select and edit polygonal objects
    Args:
        adjustEdgeFlow (Queryable[float]?): The weight value of the edge vertices to be positioned.  
                Default: 1.0f  
                Properties: create, query, edit
        divisions (Queryable[int]?): Number of divisions.  
                Default: 2  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        fixQuads (bool?): Fixes splits which go across a quad face leaving a 5 and 3  
                sided faces by splitting from the middle of the new edge to  
                the vertex accross from the edge on the 5 sided face.  
                Default: false  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        insertWithEdgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Default: false  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Angle below which new edges will be smoothed  
                Default: kPi  
                Properties: create, query, edit
        splitType (Queryable[int]?): Format: 0. Absolute, 1. Relative, 2. Multi  
                Default: TdnpolySplitRing::Relative  
                Properties: create, query, edit
        useEqualMultiplier (bool?): Changes how the profile curve effects the offset when doing  
                a multisplit.  If true then the verts will be offset the same distance  
                based on the shortest edge being split.  If false then each inserted  
                edge loop will be offset a distance relative to the length of the edge  
                that is being split.  
                Default: true  
                Properties: create, query, edit
        absoluteOffset (bool?): This flag is deprecated. Use splitType/stp instead.  
                This flag is deprecated. Use splitType/stp instead.  
                Properties: create, query, edit
        autoComplete (bool?): If true then use auto completion on selections  
                Properties: create
        deleteEdge (bool?): When true, the end edges are deleted so the end triangles are converted to quads.  
                Properties: create, query, edit
        endVertexOffset (Queryable[float]?): Weight value controlling the offset of the end vertex of the edgeloop.  
                Properties: create, query, edit
        mode (Queryable[int]?): which mode to work on.  Available modes are 1. loop and 2. ring  
                Properties: create, query, edit
        startVertexOffset (Queryable[float]?): Weight value controlling the offset of the start vertex of the edgeloop.  
                Properties: create, query, edit

    Returns:
        str: The context name

    Example:
    """

def polySelectEditCtxDataCmd(*args: Any, **kwargs: Any) -> None: ...
def polySelectSp(*args: str, query: bool = ..., loop: bool = ..., ring: bool = ...) -> None: ...
def polySeparate(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., removeShells: bool = ..., separateSpecificShell: Multiuse[int] = ...) -> Union[List[str], bool, int]:
    """This command creates new objects from the given poly.
    A new object will be created for each section of the mesh
    that is distinct (no edges connect it to the rest of the mesh).This command can only separate one object at a time.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        removeShells (bool?): Remove the shells after creation.  
                Properties: create
        separateSpecificShell (Multiuse[int]?): List of shell ids to be separated.  
                Properties: create, multiuse

    Returns:
        List[str]: Object name(s) and node name.

    Example:
    """

def polySetToFaceNormal(*args: str, setUserNormal: bool = ...) -> str:
    """This command takes selected polygonal vertices or vertex-faces and changes
    their normals. If the optionis used, the new normal
    values will be the face normals arround the vertices/vertex-faces. Otherwise
    the new normal values will be default values according to the internal
    calculation.poly, userNormal, polyNormals, setToFaceNormal, setNormal, vertexNormal
    Args:
        setUserNormal (bool?): when this flag is presented, user normals will be created on each vertex  
                face and the values will be the face normal value. Otherwise the normal  
                values will be the internal computing results. Default is false.  
                Properties: create

    Returns:
        str: of the node name

    Example:
    """

def polySetVertices() -> None: ...
def polySewEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., texture: bool = ..., tolerance: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Merge border edges within a given threshold.Perform pair-wise comparison of selected edges. Pairs whose
    corresponding vertices meet threshold conditions and whose
    orientations are aligned (i.e. their respective normals point
    in the same direction) are merged, as are the vertices (in
    other words, vertices are shared).Resulting mesh may have extra vertices or edges to ensure
    geometry is valid.Edges must be on the same object to be merged.Default : share only vertices lying exactly at the same place.
    (polySewEdge -t 0.0)
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        texture (bool?): If true : texture is sewn as well as the 3d edge.  
                C: Default is true.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance to sew edges (edge distance)  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyShortestPathCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> Union[bool, str]:
    """Creates a new context to select shortest edge path
    between two vertices or UVs in the 3d viewport.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polySlideEdge(*args: str, absolute: bool = ..., direction: int = ..., edgeDirection: float = ..., symmetry: bool = ...) -> bool:
    """Moves an edge loop selection along the edges connected to the sides of
    its vertices.
    Args:
        absolute (bool?): This flag specifies whether or not the command uses absolute mode  
                If in absolute then all vertices will move the same distance (the  
                specified percentage of the smallest edge)  
                C: Default is off  
                Properties: create
        direction (int?): This flag specifies the direction of the slide edge movement  
                0. is left direction (relative)  
                1. is right direction (relative)  
                2. is normal direction (relative)  
                C: Default is 0  
                Properties: create
        edgeDirection (float?): This flag specifies the relative percentage to move along the edges on  
                either side of the vertices along the edge loop  
                C: Default is 0.0  
                Properties: create
        symmetry (bool?): This flag specifies whether or not the command will do a symmetrical slide. Only takes effect  
                when symmetry is enabled.  
                C: Default is off  
                Properties: create

    Returns:
        bool: Success value

    Example:
    """

def polySlideEdgeCtx(*args: Any, **kwargs: Any) -> None: ...
def polySmooth(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., continuity: Queryable[float] = ..., degree: int = ..., divisions: Queryable[int] = ..., divisionsPerEdge: int = ..., keepBorder: bool = ..., keepHardEdge: bool = ..., keepMapBorders: int = ..., keepSelectionBorder: bool = ..., keepTesselation: bool = ..., keepTessellation: bool = ..., method: int = ..., osdCreaseMethod: Queryable[int] = ..., osdFvarBoundary: Queryable[int] = ..., osdFvarPropagateCorners: bool = ..., osdSmoothTriangles: bool = ..., osdVertBoundary: Queryable[int] = ..., propagateEdgeHardness: bool = ..., pushStrength: float = ..., roundness: float = ..., smoothUVs: bool = ..., subdivisionLevels: int = ..., subdivisionType: Queryable[int] = ...) -> Union[str, bool, int, float]:
    """Smooth a polygonal object. This command works on polygonal objects
    or faces.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        continuity (Queryable[float]?): This flag specifies the smoothness parameter. The minimum value of 0.0  
                specifies that the faces should only be subdivided. Maximum value of 1.0 smooths  
                the faces as much as possible.  
                C: Default is 1.0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        degree (int?): Degree of the resulting limit surface  
                Properties: create
        divisions (Queryable[int]?): This flag specifies the number of recursive smoothing steps.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        divisionsPerEdge (int?): Number of subdivisions along one edge for each step.  
                Properties: create
        keepBorder (bool?): If on, the border of the object will not move during smoothing operation.  
                C: Default is "on".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        keepHardEdge (bool?): If true, vertices on hard edges will not be modified.  
                C: Default is false.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepMapBorders (int?): Treatment of UV map borders  
                0. all map border edges will be smoothed  
                1. map borders that are also geometry borders will be smoothed  
                2. no map borders will be smoothed  
                Properties: create
        keepSelectionBorder (bool?): If true, vertices on border of the selection will not be modified.  
                C: Default is false.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        keepTesselation (bool?): If true: the object will be smoothed consistently from frame to frame.  
                This is best when the object is being deformed or animated .  
                If false: non-starlike faces will be triangulated before being  
                smoothed.  This avoids self-overlapping faces, but could lead to a  
                change in topology (number of vertices/faces) from frame to frame,  
                during an animated deformation.  
                Properties: create
        keepTessellation (bool?): If true: the object will be smoothed consistently from frame to frame.  
                This is best when the object is being deformed or animated .  
                If false: non-starlike faces will be triangulated before being  
                smoothed.  This avoids self-overlapping faces, but could lead to a  
                change in topology (number of vertices/faces) from frame to frame,  
                during an animated deformation.  
                Properties: create
        method (int?): Type of smoothing algorithm to use  
                0. exponential - traditional smoothing  
                1. linear - number of faces per edge grows linearly  
                Properties: create
        osdCreaseMethod (Queryable[int]?): Controls how boundary edges and vertices are interpolated.  
                Properties: create, query, edit
        osdFvarBoundary (Queryable[int]?): Controls how boundaries are treated for face-varying data (UVs and Vertex Colors).  
                Properties: create, query, edit
        osdFvarPropagateCorners (bool?):   
                Properties: create, query, edit
        osdSmoothTriangles (bool?): Apply a special subdivision rule be applied to all triangular faces  
                that was empirically determined to make triangles subdivide more smoothly.  
                Properties: create, query, edit
        osdVertBoundary (Queryable[int]?): Controls how boundary edges and vertices are interpolated.  
                Properties: create, query, edit
        propagateEdgeHardness (bool?): If true, edges which are a result of smoothed edges will be given  
                the same value for their edge hardness.  New subdivided edges will  
                always be smooth.  
                C: Default is false.  
                Q: When queried, this flag returns a boolean.  
                Properties: create, query, edit
        pushStrength (float?): COMMENT 0.0 is approximation, 1.0 is interpolation scheme  
                Properties: create
        roundness (float?): When 1.0, push vectors are renormalized to keep length constant  
                Properties: create
        smoothUVs (bool?): If true: UVs as well as geometry will be smoothed  
                Properties: create
        subdivisionLevels (int?): Number of times the subdivide and smooth operation is run.  
                Properties: create
        subdivisionType (Queryable[int]?): The subdivision method used for smoothing.  
                C: Default is 0.  
                0. Maya Catmull-Clark  
                1. OpenSubdiv Catmull-Clark  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySoftEdge(*args: str, edit: bool = ..., query: bool = ..., angle: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, float, bool, int]:
    """Selectively makes edges soft or hard.An edge will be made hard if the angle between two owning
    faces is sharper (larger) than the smoothing angle.An edge wil be made soft if the angle between two owning
    facets is flatter (smaller) than the smoothing angle.
    Args:
        angle (Queryable[float]?): Smoothing angle.  
                C: Default is 30 degrees.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The name of the polySoftEdge node.

    Example:
    """

def polySphere(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., createUVs: int = ..., radius: Queryable[float] = ..., subdivisionsAxis: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., subdivisionsX: Queryable[int] = ..., subdivisionsY: Queryable[int] = ..., texture: int = ...) -> Union[List[str], bool, int, Tuple[float, float, float], float]:
    """The sphere command creates a new polygonal sphere.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the sphere.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        createUVs (int?): This flag alows a specific UV mechanism to be selected, while creating the sphere.  
                The valid values are 0, 1, or 2.  
                0 implies that no UVs will be generated (No texture to be applied).  
              
                1 implies UVs are created with pinched at poles  
              
                2 implies UVs are created with sawtooth at poles  
              
                  For better understanding of these options, you may have to open the  
                     texture view window  
              
                C: Default is 2  
                Properties: create
        radius (Queryable[float]?): This flag specifies the radius of the sphere.  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): Subdivisions around the axis.  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height of the sphere.  
                Properties: create, query, edit
        subdivisionsX (Queryable[int]?): This specifies the number of subdivisions in the X direction for the sphere.  
                C: Default is 20.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsY (Queryable[int]?): This flag specifies the number of subdivisions in the Y direction for the sphere.  
                C: Default is 20.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (int?): This flag is obsolete and will be removed in the next release.  
                The -cuv/createUVs flag should be used instead.  
                Properties: create

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polySphericalProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., createNewMap: bool = ..., insertBeforeDeformers: bool = ..., keepImageRatio: bool = ..., mapDirection: str = ..., name: str = ..., nodeState: Queryable[int] = ..., perInstance: bool = ..., smartFit: bool = ..., worldSpace: bool = ..., imageCenter: Queryable[Tuple[float, float]] = ..., imageCenterX: Queryable[float] = ..., imageCenterY: Queryable[float] = ..., imageScale: Queryable[Tuple[float, float]] = ..., imageScaleU: Queryable[float] = ..., imageScaleV: Queryable[float] = ..., projectionCenter: Queryable[Tuple[float, float, float]] = ..., projectionCenterX: Queryable[float] = ..., projectionCenterY: Queryable[float] = ..., projectionCenterZ: Queryable[float] = ..., projectionHorizontalSweep: Queryable[float] = ..., projectionScale: Queryable[Tuple[float, float]] = ..., projectionScaleU: Queryable[float] = ..., projectionScaleV: Queryable[float] = ..., radius: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., rotationAngle: Queryable[float] = ..., seamCorrect: bool = ...) -> Union[str, bool, int, Tuple[float, float], float, Tuple[float, float, float]]:
    """TpolyProjCmdBase is a base class for the command to create a mapping on the selected polygonal faces.
    Projects a spherical map onto an object.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createNewMap (bool?): This flag when set true will create a new map with  
                a the name passed in, if the map does not already exist.  
                Properties: create, query
        insertBeforeDeformers (bool?): This flag specifies if the projection node should be inserted before  
                or after deformer nodes already applied to the shape. Inserting the  
                projection after the deformer leads to texture swimming during  
                animation and is most often undesirable.  
                C: Default is on.  
                Properties: create
        keepImageRatio (bool?): True means keep any image ratio  
                Properties: create
        mapDirection (str?): This flag specifies the mapping direction.  
                'x', 'y' and 'z' projects the map along the corresponding axis.  
                'c' projects along the current camera viewing direction.  
                'p' does perspective projection if current camera is perspective.  
                'b' projects along the best plane fitting the objects selected.  
                Properties: create
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        perInstance (bool?): True if the new map is per-instance, otherwise it is shared.  
                Properties: create
        smartFit (bool?): True means use the smart fit algorithm  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        imageCenter (Queryable[Tuple[float, float]]?): This flag specifies the center point of the 2D model layout.  
                C: Default is 0.5 0.5.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        imageCenterX (Queryable[float]?): This flag specifies X for the center point of the 2D model layout.  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        imageCenterY (Queryable[float]?): This flag specifies Y for the center point of the 2D model layout.  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        imageScale (Queryable[Tuple[float, float]]?): This flag specifies the UV scale : Enlarges or reduces the 2D version of the model in U  
                or V space relative to the 2D centerpoint.  
                C: Default is 1.0 1.0.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        imageScaleU (Queryable[float]?): This flag specifies the U scale : Enlarges or reduces the 2D version of the model in U space relative to the 2D centerpoint.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        imageScaleV (Queryable[float]?): This flag specifies the V scale : Enlarges or reduces the 2D version of the model in V space relative to the 2D centerpoint.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionCenter (Queryable[Tuple[float, float, float]]?): This flag specifies the origin point from which the map is projected.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        projectionCenterX (Queryable[float]?): This flag specifies X for the origin point from which the map is projected.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionCenterY (Queryable[float]?): This flag specifies Y for the origin point from which the map is projected.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionCenterZ (Queryable[float]?): This flag specifies Z for the origin point from which the map is projected.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionHorizontalSweep (Queryable[float]?): The angle swept horizontally by the projection.  The range is [0, 360].  
                Properties: create, query, edit
        projectionScale (Queryable[Tuple[float, float]]?): This flag specifies the width and the height of the map relative to the 3D projection axis.  
                C: Default is 180.0 90.0.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        projectionScaleU (Queryable[float]?): This flag specifies the width of the map relative to the 3D projection axis : the scale aperture. The range is [0, 360].  
                C: Default is 180.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionScaleV (Queryable[float]?): This flag specifies the height of the map relative to the 3D projection axis : the scale height.  
                C: Default is 90.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        radius (Queryable[float]?): Used by the UI : Manipulator.  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): This flag specifies the mapping rotate angles.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        rotateX (Queryable[float]?): This flag specifies X mapping rotate angle.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        rotateY (Queryable[float]?): This flag specifies Y mapping rotate angle.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): This flag specifies Z mapping rotate angle.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotationAngle (Queryable[float]?): This flag specifies the rotation angle in the mapping space.  
                When the angle is positive, then the map rotates  
                counterclockwise on the mapped model, whereas when it is  
                negative then the map rotates clockwise on the mapped model.  
                C: Default is 10.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        seamCorrect (bool?): This flag specifies to perform a seam correction  
                on the mapped faces.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySpinEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., frozen: bool = ..., name: str = ..., nodeState: int = ..., offset: int = ..., reverse: bool = ...) -> None: ...
def polySplit(*args: str, edit: bool = ..., query: bool = ..., constructionHistory: bool = ..., name: str = ..., adjustEdgeFlow: Queryable[float] = ..., detachEdges: bool = ..., edgepoint: Multiuse[Tuple[int, float]] = ..., facepoint: Multiuse[Tuple[int, float, float, float]] = ..., insertWithEdgeFlow: bool = ..., insertpoint: Multiuse[Union[Tuple[int, float], Tuple[int, float, float, float]]] = ..., projectedCurve: Multiuse[str] = ..., projectedCurveTolerance: float = ..., smoothingangle: float = ..., subdivision: Queryable[int] = ...) -> Union[str, bool, float, int]:
    """Split facets/edges of a polygonal object.The first and last arguments must be edges. Intermediate points
    may lie on either a shared face or an edge which neighbors the previous point.
    Args:
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        adjustEdgeFlow (Queryable[float]?): The weight value of the edge vertices to be positioned.  
                Properties: create, query, edit
        detachEdges (bool?): Value of the detachEdges attribute for the resulting poly split node.  
                Properties: create
        edgepoint (Multiuse[Tuple[int, float]]?): The given edge is split into two new edges  
                by inserting a new vertex located the given percentage  
                along the edge.  
              
                Note: This flag is not recommended for use from Python.  See the  
                insertpoint flag instead.  
                Properties: create, multiuse
        facepoint (Multiuse[Tuple[int, float, float, float]]?): A new vertex is inserted,  
                lying at the given coordinates inside the given face.  
                Coordinates are given in the local object space.  
              
                Note: This flag is not recommended for use from Python.  See the  
                insertpoint flag instead.  
                Properties: create, multiuse
        insertWithEdgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Properties: create, query, edit
        insertpoint (Multiuse[Union[Tuple[int, float], Tuple[int, float, float, float]]]?): This flag allows the caller to insert a new vertex into an edge or a face.  
              
                To insert a new vertex in an edge, pass the index of the edge and a percentage  
                along the edge at which to insert the new vertex.  When used to insert a  
                vertex into an edge, this flag takes two arguments.  
              
                To insert a new vertex into a face, pass the index of the face and three values  
                which define the coordinates for the insertion in local object space.  When  
                used to insert a vertex into a face, this flag takes four arguments.  
              
                This flag replaces the edgepoint and facepoint flags.  
                Properties: create, multiuse
        projectedCurve (Multiuse[str]?): Curves to be projected.  
                Properties: create, multiuse
        projectedCurveTolerance (float?): Tolerance for curve projection.  
                Properties: create
        smoothingangle (float?): Subdivide new edges will be soft if less then this angle.  
                C: Default is 0.0  
                Properties: create
        subdivision (Queryable[int]?): Subdivide new edges into the given number of sections.  
                Edges involving free points won't be subdivided.  
                C: Default is 1 (no subdivision).  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySplitCtx(*args: Any, edit: bool = ..., query: bool = ..., enablesnap: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., magnetsnap: Queryable[int] = ..., precsnap: Queryable[float] = ..., smoothingangle: Queryable[float] = ..., snaptoedge: bool = ..., subdivision: Queryable[int] = ...) -> Union[bool, str, int, float]:
    """Create a new context to split facets on polygonal objects
    Args:
        enablesnap (bool?): Enable/disable custom magnet snapping to start/middle/end of edge  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        magnetsnap (Queryable[int]?): number of extra magnets to snap onto, regularly spaced along the edge  
                Properties: create, query, edit
        precsnap (Queryable[float]?): precision for custom magnet snapping. Range[0,100]. Value 100  
                means any click on an edge will snap to either  
                extremities or magnets.  
                Properties: create, query, edit
        smoothingangle (Queryable[float]?): the threshold that controls whether newly created edges are hard or soft  
                Properties: create, query, edit
        snaptoedge (bool?): Enable/disable snapping to edge. If enabled any click in the  
                current face will snap to the closest valid edge. If there  
                is no valid edge, the click will be ignored.  
                NOTE: This is different from magnet snapping, which causes  
                the click to snap to certain points along the edge.  
                Properties: create, query, edit
        subdivision (Queryable[int]?): number of sub-edges to add between 2 consecutive edge  
                points. Default is 1.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polySplitCtx2(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., adjustEdgeFlow: Queryable[float] = ..., constrainToEdges: bool = ..., edgeMagnets: Queryable[int] = ..., insertWithEdgeFlow: bool = ..., snapTolerance: Queryable[float] = ..., snappedToEdgeColor: Queryable[Tuple[float, float, float]] = ..., snappedToFaceColor: Queryable[Tuple[float, float, float]] = ..., snappedToMagnetColor: Queryable[Tuple[float, float, float]] = ..., snappedToVertexColor: Queryable[Tuple[float, float, float]] = ...) -> Union[bool, str, float, int, Tuple[float, float, float]]:
    """Create a new context to split facets on polygonal objects
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        adjustEdgeFlow (Queryable[float]?): The weight value of the edge vertices to be positioned.  
                Properties: create, query, edit
        constrainToEdges (bool?): Enable/disable snapping to edge. If enabled any click in the  
                current face will snap to the closest valid edge. If there  
                is no valid edge, the click will be ignored.  
                NOTE: This is different from magnet snapping, which causes  
                the click to snap to certain points along the edge.  
                Properties: create, query, edit
        edgeMagnets (Queryable[int]?): number of extra magnets to snap onto, regularly spaced along the edge  
                Properties: create, query, edit
        insertWithEdgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Properties: create, query, edit
        snapTolerance (Queryable[float]?): precision for custom magnet snapping. Range[0,1]. Value 1  
                means any click on an edge will snap to either  
                extremities or magnets.  
                Properties: create, query, edit
        snappedToEdgeColor (Queryable[Tuple[float, float, float]]?): Color for edge snapping.  
                Properties: create, query, edit
        snappedToFaceColor (Queryable[Tuple[float, float, float]]?): Color for face snapping.  
                Properties: create, query, edit
        snappedToMagnetColor (Queryable[Tuple[float, float, float]]?): Color for magnet snapping.  
                Properties: create, query, edit
        snappedToVertexColor (Queryable[Tuple[float, float, float]]?): Color for vertex snapping.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polySplitEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., operation: Queryable[int] = ...) -> Union[str, bool, int]:
    """Split Edges.There are two operations for this command depending on the value of the
    -operation flag.If -operation is set to 1 then this command will split apart faces along all
    selected manifold edges.If -operation is set to 0 then this command will split non-manifold edges
    so as to make them manifold edges. It creates the minimum number of edges
    that can be created to make the edge manifold.The default value for -operation is 1, operate on manifold edges.Resulting mesh may have extra vertices or edges to ensure
    geometry is valid.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        operation (Queryable[int]?): 0 means use a Non-Manifold method, 1 means use a Manifold method  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySplitRing(*args: str, edit: bool = ..., query: bool = ..., adjustEdgeFlow: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., direction: bool = ..., divisions: Queryable[int] = ..., enableProfileCurve: bool = ..., fixQuads: bool = ..., insertWithEdgeFlow: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., profileCurveInputOffset: Queryable[float] = ..., profileCurveInputScale: Queryable[float] = ..., profileCurve_FloatValue: Queryable[float] = ..., profileCurve_Interp: Queryable[int] = ..., profileCurve_Position: Queryable[float] = ..., rootEdge: Queryable[int] = ..., smoothingAngle: Queryable[float] = ..., splitType: Queryable[int] = ..., useEqualMultiplier: bool = ..., useFaceNormalsAtEnds: bool = ..., weight: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, float, bool, int]:
    """Splits a series of ring edges of connected quads and
    inserts connecting edges between them.
    Args:
        adjustEdgeFlow (Queryable[float]?): The weight value of the edge vertices to be positioned.  
                Default: 1.0f  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        direction (bool?): This attribute is used when doing an absolute split.  If true then the  
                distance is taken from the start vertex of the root edge.  If false the  
                distance is taken from the end vertext of the root edge.  
                Default: true  
                Properties: create, query, edit
        divisions (Queryable[int]?): Number of divisions.  
                Default: 2  
                Properties: create, query, edit
        enableProfileCurve (bool?): Enables the use of the profile curve.  
                Default: true  
                Properties: create, query, edit
        fixQuads (bool?): Fixes splits which go across a quad face leaving a 5 and 3  
                sided faces by splitting from the middle of the new edge to  
                the vertex accross from the edge on the 5 sided face.  
                Default: false  
                Properties: create, query, edit
        insertWithEdgeFlow (bool?): True to enable edge flow. Otherwise, the edge flow is disabled.  
                Default: false  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        profileCurveInputOffset (Queryable[float]?): Changes the offset to the multisplit profile curve.  
                eg. if the profile curve values go between 0 and 1 and this  
                value is set to -1 then the profile curves values will be  
                adjusted to go between -1 and 0.  
                Default: 0.0f  
                Properties: create, query, edit
        profileCurveInputScale (Queryable[float]?): Changes the range of values that the profile curve represents.  
                eg. if the profile curve values go between 0 and 1 and this  
                value is set to 2 then the profile curves values will be  
                adjusted to go between 0 and 2.  
                Default: 1.0f  
                Properties: create, query, edit
        profileCurve_FloatValue (Queryable[float]?): ?????  
                Properties: create, query, edit
        profileCurve_Interp (Queryable[int]?): ?????  
                Default: 0  
                Properties: create, query, edit
        profileCurve_Position (Queryable[float]?): ?????  
                Properties: create, query, edit
        rootEdge (Queryable[int]?): The weight attribute uses the start vertex of this  
                edge to determine where the new split occurs.  
                Default: -1  
                Properties: create, query, edit
        smoothingAngle (Queryable[float]?): Angle below which new edges will be smoothed  
                Default: kPi  
                Properties: create, query, edit
        splitType (Queryable[int]?): Format: 0. Absolute, 1. Relative, 2. Multi  
                Default: TdnpolySplitRing::Relative  
                Properties: create, query, edit
        useEqualMultiplier (bool?): Changes how the profile curve effects the offset when doing  
                a multisplit.  If true then the verts will be offset the same distance  
                based on the shortest edge being split.  If false then each inserted  
                edge loop will be offset a distance relative to the length of the edge  
                that is being split.  
                Default: true  
                Properties: create, query, edit
        useFaceNormalsAtEnds (bool?): When doing a multisplit on a set of non-closed edge ring  
                this will toggle the normals at the ends of the split to  
                be calculated as the edge normal or the face normal.  
                Default: true  
                Properties: create, query, edit
        weight (Queryable[float]?): Weight value controlling the relative positioning of the  
                new points on existing edges. Range is [0.0, 1.0].  
                Value of 0.1 indicates the new edges will be placed closer to  
                the start vertex of the first edge of the sequence of edges.  
                Default: 0.5  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySplitVertex(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """Use this command to split one or more vertices.A mesh is made up
    of one or more faces.  The faces are defined by edges which connect vertices
    together.  Typically a face will share vertices and edges with adjacent
    faces in the same mesh.  Sharing vertices and edges helps reduce the amount
    of memory used by a mesh.  It also ensures that when a face is moved, all
    the connected faces move together.Sometimes you may want to separate a face from its connected faces so that
    it may be moved in isolation.  There are three ways to accomplish this depending
    upon which parts of the face you want to extract:Notice that the area of affect of each operation is different.  polySplitVertex
    will affect all the edges and faces that shared the vertex.  This is the broadest
    effect.  polySplitEdge will only affect the faces which shared the edge and polyChipOff
    will affect a specific face.  If we just count vertices to measure the effect of each
    command when splitting all components of a face, starting from a 3x3 plane which has 16
    vertices and we were to split the middle face:Note that polySplitVertex may create non-manifold geometry as a part of this operation.
    You can use Polygons->Cleanup afterwards to to clean up any non-manifold geometry.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The polySplitVert node name.

    Example:
    """

def polyStraightenUVBorder(*args: str, edit: bool = ..., query: bool = ..., blendOriginal: Queryable[float] = ..., caching: bool = ..., constructionHistory: bool = ..., curvature: Queryable[float] = ..., gapTolerance: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., preserveLength: Queryable[float] = ..., uvSetName: str = ..., worldSpace: bool = ...) -> Union[str, float, bool, int]:
    """Move border UVs along a simple curve.
    Args:
        blendOriginal (Queryable[float]?): Interpolation factor between the target and original UV  
                shape. When the value is 0, the UVs will exactly fit the  
                target curve. When the value is 1, no UV move.  
                Properties: create, query
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        curvature (Queryable[float]?): How curved the UV path will be. 0 is a straight line.  
                When the values is 1, the mid point of the curve will be moved  
                away from a straight line by 1/2 the length of the UV segment.  
                Properties: create, query
        gapTolerance (Queryable[int]?): When non 0, Small gaps between UV selection are  
                filled. The integer number represent how many UVs must be  
                traversed to connect togeterh selected pieces.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        preserveLength (Queryable[float]?): How much we want to respect the UV edge ratios. When  
                the value is 1, we build new UV position along the desired curve,  
                respecting the original UV spacings.  
                When the value is 0, new UVs are equally spaced along the curve.  
                Properties: create, query
        uvSetName (str?): Name of the UV set to be created  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name

    Example:
    """

def polySubdivideEdge(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., divisions: Queryable[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., size: Queryable[float] = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Subdivides an edge into two or more subedges.Default : divide edge into two edges of equal length.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        divisions (Queryable[int]?): The maximum number of vertices to be inserted in each edge.  
                This number may be reduced if it creates edges shorter than the  
                specified minimum length.  
                C: Default is 1 (divide edges in half).  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        size (Queryable[float]?): The minimum length of each subedge created. If the given  
                subdivision creates edges that are shorter than this length,  
                the number of divisions is changed to respect min length.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySubdivideFacet(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., divisions: Queryable[int] = ..., divisionsU: Queryable[int] = ..., divisionsV: Queryable[int] = ..., mode: Queryable[int] = ..., subdMethod: Queryable[int] = ...) -> Union[str, bool, int]:
    """Subdivides a face into quads or triangles.In quad mode, a center point is introduced at the center of each face
    and midpoints are inserted on all the edges of each face. New faces (all
    quadrilaterals) are built by adding edges from the midpoints towards the center.In triangle mode, only the center point is created; new faces (all
    triangles) are created by connecting the center point to all the existing
    vertices of the face.Default : one subdivision step in quad mode (polySubdFacet -dv 1 -m 0;)
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        divisions (Queryable[int]?): This number specifies how many times to  
                recursively subdivide the selected faces.  
                For example, with divisions set to 3 in quad mode,  
                each initial quadrilateral will be recursively subdivided into 4  
                subfaces 3 times, yielding a total of 4 * 4 * 4 = 64 faces.  
                C: Default is 1.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        divisionsU (Queryable[int]?): The number of subdivision steps to perform along the U direction.  
                A square face will be subdivided into 4^(divisions) faces in  
                quad mode, 4*3^(divisions-1) in triangle mode.  
                Properties: create, query, edit
        divisionsV (Queryable[int]?): The number of subdivision steps to perform along the V direction.  
                A square face will be subdivided into 4^(divisions) faces in  
                quad mode, 4*3^(divisions-1) in triangle mode.  
                Properties: create, query, edit
        mode (Queryable[int]?): The subdivision mode.  
                 0. subdivision into quads  
                 1. subdivision into triangles  
                C: Default is 0.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdMethod (Queryable[int]?): Type of subdivision to use:  
                0. exponential - traditional subdivision  
                1. linear - number of faces per edge grows linearly  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polySuperCtx(*args: Any, **kwargs: Any) -> None: ...
def polyTestPop(*args: Any, **kwargs: Any) -> None: ...
def polyToCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addUnderTransform: bool = ..., caching: bool = ..., constructionHistory: bool = ..., degree: int = ..., displaySmoothMesh: int = ..., form: int = ..., frozen: bool = ..., name: str = ..., nodeState: int = ..., object: bool = ..., conformToSmoothMeshPreview: bool = ...) -> None: ...
def polyToSubdiv(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., absolutePosition: bool = ..., applyMatrixToResult: bool = ..., caching: bool = ..., maxEdgesPerVert: Queryable[int] = ..., maxPolyCount: Queryable[int] = ..., nodeState: Queryable[int] = ..., preserveVertexOrdering: bool = ..., quickConvert: bool = ..., uvPoints: Queryable[Multiuse[Tuple[float, float]]] = ..., uvPointsU: Queryable[float] = ..., uvPointsV: Queryable[float] = ..., uvTreatment: Queryable[int] = ..., addUnderTransform: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[str, bool, int, Multiuse[Tuple[float, float]], float]:
    """This command converts a polygon and produces a subd surface.
    The name of the new subdivision surface is returned.
    If construction history is ON, then the name of the new dependency
    node is returned as well.
    Args:
        absolutePosition (bool?): If true, the possible blind data information that comes from the  
                polygon will be treated as absolute positions of the vertices,  
                instead of the relative offsets.  You most likelly just want to  
                use the default of false, unless you know that the blind data  
                has the absolute positions in it.  
                Default: false  
                Properties: create, query, edit
        applyMatrixToResult (bool?): If true, the matrix on the input geometry is applied to the object  
                and the resulting geometry will have identity matrix on it.  If false  
                the conversion is done on the local space object and the resulting  
                geometry has the input object's matrix on it.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        maxEdgesPerVert (Queryable[int]?): The maximum allowed valence for a vertex on the input mesh  
                Default: 32  
                Properties: create, query, edit
        maxPolyCount (Queryable[int]?): The maximum number of polygons accepted on the input mesh.  
                Default: 1000  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        preserveVertexOrdering (bool?): Preserve vertex ordering in conversion  
                Default: true  
                Properties: create, query, edit
        quickConvert (bool?): Debug flag to test the performance  
                Default: true  
                Properties: create, query, edit
        uvPoints (Queryable[Multiuse[Tuple[float, float]]]?): This is a cached uv point needed to transfer uv data associated with  
                finer level vertices (when switching between standard editing mode  
                and poly proxy mode.  
                Properties: create, query, edit, multiuse
        uvPointsU (Queryable[float]?): U value of a cached uv point  
                Properties: create, query, edit
        uvPointsV (Queryable[float]?): V value of a cached uv point  
                Properties: create, query, edit
        uvTreatment (Queryable[int]?): Treatment of Subd UVs when in proxy mode:  
              
                 0. preserve Subd UVs  
                 1. build Subd UVs from Poly UVs  
                 2. no UVs on Subd  
              
                Default: 0  
                Properties: create, query, edit
        addUnderTransform (bool?): If true then add the new subdivision surface under the poly's transform.  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        str: - the subdivision and optionally the dependency node name

    Example:
    """

def polyTorus(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., constructionHistory: bool = ..., createUVs: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., object: bool = ..., radius: Queryable[float] = ..., sectionRadius: Queryable[float] = ..., subdivisionsAxis: Queryable[int] = ..., subdivisionsHeight: Queryable[int] = ..., subdivisionsX: Queryable[int] = ..., subdivisionsY: Queryable[int] = ..., texture: bool = ..., twist: Queryable[float] = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The torus command creates a new polygonal torus.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): This flag specifies the primitive axis used to build the torus.  
                Q: When queried, this flag returns a vector.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        createUVs (bool?): Create UVs or not.  
                Default: true  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node (where applicable).  
                Properties: create
        radius (Queryable[float]?): Radius of the torus.  
                Default: 1.0  
                Properties: create, query, edit
        sectionRadius (Queryable[float]?): Section of the torus.  
                Default: 0.50  
                Properties: create, query, edit
        subdivisionsAxis (Queryable[int]?): Subdivisions about the vertical axis.  
                Default: 20  
                Properties: create, query, edit
        subdivisionsHeight (Queryable[int]?): Subdivisions along the height.  
                Default: 20  
                Properties: create, query, edit
        subdivisionsX (Queryable[int]?): This specifies the number of subdivisions in the X direction for the torus (number of sections).  
                C: Default is 20.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        subdivisionsY (Queryable[int]?): This flag specifies the number of subdivisions in the Y direction for the torus (number of segments per section).  
                C: Default is 20.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        texture (bool?): Apply texture or not. this is an old attribute.  
                This is unsupported and would be removed in a future release.  
                Default: true  
                Properties: create, query, edit
        twist (Queryable[float]?): Twist angle of the torus.  
                Default: 0.0  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyTransfer(*args: str, edit: bool = ..., query: bool = ..., alternateObject: Queryable[str] = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., uvSets: bool = ..., vertexColor: bool = ..., vertices: bool = ...) -> Union[str, bool, int]:
    """Transfer information from one polygonal object to another one. Both objects
    must have identical topology, that is same vertex, edge, and face
    numbering. The flags specify which of the vertices, UV sets
    or vertex colors will be copied.
    Args:
        alternateObject (Queryable[str]?): Name of the alternate object.  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        uvSets (bool?): When true, the UV sets are copied from the alternate object.  
                C: Default is "on".  
                Properties: create, query, edit
        vertexColor (bool?): When true, the colors per vertex are copied from the  
                alternate object.  
                C: Default is "off".  
                Properties: create, query, edit
        vertices (bool?): When true, the vertices positions are copied from  
                the alternate object.  
                C: Default is "off".  
                Properties: create, query, edit

    Returns:
        str: representing the node name.

    Example:
    """

def polyTriangulate(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Triangulation breaks polygons down into triangles, ensuring that all
    faces are planar and non-holed.
    Triangulation of models can be beneficial in many areas.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyUVCoverage(*args: str, uvRange: Tuple[float, float, float, float] = ...) -> List[float]:
    """Return the UV space coverage of the specified components.If no objects are specified in the command line, then components from selection list will be used.
    Args:
        uvRange (Tuple[float, float, float, float]?): UV space range for calculating the coverage  
                The 4 values specify the minimum U, V and maximum U, V in that order. Default is 0.0 0.0 1.0 1.0.  
                Properties: create

    Returns:
        List[float]: UV space coverage percentage

    Example:
    """

def polyUVOverlap(*args: str, nonOverlappingComponents: bool = ..., overlappingComponents: bool = ...) -> List[str]:
    """Return the required result on the specified components.If no objects are specified in the command line, then components from selection list will be used.
    Args:
        nonOverlappingComponents (bool?): Return non-overlapping components based on selected/specified components  
                Properties: create
        overlappingComponents (bool?): Return overlapping components based on selected/specified components  
                Properties: create

    Returns:
        List[str]: List of poly components

    Example:
    """

def polyUVRectangle(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Given two vertices, does one of the following:
    1) If the vertices define opposite corners of a rectangular area of quads,
    assigns a grid of UVs spanning the 0-1 area to that rectangle.
    2) If the vertices define an edge in a rectangular and topologically
    cylindrical area of quads, assigns UVs spanning the 0-1 area to that
    cylindrical patch, using the defined edge as the U=0 edge.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def polyUVSet(*args: str, edit: bool = ..., query: bool = ..., allUVSets: bool = ..., allUVSetsIndices: bool = ..., allUVSetsWithCount: bool = ..., copy: bool = ..., create: bool = ..., currentLastUVSet: bool = ..., currentPerInstanceUVSet: bool = ..., currentUVSet: bool = ..., delete: bool = ..., genNewUVSet: bool = ..., newUVSet: Queryable[str] = ..., perInstance: bool = ..., projections: bool = ..., rename: bool = ..., reorder: bool = ..., shareInstances: bool = ..., unshared: bool = ..., uvSet: str = ...) -> Union[bool, str]:
    """Command to do the following to uv sets:
            - delete an existing uv set.
            - rename an existing uv set.
        - create a new empty uv set.
        - copy the values from one uv set to a another
          pre-existing uv set.
            - reorder two uv sets
            - set the current uv set to a pre-existing uv set.
        - modify sharing between instances of per-instance uv sets
            - query the current uv set.
            - set the current uv set to the last uv set added to an object.
        - query the names of all uv sets.poly, uvSet, currentUVSet, renameUVSet, deleteUVSet, copyUVSet, createUVSet
    Args:
        allUVSets (bool?): This flag when used in in a query will return a list of all  
                of the uv set names  
                Properties: query, edit
        allUVSetsIndices (bool?): This flag when queried will return a list of the logical plug  
                indices of all the uv sets in the sparse uv set array.  
                Properties: query, edit
        allUVSetsWithCount (bool?): This flag when used in a query will return a list of all  
                of the uv set family names, with a count appended to the perInstance  
                sets indicating the number of instances in the uv set shared by  
                the specified or selected shape.  
                Properties: query, edit
        copy (bool?): This flag when used will result in the copying of the uv set corresponding  
                to name specified with the uvSet flag to the uvset corresponding  
                to the name specified with the newUVSet flag  
                Properties: create, query, edit
        create (bool?): This flag when used will result in the creation of an empty uv set  
                corresponding to the name specified with the uvSet flag. If  
                a uvSet with that name already exists, then no new uv set will  
                be created.  
                Properties: create, query, edit
        currentLastUVSet (bool?): This flag when used will set the current uv set that the object needs to  
                work on, to be the last uv set added to the object.  
                If no uv set exists for the object, then no uv set name will be returned.  
                Properties: create, query, edit
        currentPerInstanceUVSet (bool?): This is a query-only flag for use when the current uv set is a per-instance  
                uv set family. This returns the member of the set family that corresponds  
                to the currently select instance.  
                Properties: query, edit
        currentUVSet (bool?): This flag when used will set the current uv set that the object needs to  
                work on, to be the uv set corresponding to the name specified with the  
                uvSet flag. This does require that a uvSet with the specified name exist.  
                When queried, this returns the current uv set.  
                Properties: create, query, edit
        delete (bool?): This flag when used will result in the deletion of the uv set corresponding  
                to the name specified with the uvSet flag.  
                Properties: create, query, edit
        genNewUVSet (bool?): This is a query-only flag to generate a new unique name.  
                Properties: query, edit
        newUVSet (Queryable[str]?): Specifies the name that the uv set corresponding to the name specified with  
                the uvSet flag, needs to be renamed to.  
                Properties: create, query, edit
        perInstance (bool?): This flag can be used in conjunction with the create flag to indicate  
                whether or not the uv set is per-instance. When you create a per-instance  
                uv set, the set will be applied as shared between all selected instances  
                of the shape unless the unshared flag is used. The perInstance flag can  
                be used in query mode with the currentUVSet or allUVSets  flag to indicate  
                that the set family names (i.e. not containing instance identifiers) will  
                be returned by the query.  
                			In query mode, this flag can accept a value.  
                Properties: create, query, edit
        projections (bool?): This flag when used in a query will return a list of polygon  
                uv projection node names. The order of the list is from  
                most-recently-applied to least-recently-applied.  
                Properties: query, edit
        rename (bool?): This flag when used will result in the renaming of the uv set corresponding  
                to the name specified with the uvSet flag to the name specified using the  
                newUVSet flag.  
                Properties: create, query, edit
        reorder (bool?): This flag when used will result in the reordering of two uv sets corresponding  
                to name specified with the uvSet flag, and the uvset corresponding  
                to the name specified with the newUVSet flag  
                Properties: create, query, edit
        shareInstances (bool?): This flag is used to modify the sharing of per-instance uv sets within  
                a given uv set family so that all selected instances share the specified  
                set. In query mode, it returns a list of the instances that share the  
                set specified by the uvSet flag.  
                Properties: create, query, edit
        unshared (bool?): This flag can be used in conjunction with the create and perInstance flags  
                to indicate that the newly created per-instance set should be created with  
                a separate set per instance.  
                Properties: create, query, edit
        uvSet (str?): Specifies the name of the uv set that this command needs to work on.  
                This flag has to be specified for this command to do anything meaningful  
                other than query the current uv set.  
                			In query mode, this flag needs a value.  
                Properties: create, query, edit

    Returns:
        bool: Success or Failure.

    Example:
    """

def polyUVStackSimilarShells(*args: str, onlyMatch: bool = ..., tolerance: float = ...) -> List[str]:
    """Stack Similar UV Shells.
    Args:
        onlyMatch (bool?): If this flag is true, only match UV shells and return UVs of target UV shells but don't stack.  
                Properties: create
        tolerance (float?): The tolerance setting for stacking how similar UV shells.  
                Properties: create

    Returns:
        List[str]: UVs of stacked UV Shells or target UV shells.

    Example:
    """

def polyUVStackSimilarShellsCmd(*args: Any, **kwargs: Any) -> None: ...
def polyUnite(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., mergeUVSets: int = ..., nodeState: Queryable[int] = ..., centerPivot: bool = ..., objectPivot: bool = ...) -> Union[List[str], bool, int]:
    """This command creates a new poly as an union of a list of polys
    If no objects are specified in the command line, then the
    objects from the active list are used.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        mergeUVSets (int?): Specify how UV sets will be merged on the output mesh.  
                The choices are 0 | 1 | 2.  
                0 = Do not merge. Each UV set on each mesh will become a new UV set in the output.  
                1 = Merge by name. UV sets with the same name will be merged.  
                2 = Merge by UV links. UV sets will be merged so that UV linking on the input meshes continues to work.  
                The default is 1 (merge by name).  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        centerPivot (bool?): Set the resulting object's pivot to the center of the selected objects bounding box.  
                Properties: create
        objectPivot (bool?): Set the resulting object's pivot to last selected object's pivot.  
                Properties: create

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def polyUniteSkinned(*args: str, edit: bool = ..., query: bool = ..., centerPivot: bool = ..., constructionHistory: bool = ..., mergeUVSets: Queryable[int] = ..., objectPivot: bool = ...) -> Union[bool, int]:
    """Command to combine poly mesh objects (as polyUnite)
    while retaining the smooth skinning setup on the
    combined object.skinCluster, poly
    Args:
        centerPivot (bool?): Set the resulting object's pivot to the center of the selected objects bounding box.  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create, query, edit
        mergeUVSets (Queryable[int]?): Specify how UV sets will be merged on the output mesh.  
                The choices are 0 | 1 | 2.  
                0 = Do not merge. Each UV set on each mesh will become a new UV set in the output.  
                1 = Merge by name. UV sets with the same name will be merged.  
                2 = Merge by UV links. UV sets will be merged so that UV linking on the input meshes continues to work.  
                The default is 1 (merge by name).  
                Properties: create, query, edit
        objectPivot (bool?): Set the resulting object's pivot to last selected object's pivot.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def polyUnsmooth(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., divisionLevels: Queryable[int] = ..., frozen: bool = ..., name: str = ..., nodeState: Queryable[int] = ..., replaceOriginal: bool = ...) -> Union[str, bool, int]:
    """Attempt to recreate the lower subdivision levels of a mesh that was subdivided
    with the Catmull-Clark subdivision method.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        divisionLevels (Queryable[int]?): This flag specifies how many subdivision levels to attempt to step backwards.  
                Properties: create, query, edit
        frozen (bool?): Inherited from base class TpolyCleanCmd.  
                Properties: create, query, edit
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        replaceOriginal (bool?): Create "in place" (i.e., replace) (not available in all commands). NOTE:  
                This flag is intended for use by the "Unsmoorh" menu item. If  
                'polyUnsmooth -rpo 0' is executed from the command line, Shader information will  
                not be copied from the original mesh to the result.  
                Properties: create

    Returns:
        str: The node name.

    Example:
    """

def polyVertexNormalCtx(*args: Any, **kwargs: Any) -> None: ...
def polyWarpImage(*args: str, bilinear: bool = ..., background: Tuple[int, int, int] = ..., fileFormat: str = ..., inputName: str = ..., inputUvSetName: str = ..., noAlpha: bool = ..., overwrite: bool = ..., outputName: str = ..., outputUvSetName: str = ..., tiled: bool = ..., xResolution: int = ..., yResolution: int = ...) -> None: ...
def polyWedgeFace(*args: str, edit: bool = ..., query: bool = ..., axis: Tuple[float, float, float] = ..., caching: bool = ..., center: Tuple[float, float, float] = ..., constructionHistory: bool = ..., divisions: int = ..., edge: Multiuse[int] = ..., name: str = ..., nodeState: Queryable[int] = ..., wedgeAngle: float = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """Extrude faces about an axis.
    The axis is the average of all the selected edges.
    If the edges are not aligned, the wedge may not look
    intuitive.  To separately wedge faces about different
    wedge axes, the command should be issued as many times
    as the wedge axes. (as in the second example)
    Args:
        axis (Tuple[float, float, float]?): This flag (along with -center) can be used instead of the -edge flag to  
                specify the axis about which the wedge is performed. The flag expects  
                three coordinates that form a vector about which the rotation is performed.  
                Properties: create
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        center (Tuple[float, float, float]?): This flag (along with -axis) can be used instead of the -edge flag to  
                specify the location about which the wedge is performed. The flag expects  
                three coordinates that define the center of rotation.  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off (where applicable). If  
                construction history is on then the corresponding node will be  
                inserted into the history chain for the mesh. If construction history  
                is off then the operation will be performed directly on the object.  
              
                Note: If the object already has construction history then  
                this flag is ignored and the node will always be inserted into  
                the history chain.  
                Properties: create, query
        divisions (int?): This flag specifies the number of subdivisions  
                along the extrusion.  
                Properties: create
        edge (Multiuse[int]?): This flag specifies the edgeId that should be  
                used to perform the wedge about. Multiple edges  
                can be specified. The wedge operation is performed  
                about an axis that is the average of all the edges.  
                It is recommended that only colinear edges are  
                used, otherwise the result may not look intuitive.  
              
                Instead of specifying the -edge flag, the wedge can be  
                performed about a point and axis. See the -center and  
                -axis flags for details.  
                Properties: create, multiuse
        name (str?): Give a name to the resulting node.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        wedgeAngle (float?): This flag specifies the angle of rotation.  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is off.  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def popListItem() -> None: ...
def popupMenu(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowOptionBoxes: bool = ..., altModifier: bool = ..., button: Queryable[int] = ..., ctrlModifier: bool = ..., defineTemplate: str = ..., deleteAllItems: bool = ..., exists: bool = ..., itemArray: bool = ..., markingMenu: bool = ..., numberOfItems: bool = ..., parent: str = ..., postMenuCommand: Callable[..., Any] = ..., postMenuCommandOnce: bool = ..., shiftModifier: bool = ..., useTemplate: str = ...) -> Union[str, bool, int]:
    """This command creates a popup menu and attaches it to the current
    control if no parent is specified.  The popup menu is posted with the
    right mouse button by default.Popup menus can be added to any kind of control, however,
    on some widgets, only the standard menu button (3rd mouse button)
    can be used to trigger popup menus. This is to meet generally
    accepted UI guidelines that assign the 3rd mouse button and only
    this one to popup menus, and also to prevent unexpected behavior
    of controls like text fields, that expect 1st and 2nd button to be
    reserved for contextual operations like text or item selection...
    Args:
        allowOptionBoxes (bool?): Indicate whether the menu will be able to support option box  
                menu items.  An error results if an option box item is added to a  
                menu that doesn't allow them.  This flag may be queried and must be  
                specified when the popup menu is created.  The default value is  
                false.  
                Properties: create, query
        altModifier (bool?): Specify this flag if the Alt modifier must be pressed when  
                posting the popup menu.  
                Properties: create, query, edit
        button (Queryable[int]?): Indicate which button posts the popup menu.  Valid values  
                range from 1 to 3 where 1 is the left most button on the mouse.  
                Properties: create, query, edit
        ctrlModifier (bool?): Specify this flag if the Cntl modifier must be pressed when  
                posting the popup menu.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteAllItems (bool?): Delete all the items in this menu.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        itemArray (bool?): Return string array of the menu item names.  
                Properties: query
        markingMenu (bool?): Set the marking menu state of this popup menu.  
                Properties: create, query, edit
        numberOfItems (bool?): Return number of items in the menu.  
                Properties: query
        parent (str?): Specify the control that the popup menu will appear in.  
                Properties: create
        postMenuCommand (Callable[..., Any]?): Specify a script to be executed when the popup menu is about  
                to be shown.  
                Properties: create, edit
        postMenuCommandOnce (bool?): Indicate the -pmc/postMenuCommand should only be  
                invoked once.  Default value is false, ie.  
                the -pmc/postMenuCommand is invoked every time the popup menu is  
                shown.  
                Properties: create, query, edit
        shiftModifier (bool?): Specify this flag if the Shift modifier must be pressed  
                when posting the popup menu.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Full path name to the menu.

    Example:
    """

def pose(*args: str, edit: bool = ..., query: bool = ..., allPoses: bool = ..., apply: bool = ..., name: Queryable[str] = ...) -> Union[str, bool]:
    """This command is used to create character poses.character, clip, animation, pose
    Args:
        allPoses (bool?): This flag is used to query all the poses in the scene.  
                Properties: query
        apply (bool?): This flag is used in conjunction with the name flag to specify a pose should be applied to the character.  
                Properties: create
        name (Queryable[str]?): In create mode, specify the pose name. In query mode, return a list of all the poses for the character. In apply mode, specify the pose to be applied.  
                Properties: create, query

    Returns:
        str: Pose name

    Example:
    """

def poseEditor(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command creates an editor that derives from the base editor
    class that has controls for deformer and control nodes.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the editor

    Example:
    """

def poseInterpolator(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., addPose: str = ..., drivers: bool = ..., deletePose: str = ..., exportPoses: str = ..., goToPose: str = ..., index: bool = ..., importPoses: str = ..., kernelWidth: str = ..., mirror: Multiuse[str] = ..., name: str = ..., pose: Multiuse[Tuple[str, str]] = ..., poseNames: bool = ..., rename: Tuple[str, str] = ..., searchAndReplace: Tuple[str, str] = ..., updatePose: str = ...) -> None: ...
def posePanel(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., poseEditor: bool = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command creates a panel that derives from the base panel
    class that houses a poseEditor.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        poseEditor (bool?): Query only flag that returns the name of an editor to be associated with the panel.  
                Properties: query
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the panel

    Example:
    """

def preferredRenderer(arg0: str = ..., /, *, query: bool = ..., fallback: Queryable[str] = ..., makeCurrent: bool = ...) -> Union[bool, str]:
    """Command to set the preferred renderer. This command can be used
    to query the preferred renderer and to set the current renderer
    as the preferred one. It also allows users to specify a
    preferred fallback renderer.renderer
    Args:
        fallback (Queryable[str]?): Sets the preferred fallback renderer.  
                Properties: create, query
        makeCurrent (bool?): Sets the current renderer as the preferred one.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def preloadRefEd(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectCommand: Queryable[Callable[..., Any]] = ..., selectFileNode: bool = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This creates an editor for managing which references will be read in
    (loaded) and which deferred (unloaded) upon opening a file.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectCommand (Queryable[Callable[..., Any]]?): A script to be executed when an item is selected.  
                Properties: create, query, edit
        selectFileNode (bool?): Query the currently selected load setting. Returns the id of the  
                currently selected load setting. This id can be used as an argument  
                to the selLoadSettings command.  
                Properties: query
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Name of editor

    Example:
    """

def prepareRender(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., defaultTraversalSet: Queryable[str] = ..., deregister: str = ..., invokePostRender: bool = ..., invokePostRenderFrame: bool = ..., invokePostRenderLayer: bool = ..., invokePreRender: bool = ..., invokePreRenderFrame: bool = ..., invokePreRenderLayer: bool = ..., invokeSettingsUI: bool = ..., label: Queryable[str] = ..., listTraversalSets: bool = ..., postRender: Queryable[Callable[..., Any]] = ..., postRenderFrame: Queryable[Callable[..., Any]] = ..., postRenderLayer: Queryable[Callable[..., Any]] = ..., preRender: Queryable[Callable[..., Any]] = ..., preRenderFrame: Queryable[Callable[..., Any]] = ..., preRenderLayer: Queryable[Callable[..., Any]] = ..., restore: bool = ..., saveAssemblyConfig: bool = ..., settingsUI: Queryable[Callable[..., Any]] = ..., setup: bool = ..., traversalSet: str = ..., traversalSetInit: Queryable[Callable[..., Any]] = ...) -> Union[bool, str, Callable[..., Any]]:
    """This command is used to register, manage and invoke render traversals.
    Render traversals are used to configure a scene to prepare it for rendering.This command has special support for scene assembly nodes.  To render scene
    assembly nodes, a rendering traversal can activate an appropriate
    representation, for each assembly node in the scene.  When rendering is
    done, this command can correspondingly restore the representation that was
    active before rendering on each assembly.
    Render traversals are grouped into traversal sets.  A render traversal set
    includes callbacks, or render traversals, for one or more of the following
    steps of rendering, ordered by decreasing level of granularity.
    A render traversal callback is an arbitrary script, either MEL or Python,
    that can transform the Maya scene for rendering purposes.During a render view or batch render, Maya will run the render traversals from
    the same traversal set, the default traversal set.  Traversal sets are named,
    so multiple traversal sets can be registered with this command, and the
    default render traversal set can be switched to any one of these registered
    traversal sets.  When changing the default traversal set, the different
    render traversal callbacks (preRender, preRenderLayer, preRenderFrame,
    postRender, postRenderLayer, postRenderFrame) are switched as a unit.At render time, the software rendering code invokes the callbacks of the
    default traversal set.  The prepareRender scripting capability allows for the
    development of multiple rendering preparation scripts, including from plugins,
    to provide extensibility rather than being constrained to a single
    implementation.A special traversal set is the "null" traversal set.  It is the initial
    default traversal set, and cannot be deregistered.  It performs no work,
    and does not save and restore the assembly node active representation
    configuration.  It will provide WYSIWYG (What You See Is What You Get)
    rendering of assembly nodes, without switching to a different representation
    to render.Render traversals are invoked by Maya using this command's create mode.
    This is done by Maya's rendering infrastructure, and should not be required
    unless developing new render views or batch render code.  Most uses of this
    command will simply use the edit mode to register render traversals into a
    render traversal set, or the query mode to query the names of the render
    traversals in a render traversal set.Render traversals are similar in intent to the user-specified pre- and
    post-render, pre- and post-render layer, pre- and post-render frame MEL
    script capability.  The difference with the user MEL scripts is
    that prepareRender is in addition to, and does not replace, the user
    MEL scripts, can register multiple render traversal sets and switch them,
    and supports both MEL and Python.  The MEL render scripts are run inside
    the scope of the render traversals, that is, the preRender traversal is
    run before the pre-render MEL script and the postRender traversal is run
    after the post-render MEL script, the preRenderLayer traversal is run before
    the pre-render layer MEL script and the postRenderLayer traversal is run
    after the post-render layer MEL script, and finally the preRenderFrame
    traversal is run before the pre-render frame MEL script and the
    postRenderFrame traversal is run after the post-render frame MEL script.The prepareRender command has support for saving and restoring the active
    representation of assembly nodes in the scene.  Use the saveAssemblyConfig flag
    to indicate that the render traversal set requires saving the assembly node
    active representation before rendering begins, and should restore the
    assembly node active representation after rendering ends.It is the responsibility of render traversals that modify the scene in ways
    other than changing the active representation on assembly nodes to restore the
    scene to its previous state, most likely using the postRender, postRenderLayer,
    and postRenderFrame traversals.Note that Maya does not call the prepareRender -restore command on
    batch render completion, since batch rendering is done on a copy of the
    scene which is discarded once rendering terminates.  Implementors of
    render traversals may wish to check whether they are running in batch mode,
    to implement the same optimization.render, assembly
    Args:
        defaultTraversalSet (Queryable[str]?): Set or query the default traversal set.  The prepareRender  
                command performs operations on the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: query, edit
        deregister (str?): Deregister a registered traversal set.  If the deregistered traversal set is  
                the default traversal set, the new default traversal set will be the "null"  
                traversal set.  
                Properties: edit
        invokePostRender (bool?): Invoke the postRender render traversal for a given traversal  
                set.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        invokePostRenderFrame (bool?): Invoke the postRenderFrame render traversal for a given traversal  
                set.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        invokePostRenderLayer (bool?): Invoke the postRenderLayer render traversal for a given traversal  
                set.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        invokePreRender (bool?): Invoke the preRender render traversal for a given traversal  
                set.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        invokePreRenderFrame (bool?): Invoke the preRenderFrame render traversal for a given traversal  
                set.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        invokePreRenderLayer (bool?): Invoke the preRenderLayer render traversal for a given traversal  
                set.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        invokeSettingsUI (bool?): Invoke the settings UI callback to populate a layout with UI controls,  
                for a given traversal set.  The current UI parent will be a form layout,  
                which the callback can query using the setParent command.  The traversal set  
                will be the default traversal set, unless the -traversalSet flag is used to  
                specify an explicit traversal set.  
                Properties: create
        label (Queryable[str]?): Set or query the label for a given traversal set.  The label is used for UI  
                display purposes, and can be localized.  The traversal set will be the default,  
                unless the -traversalSet flag is used to specify an explicit traversal set.  
                Properties: query, edit
        listTraversalSets (bool?): Query the supported render traversal sets.  
                Properties: query
        postRender (Queryable[Callable[..., Any]]?): Set or query the postRender render traversal for a given traversal  
                set.  This traversal is run after a render.  The traversal set will be the  
                default traversal set, unless the -traversalSet flag is used to specify an  
                explicit traversal set.  
                Properties: query, edit
        postRenderFrame (Queryable[Callable[..., Any]]?): Set or query the postRenderFrame render traversal for a given traversal  
                set.  This traversal is run after the render of a single frame, with a  
                render layer.  The traversal set will be the default traversal set, unless  
                the -traversalSet flag is used to specify an explicit traversal set.  
                Properties: query, edit
        postRenderLayer (Queryable[Callable[..., Any]]?): Set or query the postRenderLayer render traversal for a given traversal  
                set.  This traversal is run after a render layer is rendered, within a  
                render.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: query, edit
        preRender (Queryable[Callable[..., Any]]?): Set or query the preRender render traversal for a given traversal  
                set.  This traversal is run before a render.  The traversal set will be the  
                default traversal set, unless the -traversalSet flag is used to specify an  
                explicit traversal set.  
                Properties: query, edit
        preRenderFrame (Queryable[Callable[..., Any]]?): Set or query the preRenderFrame render traversal for a given traversal  
                set.  This traversal is run before the render of a single frame, with a  
                render layer.  The traversal set will be the default traversal set, unless  
                the -traversalSet flag is used to specify an explicit traversal set.  
                Properties: query, edit
        preRenderLayer (Queryable[Callable[..., Any]]?): Set or query the preRenderLayer render traversal for a given traversal  
                set.  This traversal is run before a render layer is rendered, within a  
                render.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: query, edit
        restore (bool?): Clean up after rendering, including restoring the assembly active  
                representation configuration for the whole scene, if the saveAssemblyConfig  
                flag for the traversal set is true.  The traversal set will be the default  
                traversal set, unless the -traversalSet flag is used to specify an explicit  
                traversal set.  
                Properties: create
        saveAssemblyConfig (bool?): Set or query whether or not the assembly active representation configuration  
                for the whole scene should be saved for a given traversal set.  The traversal  
                set will be the default, unless the -traversalSet flag is used to specify an  
                explicit traversal set.  
                Properties: query, edit
        settingsUI (Queryable[Callable[..., Any]]?): Set or query the settings UI callback for a given traversal set.  The  
                traversal set will be the default traversal set, unless the -traversalSet  
                flag is used to specify an explicit traversal set.  
                Properties: query, edit
        setup (bool?): Setup render preparation, including saving the assembly active representation  
                configuration for the whole scene, if the saveAssemblyConfig flag for  
                the traversal set is true.  Any previously-saved configuration will be  
                overwritten.  The traversal set will be the default traversal set, unless the  
                -traversalSet flag is used to specify an explicit traversal set.  
                Properties: create
        traversalSet (str?): Set or query properties for the specified registered traversal set.  
                			In query mode, this flag needs a value.  
                Properties: create, query, edit
        traversalSetInit (Queryable[Callable[..., Any]]?): Set or query the traversal set initialisation callback for a given traversal set.  
                The traversal set will be the default traversal set, unless the -traversalSet flag  
                is used to specify an explicit traversal set. This callback is invoked whenever  
                the specified traversal set becomes the default.  
                traversal set.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def prependListItem() -> None: ...
def profiler(*, query: bool = ..., addCategory: str = ..., allCategories: bool = ..., bufferSize: Queryable[int] = ..., categoryIndex: int = ..., categoryIndexToName: int = ..., categoryInfo: Queryable[str] = ..., categoryName: str = ..., categoryNameToIndex: str = ..., categoryRecording: bool = ..., clearAllMelInstrumentation: bool = ..., colorIndex: int = ..., eventCPUId: bool = ..., eventCategory: bool = ..., eventColor: bool = ..., eventCount: bool = ..., eventDescription: bool = ..., eventDuration: bool = ..., eventIndex: int = ..., eventName: bool = ..., eventStartTime: bool = ..., eventThreadId: bool = ..., instrumentMel: bool = ..., load: Queryable[str] = ..., output: Queryable[str] = ..., procedureDescription: str = ..., procedureName: str = ..., removeCategory: str = ..., reset: bool = ..., sampling: bool = ..., signalEvent: bool = ..., signalMelEvent: bool = ...) -> Union[bool, int, str]:
    """The profiler is used to record timing information from key events within Maya,
    as an aid in tuning the performance of scenes, scripts and plug-ins.
    User written plug-ins and Python scripts can also generate profiling information
    for their own code through the MProfilingScope (C++), MProfilingContextManager
    (Python) and MProfiler classes in the API.This command provides the ability to control the collection of profiling data and
    to query information about the recorded events. The recorded information can also
    be viewed graphically in the Profiler window.The buffer size cannot be changed while sampling is active, it will return an error
    The reset flag cannot be called while sampling is active, it will return an error.
    Any changes to the buffer size will only be applied on start of the next recording.
    You can't save and load in the same command, save has priority, load would be ignored.timing, performance, profiling, optimize
    Args:
        addCategory (str?): Add a new category for the profiler.  
                Returns the index of the new category.  
                Properties: create
        allCategories (bool?): Query the names of all categories.  
                If the categoryInfo flag is set then alternate the name of the category  
                with the description of the category.  
                Properties: query
        bufferSize (Queryable[int]?): Toggled : change the buffer size to fit the specified number of events (requires that sampling is off)  
                Query : return the current buffer size  
                The new buffer size will only take effect when next sampling starts.  
                When the buffer is full, the recording stops.  
                Properties: create, query
        categoryIndex (int?): Used in conjunction with other flags, to indicate the index of the category.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        categoryIndexToName (int?): Returns the name of the category with a given index.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        categoryInfo (Queryable[str]?): When used with the addCategory flag set the description of the added profiler category.  
                In query mode return the description of the category referenced by either  
                the categoryIndex or categoryName flags.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        categoryName (str?): Used in conjunction with other flags, to indicate the name of the category.  
                			In query mode, this flag needs a value.  
                Properties: query
        categoryNameToIndex (str?): Returns the index of the category with a given name.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        categoryRecording (bool?): Toggled : Enable/disable the recording of the category.  
                Query : return if the recording of the category is On.  
                Requires the -categoryIndex or -categoryName flag to specify the category to be queried.  
                Properties: create, query
        clearAllMelInstrumentation (bool?): Clear all MEL command or procedure instrumentation.  
                Properties: create
        colorIndex (int?): Used with "-instrumentMel true" to specify the color index to show the  
                profiling result.  
                Properties: create
        eventCPUId (bool?): Query the CPU ID of the event at the given index.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventCategory (bool?): Query the category index the event at the given index belongs to.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventColor (bool?): Query the color of the event at the given index.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventCount (bool?): Query the number of events in the buffer  
                Properties: query
        eventDescription (bool?): Query the description of the event at the given index.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventDuration (bool?): Query the duration of the event at the given index, the time unit is microsecond.  
                Note that a signal event has a 0 duration.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventIndex (int?): Used usually in conjunction with other flags, to indicate the index of the event.  
                			In query mode, this flag needs a value.  
                Properties: query
        eventName (bool?): Query the name of the event at the given index.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventStartTime (bool?): Query the time of the event at the given index, the time unit is microsecond.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        eventThreadId (bool?): Query the thread ID of the event at the given index.  
                Requires the -eventIndex flag to specify the event to be queried.  
                Properties: query
        instrumentMel (bool?): Enable/Diable the instrumentation of a MEL command or procedure.  
                When the instrumentation is enabled, the execution of MEL command  
                or procedure can be profiled and shown in the Profiler window.  
                To enable the instrumentation requires the -procedureName, -colorIndex  
                and -categoryIndex flags.  
                To disable the instrumentation requires the -procedureName flag.  
                Properties: create
        load (Queryable[str]?): Read the recorded events from the specified file  
                Properties: create, query
        output (Queryable[str]?): Output the recorded events to the specified file  
                Properties: create, query
        procedureDescription (str?): Used with "-instrumentMel true" to provide a description of the MEL  
                command or procedure being instrumented.  
                This description can be viewed in the Profiler Tool window.  
                Properties: create
        procedureName (str?): Used with -instrumentMel to specify the name of the procedure to be  
                enabled/disabled the instrumentation.  
                Properties: create
        removeCategory (str?): Remove an existing category for the profiler.  
                Returns the index of the removed category.  
                Properties: create
        reset (bool?): reset the profiler's data (requires that sampling is off)  
                Properties: create, query
        sampling (bool?): Toggled : Enable/disable the recording of events  
                Query : return if the recording of events is On.  
                Properties: create, query
        signalEvent (bool?): Query if the event at the given index is a signal event.  
                Requires the -eventIndex flag to specify the event to be queried.  
                A Signal Event only remembers the start moment and has no knowledge about  
                duration. It can be used in cases when the user does not care about the  
                duration but only cares if this event does happen.  
                Properties: query
        signalMelEvent (bool?): Used with "-instrumentMel true", inform profiler that this instrumented  
                MEL command or procedure will be taken as a signal event during profiling.  
                A Signal Event only remembers the start moment and has no knowledge about  
                duration. It can be used in cases when the user does not care about the  
                duration but only cares if this event does happen.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def profilerTool(*args: Any, edit: bool = ..., query: bool = ..., categoryView: bool = ..., collapseSelectedEvents: bool = ..., collapseSelectedEventsRepetition: bool = ..., cpuView: bool = ..., destroy: bool = ..., eventTypes: bool = ..., exists: bool = ..., expandSelectedEvents: bool = ..., expandSelectedEventsRepetition: bool = ..., findNext: bool = ..., findPrevious: bool = ..., frameAll: bool = ..., frameSelected: bool = ..., isolateSegment: int = ..., make: bool = ..., matchWholeWord: bool = ..., searchEvent: str = ..., segmentCount: bool = ..., showAllEvent: bool = ..., showCriticalPath: bool = ..., showHotspot: bool = ..., showSelectedEvents: bool = ..., showSelectedEventsRepetition: bool = ..., threadView: bool = ..., unisolateSegment: bool = ...) -> bool:
    """This script is intended to be used by the profilerPanel to interact with the profiler tool's view (draw region).
    It can be used to control some behaviors about the profiler Tool.profiler, tool, profilerTool, timing, performance, profiling
    Args:
        categoryView (bool?): Change view mode to category view  
                Properties: edit
        collapseSelectedEvents (bool?): Hide all sub-events of selected events so that only top-level events show  
                Properties: edit
        collapseSelectedEventsRepetition (bool?): Hide all sub-events repetition of selected events based on their comment  
                Properties: edit
        cpuView (bool?): Change view mode to cpu view  
                Properties: edit
        destroy (bool?): Destroy the profiler tool  
                Internal flag. Should not be used by user.  
                Properties: create
        eventTypes (bool?): Return JSON data containing the list of event types on currently existing events.  
                If the value of the flag is true then show only event types for selected events,  
                otherwise show them for all events.  The JSON return string will contain the event  
                type information in the following format:  
              
                {  
                    "eventSummary" : [  
                        { "type"        : EVENT_TYPE_NAME,  
                        , "description" : EVENT_TYPE_DESCRIPTION,  
                        , "color"       : [ RED_AS_FLOAT, GREEN_AS_FLOAT, BLUE_AS_FLOAT ]  
                        , "category"    : CATEGORY_NAME  
                        , "count"       : EVENT_TYPE_COUNT  
                        }  
                    ]  
                }  
              
                "type" and "description" may be omitted, indicating that the results  
                correspond to anonymous events.  
                Properties: query
        exists (bool?): Query if the profiler tool view exists.  
                Profiler tool can only exist after "profilerTool -make" is called.  
                Properties: query
        expandSelectedEvents (bool?): Show all sub-events of selected events  
                Properties: edit
        expandSelectedEventsRepetition (bool?): Show all sub-events repetition of selected events based on their comment  
                Properties: edit
        findNext (bool?): This flag is used along with flag -searchEvent.  
                Properties: query
        findPrevious (bool?): This flag is used along with flag -searchEvent.  
                Properties: query
        frameAll (bool?): Frame on all events in the profilerToolView  
                Properties: edit
        frameSelected (bool?): Frame on all selected events in the profilerToolView  
                Properties: edit
        isolateSegment (int?): Isolate a specified segment.  
                A segment is a set of events that happened in one animation frame.  
                You can use flag -segmentCount to query the number of segments in the event buffer.  
                The segment index starts from 0.  
                If the specified segment does not exist, an error will be thrown.  
                Properties: edit
        make (bool?): Make the profiler tool and parent it to the most recent layout created  
                Internal flag. Should not be used by user.  
                Properties: create
        matchWholeWord (bool?): Tells profiler tool if it should match whole word when searching event(s).  
                The default value is false.  
                Properties: edit
        searchEvent (str?): Search event(s).  
                You can set -matchWholeWord before you use -searchEvent.  
                If -matchWholeWord has been set to true, the profiler tool will search event(s) whose name exactly matches with the string.  
                If -matchWholeWord has been set to false, the profiler tool will search event(s) whose name contains the string.  
                If -findNext is also used along with this flag, the profiler tool will find the first event next to the current selected event.  
                If -findPrevious is also used along with this flag, the profiler tool will find the first event previous to the current selected event.  
                If currently don't have a selected event or there are multiple selected events, the search will start at  
                the first event in profiler buffer.  
                If -findNext and -findPrevious are not used along with this flag, the profiler tool will find all events.  
                			In query mode, this flag needs a value.  
                Properties: query
        segmentCount (bool?): Returns the number of segments in the event buffer.  
                Properties: query
        showAllEvent (bool?): Show all events (if events were hidden by filtering) (true) or  
                Hide all events (false)  
                Properties: edit
        showCriticalPath (bool?): Show critical path of selected frame  
                Properties: edit
        showHotspot (bool?): Show hotspot of selected frame  
                Properties: edit
        showSelectedEvents (bool?): Show only the selected events (true) or  
                hide all selected events (false)  
                Properties: edit
        showSelectedEventsRepetition (bool?): Show only the selected events repetition based on their comment (true) or  
                Hide all selected events repetition based on their comment (false)  
                Properties: edit
        threadView (bool?): Change view mode to thread view  
                Properties: edit
        unisolateSegment (bool?): Unisolate current isolated segment.  
                If no segment is currently isolated, nothing will happen.  
                Properties: edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def progressBar(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., beginProgress: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., endProgress: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isCancelled: bool = ..., isInterruptable: bool = ..., isMainProgressBar: bool = ..., isObscured: bool = ..., manage: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., progress: Queryable[int] = ..., status: Queryable[str] = ..., statusBarMessage: str = ..., step: int = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Creates a progress bar control that graphically fills in as its
    progress value increases.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        beginProgress (bool?): Only valid for the main progress bar  
                Shows the main progress bar (normally in the Help Line).  
                This is normally issued through MEL when a length computation is  
                about to occur.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        endProgress (bool?): Only valid for the main progress bar  
                Hides the progress bar. No other flags can be used at the  
                same time. This is normally issued through  
                MEL in response to the -ic/isCancelled flag being set or if the progress  
                value reaches its maximum.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isCancelled (bool?): Returns true if the user has tried to cancel the operation.  
                Returns false otherwise.  
                Properties: query
        isInterruptable (bool?): Only valid for the main progress bar  
                 Returns true if the isCancelled flag should respond to attempts  
                to cancel the operation. Setting this to true will add a note in the help  
                line display message to the user indicating that they can cancel the  
                operation.  
                Properties: create, query, edit
        isMainProgressBar (bool?): Determines whether this progressBar is used to show the progress  
                of all basic operations such as Open/Save file.  
                The main progressBar behaves very differently, in that it only shows itself  
                when there is an ongoing basic operation.  
                Defaults to false, and only one progress bar will be recognized as the "main" one.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): The maximum or "ending" value of the progress indicator.  
                If the progress value is greater than the -max/maxValue, the  
                progress value will be set to the maximum.  
                Default value is 100.  
                Properties: create, query, edit
        minValue (Queryable[int]?): The minimum or "starting" value of the progress indicator.  
                If the progress value is less than the -min/minValue, the  
                progress value will be set to the minimum.  
                Default value is 0.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        progress (Queryable[int]?): The amount of progress currently shown on the control.  
                The value will always be between min and max.  
                Default is equal to the minimum when the control is created.  
                Properties: create, query, edit
        status (Queryable[str]?): Only valid for the main progress bar  
                Sets the contents of the helpLine control when the  
                progressBar is showing. Use this instead of setting the helpLine  
                directly because this will force a graphical refresh before returning.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (int?): Increments the -pr/progress value by the amount specified.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def progressWindow(*, edit: bool = ..., query: bool = ..., endProgress: bool = ..., isCancelled: bool = ..., isInterruptable: bool = ..., maxValue: Queryable[int] = ..., minValue: Queryable[int] = ..., progress: Queryable[int] = ..., status: Queryable[str] = ..., step: int = ..., title: Queryable[str] = ...) -> Union[bool, int, str]:
    """The progressWindow command creates a window
    containing a status message, a graphical progress gauge,
    and optionally a "Hit ESC to Cancel" label for interruptable operations.Only one progress window is allowed on screen at a time. While the window
    is visible, the busy cursor is shown.
    Args:
        endProgress (bool?): Terminates the progress window. No other flags can be used  
                at the same time. This is normally issued through  
                MEL in response to the -ic/isCancelled flag being set or if the progress  
                value reaches its maximum.  
                Properties: create
        isCancelled (bool?): Returns true if the user has tried to cancel the operation.  
                Returns false otherwise.  
                Properties: query
        isInterruptable (bool?): Returns true if the progress window should respond to attempts  
                to cancel the operation. The cancel button is disabled if this is set  
                to true.  
                Properties: create, query, edit
        maxValue (Queryable[int]?): The maximum or "ending" value of the progress indicator.  
                If the progress value is greater than the -max/maxValue, the  
                progress value will be set to the maximum.  
                Default value is 100.  
                Properties: create, query, edit
        minValue (Queryable[int]?): The minimum or "starting" value of the progress indicator.  
                If the progress value is less than the -min/minValue, the  
                progress value will be set to the minimum.  
                Default value is 0.  
                Properties: create, query, edit
        progress (Queryable[int]?): The amount of progress currently shown on the control.  
                The value will always be between min and max.  
                Default is equal to the minimum when the control is created.  
                Properties: create, query, edit
        status (Queryable[str]?): The status text appearing above the progress gauge.  
                Properties: create, query, edit
        step (int?): Increments the -pr/progress value by the amount specified.  
                Properties: edit
        title (Queryable[str]?): The window title.  
                Properties: create, query, edit

    Returns:
        bool: Returns true if the window was successfully
            created, and false if the window could not be created (possibly
            because one is already showing).

    Example:
    """

def projectCurve(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., direction: Queryable[Tuple[float, float, float]] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., nodeState: Queryable[int] = ..., tolerance: Queryable[float] = ..., useNormal: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., range: bool = ...) -> Union[List[str], bool, Tuple[float, float, float], float, int]:
    """The projectCurve command creates curves on surface where all
    selected curves project onto the selected surfaces. Projection can
    be done using the surface normals or the user can specify the vector to
    project along. Note: the user does not have to specify the curves and
    surfaces in any particular order in the command line.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[Tuple[float, float, float]]?): Direction of projection. Available only if useNormal is false.  
                Properties: create, query, edit
        directionX (Queryable[float]?): X direction of projection.  
                Default: 0.0  
                Properties: create, query, edit
        directionY (Queryable[float]?): Y direction of projection.  
                Default: 0.0  
                Properties: create, query, edit
        directionZ (Queryable[float]?): Z direction of projection.  
                Default: 1.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance to fit to.  
                Default: 0.01  
                Properties: create, query, edit
        useNormal (bool?): True if the surface normal is to be used and false if the direction vector should be used instead.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def projectTangent(arg0: str = ..., arg1: str = ..., arg2: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., curvature: bool = ..., curvatureScale: Queryable[float] = ..., ignoreEdges: bool = ..., nodeState: Queryable[int] = ..., reverseTangent: bool = ..., rotate: Queryable[float] = ..., tangentDirection: Queryable[int] = ..., tangentScale: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, float, int]:
    """The project tangent command is used to align (for tangents) a curve
    to two other curves or a surface. A surface isoparm may be selected
    to define the direction (U or V) to align to. The end of the curve
    must intersect with these other objects. Curvature continuity may also
    be applied if required.Tangent continuity means the end of the curve is modified to be tangent
    at the point it meets the other objects.Curvature continuity means the end of the curve is modified to be
    curvature continuous as well as tangent.If the normal tangent direction is used, the curvature continuity
    and rotation do not apply. Also, curvature continuity is only available
    if align to a surface (not with 2 curves).
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        curvature (bool?): Curvature continuity is on if true and off otherwise.  
                Default: false  
                Properties: create, query, edit
        curvatureScale (Queryable[float]?): Curvature scale applied to curvature of curve to align. Available if curvature option is true.  
                Default: 0.0  
                Properties: create, query, edit
        ignoreEdges (bool?): If false, use the tangents of the trim edge curves if the surface is trimmed. If true, use the tangents of the underlying surface in the U/V directions.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        reverseTangent (bool?): Reverse the tangent direction if true and leave it the way it is if false.  
                Default: false  
                Properties: create, query, edit
        rotate (Queryable[float]?): Amount by which the tangent of the curve to align will be rotated. Available only if the normal direction (3) is not used for tangentDirection.  
                Default: 0.0  
                Properties: create, query, edit
        tangentDirection (Queryable[int]?): Tangent align direction type legal values: 1=u direction (of surface or use first curve), 2=v direction (of surface or use second curve), 3=normal direction (at point of intersection).  
                Default: 1  
                Properties: create, query, edit
        tangentScale (Queryable[float]?): Tangent scale applied to tangent of curve to align.  
                Default: 1.0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def projectionContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Set the context for projection manips
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Context name.
    """

def projectionManip(*, query: bool = ..., fitBBox: bool = ..., projType: int = ..., switchType: bool = ...) -> bool:
    """Various commands to set the manipulator to interesting positions.
    Args:
        fitBBox (bool?): Fit the projection manipulator size and position to the shading  
                group bounding box. The orientation is not modified.  
                Properties: create
        projType (int?): Set the projection type to the given value. Projection type values are:  
              
                 1 = planar.  
                 2 = spherical.  
                 3 = cylindrical.  
                 4 = ball.  
                 5 = cubic.  
                 6 = triplanar.  
                 7 = concentric.  
                 8 = camera.  
                Properties: create
        switchType (bool?): Loop over the allowed types. If the hardware shading is on, it loops  
                over the hardware shadeable types (planar, cylindrical, spherical),  
                otherwise, it loops over all the types.  
                If there is no given value, it loops over the different projection  
                types.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def promptDialog(*, query: bool = ..., backgroundColor: Tuple[float, float, float] = ..., button: Multiuse[str] = ..., cancelButton: str = ..., defaultButton: str = ..., dismissString: str = ..., message: str = ..., messageAlign: str = ..., parent: str = ..., scrollableField: bool = ..., style: str = ..., text: Queryable[str] = ..., title: str = ...) -> str:
    """The promptDialog command creates a modal dialog with a message to the
    user, a text field in which the user may enter a response, and a
    variable number of buttons to dismiss the dialog.  The dialog is
    dismissed when the user presses any button or chooses the
    close item from the window menu.  In the case where a button is
    pressed then the name of the button selected is returned.  If the
    dialog is dismissed via the close item then the string returned is
    specified by theflag.The default behaviour when no arguments are specified is to create an
    empty single button dialog.To obtain the text entered by the user simply query
    theflag.
    Args:
        backgroundColor (Tuple[float, float, float]?): The background color of the dialog. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0. (Windows only flag)  
                Properties: create
        button (Multiuse[str]?): Create a button with the given string as it's text.  
                Properties: create, multiuse
        cancelButton (str?): The cancel button is activated by pressing the escape key.  
                Note that this flag does not create a button, it simply indicates  
                which button created via the -b/button flag shall respond  
                to the escape key.  
                Properties: create
        defaultButton (str?): The default button is activated by pressing the enter key.  
                Note that this flag does not create a button, it simply indicates  
                which button created via the -b/button flag shall respond  
                to the enter key.  
                Properties: create
        dismissString (str?): The string returned when the user selects the 'Close' item  
                from the Window Manager menu.  If this flag is not set then the  
                string "dismiss" is returned.  
                Properties: create
        message (str?): The message text appearing in the dialog.  
                Properties: create
        messageAlign (str?): Align the message left, center, or right.  
                Properties: create
        parent (str?): Specify the parent window for the dialog.  The dialog will  
                be centered on this window and raise and lower with it's parent.  
                By default, the dialog is not parented to a particular window and  
                is simply centered on the screen.  
                Properties: create
        scrollableField (bool?): By default a single line text field is used in the dialog.  
                Specify true for a multi-line scroll field.  
                Properties: create
        style (str?): Specify the type of input expected in the input field.  
                Vaid input types are "integer" "float" "text".  
                If this flag is not specified, we assume the input type is "text".  
                Properties: create
        text (Queryable[str]?): The field text.  
                Properties: create, query
        title (str?): The dialog title.  
                Properties: create

    Returns:
        str: Indicates how the dialog was dismissed. If a button is
            pressed then the label of the button is returned. If the dialog is
            closed then the value for the flag ds/dismissString is
            returned.

    Example:
    """

def propModCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., animCurve: Queryable[str] = ..., animCurveFalloff: Queryable[Tuple[float, float]] = ..., animCurveParam: Queryable[str] = ..., direction: Queryable[Tuple[float, float, float]] = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., linear: Queryable[float] = ..., linearParam: Queryable[Tuple[float, float]] = ..., nurbsCurve: Queryable[str] = ..., powerCutoff: Queryable[float] = ..., powerCutoffParam: Queryable[Tuple[float, float]] = ..., powerDegree: Queryable[float] = ..., powerDegreeParam: Queryable[float] = ..., script: Queryable[str] = ..., scriptParam: Queryable[str] = ..., type: Queryable[int] = ..., worldspace: bool = ...) -> Union[str, Tuple[float, float], Tuple[float, float, float], float, int, bool]:
    """Controls the proportional move context.
    Args:
        animCurve (Queryable[str]?): Name of the anim curve to use as a drop-off curve.  
                Only the 0. > side of the curve will be used and the distance  
                will be mapped to "seconds".  The profile of the curve will be  
                used as the profile for propmod function.  
                Properties: create, query, edit
        animCurveFalloff (Queryable[Tuple[float, float]]?): The profile of the curve will be used as the profile for propmod function in  
                both U and V. This will be scaled in U, V according to the paramters provided.  
                The ratio of the U, V scaling parameters will dictate the footprint of the fuction  
                while the curve itself provides the magnitudes.  
                Properties: create, query, edit
        animCurveParam (Queryable[str]?): Name of the anim curve to use as a drop-off curve.  
                Only the 0. > side of the curve will be used and the distance  
                will be mapped to "seconds", where 1 second maps to 0.01 units  
                in parametric space.  
                Properties: create, query, edit
        direction (Queryable[Tuple[float, float, float]]?): Direction along which to compute the distance for  
                the distance based drop-off functions.  The default is (1 1 1)  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        linear (Queryable[float]?): If using linear drop-off function, this is its  
                slope.  The default of -0.1 means the point at the locator  
                moves with it and the point 10 units away doesn't move at all.  
                Properties: create, query, edit
        linearParam (Queryable[Tuple[float, float]]?): If using parametric linear drop-off function, these specify  
                its limits along the U and V directions.  
                Properties: create, query, edit
        nurbsCurve (Queryable[str]?): Name of the nurbs curve to use as a drop-off curve.  
                The closest point distance would be used as the drop off percentage.  
                Properties: create, query, edit
        powerCutoff (Queryable[float]?): If using the power drop-off function, this is its  
                distance cutoff value.  The default is 10.0.  
                Properties: create, query, edit
        powerCutoffParam (Queryable[Tuple[float, float]]?): If using the power drop-off function, these specify  
                one of it's limits, 0 for U, and 1 and V.  The default cutoff is 10.0.  
                Properties: create, query, edit
        powerDegree (Queryable[float]?): If using the power drop-off function, this is its  
                degree.  The default is 3.  
                Properties: create, query, edit
        powerDegreeParam (Queryable[float]?): If using the power drop-off function, this is its  
                degree.  The default is 3.  
                Properties: create, query, edit
        script (Queryable[str]?): The name of the script to use to compute the drop-off.  
                The script takes 6 floats as input - first 3 are the position of  
                the move locator, the next 3 the position of the point to be  
                manipulated.  The script should return a drop-off coefficient  
                which could be negative or zero.  
                Properties: create, query, edit
        scriptParam (Queryable[str]?): The name of the script to use to compute the drop-off.  
                The script takes 4 floats as input - first 2 are the parametric  
                position of the move locator, the next 2 the parametric position of  
                the point to be manipulated.  The script should return a drop-off coefficient  
                which could be negative or zero.  
                Properties: create, query, edit
        type (Queryable[int]?): Choose the type for the drop-off function.  Legal  
                values are 1 for linear, 2 for power,  
                3 for script,  
                4 for anim curve.  
                The default is 1.  
                Properties: create, query, edit
        worldspace (bool?): Set the space in which the tool works. True for  
                world space, false for parametric space.  
                Properties: create, query, edit

    Returns:
        str: Name of the new context created

    Example:
    """

def propMove(arg0: float = ..., arg1: float = ..., arg2: float = ..., /, *args: str, percent: Multiuse[float] = ..., percentX: Multiuse[float] = ..., percentY: Multiuse[float] = ..., percentZ: Multiuse[float] = ..., pivot: Tuple[float, float, float] = ..., rotate: Tuple[float, float, float] = ..., scale: Tuple[float, float, float] = ..., translate: Tuple[float, float, float] = ..., worldSpace: bool = ...) -> bool:
    """Performs a proportional translate, scale or rotate operation on any
    number of objects. The percentages to rotate, scale or translate by
    can be specified using either the -p flags or -px, -py, -pz
    flags. Each selected object must have a corresponding -p or -px, -py,
    -pz flag. The rotate, scale or translate performed is relative.
    Args:
        percent (Multiuse[float]?): The percentage effect that the specified x,y,z has on an object.  
                This flag must be specified once for each object, ie. if there  
                are 4 objects specified, there must be 4 "-p" flags, (otherwise  
                a percentage of 1.0 will be used).  This flag generally has a  
                range between 0.0 and 1.0, but can be any float value.  
                Properties: create, multiuse
        percentX (Multiuse[float]?): The percentage effect that the specified x has on an object.  
                This flag is specified one per object.  
                The value ranges between 0.0 and 1.0, but can be any float value.  
                If the -p flag has been specified, this flag usage is invalid.  
                Properties: create, multiuse
        percentY (Multiuse[float]?): The percentage effect that the specified y has on an object.  
                This flag is specified one per object.  
                The value ranges between 0.0 and 1.0, but can be any float value.  
                If the -p flag has been specified, this flag usage is invalid.  
                Properties: create, multiuse
        percentZ (Multiuse[float]?): The percentage effect that the specified z has on an object.  
                This flag is specified one per object.  
                The value ranges between 0.0 and 1.0, but can be any float value.  
                If the -p flag has been specified, this flag usage is invalid.  
                Properties: create, multiuse
        pivot (Tuple[float, float, float]?): Specify the pivot about which a rotation or scale will occur.  
                The change in pivot lasts only as long as the current 'propMove' command, and so  
                must be used in conjunction with one of the above move flags for any effect to be  
                noticeable.  
                Properties: create
        rotate (Tuple[float, float, float]?): Proportionally rotate each object by the given angles. The rotation values  
                are scaled by the percentage specified by that object's  
                corresponding "-percent" flag.  
                All angles are in degrees.  
                The rotation is about the pivot specified by the "-pivot" flag, or (0, 0, 0)  
                if the "-pivot" flag is not present.  
                Properties: create
        scale (Tuple[float, float, float]?): Proportionally scale each object by the given amounts. The scale values  
                are scaled by the percentage specified by that object's  
                corresponding "-percent" flag.  
                The position and size of each object is measured relative to the pivot  
                specified by the "-pivot" flag, and defaults to each object's individual pivot.  
                In the case of control vertices, or some other object component, the  
                default is the parent object's pivot.  
                Properties: create
        translate (Tuple[float, float, float]?): Proportionally translate each object by the given amounts. The translation  
                values are scaled by the percentage specified by that object's  
                corresponding "-percent" flag.  
                The "-pivot" flag has no effect on translation.  
                Properties: create
        worldSpace (bool?): Use worldspace for the calculations.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def proximityWrap(*args: str, edit: bool = ..., query: bool = ..., addDrivers: Multiuse[str] = ..., applyUserDefaults: bool = ..., canBeAdded: Queryable[Multiuse[str]] = ..., driverIndices: bool = ..., dumpInfo: bool = ..., freeDriverIndex: bool = ..., removeDrivers: Multiuse[str] = ...) -> Union[List[str], Multiuse[str], bool]:
    """This command creates a proximityWrap deformer, which deforms geometry based on the
    distance from its drivers.
    Args:
        addDrivers (Multiuse[str]?): Add connect new drivers to the proximityWrap node  
                Properties: edit, multiuse
        applyUserDefaults (bool?): Flag used in with the addDriver flag. When set, new drivers will set the  
                user default attributes from the option var settings. When the flag is not set,  
                the user default attributes will not be set.  
                Default is on.  
                Properties: edit
        canBeAdded (Queryable[Multiuse[str]]?): Returns true if all listed shapes can be added as drivers. The reason for an item  
                returning false would be that it is already connected as a driver, it is connected  
                as the deformed geometry or it represents in invalid object.  
                Properties: query, multiuse
        driverIndices (bool?): List connected driver indices  
                Properties: query
        dumpInfo (bool?): Return a python dictionary containing information relating to the proximityWrap  
                node. Some information is returned in string form in mel but the flag is meant to be used  
                in python.  
                Properties: query
        freeDriverIndex (bool?): Returns the first index which has no driver connected  
                Properties: query
        removeDrivers (Multiuse[str]?): Remove connected drivers  
                Properties: edit, multiuse

    Returns:
        List[str]: (the proximityWrap node name)

    Example:
    """

def psdChannelOutliner(*args: Any, edit: bool = ..., query: bool = ..., addChild: Multiuse[Tuple[str, str]] = ..., allItems: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., doubleClickCommand: str = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfItems: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., psdParent: str = ..., removeAll: bool = ..., removeChild: Multiuse[str] = ..., select: str = ..., selectCommand: str = ..., selectItem: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Callable[..., Any]]:
    """Create a psdChannelOutliner control which is capable of displaying
    a tree structure upto one level.
    Args:
        addChild (Multiuse[Tuple[str, str]]?): This flag should be used along with the "-psdParent/ppa" flag. A string  
                item gets added as a child to the parent specifed with "-psdParent/ppa"  
                flag. The next string assigns an associated image name.  
                Properties: edit, multiuse
        allItems (bool?): Returns all the items in the form parent.child.  
                Properties: query
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (str?): Specify the command to be executed when an item is double  
                clicked.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfItems (bool?): Total number of items in the control.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        psdParent (str?): Adds an item string to the controls which is treated as parent.  
                Properties: edit
        removeAll (bool?): Removes all the items from the control.  
                Properties: edit
        removeChild (Multiuse[str]?): Deletes the particular child of the parent as specifed in "-psdParent/ppa"  
                flag.  
                Properties: edit, multiuse
        select (str?): Select the named item.  
                Properties: edit
        selectCommand (str?): Specify the command to be executed when an item is selected.  
                Properties: create, edit
        selectItem (bool?): Returns the selected items.  
                Properties: query
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the psdChannelOutliner control

    Example:
    """

def psdConvSolidTxOptions(*args: Any, **kwargs: Any) -> None: ...
def psdEditTextureFile(*args: Any, addChannel: Multiuse[str] = ..., addChannelColor: Multiuse[Tuple[str, float, float, float]] = ..., addChannelImage: Multiuse[Tuple[str, str]] = ..., deleteChannel: Multiuse[str] = ..., psdFileName: str = ..., snapShotImage: str = ..., uvSnapPostionTop: bool = ...) -> bool:
    """Edits the existing PSD file. Addition and deletion of the channels (layer sets) are
    supported.
    Args:
        addChannel (Multiuse[str]?): Adds an empty layer set with the given name to a already existing PSD file.  
                Properties: create, multiuse
        addChannelColor (Multiuse[Tuple[str, float, float, float]]?): (M) Specifies the filled color of  the layer which is created in a layer set given  
                by the layer name.  
                Properties: create, multiuse
        addChannelImage (Multiuse[Tuple[str, str]]?): (M) Specifies the image file name whose image needs to be added  
                as a layer to a given layer set which is the first string.  
                Properties: create, multiuse
        deleteChannel (Multiuse[str]?): (M) Deletes the channels (layer sets) from a PSD file. This is a multiuse  
                flag.  
                Properties: create, multiuse
        psdFileName (str?): PSD file name.  
                Properties: create
        snapShotImage (str?): Image file name on the disk containing UV snapshot / reference image.  
                Properties: create
        uvSnapPostionTop (bool?): Specifies the position of UV snapshot image layer  in the PSD file. "True"  
                positions this layer at the top and "False" positions the layer at the bottom  
                next to the background layer in the PSD file  
                Properties: create

    Returns:
        bool:

    Example:
    """

def psdExport(*args: Any, query: bool = ..., alphaChannelIdx: Queryable[int] = ..., bytesPerChannel: Queryable[int] = ..., emptyLayerSet: bool = ..., format: Queryable[str] = ..., layerName: Queryable[str] = ..., layerSetName: str = ..., outFileName: Queryable[str] = ..., preMultiplyAlpha: bool = ..., psdFileName: str = ...) -> Union[bool, int, str]:
    """Writes the Photoshop file layer set into different formats.  The output
            file depth (bit per channel ) can be different from that of the input.
            If the input is 16 bpc and output is 8 bpc, there will be data loss.photoshop, psd, texture, convert, export
    Args:
        alphaChannelIdx (Queryable[int]?): Index of the alpha channel to output, if not supplied, writes out the  
                default alpha channel.  The index is zero based.  
                This is useful to write out specific alpha channels available as  
                "Additional Alpha Channels" of Photoshop.  
                Properties: create, query
        bytesPerChannel (Queryable[int]?): Output file depth. Any of these keyword:  
              
                0 for choosing depth based on input  
                1 for 8 bits per channel  
                2 for 16 bits per channel  
              
                Default is 0.  
                Properties: create, query
        emptyLayerSet (bool?): Option to check if the given layer set is empty or not.  This should be  
                used in query mode and input file name and layer set names should be specified.  
                Properties: create, query
        format (Queryable[str]?): Output file format. Any of these keyword: "iff", "sgi", "pic", "tif", "als", "gif", "rla", "jpg"  
                Default is iff.  
                Properties: create, query
        layerName (Queryable[str]?): Name of the layer to output.  
                Properties: create, query
        layerSetName (str?): Name of the layer set to output, if not supplied, writes out the Composite image.  
                			In query mode, this flag needs a value.  
                Properties: create, query
        outFileName (Queryable[str]?): Name(with path) of the output file.  
                Properties: create, query
        preMultiplyAlpha (bool?): Option to multiply RGB colors with alpha values.  If (r,g,b,a) is the  
                value of pixel, it will be changed to (r*a, g*a, b*a, a) when this flag  
                is used.  
                Properties: create, query
        psdFileName (str?): Name(with path) of the input Photoshop file.  
                			In query mode, this flag needs a value.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def psdTextureFile(*args: Any, channelRGB: Multiuse[Tuple[str, int, int, int, int]] = ..., channels: Multiuse[Tuple[str, int, bool]] = ..., imageFileName: Multiuse[Tuple[str, str, int]] = ..., psdFileName: str = ..., snapShotImageName: str = ..., uvSnapPostionTop: bool = ..., xResolution: int = ..., yResolution: int = ...) -> bool:
    """Creates a Photoshop file with UVSnap shot image and the layer set
    names as the input.
    Args:
        channelRGB (Multiuse[Tuple[str, int, int, int, int]]?): (M) Layer set names, index, red, green and blue values are given as input.  
                Using this flag, the layers created can be filled with specified  
                colors.  This is a multi use flag.  The index specifies the  
                placement order of layer sets in the created file.  
                Properties: create, multiuse
        channels (Multiuse[Tuple[str, int, bool]]?): (M) Layer set names and index are given as input. This is a multi use flag.  
                A layer set with the given name will be created.  The second argument  
                is the index which specifies the placement order of layer sets  
                in the created file. The third argument is a boolean, if "true" a layer  
                is created inside the layer set , "false" creates an  empty layer set  
                Properties: create, multiuse
        imageFileName (Multiuse[Tuple[str, str, int]]?): Image file name, Layerset name and index.  The image in the file will be  
                transferred to layer set specified.  The index specifies the  
                placement order of layer sets in the created psd file.  The image file  
                specified can be in any of the formats supported by maya  
                (ex. iff, jpg, gif, tif etc.)  
                Properties: create, multiuse
        psdFileName (str?): PSD file name.  
                Properties: create
        snapShotImageName (str?): Image file name on the disk containing UV snapshot / reference image.  
                Properties: create
        uvSnapPostionTop (bool?): Specifies the position of UV snapshot image layer  in the PSD file. "True"  
                positions this layer at the top and "False" positions the layer at the bottom  
                next to the background layer in the PSD file  
                Properties: create
        xResolution (int?): X - resolution of the image.  
                Properties: create
        yResolution (int?): Y - resolution of the image.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def python() -> None: ...
def querySubdiv(*args: Any, action: int = ..., level: int = ..., relative: bool = ...) -> bool:
    """Queries a subdivision surface based on a set of query parameters and updates the selection list with the results.subdivision, surface, query
    Args:
        action (int?): Specifies the query parameter:  
                        1 = find all tweaked verticies at level  
                        2 = find all sharpened vertices at level  
                        3 = find all sharpened edges at level  
                        4 = find all faces at level  
                If the attribute "level" is not specified then the query is applied to  
                the current component display level. If the attribute level is  
                specified then the query is applied to that level, either absolute or  
                relative to the current level based on the "relative" flag state.  
                Properties: create
        level (int?): Specify the level of the subdivision surface on which to perform the operation.  
                Properties: create
        relative (bool?): If set, level flag refers to the level relative to the current component display level.  
                Properties: create

    Returns:
        bool: Command result

    Example:
    """

def quit(*, abort: bool = ..., exitCode: int = ..., force: bool = ...) -> bool:
    """This command is used to exit the application.
    Args:
        abort (bool?): Will quit without saving like -force, but will also prevent  
                preferences/hotkeys/colors from being saved.  Use at  
                your own risk.  
                Properties: create
        exitCode (int?): Specifies the exit code to be returned once the application  
                exits.  The default exit code is 0.  
                Properties: create
        force (bool?): If specified, this flag will force a quit without saving  
                or prompting for saving changes. Use at  
                your own risk.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def radial(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., type: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A radial field pushes objects directly towards or directly away from it,
    like a magnet.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        type (Queryable[float]?): Type of radial field (0. 1).  This controls the algorithm by  
                which the field is attenuated. Type 1, provided for backward  
                compatibility, specifies the same algorithm as Alias |  
                Wavefront Dynamation. A value between 0 and 1 yields a linear blend.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def radioButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., collection: str = ..., data: Queryable[int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., offCommand: Callable[..., Any] = ..., onCommand: Callable[..., Any] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., recomputeSize: bool = ..., select: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, bool, Callable[..., Any]]:
    """This command creates a radio button that is added to the most
    recently created radio collection if theflag
    is not used.
    Args:
        align (Queryable[str]?): This flag is obsolete and should no longer be used.  
                The radio button label will always be left-aligned.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the radio button's state is changed.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of the radio button from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, edit
        collection (str?): To explicitly add a radio button to a collection of radio  
                buttons specify the name of the radio collection.  
                Properties: create
        data (Queryable[int]?): Internal data associated with the radio button.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the radio button.  By default, this flag  
                is set to true and the radio button value may be changed by  
                clicking on it.  If false then the radio button is 'read only' and  
                can not be clicked on. The value of the radio button can always be  
                changed with the -sl/select flag regardless of the state of  
                the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text.  The default label is the name of  
                the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Callable[..., Any]?): Command executed when the radio button is turned off.  
                Properties: create, edit
        onCommand (Callable[..., Any]?): Command executed when the radio button is turned on.  
                Properties: create, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        recomputeSize (bool?): If true then the control will recompute it's size to  
                just fit the size of the label.  If false then the control size  
                will remain fixed as you change the size of the label.  The  
                default value of this flag is true.  
                Properties: create, query, edit
        select (bool?): Select the radio button.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def radioButtonGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., annotation1: Queryable[str] = ..., annotation2: Queryable[str] = ..., annotation3: Queryable[str] = ..., annotation4: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., changeCommand1: Callable[..., Any] = ..., changeCommand2: Callable[..., Any] = ..., changeCommand3: Callable[..., Any] = ..., changeCommand4: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., data1: Queryable[int] = ..., data2: Queryable[int] = ..., data3: Queryable[int] = ..., data4: Queryable[int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enable1: bool = ..., enable2: bool = ..., enable3: bool = ..., enable4: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., label1: Queryable[str] = ..., label2: Queryable[str] = ..., label3: Queryable[str] = ..., label4: Queryable[str] = ..., labelAnnotation: Queryable[str] = ..., labelArray2: Queryable[Tuple[str, str]] = ..., labelArray3: Queryable[Tuple[str, str, str]] = ..., labelArray4: Queryable[Tuple[str, str, str, str]] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., numberOfRadioButtons: int = ..., offCommand: Callable[..., Any] = ..., offCommand1: Callable[..., Any] = ..., offCommand2: Callable[..., Any] = ..., offCommand3: Callable[..., Any] = ..., offCommand4: Callable[..., Any] = ..., onCommand: Callable[..., Any] = ..., onCommand1: Callable[..., Any] = ..., onCommand2: Callable[..., Any] = ..., onCommand3: Callable[..., Any] = ..., onCommand4: Callable[..., Any] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., select: Queryable[int] = ..., shareCollection: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., vertical: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, bool, Tuple[str, str], Tuple[str, str, str], Tuple[str, str, str, str], Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates from one to four radio buttons in a single row.
    By default the radio buttons will share a single collection, but they
    can also share the collection of another radio button group.  The buttons
    can also have an optional text label.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        annotation1 (Queryable[str]?): specifies the tooptip of the first radiobutton  
                Properties: create, query, edit
        annotation2 (Queryable[str]?): specifies the tooptip of the second radiobutton  
                Properties: create, query, edit
        annotation3 (Queryable[str]?): specifies the tooptip of the third radiobutton  
                Properties: create, query, edit
        annotation4 (Queryable[str]?): specifies the tooptip of the fourth radiobutton  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the group changes state.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of a radio button from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, edit
        changeCommand1 (Callable[..., Any]?):   
                Properties: create, edit
        changeCommand2 (Callable[..., Any]?):   
                Properties: create, edit
        changeCommand3 (Callable[..., Any]?):   
                Properties: create, edit
        changeCommand4 (Callable[..., Any]?): Specify a changed state command for each respective radio  
                button.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        data1 (Queryable[int]?):   
                Properties: create, query, edit
        data2 (Queryable[int]?):   
                Properties: create, query, edit
        data3 (Queryable[int]?):   
                Properties: create, query, edit
        data4 (Queryable[int]?): Internal data associated with each radio button.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the group.  By default, this flag  
                is set to true and the radio button values may be changed by  
                clicking on them.  If false then the radio buttons are 'read only'  
                and can not be clicked on. The value of the radio button can  
                always be changed with the sl/select flags regardless of  
                the state of the ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enable1 (bool?):   
                Properties: create, query, edit
        enable2 (bool?):   
                Properties: create, query, edit
        enable3 (bool?):   
                Properties: create, query, edit
        enable4 (bool?): Enable state of the individual radio buttons.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): When present on creation an optional text label will be  
                built with the group.  The string specifies the label text.  
                Properties: create, query, edit
        label1 (Queryable[str]?):   
                Properties: create, query, edit
        label2 (Queryable[str]?):   
                Properties: create, query, edit
        label3 (Queryable[str]?):   
                Properties: create, query, edit
        label4 (Queryable[str]?): Specify label strings for the respective radio buttons in  
                the group.  
                Properties: create, query, edit
        labelAnnotation (Queryable[str]?): when present on creation an optional text label will be  
                built with the group . The string specifies the label tooltip  
                Properties: create, query, edit
        labelArray2 (Queryable[Tuple[str, str]]?):   
                Properties: create, query, edit
        labelArray3 (Queryable[Tuple[str, str, str]]?):   
                Properties: create, query, edit
        labelArray4 (Queryable[Tuple[str, str, str, str]]?): Specify multiple labels in a single flag.  These flags  
                are ignored if the number of radio buttons doesn't match.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfRadioButtons (int?): Number of radio buttons in the group (1. 4).  
                Properties: create
        offCommand (Callable[..., Any]?): Command executed when any radio button turns off.  
                Properties: create, edit
        offCommand1 (Callable[..., Any]?):   
                Properties: create, edit
        offCommand2 (Callable[..., Any]?):   
                Properties: create, edit
        offCommand3 (Callable[..., Any]?):   
                Properties: create, edit
        offCommand4 (Callable[..., Any]?): Off command for each respective radio button.  
                Properties: create, edit
        onCommand (Callable[..., Any]?): Command executed when any radio button turns on.  
                Properties: create, edit
        onCommand1 (Callable[..., Any]?):   
                Properties: create, edit
        onCommand2 (Callable[..., Any]?):   
                Properties: create, edit
        onCommand3 (Callable[..., Any]?):   
                Properties: create, edit
        onCommand4 (Callable[..., Any]?): On command for each respective radio button.  
                Properties: create, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        select (Queryable[int]?): Selected radio button.  The argument is a 1 based integer.  
                Properties: create, query, edit
        shareCollection (str?): Specify the radioButtonGrp that this radio group is to be  
                associated with.  By default the radio group will be a separate  
                collection.  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        vertical (bool?): Whether the orientation of the radio buttons in this group  
                are horizontal (default) or vertical.  
                Properties: create, query
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def radioCollection(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., collectionItemArray: bool = ..., defineTemplate: str = ..., exists: bool = ..., gl: bool = ..., numberOfCollectionItems: bool = ..., parent: str = ..., select: Queryable[str] = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command creates a radio button collection. Collections are
    parented to the current default layout if no parent is specified with
    theflag.  As children of the layout they will be
    deleted when the layout is deleted. Collections may also span more
    than one window if theflag is used. In this case
    the collection has no parent and must be explicitly deleted with thecommand when it is no longer wanted.
    Args:
        collectionItemArray (bool?): Return a string list giving the long names of all the items  
                in this collection.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        gl (bool?): Set the collection to have no parent layout.  Global  
                collections must be explicitly deleted.  
                Properties: create, query
        numberOfCollectionItems (bool?): Return the number of items in this collection.  
                Properties: query
        parent (str?): The parent of the collection.  The collection will be deleted  
                along with the parent.  
                Properties: create
        select (Queryable[str]?): Select the specified collection item.  If queried will  
                return the name of the currently selected collection item.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Full path name to the collection.

    Example:
    """

def radioMenuItemCollection(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., defineTemplate: str = ..., exists: bool = ..., gl: bool = ..., parent: str = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command creates a radioMenuItemCollection.  Attach radio menu
    items to radio menu item collection objects to get radio button
    behaviour.  Radio menu item collections will be parented to the
    current menu if no parent is specified with theflag. As children of the menu they will be deleted when the menu is
    deleted. Collections may also span more than one menu if
    theflag is used. In this case the collection has no
    parent menu and must be explicitly deleted with thecommand when it is no longer wanted.
    Args:
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        gl (bool?): Set the collection to have no parent menu.  Global  
                collections must be explicitly deleted.  
                Properties: create, query
        parent (str?): The parent of the collection.  The collection will be deleted  
                along with the parent.  
                Properties: create
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Full path name to the collection.

    Example:
    """

def rampColorPort(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., node: str = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., selectedColorControl: str = ..., selectedInterpControl: str = ..., selectedPositionControl: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., verticalLayout: bool = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a control that displays an image representing
    the ramp node specified, and supports editing of that node.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        node (str?): Specifies the name of the newRamp texture node  
                this port will represent.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        selectedColorControl (str?): Set the name of the control (if any) which is to be used to show  
                the color of the currently selected entry in the ramp. This control  
                will automatically update as the user selects different entries in  
                the ramp, and will modify the selected entry if edited. The type of  
                control must be an attrColorSliderGrp.  
                Properties: create, edit
        selectedInterpControl (str?): Set the name of the control (if any) which is to be used to show  
                the interpolation of the currently selected entry in the ramp. This control  
                will automatically update as the user selects different entries in  
                the ramp, and will modify the selected entry if edited. The type of  
                control must be an attrEnumOptionMenuGrp.  
                Properties: create, edit
        selectedPositionControl (str?): Set the name of the control (if any) which is to be used to show  
                the position of the currently selected entry in the ramp. This control  
                will automatically update as the user selects different entries in  
                the ramp, and will modify the selected entry if edited. The type of  
                control must be an attrFieldSliderGrp.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalLayout (bool?): Set the preview's layout.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the port created or modified

    Example:
    """

def rampWidget(*args: Any, **kwargs: Any) -> None: ...
def rampWidgetAttrless(*args: Any, **kwargs: Any) -> None: ...
def rangeControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changedCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., maxRange: Queryable[int] = ..., minRange: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., widthHeight: Tuple[int, int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a control used for displaying and modifying the current playback range.: only one main rangeControl may exist. Any additional rangeControls
    that a user creates are driven by the main range control widget.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changedCommand (Callable[..., Any]?): script to be executed when the range changes  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxRange (Queryable[int]?): Controls the max range displayable in the control  
                Properties: create, query, edit
        minRange (Queryable[int]?): Controls the max range displayable in the control  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        widthHeight (Tuple[int, int]?): Controls the dimensions of the control  
                Properties: create, edit

    Returns:
        str: Name of newly created rangeControl.

    Example:
    """

def readPDC(*args: str, file: str = ..., test: bool = ...) -> None: ...
def readTake(*args: Any, angle: str = ..., device: str = ..., frequency: float = ..., linear: str = ..., noTime: bool = ..., take: str = ...) -> bool:
    """This action reads a take (.mov) file to a defined device.See also: writeTake, applyTake
    Args:
        angle (str?): Sets the angular unit used in the take. Valid strings are  
                "deg", "degree", "rad", and "radian".   
                C: The default is the current user angular unit.  
                Properties: create
        device (str?): Specifies the device into which the take data is read. This is a  
                required argument.  
                Properties: create
        frequency (float?): The timestamp is ignored and the specified frequency is used. If  
                timeStamp data is not in the .mov file, the -noTimestamp flag  
                should also be used. This flag resample, instead  
                the data is assumed to be at the specified frequency.   
                C: If the take file does not use time stamps, the default frequency  
                is 60Hz.  
                Properties: create
        linear (str?): Sets the linear unit used in the take. Valid strings are  
                "mm", "millimeter", "cm", "centimeter", "m", "meter", "km",  
                "kilometer", "in", "inch", "ft", "foot", "yd", "yard", "mi",  
                and "mile".   
                C: The default is the current user linear unit.  
                Properties: create
        noTime (bool?): Specifies if the take (.mov) file contains time stamps.   
                C: The default is to assume time stamps are part of the take file.  
                Properties: create
        take (str?): Reads the specified take file. It is safest to pass the full  
                path to the flag.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def rebuildCurve(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., degree: Queryable[int] = ..., endKnots: Queryable[int] = ..., fitRebuild: bool = ..., keepControlPoints: bool = ..., keepEndPoints: bool = ..., keepRange: Queryable[int] = ..., keepTangents: bool = ..., nodeState: Queryable[int] = ..., rebuildType: Queryable[int] = ..., smartSurfaceCurveRebuild: bool = ..., spans: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., range: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, float]:
    """This command rebuilds a curve by modifying its parameterization.
    In some cases the shape may also change. The rebuildType (-rt)
    determines how the curve is to be rebuilt.The optional second curve can be used to specify a reference
    parameterization.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting curve  
                1. linear,  
                2. quadratic,  
                3. cubic,  
                5. quintic,  
                7. heptic  
                Default: 3  
                Properties: create, query, edit
        endKnots (Queryable[int]?): End conditions for the curve  
                0. uniform end knots,  
                1. multiple end knots,  
                Default: 0  
                Properties: create, query, edit
        fitRebuild (bool?): If true use the least squares fit rebuild.  
                Otherwise use the convert method.  
                Default: true  
                Properties: create, query, edit
        keepControlPoints (bool?): If true, the CVs will remain the same.  
                This forces uniform parameterization unless rebuildType is matchKnots.  
                Default: false  
                Properties: create, query, edit
        keepEndPoints (bool?): If true, keep the endpoints the same.  
                Default: true  
                Properties: create, query, edit
        keepRange (Queryable[int]?): Determine the parameterization for the resulting curve.  
                0. reparameterize the resulting curve from 0 to 1,  
                1. keep the original curve parameterization,  
                2. reparameterize the result from 0 to number of spans  
                Default: 1  
                Properties: create, query, edit
        keepTangents (bool?): If true, keep the end tangents the same.  
                Default: true  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        rebuildType (Queryable[int]?): How to rebuild the input curve.  
                0. uniform,  
                1. reduce spans,  
                2. match knots,  
                3. remove multiple knots,  
                4. curvature  
                5. rebuild ends  
                6. clean  
                Default: 0  
                Properties: create, query, edit
        smartSurfaceCurveRebuild (bool?): If true, curve on surface is rebuild in 3D and 2D info is kept  
                Default: false  
                Properties: create, query, edit
        spans (Queryable[int]?): The number of spans in resulting curve  
                Used only if rebuildType is uniform.  
                Default: 4  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to rebuild.  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def rebuildSurface(arg0: str = ..., arg1: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., degreeU: Queryable[int] = ..., degreeV: Queryable[int] = ..., direction: Queryable[int] = ..., endKnots: Queryable[int] = ..., fitRebuild: Queryable[int] = ..., keepControlPoints: bool = ..., keepCorners: bool = ..., keepRange: Queryable[int] = ..., nodeState: Queryable[int] = ..., rebuildType: Queryable[int] = ..., spansU: Queryable[int] = ..., spansV: Queryable[int] = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, float]:
    """This command rebuilds a surface by modifying its parameterization.
    In some cases the shape of the surface may also change. The
    rebuildType (-rt) attribute determines how the surface is rebuilt.The optional second surface can be used to specify a reference
    parameterization.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degreeU (Queryable[int]?): The degree of the resulting surface in the u direction  
                0. maintain current,  
                1. linear,  
                2. quadratic,  
                3. cubic,  
                5. quintic,  
                7. heptic  
                Default: 3  
                Properties: create, query, edit
        degreeV (Queryable[int]?): The degree of the resulting surface in the v direction  
                0. maintain current,  
                1. linear,  
                2. quadratic,  
                3. cubic,  
                5. quintic,  
                7. heptic  
                Default: 3  
                Properties: create, query, edit
        direction (Queryable[int]?): The direction in which to rebuild:  
                0. U,  
                1. V,  
                2. Both U and V  
                Default: 2  
                Properties: create, query, edit
        endKnots (Queryable[int]?): End conditions for the surface  
                0. uniform end knots,  
                1. multiple end knots,  
                Default: 0  
                Properties: create, query, edit
        fitRebuild (Queryable[int]?): Specify the type of rebuild method to be used:  
                0. Convert Classic, the default and original convert method.  
                1. Fit using the least squares fit method.  
                2. Convert Match, alternate matching convert method.  
                3. Convert Grid, uses a grid-based fit algorithm.  
                Default: 0  
                Properties: create, query, edit
        keepControlPoints (bool?): Use the control points of the input surface.  
                This forces uniform parameterization unless rebuildType is 2 (match knots)  
                Default: false  
                Properties: create, query, edit
        keepCorners (bool?): The corners of the resulting surface will not change from the corners of the input surface.  
                Default: true  
                Properties: create, query, edit
        keepRange (Queryable[int]?): Determine the parameterization for the resulting surface.  
                0. reparameterize the resulting surface from 0 to 1;  
                1. keep the original surface parameterization;  
                2. reparameterize the result from 0 to number of spans  
                Default: 1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        rebuildType (Queryable[int]?): The rebuild type:  
                0. uniform,  
                1. reduce spans,  
                2. match knots,  
                3. remove multiple knots,  
                4. force non rational  
                5. rebuild ends  
                6. trim convert (uniform)  
                7. into Bezier mesh  
                Default: 0  
                Properties: create, query, edit
        spansU (Queryable[int]?): The number of spans in the u direction in resulting surface. Used only when rebuildType is 0. uniform. If 0, keep the same number of spans as the original surface.  
                Default: 4  
                Properties: create, query, edit
        spansV (Queryable[int]?): The number of spans in the v direction in resulting surface. Used only when rebuildType is 0. uniform. If 0, keep the same number of spans as the original surface.  
                Default: 4  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to rebuild  
                Default: 0.01  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def recordAttr(*args: str, query: bool = ..., attribute: Multiuse[str] = ..., delete: bool = ...) -> bool:
    """This command sets up an attribute to be recorded.  When
    the record command is executed, any changes to this attribute
    are recorded.  When recording stops these changes are turned
    into keyframes.If no attributes are specified all attributes of the node
    are recorded.When the query flag is used, a list of the attributes being recorded will be returned.
    Args:
        attribute (Multiuse[str]?): specify the attribute to record  
                Properties: create, multiuse
        delete (bool?): Do not record the specified attributes  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def recordDevice(*args: Any, query: bool = ..., cleanup: bool = ..., data: bool = ..., device: Multiuse[str] = ..., duration: Queryable[int] = ..., playback: bool = ..., state: bool = ..., wait: bool = ...) -> Union[bool, int]:
    """Starts and stops server side device recording. The data is recorded
    at the device rate. Once recorded, the data may be brought into Maya
    with the applyTake command.See also: enableDevice, applyTake, readTake, writeTake
    Args:
        cleanup (bool?): Removes the recorded data from the device.  
                Properties: create
        data (bool?): Specifies if the device has recorded data. If the device is  
                recording at the time of query, the flag will return false.   
                Q: When queried, this flag returns an int.  
                Properties: query
        device (Multiuse[str]?): Specifies which device(s) to start record recording.  
                The listed device(s) will start recording regardless of their record  
                enable state.   
                C: The default is to start recording all devices that are  
                record enabled.  
                Properties: create, multiuse
        duration (Queryable[int]?): Duration (in seconds) of the recording. When the duration  
                expires, the device will still be in a recording state and must  
                be told to stop recording.   
                C: The default is 60.   
                Q: When queried, this flag returns an int.  
                Properties: create, query
        playback (bool?): If any attribute is connected to an animation curve, the  
                animation curve will play back while recording the device(s)  
                including any animation curves attached to attributes being  
                recorded.   
                C: The default is false.   
                Q: When queried, this flag returns an int.  
                Properties: create, query
        state (bool?): Start or stop device recording.   
                C: The default is true.   
                Q: When queried, this flag returns an int.  
                Properties: create, query
        wait (bool?): If -p/playback specified, wait until playback completion before  
                returning control to the user. This flag is ignored if -p is not used.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def redo() -> bool:
    """Takes the most recently undone command from the undo list
    and redoes it.
    Returns:
        bool:

    Example:
    """

def reference(*args: str) -> None:
    """Obsolete command: use referenceEdit and referenceQuery instead."""

def referenceEdit(*args: str, applyFailedEdits: bool = ..., changeEditTarget: Tuple[str, str] = ..., failedEdits: bool = ..., removeEdits: bool = ..., successfulEdits: bool = ..., editCommand: Queryable[Multiuse[str]] = ..., onReferenceNode: Queryable[Multiuse[str]] = ...) -> Union[bool, Multiuse[str]]:
    """Use this command to remove and change the modifications which have
    been applied to references. A valid commandTarget is either a reference node,
    a reference file, a node in a reference, or a plug from a reference.
    Only modifications that have been made from the currently open scene can
    be changed or removed. The 'referenceQuery -topReference' command can be used
    to determine what modifications have been made to a given commandTarget.
    Additionally only unapplied edits will be affected. Edits are unapplied
    when the node(s) which they affect are unloaded, or when they could
    not be successfully applied. By default this command only works on failed
    edits (this can be adjusted using the "-failedEdits" and
    "-successfulEdits" flags).
    Specifying a reference node as the command target is equivalent to
    specifying every node in the target reference file as a target. In this
    situation the results may differ depending on whether the target
    reference is loaded or unloaded. When it is unloaded, edits that affect both
    a node in the target reference and a node in one of its descendant references
    may be missed (e.g. those edits may not be removed). This is because when a
    reference is unloaded Maya no longer retains detailed information about which
    nodes belong to it. However, edits that only affect nodes in the target reference
    or in one of its ancestral references should be removed as expected.
    When the flags -removeEdits and -editCommand are used together, by default
    all connectAttr edits are removed from the specified source object. To remove
    only edits that connect to a specific target object, the target object can be
    passed as an additional argument to the command. This narrows the match criteria,
    so that only edits that connect the source object to the provided target in this
    additional argument are removed. See the example below.
    NOTE:
    When specifying a plug it is important to use the appropriate long attribute
    name.reference, attribute, node
    Args:
        applyFailedEdits (bool?): Attempts to apply any unapplied edits. This flag is useful if previously  
                failing edits have been fixed using the -changeEditTarget flag. This flag  
                can only be used on loaded references. If the command target is a referenced  
                node, the associated reference is used instead.  
                Properties: create
        changeEditTarget (Tuple[str, str]?): Used to change a target of the specified edits.  
                This flag takes two parameters: the old target of the edits, and the  
                new target to change it to. The target can either be a node name ("node"), a  
                node and attribute name ("node.attr"), or just an attribute name (".attr").  
                If an edit currently affects the old target, it will be changed to affect  
                the new target.  
                Flag 'referenceQuery' should be used to determine the format of the edit targets.  
                As an example most edits store the long name of the attribute  
                (e.g. "translateX"), so when specifying the old target, a long name must also  
                be used. If the short name is specified (e.g. "tx"), chances are the edit  
                won't be retargeted.  
                Properties: create
        failedEdits (bool?): This is a secondary flag used to indicate whether or not failed  
                edits should be acted on (e.g. queried, removed, etc...). A failed  
                edit is an edit which could not be successfully applied the last  
                time its reference was loaded.  
                An edit can fail for a variety of reasons (e.g. the referenced  
                node to which it applies was removed from the referenced file).  
                By default failed edits will be acted on.  
                Properties: create
        removeEdits (bool?): Remove edits which affect the specified unloaded commandTarget.  
                Properties: create
        successfulEdits (bool?): This is a secondary flag used to indicate whether or not successful  
                edits should be acted on (e.g. queried, removed, etc...). A successful  
                edit is any edit which was successfully applied the last time its  
                reference was loaded. This flag will have no affect if the  
                commandTarget is loaded.  
                By default successful edits will not be acted on.  
                Properties: create
        editCommand (Queryable[Multiuse[str]]?): This is a secondary flag used to indicate which type of reference edits should  
                be considered by the command.  
                If this flag is not specified all edit types will be included.  
                This flag requires a string parameter. Valid values are: "addAttr",  
                "connectAttr", "deleteAttr", "disconnectAttr", "parent", "setAttr",  
                "lock" and "unlock". In some contexts, this flag may be specified  
                more than once to specify multiple edit types to consider.  
                Properties: create, query, multiuse
        onReferenceNode (Queryable[Multiuse[str]]?): This is a secondary flag used to indicate that only those edits which are stored  
                on the indicated reference node should be considered. This flag only supports  
                multiple uses when specified with the "exportEdits" command.  
                Properties: create, query, multiuse

    Returns:
        bool:

    Example:
    """

def referenceQuery(*args: str, child: bool = ..., isExportEdits: bool = ..., isLoaded: bool = ..., liveEdits: bool = ..., dagPath: bool = ..., editAttrs: bool = ..., editNodes: bool = ..., editStrings: bool = ..., failedEdits: bool = ..., filename: bool = ..., isNodeReferenced: bool = ..., isPreviewOnly: bool = ..., namespace: bool = ..., nodes: bool = ..., parent: bool = ..., parentNamespace: bool = ..., referenceNode: bool = ..., shortName: bool = ..., showDagPath: bool = ..., showFullPath: bool = ..., showNamespace: bool = ..., successfulEdits: bool = ..., topReference: bool = ..., unresolvedName: bool = ..., withoutCopyNumber: bool = ..., editCommand: Queryable[Multiuse[str]] = ..., onReferenceNode: Queryable[Multiuse[str]] = ...) -> Union[List[str], Multiuse[str]]:
    """Use this command to find out information about references and referenced nodes.
    A valid target is either a reference node, a reference file, or a referenced node.
    Some flags don't require a target, see flag descriptions for more information
    on what effect this has.
    When a scene contains multiple levels of file references, those edits which
    affect a nested reference may be stored on several different reference nodes.
    For example:
    A.ma has a reference to B.ma which has a reference to C.ma which contains
    a poly sphere (pSphere1).
    If you were to open B.ma and translate the sphere, an edit would be stored
    on CRN which refers to a node named "C:pSphere1".
    If you were then to open A.ma and parent the sphere, an edit would be
    stored on BRN which refers to a node named "B:C:pSphere1".
    It is important to note that when querying edits which affect a nested
    reference, the edits will be returned in the same format that they were
    applied. In the above example, opening A.ma and querying all edits which affect
    C.ma, would return two edits a parent edit affecting "B:C:pSphere1", and a
    setAttr edit affecting "C:pSphere1". Since there is currently no node named
    C:pSphere1 (only B:C:pSphere1) care will have to be taken when interpreting the
    returned information.
    The same care should be taken when referenced DAG nodes have been parented or
    instanced. Continuing with the previous example, let's say that you were to
    open A.ma and, instead of simply parenting pSphere1, you were to instance it.
    While A.ma is open, "B:C:pSphere1" may now be an amibiguous name, replaced by
    "|B:C:pSphere1" and "group1|B:C:pSphere1". However querying the edits which
    affect C.ma would still return a setAttr edit affecting "C:pSphere1" since it
    was applied prior to B:C:pSphere1 being instanced.
    Some tips:
    1. Use the '-topReference' flag to query only those edits which were applied
       from the currently open file.
    2. Use the '-onReferenceNode' flag to limit the results to those edits where
       are stored on a given reference node. You can then use various string
       manipulation techniques to extrapolate the current name of any affected
       nodes.reference, attribute, node
    Args:
        child (bool?): This flag modifies the '-rfn/-referenceNode' and '-f/-filename' flags  
                to indicate the the children of the target reference will be returned.  
                Returns a string array.  
                Properties: create
        isExportEdits (bool?): Returns a boolean indicating whether the specified reference node or file  
                name is an edits file (created with the Export Edits feature)  
                Properties: create
        isLoaded (bool?): Returns a boolean indicating whether the specified reference node or  
                file name refers to a loaded or unloaded reference.  
                Properties: create
        liveEdits (bool?): Specifies that the edits should be returned based on the live edits  
                database. Only valid when used in conjunction with the editStrings flag.  
                Properties: create
        dagPath (bool?): This flag modifies the '-n/-nodes' flag to indicate that the names of  
                any dag objects returned will include as much of the dag path as is  
                necessary to make the names unique. If this flag is not present, the  
                names returned will not include any dag paths.  
                Properties: create
        editAttrs (bool?): Returns string array.  
                A main flag used to query the edits that have  
                been applied to the target. Only the names of  
                the attributes involved in the reference edit will be  
                returned. If an edit involves multiple attributes (e.g. "connectAttr"  
                edits) the nodes will be returned as separate,  
                consecutive entries in the string array. A valid target is either  
                a reference node, a reference file, or a referenced node.  
                If a referenced node is specified, only those edits which  
                affect that node will be returned. If a reference file  
                or reference node is specified any edit which affects  
                a node in that reference will be returned. If no target is  
                specified all edits are returned. This command can  
                be used on both loaded and unloaded references. By default  
                it will return all the edits, formatted as MEL commands,  
                which apply to the target.  
                This flag can be used in combination with the  
                '-ea/-editAttrs' flag to indicate that the names  
                of both the involved nodes and attributes will be  
                returned in the format 'node.attribute'.  
                Properties: create
        editNodes (bool?): Returns string array.  
                A main flag used to query the edits that have  
                been applied to the target. Only the names of  
                the nodes involved in the reference edit will be  
                returned. If an edit involves multiple nodes (e.g. "connectAttr"  
                edits) the nodes will be returned as separate,  
                consecutive entries in the string array. A valid target is either  
                a reference node, a reference file, or a referenced node.  
                If a referenced node is specified, only those edits which  
                affect that node will be returned. If a reference file  
                or reference node is specified any edit which affects  
                a node in that reference will be returned. If no target is  
                specified all edits are returned. This command can  
                be used on both loaded and unloaded references. By default  
                it will return all the edits, formatted as MEL commands,  
                which apply to the target.  
                This flag can be used in combination with the  
                '-ea/-editAttrs' flag to indicate that the names  
                of both the involved nodes and attributes will be  
                returned in the format 'node.attribute'.  
                Properties: create
        editStrings (bool?): Returns string array.  
                A main flag used to query the edits that have  
                been applied to the target. The edit will be returned  
                as a valid MEL command. A valid target is either  
                a reference node, a reference file, or a referenced node.  
                If a referenced node is specified, only those edits which  
                affect that node will be returned. If a reference file  
                or reference node is specified any edit which affects  
                a node in that reference will be returned. If no target is  
                specified all edits are returned. This command can be used  
                on both loaded and unloaded references. By default it will  
                return all the edits, formatted as MEL commands,  
                which apply to the target.  
                This flag cannot be used with either the '-en/-editNodes'  
                or '-ea/-editAttrs' flags.  
                Properties: create
        failedEdits (bool?): This is a secondary flag used to indicate whether or not failed  
                edits should be acted on (e.g. queried, removed, etc...). A failed  
                edit is an edit which could not be successfully applied the last  
                time its reference was loaded.  
                An edit can fail for a variety of reasons (e.g. the referenced  
                node to which it applies was removed from the referenced file).  
                By default failed edits will not be acted on.  
                Properties: create
        filename (bool?): Returns string.  
                A main flag used to query the filename associated with the target reference.  
                Properties: create
        isNodeReferenced (bool?): Returns boolean.  
                A main flag used to determine whether or not the target node comes  
                from a referenced file.  
                true if the target node comes from a referenced file, false if not.  
                Properties: create
        isPreviewOnly (bool?): Returns boolean.  
                This flag is used to determine whether or not the target reference node is  
                only a preview reference node.  
                Properties: create
        namespace (bool?): Returns string.  
                This flag returns the full namespace path of the target reference, starting from the root namespace ":".  
                It can be combined with the shortName flag to return just the base name of the namespace.  
                Properties: create
        nodes (bool?): Returns string array.  
                A main flag used to query the contents of the target reference.  
                Properties: create
        parent (bool?): This flag modifies the '-rfn/-referenceNode' and '-f/-filename' flags  
                to indicate the the parent of the target reference will be returned.  
                Properties: create
        parentNamespace (bool?): A main flag used to query and return the parent namespace of the target reference.  
                Properties: create
        referenceNode (bool?): Returns string.  
                A main flag used to query the reference node associated with the target  
                reference.  
                Properties: create
        shortName (bool?): This flag modifies the '-f/-filename' and '-ns/-namespace' flags.  
                Used with the '-f/-filename' flag indicates that the file name returned will be the short name  
                (i.e. just a file name without any directory paths). If this flag is not present, the full name  
                and directory path will be returned.  
                Used with the '-ns/-namespace' flag indicates that the namespace returned will be the base name of the namespace.  
                (i.e. the base name of the full namespace path ":AAA:BBB:CCC" is "CCC"  )  
                Properties: create
        showDagPath (bool?): Shows/hides the full dag path for edits. If false only displays the  
                node-name of reference edits. Must be used with the -editNodes,  
                -editStrings or -editAttrs flag.  
                Properties: create
        showFullPath (bool?): Return the full path from the root namespace for reference edits.  
                Must be used with the -editNodes, -editStrings or -editAttrs flags.  
                Properties: create
        showNamespace (bool?): Shows/hides the namespaces on nodes in the reference edits.  
                Must be used with the -editNodes, -editStrings or -editAttrs flag  
                Properties: create
        successfulEdits (bool?): This is a secondary flag used to indicate whether or not successful  
                edits should be acted on (e.g. queried, removed, etc...). A successful  
                edit is any edit which was successfully applied the last time its  
                reference was loaded.  
                By default successful edits will be acted on.  
                Properties: create
        topReference (bool?): This flag modifies the '-rfn/-referenceNode' flag  
                to indicate the top level ancestral reference of the target reference will be  
                returned.  
                Properties: create
        unresolvedName (bool?): This flag modifies the '-f/-filename' flag to indicate that the file name  
                returned will be unresolved (i.e. it will be the path originally  
                specified when the file was loaded into Maya; this path may  
                contain environment variables and may not exist on disk). If this  
                flag is not present, the resolved name will     be returned.  
                Properties: create
        withoutCopyNumber (bool?): This flag modifies the '-f/-filename' flag to indicate that the file name  
                returned will not have a copy number (e.g. '{1}') appended to the end. If this  
                flag is not present, the file name returned may have a copy number  
                appended to the end.  
                Properties: create
        editCommand (Queryable[Multiuse[str]]?): This is a secondary flag used to indicate which type of reference edits should  
                be considered by the command.  
                If this flag is not specified all edit types will be included.  
                This flag requires a string parameter. Valid values are: "addAttr",  
                "connectAttr", "deleteAttr", "disconnectAttr", "parent", "setAttr",  
                "lock" and "unlock". In some contexts, this flag may be specified  
                more than once to specify multiple edit types to consider.  
                Properties: create, query, multiuse
        onReferenceNode (Queryable[Multiuse[str]]?): This is a secondary flag used to indicate that only those edits which are stored  
                on the indicated reference node should be considered. This flag only supports  
                multiple uses when specified with the "exportEdits" command.  
                Properties: create, query, multiuse

    Returns:
        List[str]: For query execution.

    Example:
    """

def refineSubdivSelectionList(*args: Any) -> bool:
    """Refines a subdivision surface set of components based on the selection list. The
    selected components are subdivided. The selection list after the command is the
    newly created components at the finer subdivision level.subdivision, surface, select, region, refine, level, coarse, fine
    Returns:
        bool: Command result

    Example:
    """

def refresh(*, currentView: bool = ..., fileExtension: str = ..., filename: str = ..., force: bool = ..., suspend: bool = ...) -> bool:
    """This command is used to force a redraw during script execution.
    Normally, redraw is suspended while scripts are executing but
    sometimes it is useful to show intermediate results for purposes
    such as capturing images from the screen.If the -cv flag is specified, then only the current active view
    is redrawn.
    Args:
        currentView (bool?): Redraw only the current view (default redraws all views).  
                Properties: create
        fileExtension (str?): Specify the type of file to save using the filename flag.  
                Properties: create
        filename (str?): Specify the name of a file in which to save a snapshot of the  
                viewports, or just the current one if the currentView flag is set.  
                Properties: create
        force (bool?): Force the refresh regardless of the state of the model.  
                Properties: create
        suspend (bool?): Suspends or resumes Maya's handling of refresh events. Specify "on" to  
                suspend refreshing, and "off" to resume refreshing. Note that  
                resuming refresh does not itself cause a refresh -- the next natural refresh  
                event in Maya after "refresh -suspend off" is issued will cause the refresh  
                to occur. Use this flag with caution: although it provides opportunities  
                to enhance performance, much of Maya's dependency graph evaluation in  
                interactive mode is refresh driven, thus use of this flag may lead to  
                slight solve differences when you have a complex dependency graph with  
                interrelations.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def refreshEditorTemplates() -> bool:
    """This command refreshes all cached attribute editor templates,
    including those copied from the standard AE. These are the templates
    constructed internally on a per node type basis. This is useful
    if attribute elements have changed and the templates need to
    be re-evaluated accordingly.
    Returns:
        bool:

    Example:
    """

def regionSelectKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., bottomManip: Queryable[float] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., leftManip: Queryable[float] = ..., name: str = ..., rightManip: Queryable[float] = ..., topManip: Queryable[float] = ...) -> Union[float, str]:
    """This command creates a context which may be used to scale keyframes
    within the graph editor using the region select tool.
    Args:
        bottomManip (Queryable[float]?): Get a point located inside the bottom manipulator of the region box, in screen space.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        leftManip (Queryable[float]?): Get a point located inside the left manipulator of the region box, in screen space.  
                Properties: query
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        rightManip (Queryable[float]?): Get a point located inside the right manipulator of the region box, in screen space.  
                Properties: query
        topManip (Queryable[float]?): Get a point located inside the top manipulator of the region box, in screen space.  
                Properties: query

    Returns:
        float: Manip values, when queried

    Example:
    """

def rehash() -> None: ...
def relationship(arg0: str = ..., arg1: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., b: bool = ..., relationshipData: Queryable[Multiuse[str]] = ...) -> Union[bool, Multiuse[str]]:
    """This is primarily for use with file IO. Rather than write out the specific attributes/connections required to maintain a relationship, a description of the related nodes/plugs is written instead. The relationship must have an owner node, and have a specific type. During file read, maya will make the connections and/or set the data necessary to represent the realtionship in the dependency graph.relationship, lightLinker
    Args:
        b (bool?): Break the specified relationship instead of creating it  
                Properties: create, query, edit
        relationshipData (Queryable[Multiuse[str]]?): Provide relationship data to be used when creating the relationship.  
                Properties: create, query, edit, multiuse

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def reloadImage(arg0: str = ..., arg1: str = ..., /) -> bool:
    """This command reloads an xpm image from disk. This can be used when the
    file has changed on disk and needs to be reloaded.The first string argument is the file name of the .xpm file. The
    second string argument is the name of a control using the specified
    pixmap.
    Returns:
        bool: True if image is successfully loaded, false otherwise.

    Example:
    """

def rememberCtxSettings(arg0: str = ..., /) -> bool:
    """This command restores a tool to its saved settings. This command must
    only be called once for each tool created and should be called at the
    point the tool is created.
    Returns:
        bool:

    Example:
    """

def removeJoint(*args: str) -> bool:
    """This command will remove the selected joint or the joint given at the
    command line from the skeleton.The given (or selected) joint should not be the root joint of the skeleton,
    and not have skin attached. The command works on the given (or selected)
    joint. No options or flags are necessary.
    Returns:
        bool:

    Example:
    """

def removeListItem() -> None: ...
def removeMultiInstance(arg0: str = ..., /, *, allChildren: bool = ..., b: bool = ...) -> bool:
    """Removes a particular instance of a multiElement. This is only
    useful for input attributes since outputs will get regenerated the
    next time the node gets executed. This command will remove the
    instance and optionally break all incoming and outgoing connections
    to that instance. If the connections are not broken (with the -b
    true) flag, then the command will fail if connections exist.
    Args:
        allChildren (bool?): If the argument is true, remove all children of the multi parent.  
                Properties: create
        b (bool?): If the argument is true, all connections to the attribute  
                will be broken before the element is removed. If false, then  
                the command will fail if the element is connected.  
                Properties: create

    Returns:
        bool: (true if the instance was removed, false if something went wrong,
            like the attribute is connected but -b true was not specified)

    Example:
    """

def rename(arg0: str = ..., arg1: str = ..., /, *, ignoreShape: bool = ..., uuid: bool = ...) -> str:
    """Renames the given object to have the new name. If only one
    argument is supplied the command will rename the (first) selected
    object. If the new name conflicts with an existing name, the
    object will be given a unique name based on the supplied name.
    It is not legal to rename an object to the empty string.When a transform is renamed then any shape nodes beneath the
    transform that have the same prefix as the old transform name
    are renamed. For example, "rename nurbsSphere1 ball" would
    rename "nurbsSphere1|nurbsSphereShape1" to "ball|ballShape".If the new name ends in a single '#' then the rename command
    will replace the  trailing '#' with a number that ensures
    the new name is unique.If the name has an absolute namespace part, it will be considered.
    Namespaces that do not exist will be created automatically as needed.
    If the name has a relative namespace part, it will be ignored.
    In that case, the object will be put under the current namespace.
    (see example below).
    Args:
        ignoreShape (bool?): Indicates that renaming of shape nodes below  
                transform nodes should be prevented.  
                Properties: create
        uuid (bool?): Indicates that the new name is actually a UUID,  
                and that the command should change the node's UUID.  
                (In which case its name remains unchanged.)  
                Properties: create

    Returns:
        str: The new name. When undone returns original name.

    Example:
    """

def renameAttr(*args: str) -> str:
    """Renames the given user-defined attribute to the name given in the
    string argument. If the new name conflicts with an existing name then
    this command will fail.
    Note that it is not legal to rename an attribute to the empty string.node, connection, rename, attribute, dynamic
    Returns:
        str: The new name. When undone returns the original name.

    Example:
    """

def renameUI(arg0: str = ..., arg1: str = ..., /) -> str:
    """This command renames the UI object passed as first arument to the new
    name specified as second argument. If the
    new name is a duplicate, or not valid, then re-naming fails and the
    old name is returned.This command does not update other objects or commands that reference
    this object by name, so use this command at your own risk.
    Returns:
        str: The new name, or the old name if re-naming fails.

    Example:
    """

def render(arg0: str = ..., /, *args: str, abortMissingTexture: bool = ..., batch: bool = ..., keepPreImage: bool = ..., layer: str = ..., nglowpass: bool = ..., nshadows: bool = ..., replace: bool = ..., xresolution: int = ..., yresolution: int = ...) -> str:
    """The render command is used to start off a MayaSoftware rendering
    session of the currently active camera. If a rendering is already
    in progress, then this command stops the rendering. This command is
    not undoable.
    Args:
        abortMissingTexture (bool?): Abort renderer when encountered missing texture. Only  
                available when -batch is set  
                Properties: create
        batch (bool?): Run in batch mode. Compute the images for all renderable  
                cameras. This is the mel equivalent of running maya in batch  
                mode with the -render flag set. All other flags are ignored  
                when -batch is used.  
                Properties: create
        keepPreImage (bool?): Keep the renderings prior to post-process around. Only  
                available when -batch is set  
                Properties: create
        layer (str?): Render the specified render layer.  
                Only this render layer will be rendered,  
                regardless of the renderable attribute value of the render layer.  
                The layer name will be appended to the output image file name.  
                The specified render layer becomes the current render layer before rendering,  
                and remains as current render layer after the rendering.  
                Properties: create
        nglowpass (bool?): Overwrite glow pass capabilities (can turn off glow pass globally  
                by setting this value to false)  
                Properties: create
        nshadows (bool?): Shadowing capabilities (can turn off shadow globally  
                by setting this value to false)  
                Properties: create
        replace (bool?): Replace the rendered image if it already exists. Only  
                available when -batch is set  
                Properties: create
        xresolution (int?): Overwrite x resolution  
                Properties: create
        yresolution (int?): Overwrite y resolution  
                Properties: create

    Returns:
        str: The name of the rendered image.

    Example:
    """

def renderGlobalsNode(arg0: str = ..., /, *, name: str = ..., parent: str = ..., renderQuality: str = ..., renderResolution: str = ..., shared: bool = ..., skipSelect: bool = ...) -> str:
    """This command creates a new node in the dependency graph of the
    specified type.The renderGlobalsNode creates a render globals node and registers it
    with the model. The createNode command will not register nodes of this
    type correctly.
    Args:
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace doesn't exist, we  
                will create the namespace.  
                Properties: create
        parent (str?): Specifies the parent in the DAG under which the new node belongs.  
                Properties: create
        renderQuality (str?): Set the quality to be the renderQuality node with the given name.  
                Properties: create
        renderResolution (str?): Set the resolution to be the resolution node with the given name.  
                Properties: create
        shared (bool?): This node is shared across multiple files, so only create it if  
                it does not already exist.  
                Properties: create
        skipSelect (bool?): This node is not to be selected after creation, the original selection  
                will be preserved.  
                Properties: create

    Returns:
        str: The name of the new node.
        str: The name of the render globals node

    Example:
    """

def renderInfo(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., castShadows: bool = ..., chordHeight: float = ..., chordHeightRatio: float = ..., doubleSided: bool = ..., edgeSwap: bool = ..., minScreen: float = ..., name: str = ..., opposite: bool = ..., smoothShading: bool = ..., unum: int = ..., useChordHeight: bool = ..., useChordHeightRatio: bool = ..., useDefaultLights: bool = ..., useMinScreen: bool = ..., utype: int = ..., vnum: int = ..., vtype: int = ...) -> bool:
    """The renderInfo commands sets geometric properties of surfaces
    of the selected object.
    Args:
        castShadows (bool?): Determines if object casts shadow or not.  
                Properties: create
        chordHeight (float?): Tessellation subdivision criteria.  
                Properties: create
        chordHeightRatio (float?): Tessellation subdivision criteria.  
                Properties: create
        doubleSided (bool?): Determines if object double or single sided.  
                Properties: create
        edgeSwap (bool?): Tessellation subdivision criteria.  
                Properties: create
        minScreen (float?): Tessellation subdivision criteria.  
                Properties: create
        name (str?): Namespace to use.  
                Properties: create
        opposite (bool?): Determines if the normals of the object is to be reversed.  
                Properties: create
        smoothShading (bool?): Determines if smooth shaded, or flat shaded - applies only to polysets.  
                Properties: create
        unum (int?): Tessellation subdivision criteria.  
                Properties: create
        useChordHeight (bool?): Tessellation subdivision criteria.  
                Properties: create
        useChordHeightRatio (bool?): Tessellation subdivision criteria.  
                Properties: create
        useDefaultLights (bool?): Obsolete flag.  
                Properties: create
        useMinScreen (bool?): Tessellation subdivision criteria.  
                Properties: create
        utype (int?): Tessellation subdivision criteria.  
                Properties: create
        vnum (int?): Tessellation subdivision criteria.  
                Properties: create
        vtype (int?): Tessellation subdivision criteria.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def renderLayerMembers() -> None: ...
def renderLayerPostProcess(*, query: bool = ..., keepImages: bool = ..., sceneName: Queryable[str] = ...) -> Union[bool, str]:
    """Post process the results when rendering is done with. Presently this
    generates a layered PSD file using individual iff files.renderlayers, psd, photoshop
    Args:
        keepImages (bool?): When set to on, the original iff images are kept after the conversion to PSD.  
                Default is to remove them.  
                Properties: create, query
        sceneName (Queryable[str]?): Specifies the scene name for interactive batch rendering.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def renderManip(*args: str, edit: bool = ..., query: bool = ..., camera: Queryable[Tuple[bool, bool, bool, bool, bool]] = ..., light: Queryable[Tuple[bool, bool, bool]] = ..., spotLight: Queryable[Tuple[bool, bool, bool, bool, bool, bool, bool]] = ..., state: bool = ...) -> Union[bool, Tuple[bool, bool, bool, bool, bool], Tuple[bool, bool, bool], Tuple[bool, bool, bool, bool, bool, bool, bool]]:
    """This command creates manipulators for cameras or lights.
    Args:
        camera (Queryable[Tuple[bool, bool, bool, bool, bool]]?): Query or edit the visiblity status of the component camera  
                manipulators. The order of components are: cycling index,  
                center of interest, pivot, clipping planes, and unused.  
                Properties: query, edit
        light (Queryable[Tuple[bool, bool, bool]]?): Query or edit the visiblity status of the component light  
                manipulators. The order of components are: cycling index,  
                center of interest, and pivot.  
                Properties: query, edit
        spotLight (Queryable[Tuple[bool, bool, bool, bool, bool, bool, bool]]?): Query or edit the visiblity status of the component spot light  
                manipulators. The order of components are: cycling index,  
                center of interest, pivot, cone angle, penumbra, look through  
                barn doors, and decay regions.  
                Properties: query, edit
        state (bool?): Query or edit the state of manipulators on an camera, ambient  
                light, directional light, point light, or spot light. This  
                flag's default value is on.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def renderPartition(arg0: str = ..., /) -> str:
    """Set or query the model's current partition. When flagis
    not used, a partion name must be passed as an argument. In this
    case the current partition is set to that name.
    Returns:
        str: The render partition

    Example:
    """

def renderPassRegistry(*, channels: int = ..., isPassSupported: bool = ..., passID: str = ..., passName: bool = ..., renderer: str = ..., supportedChannelCounts: bool = ..., supportedDataTypes: bool = ..., supportedPassSemantics: bool = ..., supportedRenderPassNames: bool = ..., supportedRenderPasses: bool = ...) -> List[str]:
    """query information related with render passes.render, pass
    Args:
        channels (int?): Specify the number of channels for query.  
                Properties: create
        isPassSupported (bool?): Return whether the pass is supported by the renderer  
                This flag must be specified by the flag -passID firstly. The renderer whose default  
                value is the current renderer is specified by the flag renderer.  
                Properties: create
        passID (str?): Specify the render pass ID for query.  
                Properties: create
        passName (bool?): Get the pass name for the passID.  
                This flag must be specified by the flag -passID firstly.  
                Properties: create
        renderer (str?): Specify a renderer when using this command.  
                By default the current renderer is specified.  
                Properties: create
        supportedChannelCounts (bool?): List channel counts supported by the renderer(specified by the flag -renderer) and  
                the specified pass ID.  
                This flag must be specified by the flag -passID firstly.  
                Properties: create
        supportedDataTypes (bool?): List frame buffer types supported by the renderer(specified by the flag -renderer),  
                the specified passID and channels.  
                This flag must be specified by the flag -passID and -channels firstly.  
                Properties: create
        supportedPassSemantics (bool?): List pass semantics supported by the specified passID.  
                This flag must be specified by the flag -passId firstly.  
                Properties: create
        supportedRenderPassNames (bool?): List render pass names supported by the renderer(specified by the flag -renderer).  
                Properties: create
        supportedRenderPasses (bool?): List render passes supported by the renderer(specified by the flag -renderer).  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def renderQualityNode(arg0: str = ..., /, *, name: str = ..., parent: str = ..., shared: bool = ..., skipSelect: bool = ...) -> str:
    """This command creates a new node in the dependency graph of the
    specified type.The renderQualityNode creates a render quality node
    and registers it with the model.  The createNode
    command will not register nodes of this type correctly.
    Args:
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace doesn't exist, we  
                will create the namespace.  
                Properties: create
        parent (str?): Specifies the parent in the DAG under which the new node belongs.  
                Properties: create
        shared (bool?): This node is shared across multiple files, so only create it if  
                it does not already exist.  
                Properties: create
        skipSelect (bool?): This node is not to be selected after creation, the original selection  
                will be preserved.  
                Properties: create

    Returns:
        str: The name of the new node.
        str: The Name of the render quality node

    Example:
    """

def renderSettings(*args: Any, camera: str = ..., customTokenString: str = ..., firstImageName: bool = ..., fullPath: bool = ..., fullPathTemp: bool = ..., genericFrameImageName: str = ..., imageGenericName: bool = ..., lastImageName: bool = ..., layer: str = ..., leaveUnmatchedTokens: bool = ...) -> List[str]:
    """Query interface to the common tab of the render settingsrender, settings
    Args:
        camera (str?): Specify a camera that you want to replace the current renderable camera  
                Properties: create
        customTokenString (str?): Specify a custom key-value string to use to replace custom tokens in  
                the file name. Use with firstImageName or lastImageName. Basic tokens  
                (Scene, Layer, RenderLayer, Camera, Version, Extension) will be  
                automatically expanded. Any other tokens must be specified here to  
                be expanded.  
                The format of the string is a space separated list of tokens-value pairs.  
                For example, if the file name string is "myFile_<myToken>_<myOtherToken>_v"  
                then the argument to this flag string should take the form  
                "myToken=myTokenValue myOtherToken=myOtherTokenValue".  
                Properties: create
        firstImageName (bool?): Returns the first image name  
                Properties: create
        fullPath (bool?): Returns the full path for the image using the current project. Use with  
                firstImageName, lastImageName, or genericFrameImageName.  
                Properties: create
        fullPathTemp (bool?): Returns the full path for the preview render of the image using the current  
                project. Use with firstImageName, lastImageName, or genericFrameImageName.  
                Properties: create
        genericFrameImageName (str?): Returns the generic frame image name with the custom specified frame  
                index token  
                Properties: create
        imageGenericName (bool?): Returns the image generic name  
                Properties: create
        lastImageName (bool?): Returns the last image name  
                Properties: create
        layer (str?): Specify a render layer name that you want to replace the current render layer  
                Properties: create
        leaveUnmatchedTokens (bool?): Do not remove unmatched tokens from the name string. Use with  
                firstImageName or lastImageName.  
                Properties: create

    Returns:
        List[str]: Command result

    Example:
    """

def renderSetup(*, query: bool = ..., renderLayers: bool = ...) -> None: ...
def renderSetupFind() -> None: ...
def renderSetupLegacyLayer(*args: str) -> None: ...
def renderSetupLocalOverride(*, query: bool = ..., state: bool = ...) -> None: ...
def renderSetupPostApply() -> None: ...
def renderSetupSwitchVisibleRenderLayer() -> None: ...
def renderThumbnailUpdate(*args: Any, query: bool = ..., forceUpdate: str = ...) -> bool:
    """Toggle the updating of object thumbnails. These are visible in tools
    like the Attribute Editor and Hypershade. All thumbnails everywhere
    will not update to reflect changes to the object until this command is
    used to toggle to true unless a specific thumbnail is forced to render
    using the -forceUpdate flag.
    Args:
        forceUpdate (str?): Force the thumbnail to update.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def renderWindowEditor(*args: Any, edit: bool = ..., query: bool = ..., autoResize: bool = ..., blendMode: Queryable[int] = ..., caption: Queryable[str] = ..., changeCommand: Queryable[Tuple[str, str, str, str]] = ..., clear: Queryable[Tuple[int, int, float, float, float]] = ..., cmEnabled: bool = ..., colorManage: bool = ..., compDisplay: Queryable[int] = ..., compImageFile: Queryable[str] = ..., control: bool = ..., currentCamera: Queryable[str] = ..., currentCameraRig: Queryable[str] = ..., defineTemplate: str = ..., displayImage: Queryable[int] = ..., displayImageViewCount: Queryable[int] = ..., displayStyle: Queryable[str] = ..., docTag: Queryable[str] = ..., doubleBuffer: bool = ..., drawAxis: bool = ..., editorName: bool = ..., exists: bool = ..., exposure: Queryable[float] = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., frameImage: bool = ..., frameRegion: bool = ..., gamma: Queryable[float] = ..., highlightConnection: Queryable[str] = ..., loadImage: str = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., marquee: Queryable[Tuple[float, float, float, float]] = ..., nbImages: bool = ..., nextViewImage: bool = ..., outputColorManage: bool = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., pcaption: Queryable[str] = ..., realSize: bool = ..., refresh: bool = ..., removeAllImages: bool = ..., removeImage: bool = ..., resetRegion: bool = ..., resetViewImage: bool = ..., saveImage: bool = ..., scaleBlue: Queryable[float] = ..., scaleGreen: Queryable[float] = ..., scaleRed: Queryable[float] = ..., selectionConnection: Queryable[str] = ..., showRegion: Queryable[Tuple[int, int]] = ..., singleBuffer: bool = ..., snapshot: Queryable[Tuple[str, int, int]] = ..., snapshotMode: bool = ..., stateString: bool = ..., stereo: Queryable[int] = ..., stereoImageOrientation: Queryable[Tuple[str, str]] = ..., stereoMode: Queryable[str] = ..., toggle: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., viewImageCount: Queryable[int] = ..., viewTransformName: Queryable[str] = ..., writeImage: str = ...) -> Union[str, bool, int, Tuple[str, str, str, str], Tuple[int, int, float, float, float], float, Tuple[float, float, float, float], Tuple[int, int], Tuple[str, int, int], Tuple[str, str]]:
    """Create a editor window that can receive the result of the
    rendering process
    Args:
        autoResize (bool?): Lets the render view editor automatically resize the viewport or not.  
                Properties: create, query, edit
        blendMode (Queryable[int]?): Sets the blend mode for the render view.  
                New image sent to the render view will be blended  
                with the previous image in the render view,  
                and the composited image will appear.  
                Properties: create, query, edit
        caption (Queryable[str]?): Sets the caption which appears at the bottom of the render view.  
                Properties: create, query, edit
        changeCommand (Queryable[Tuple[str, str, str, str]]?): Parameters:  
              
                First string: command  
                Second string: editorName  
                Third string: editorCmd  
                Fourth string: updateFunc  
              
              
                Call the command when something changes in the editor The command  
                should have this prototype :  
              
                command(string $editor, string $editorCmd, string $updateFunc, int $reason)  
              
                The possible reasons could be :  
              
                0. no particular reason  
                1. scale color  
                2. buffer (single/double)  
                3. axis   
                4. image displayed  
                5. image saved in memory  
                Properties: create, query, edit
        clear (Queryable[Tuple[int, int, float, float, float]]?): Clear the image with the given color at the given resolution.  
                Arguments are respectively: width height red green blue.  
                Properties: create, query, edit
        cmEnabled (bool?): Turn on or off applying color management in the View.  If set, the color  
                management configuration set in the current view is used.  
                Properties: query, edit
        colorManage (bool?): When used with the writeImage flag, causes the written image to  
                be color-managed using the settings from the view color manager  
                attached to the view.  
                Properties: edit
        compDisplay (Queryable[int]?): 0. disable compositing.  
                1. displays the composited image immediately.  
                For example, when foreground layer tile is sent to the render  
                view window,  
                the composited tile is displayed in the render view window,  
                and the original foreground layer tile is not displayed.  
                2. display the un-composited image, and keep the  
                composited image for the future command.  
                For example, when foreground layer tile is sent to the  
                render view window,  
                the original foreground layer tile is not displayed,  
                and the composited tile is stored in a buffer.  
                3. show the current composited image.  
                If there is a composited image in the buffer, display it.  
                Properties: create, query, edit
        compImageFile (Queryable[str]?): Open the given image file  
                and blend with the buffer  
                as if the image was just rendered.  
                Properties: create, query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        currentCamera (Queryable[str]?): Get or set the current camera. (used when redoing last render)  
                Properties: create, query, edit
        currentCameraRig (Queryable[str]?): Get or set the current camera rig name. If a camera rig is  
                specified, it will be used when redoing the last render as  
                opposed to the currentCamera value, as the currentCamera  
                value will hold the child camera last used for rendering  
                the camera rig.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayImage (Queryable[int]?): Set a particular image in the Editor Image Stack as the current Editor Image.  
                Images are added to the Editor Image Stack using the "si/saveImage" flag.  
                Properties: query, edit
        displayImageViewCount (Queryable[int]?): Query the number of views stored for a given image in the Editor Image Stack. This is not the same  
                as querying using "viewImageCount" which returns the number of views for the current rendered image.  
                Properties: query
        displayStyle (Queryable[str]?): Set the mode to display the image. Valid values are:  
              
                "color" to display the basic RGB image  
                "mask" to display the mask channel  
                "lum" to display the luminance of the image  
                Properties: create, query, edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        doubleBuffer (bool?): Set the display in double buffer mode  
                Properties: create, query, edit
        drawAxis (bool?): Set or query whether the axis will be drawn.  
                Properties: create, query, edit
        editorName (bool?): Returns the name of the editor, or an empty string if the editor has not been created yet.  
                Properties: query
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        exposure (Queryable[float]?): The exposure value used by the color management of the current view.  
                Properties: query, edit
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        frameImage (bool?): Frames the image inside the window.  
                Properties: create, query, edit
        frameRegion (bool?): Frames the region inside the window.  
                Properties: create, query, edit
        gamma (Queryable[float]?): The gamma value used by the color management of the current view.  
                Properties: query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        loadImage (str?): load an image from disk and set it as the current Editor Image  
                Properties: edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        marquee (Queryable[Tuple[float, float, float, float]]?): The arguments define the four corners of a rectangle: top left bottom right.  
                The rectangle defines a marquee for the render computation.  
                Properties: create, query, edit
        nbImages (bool?): returns the number of images  
                Properties: query
        nextViewImage (bool?): The render editor has the capability to render multiple cameras within a  
                single view. This is different from image binning where an image is saved. Multiple image views  
                are useful for comparing two different camera renders side-by-side. The nextViewImage flag tells  
                the editor that it should prepare its internal image storage mechanism to store to the next  
                view location.  
                Properties: create, edit
        outputColorManage (bool?): When used with the writeImage flag, causes the written image to  
                be color-managed using the outpute color space in the color preferences  
                attached to the view.  
                Properties: edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        pcaption (Queryable[str]?): Get or set the permanent caption which appears under  
                the image that is currently showing in the render editor.  
                Properties: create, query, edit
        realSize (bool?): Display the image with a one to one pixel match.  
                Properties: create, query, edit
        refresh (bool?): requests a refresh of the current Editor Image.  
                Properties: edit
        removeAllImages (bool?): remove all the Editor Images from the Editor Image Stack  
                Properties: edit
        removeImage (bool?): remove the current Editor Image from the Editor Image Stack  
                Properties: edit
        resetRegion (bool?): Forces a reset of any marquee/region.  
                Properties: create, query, edit
        resetViewImage (bool?): The render editor has the capability to render multiple cameras within a  
                single view. This is different from image binning where an image is saved. Multiple image views  
                are useful for comparing two different camera renders side-by-side. The resetViewImage flag tells  
                the editor that it should reset its internal image storage mechanism to the first image.  
                This would happen at the very start of a render view render.  
                Properties: create, edit
        saveImage (bool?): save the current Editor Image to memory. Saved Editor Images are  
                stored in an Editor Image Stack. The most recently saved image is stored in  
                position 0, the second most recently saved image in position 1,  
                and so on... To set the current Editor Image to a previously saved  
                image use the "di/displayImage" flag.  
                Properties: edit
        scaleBlue (Queryable[float]?): Define the scaling factor for the blue component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        scaleGreen (Queryable[float]?): Define the scaling factor for the green component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        scaleRed (Queryable[float]?): Define the scaling factor for the red component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        showRegion (Queryable[Tuple[int, int]]?): Shows the current region at the given resolution. The two parameters  
                define the width and height.  
                Properties: create, query, edit
        singleBuffer (bool?): Set the display in single buffer mode  
                Properties: create, query, edit
        snapshot (Queryable[Tuple[str, int, int]]?): Makes a copy of the camera of the model editor at the  
                given size.  
                First argument is the editor name, second is the width, third is the height.  
                Properties: create, query, edit
        snapshotMode (bool?): Get or set the window's snapshot mode.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        stereo (Queryable[int]?): Puts the editor into stereo image mode.  The effective resolution of the  
                output image is twice the size of the horizontal size. The orientation of the  
                images can be set using the stereoOrientation flag.  
                Properties: create, query, edit
        stereoImageOrientation (Queryable[Tuple[str, str]]?): Specifies the orientation of stereo camera renders.  The first argument specifies the orientation  
                value for the firstleft image and the second argument specifies the orientation value for the right  
                image. The orientation values are 'normal', the image appears as seen throught he camera, or  
                'mirrored', the image is mirrored horizontally.  
                Properties: create, query, edit
        stereoMode (Queryable[str]?): Specifies how the image is displayed in the view.  By default the stereo is rendered with a  
                side by side image.  The rendered image is a single image that is twice the size of a normal image,  
                'both'. Users can also choose to display as 'redcyan', 'redcyanlum', 'leftonly', 'rightonly', or 'stereo'.  
              
                both - displays both the left and right  
                redcyan - displays the images as a red/cyan pair.  
                redcyanlum - displays the luminance of the images as a red/cyan pair.  
                leftonly - displays the left side only  
                rightonly - displays the right side only  
                stereo - mode that supports Crystal Eyes(tm) or Zscreen (tm) renders  
                Properties: create, query, edit
        toggle (bool?): Turns the ground plane display on/off.  
                Properties: create, query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        viewImageCount (Queryable[int]?): The render editor has the capability to render multiple cameras within a  
                single view. This is different from image binning where an image is saved. Multiple image views  
                are useful for comparing two different camera renders side-by-side. The viewImageCount flag tells  
                the editor that it should prepare its internal image storage mechanism for a given number of views.  
                Properties: create, query, edit
        viewTransformName (Queryable[str]?): Sets/gets the view transform to be applied if color management is enabled in the  
                current view.  
                Properties: query, edit
        writeImage (str?): write the current Editor Image to disk  
                Properties: edit

    Returns:
        str: The name of the editor

    Example:
    """

def renderWindowSelectContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """Set the selection context for the render view panel.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: Context name
    """

def renderer(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addGlobalsNode: Queryable[str] = ..., addGlobalsTab: Tuple[str, str, str] = ..., batchRenderOptionsProcedure: Queryable[str] = ..., batchRenderOptionsStringProcedure: Queryable[str] = ..., batchRenderProcedure: Queryable[str] = ..., cancelBatchRenderProcedure: Queryable[str] = ..., changeIprRegionProcedure: Queryable[str] = ..., commandRenderProcedure: Queryable[str] = ..., exists: bool = ..., globalsNodes: bool = ..., globalsTabCreateProcNames: bool = ..., globalsTabLabels: bool = ..., globalsTabUpdateProcNames: bool = ..., iprOptionsMenuLabel: Queryable[str] = ..., iprOptionsProcedure: Queryable[str] = ..., iprOptionsSubMenuProcedure: Queryable[str] = ..., iprRenderProcedure: Queryable[str] = ..., iprRenderSubMenuProcedure: Queryable[str] = ..., isRunningIprProcedure: Queryable[str] = ..., logoCallbackProcedure: Queryable[str] = ..., logoImageName: Queryable[str] = ..., materialViewRendererList: bool = ..., materialViewRendererPause: bool = ..., materialViewRendererSuspend: bool = ..., namesOfAvailableRenderers: bool = ..., pauseIprRenderProcedure: Queryable[str] = ..., polyPrelightProcedure: Queryable[str] = ..., refreshIprRenderProcedure: Queryable[str] = ..., renderDiagnosticsProcedure: Queryable[str] = ..., renderGlobalsProcedure: Queryable[str] = ..., renderMenuProcedure: Queryable[str] = ..., renderOptionsProcedure: Queryable[str] = ..., renderProcedure: Queryable[str] = ..., renderRegionProcedure: Queryable[str] = ..., renderSequenceProcedure: Queryable[str] = ..., rendererUIName: Queryable[str] = ..., renderingEditorsSubMenuProcedure: Queryable[str] = ..., showBatchRenderLogProcedure: Queryable[str] = ..., showBatchRenderProcedure: Queryable[str] = ..., showRenderLogProcedure: Queryable[str] = ..., startIprRenderProcedure: Queryable[str] = ..., stopIprRenderProcedure: Queryable[str] = ..., supportColorManagement: bool = ..., textureBakingProcedure: Queryable[str] = ..., unregisterRenderer: bool = ...) -> Union[bool, str]:
    """Command to register renders.  This command allows you to
    specify the UI name and procedure names for renderers.
    The command also allow you to query the UI name and the procedure
    names for the registered renders.renderer, registration
    Args:
        addGlobalsNode (Queryable[str]?): This flag allows the user to add a globals node the specified  
                renderer uses.  
                Properties: create, query, edit
        addGlobalsTab (Tuple[str, str, str]?): Add a tab associated with the specified renderer for the  
                unified render globals window.  
                Properties: create, edit
        batchRenderOptionsProcedure (Queryable[str]?): Set or query the batch render options procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        batchRenderOptionsStringProcedure (Queryable[str]?): Set or query the argument string that will be used with the command  
                line utility 'Render' when doing a batch render  
                Properties: create, query, edit
        batchRenderProcedure (Queryable[str]?): Set or query the batch render procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        cancelBatchRenderProcedure (Queryable[str]?): Set or query returns the cancel batch render procedure associated  
                with the specified renderer.  
                Properties: create, query, edit
        changeIprRegionProcedure (Queryable[str]?): Set or query the change IPR region procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        commandRenderProcedure (Queryable[str]?): Set or query the command line rendering procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        exists (bool?): The flag returns true if the specified renderer is registered  
                in the registry, and it returns false otherwise.  
                Properties: query, edit
        globalsNodes (bool?): This flag returns the list of render globals nodes the  
                specified renderer uses.  
                Properties: create, query, edit
        globalsTabCreateProcNames (bool?): This flag returns the names of procedures that are used to  
                create the unified render globals window tabs  
                that are associated with the specified renderer.  
                Properties: create, query, edit
        globalsTabLabels (bool?): This flag returns the labels of unified render globals window tabs  
                that are associated with the specified renderer.  
                Properties: create, query, edit
        globalsTabUpdateProcNames (bool?): This flag returns the names of procedures that are used to  
                update the unified render globals window tabs  
                that are associated with the specified renderer.  
                Properties: create, query, edit
        iprOptionsMenuLabel (Queryable[str]?): Set or query the label for the IPR update options menu which is under  
                the render view's IPR menu.  
                Properties: create, query, edit
        iprOptionsProcedure (Queryable[str]?): Set or query the IPR render options procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        iprOptionsSubMenuProcedure (Queryable[str]?): Set or query the procedure for creating the sub menu for the IPR  
                update options menu which is under the render view's IPR menu.  
                Properties: create, query, edit
        iprRenderProcedure (Queryable[str]?): Set or query the IPR render command associated with the  
                specified renderer.  
                Properties: create, query, edit
        iprRenderSubMenuProcedure (Queryable[str]?): Set or query the procedure for creating the sub menu for the IPR  
                render menu which is under the render view's IPR menu.  
                Properties: create, query, edit
        isRunningIprProcedure (Queryable[str]?): Set or query the isRunningIpr command associated with the  
                specified renderer.  
                Properties: create, query, edit
        logoCallbackProcedure (Queryable[str]?): Set or query the procedure which is a callback associated to the  
                logo for the specified renderer.   For example, the logo and the  
                callback can be used in the unified render globals window beside  
                the "Render Using" optionMenu.  
                Properties: create, query, edit
        logoImageName (Queryable[str]?): Set or query the logo image name for the specified renderer.  
                The logo is a image representing the renderer.  
                Properties: create, query, edit
        materialViewRendererList (bool?): Returns the names of material view renderers that are currently registered.  
                Properties: query, edit
        materialViewRendererPause (bool?): Specifies whether to pause the material viewer.  
                Useful for globally halting updates to the material viewer.  
                The material view renderer will remain suspended while the viewer is paused.  
                Properties: query, edit
        materialViewRendererSuspend (bool?): Specifies whether to suspend or resume the material view renderer.  
                Useful for temporarily stopping the material view renderer while another  
                rendering task is running.  
                Properties: query, edit
        namesOfAvailableRenderers (bool?): Returns the names of renderers that are currently registered.  
                Properties: query, edit
        pauseIprRenderProcedure (Queryable[str]?): Set or query the pause IPR render procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        polyPrelightProcedure (Queryable[str]?): Set or query the polygon prelight procedure associated with  
                the specified renderer.  
                Properties: create, query, edit
        refreshIprRenderProcedure (Queryable[str]?): Set or query the refresh IPR render procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        renderDiagnosticsProcedure (Queryable[str]?): Set or query the render diagnostics procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        renderGlobalsProcedure (Queryable[str]?): This flag is obsolete.  It will be removed in the next release.  
                Properties: create, query, edit
        renderMenuProcedure (Queryable[str]?): This flag is obsolete. It will be removed in the next release.  
                Properties: create, query, edit
        renderOptionsProcedure (Queryable[str]?): Set or query the render options procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        renderProcedure (Queryable[str]?): Set or query the render command associated with the specified renderer.  
                Properties: create, query, edit
        renderRegionProcedure (Queryable[str]?): Set or query the render region procedure associated with the specified  
                renderer.  
                Properties: create, query, edit
        renderSequenceProcedure (Queryable[str]?): Set or query the sequence rendering procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        rendererUIName (Queryable[str]?): Set or query the rendererUIName for the specified renderer.  
                The rendererUIName is the name of the renderer as it would appear  
                in menus.  
                Properties: create, query, edit
        renderingEditorsSubMenuProcedure (Queryable[str]?): Set or query the procedure reponsible for creating renderer  
                specific editors submenu under the "Rendering Editors" menu  
                for the specified renderer.  
                Properties: create, query, edit
        showBatchRenderLogProcedure (Queryable[str]?): Set or query the log file batch procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        showBatchRenderProcedure (Queryable[str]?): Set or query the show batch render procedure associated with  
                the specified renderer.  
                Properties: create, query, edit
        showRenderLogProcedure (Queryable[str]?): Set or query the log file render procedure associated with  
                the specified renderer.  
                Properties: create, query, edit
        startIprRenderProcedure (Queryable[str]?): Set or query the start IPR render procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        stopIprRenderProcedure (Queryable[str]?): Set or query the stop IPR render procedure associated with the  
                specified renderer.  
                Properties: create, query, edit
        supportColorManagement (bool?): Specifies whether the renderer supports color management.  
                Properties: query, edit
        textureBakingProcedure (Queryable[str]?): Set or query the texture baking procedure associated with  
                the specified renderer.  
                Properties: create, query, edit
        unregisterRenderer (bool?): Unregister the specified renderer.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def reorder(*args: str, back: bool = ..., front: bool = ..., relative: int = ...) -> bool:
    """This command reorders (moves) objects relative to their siblings.For relative moves, both positive and negative numbers may be
    specified.  Positive numbers move the object forward and
    negative numbers move the object backward amoung its
    siblings. When an object is at the end (beginning) of the list
    of siblings, a relative move of 1 (-1) will put the object at
    the beginning (end) of the list of siblings.  That is,
    relative moves will wrap if necessary.If a shape is specified and it is the only child then its parent
    will be reordered.
    Args:
        back (bool?): Move object(s) to back of sibling list.  
                Properties: create
        front (bool?): Move object(s) to front of sibling list.  
                Properties: create
        relative (int?): Move object(s) relative to other siblings.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def reorderContainer(*args: str, edit: bool = ..., query: bool = ..., back: bool = ..., front: bool = ..., relative: Queryable[int] = ...) -> Union[bool, int]:
    """This command reorders (moves) objects relative to their siblings in
    a container.For relative moves, both positive and negative numbers may be
    specified.  Positive numbers move the object forward and
    negative numbers move the object backward amoung its
    siblings. When an object is at the end (beginning) of the list
    of siblings, a relative move of 1 (-1) will put the object at
    the beginning (end) of the list of siblings.  That is,
    relative moves will wrap if necessary.Only nodes within one container can be moved at a time.
    Note: The container command's -nodeList flag will return a sorted list of
    contained nodes. To see the effects of reordering, use the -unsortedOrder flag
    in conjunction with the -nodeList flag.node, container, reorder
    Args:
        back (bool?): Move object(s) to back of container contents list  
                Properties: create, query, edit
        front (bool?): Move object(s) to front of container contents list  
                Properties: create, query, edit
        relative (Queryable[int]?): Move object(s) relative to other container contents  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def reorderDeformers(arg0: str = ..., arg1: str = ..., /, *args: str, name: str = ...) -> bool:
    """This command changes the order in which 2 deformation nodes affect the
    output geometry. The first string argument is the name of deformer1,
    the second is deformer2, followed by the list of objects they
    deform.It inserts deformer2 before deformer1. Currently supported deformer
    nodes include: sculpt, cluster, jointCluster, lattice, wire,
    jointLattice, boneLattice, blendShape.
    Args:
        name (str?): This flag is obsolete and is not used.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def repeatLast(*, edit: bool = ..., query: bool = ..., addCommand: str = ..., addCommandLabel: str = ..., commandList: int = ..., commandNameList: int = ..., historyLimit: int = ..., item: int = ..., numberOfHistoryItems: bool = ..., pythonCommand: bool = ...) -> None: ...
def replaceCacheFrames() -> None: ...
def replaceCacheFramesOpt() -> None: ...
def requires(arg0: str = ..., arg1: str = ..., /, *, dataType: Multiuse[str] = ..., nodeType: Multiuse[str] = ...) -> bool:
    """This command is used during file I/O to specify the requirements
    needed to load the given file.  It defines what file format
    version was used to write the file, or what plug-ins are required to
    load the scene.The first string names a product (either "maya", or a plug-in name)The second string gives the version. This command is only useful during
    file I/O, so users should not have any need to use this command themselves.The flags "-nodeType" and "-dataType" specify the node types
    and data types defined by the plug-in. When Maya open a scene file, it
    runs "requires" command in the file and load required plug-ins. But some
    plug-ins may be not loaded because they are missing. The flags "-nodeType"
    and "-dataType" are used by the missing plug-ins. If one plug-in is missing,
    nodes and data created by this plug-in are created as unknown nodes and
    unknown data. Maya records their original types for these unknown nodes
    and data. When these nodes and data are saved back to file, it will be
    possible to determine the associated missing plug-ins. And when export
    selected nodes, Maya can write out the exact required plug-ins.
    The flags "-nodeType" and "-dataType" is optional. In this command, if these
    flags are not given for one plug-in and the plug-in is missing, the "requires"
    command of this plug-in will always be saved back.
    Args:
        dataType (Multiuse[str]?): Specify a data type defined by this plug-in.  
                The data type is specified by MFnPlugin::registerData() when register  
                the plug-in.  
                Properties: create, multiuse
        nodeType (Multiuse[str]?): Specify a node type defined by this plug-in.  
                The node type is specified by MFnPlugin::registerNode() when register  
                the plug-in.  
                Properties: create, multiuse

    Returns:
        bool:

    Example:
    """

def reroot(arg0: str = ..., /) -> bool:
    """This command will reroot a skeleton. The selected joint or the given joint
    at the command line will be the new    root of the skeleton. All ikHandles
    passing through the selected joint or above it will be deleted.The given(or selected) joint should not have skin attached. The    command
    works on the given or selected joint. No options or flags are necessary.
    Returns:
        bool:

    Example:
    """

def resampleFluid(*args: str, edit: bool = ..., query: bool = ..., resampleDepth: Queryable[int] = ..., resampleHeight: Queryable[int] = ..., resampleWidth: Queryable[int] = ...) -> Union[bool, int]:
    """A command to extend the fluid grid, keeping the voxels the same size,
    and keeping the existing contents of the fluid in the same place. Note
    that the fluid transform is also modified to make this possible.fluid
    Args:
        resampleDepth (Queryable[int]?): Change depth resolution to this value  
                Properties: create, query, edit
        resampleHeight (Queryable[int]?): Change height resolution to this value  
                Properties: create, query, edit
        resampleWidth (Queryable[int]?): Change width resolution to this value  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def resetTool(arg0: str = ..., /) -> bool:
    """This command resets a tool back to its "factory settings"
    Returns:
        bool:

    Example:
    """

def resolutionNode(arg0: str = ..., /, *, name: str = ..., parent: str = ..., shared: bool = ..., skipSelect: bool = ...) -> str:
    """This command creates a new node in the dependency graph of the
    specified type.The resolutionNode creates a render resolution node
    and registers it with the model.  The createNode
    command will not register nodes of this type correctly.
    Args:
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace doesn't exist, we  
                will create the namespace.  
                Properties: create
        parent (str?): Specifies the parent in the DAG under which the new node belongs.  
                Properties: create
        shared (bool?): This node is shared across multiple files, so only create it if  
                it does not already exist.  
                Properties: create
        skipSelect (bool?): This node is not to be selected after creation, the original selection  
                will be preserved.  
                Properties: create

    Returns:
        str: The name of the new node.
        str: The name of the render resolution node

    Example:
    """

def resourceManager(*, nameFilter: str = ..., saveAs: Tuple[str, str] = ...) -> bool:
    """List resources matching certain properties.resources, file
    Args:
        nameFilter (str?): List only resources matching the name. Argument may contain ? and *  
                characters.  
                Properties: create
        saveAs (Tuple[str, str]?): Saves a copy of the resource (first parameter) as a separate file (second parameter).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def retimeHelper(*, edit: bool = ..., query: bool = ..., deleteFrame: int = ..., frame: float = ..., lockBar: Tuple[int, int] = ..., locks: int = ..., moveFrame: Tuple[int, float] = ..., mouseOver: bool = ...) -> None: ...
def retimeKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., moveByFrame: int = ..., name: str = ..., snapOnFrame: bool = ...) -> Union[bool, str]:
    """This command creates a context which may be used to scale keyframes
    within the graph editor using the retime tool.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        moveByFrame (int?): Move the selected retime bar by the specified number of frames  
                Properties: edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        snapOnFrame (bool?): When set, the retime markers will snap on frames as they are moved.  
                Properties: query, edit

    Returns:
        bool: Query value from the snapOnFame setting.

    Example:
    """

def reverseCurve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., object: bool = ..., range: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int]:
    """The reverseCurve command reverses the direction of a curve or
    curve-on-surface.  A string is returned containing the pathname
    of the newly reversed curve and the name of the resulting dependency
    node.  The reversed curve has the same parameter range as the original
    curve.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: (object name and node name)

    Example:
    """

def reverseSurface(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., direction: Queryable[int] = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int]:
    """The reverseSurface command reverses one or both directions of a
    surface or can be used to "swap" the U and V directions (this creates
    the effect of reversing the surface normal). The name of the newly
    reversed surface and the name of the resulting dependency node is
    returned. The resulting surface has the same parameter ranges as the
    original surface.This command also handles selected surface isoparms. For a selected
    isoparm, imagine that the isoparm curve is reversed after the
    operation. E.g. reverseSurface surface.v[0.1] will reverse in the U
    direction.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[int]?): The direction to reverse the surface in:  
                0. U,  
                1. V,  
                2. Both U and V,  
                3. Swap  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def revolve(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., autoCorrectNormal: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., axisChoice: Queryable[int] = ..., axisX: Queryable[float] = ..., axisY: Queryable[float] = ..., axisZ: Queryable[float] = ..., bridge: bool = ..., caching: bool = ..., computePivotAndAxis: Queryable[int] = ..., degree: Queryable[int] = ..., endSweep: Queryable[float] = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., pivotX: Queryable[float] = ..., pivotY: Queryable[float] = ..., pivotZ: Queryable[float] = ..., radius: Queryable[float] = ..., radiusAnchor: Queryable[float] = ..., sections: Queryable[int] = ..., startSweep: Queryable[float] = ..., tolerance: Queryable[float] = ..., useTolerance: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ..., range: bool = ..., rebuild: bool = ..., useLocalPivot: bool = ...) -> Union[List[str], bool, Tuple[float, float, float], int, float]:
    """This command creates a revolved surface by revolving the given profile
    curve about an axis.  The profile curve can be a curve, curve-on-surface,
    surface isoparm, or trim edge.
    Args:
        autoCorrectNormal (bool?): If this is set to true we will attempt to reverse the direction of the axis in case it is necessary to do so for the surface normals to end up pointing to the outside of the object.  
                Default: false  
                Properties: create, query, edit
        axis (Queryable[Tuple[float, float, float]]?): Revolve axis  
                Properties: create, query, edit
        axisChoice (Queryable[int]?): Only used for computed axis/pivot case.  As we are computing the axis for a planar curve, we have two choices for the major axis based axis.  We will choose the axis corresponding to the longer dimension of the object (0), or explicitly choose one or the other (choices 1 and 2).  
                Default: 0  
                Properties: create, query, edit
        axisX (Queryable[float]?): X of the axis  
                Default: 1  
                Properties: create, query, edit
        axisY (Queryable[float]?): Y of the axis  
                Default: 0  
                Properties: create, query, edit
        axisZ (Queryable[float]?): Z of the axis  
                Default: 0  
                Properties: create, query, edit
        bridge (bool?): If true, we will close a partial revolve to get a pie shaped surface.  The surface will be closed, but not periodic the way it is in the full revolve case.  
                Default: false  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        computePivotAndAxis (Queryable[int]?): If this is set to 2, we will compute the axis, use the curve position and radius to compute the pivot for the revolve internally.  The value of the pivot and axis attributes are ignored.  If this is set to 1, we will take the supplied axis, but compute the pivot.  If this is set to 0, we will take both the supplied axis and pivot.  
                Default: 0  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface.  
                Default: 3  
                Properties: create, query, edit
        endSweep (Queryable[float]?): The value for the end sweep angle, in the current units.  This must be no more than the maximum, 360 degrees, or 2 Pi radians.  
                Default: 6.2831853  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): Revolve pivot point  
                Properties: create, query, edit
        pivotX (Queryable[float]?): X of the pivot  
                Default: 0  
                Properties: create, query, edit
        pivotY (Queryable[float]?): Y of the pivot  
                Default: 0  
                Properties: create, query, edit
        pivotZ (Queryable[float]?): Z of the pivot  
                Default: 0  
                Properties: create, query, edit
        radius (Queryable[float]?): The pivot point will be this distance away from the bounding box of the curve, if computedPivot is set to true.  The value of the pivot attribute is ignored.  
                Default: 1  
                Properties: create, query, edit
        radiusAnchor (Queryable[float]?): The position on the curve for the anchor point so that we can compute the pivot using the radius value.  If in 0. 1 range, its on the curve, normalized parameter range.  If < 0 or > 1, its computed based on the bounding box.  
                Default: -1  
                Properties: create, query, edit
        sections (Queryable[int]?): Number of sections of the resulting surface (if tolerance is not used).  
                Default: 8  
                Properties: create, query, edit
        startSweep (Queryable[float]?): The value for the start sweep angle, in the current units.  This must be no more than the maximum, 360 degrees, or 2 Pi radians.  
                Default: 0  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Tolerance to build to (if useTolerance attribute is set)  
                Default: 0.01  
                Properties: create, query, edit
        useTolerance (bool?): Use the tolerance, or the number of sections to control the sections.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create
        range (bool?): Force a curve range on complete input curve.  
                Properties: create
        rebuild (bool?): Rebuild the input curve(s) before using them in the operation.  Use nurbsCurveRebuildPref to set the parameters for the conversion.  
                Properties: create
        useLocalPivot (bool?): If true, then the pivot of the profile curve is used  
                as the start point of the axis of revolution.  
                Properties: create, query, edit

    Returns:
        List[str]: Object name and node name

    Example:
    """

def rigidBody(*args: str, edit: bool = ..., query: bool = ..., active: bool = ..., angularVelocity: bool = ..., applyForceAt: Queryable[str] = ..., bounciness: Queryable[float] = ..., cache: bool = ..., centerOfMass: Queryable[Tuple[float, float, float]] = ..., collisions: bool = ..., contactCount: bool = ..., contactName: bool = ..., contactPosition: bool = ..., damping: Queryable[float] = ..., deleteCache: bool = ..., dynamicFriction: Queryable[float] = ..., force: bool = ..., ignore: bool = ..., impulse: Tuple[float, float, float] = ..., impulsePosition: Tuple[float, float, float] = ..., initialAngularVelocity: Queryable[Tuple[float, float, float]] = ..., initialVelocity: Queryable[Tuple[float, float, float]] = ..., layer: Queryable[int] = ..., lockCenterOfMass: bool = ..., mass: Queryable[float] = ..., name: Queryable[str] = ..., orientation: Queryable[Tuple[float, float, float]] = ..., particleCollision: bool = ..., passive: bool = ..., position: Queryable[Tuple[float, float, float]] = ..., removeShape: Queryable[str] = ..., solver: Queryable[str] = ..., spinImpulse: Tuple[float, float, float] = ..., standInObject: Queryable[str] = ..., staticFriction: Queryable[float] = ..., tesselationFactor: Queryable[int] = ..., velocity: bool = ...) -> Union[str, bool, float, Tuple[float, float, float], int]:
    """This command creates a rigid body from a polygonal or nurbs surface.
    Args:
        active (bool?): Creates a rigid body that is active.  An active rigid body accepts and  
                causes collisions and is effected by dynamic fields.  This is the  
                default.  
                Properties: create, query, edit
        angularVelocity (bool?): Current angular velocity of rigid body.  
                Properties: query
        applyForceAt (Queryable[str]?): Determines how forces are applied to the rigid body.  
                The choices are centerOfMass | boundingBox | verticesOrCVs.  
                Default: boundingBox  
                Properties: create, query, edit
        bounciness (Queryable[float]?): Sets the restitution (or bounciness) of the rigid body.  
                Range:   0.0. 2.0  
                Default: 0.6  
                Properties: create, query, edit
        cache (bool?): Turns caching on (1) or off (0) for the rigid body.  
                Default: off  
                Properties: create, query, edit
        centerOfMass (Queryable[Tuple[float, float, float]]?): Sets the center of mass (x,y,z) of the rigid body.  
                Default: actual center of mass.  
                Properties: create, query, edit
        collisions (bool?): Truns collisions on/off for the rigid body.  If the collisions  
                are turned of the rigid body will not collide with any other rigid body.  
                Default: on.  
                Properties: create, query, edit
        contactCount (bool?): returns the current contact count for the rigid body.  
                Properties: query
        contactName (bool?): returns all the rigid body names which are in contact with this shape.  One name  
                for each contact will be returned.  
                Properties: query
        contactPosition (bool?): returns all the contact position.  One position for each contact  
                will be returned.  
                Properties: query
        damping (Queryable[float]?): Sets the damping value of the rigid body.  
                Range:   -2.0. 2.0  
                Default: 0.0  
                Properties: create, query, edit
        deleteCache (bool?): Deletes the cache (if one exists) of the rigid body.  
                Properties: edit
        dynamicFriction (Queryable[float]?): Sets the dynamic friction for the rigid body.  
                Range:   0.0. 1.0  
                Default: 0.2  
                Properties: create, query, edit
        force (bool?): Current force on the rigid body.  
                Properties: query
        ignore (bool?): Causes the rigid body to be ignored in the rigid solver.  
                Default: off  
                Properties: create, query, edit
        impulse (Tuple[float, float, float]?): Applies an impulse (instantaneous) force on a rigid body.  
                Default: 0.0 0.0 0.0  
                Properties: create, edit
        impulsePosition (Tuple[float, float, float]?): The position at which the impulse is applied.  
                Default: the bodies center of mass.  
                Properties: create, edit
        initialAngularVelocity (Queryable[Tuple[float, float, float]]?): Sets the initial angular velocity of the rigid body.  
                Default: 0.0 0.0 0.0  
                Properties: create, query, edit
        initialVelocity (Queryable[Tuple[float, float, float]]?): Sets the initial velocity of the rigid body.  
                Default: 0.0 0.0 0.0  
                Properties: create, query, edit
        layer (Queryable[int]?): Sets the collision layer of the rigid body.  Only rigid bodies in the  
                same collision layer can collide with each other.  
                Range:   >= 0  
                Default: 0.  
                Properties: create, query, edit
        lockCenterOfMass (bool?): Locks the center of mass for the rigid body.  
                Default: off  
                Properties: create, query, edit
        mass (Queryable[float]?): Sets the mass of the rigid body.  
                Range:   > 0  
                Default: 1.0  
                Properties: create, query, edit
        name (Queryable[str]?): Assigns the rigid body the given name.  
                Properties: create, query, edit
        orientation (Queryable[Tuple[float, float, float]]?): Sets the initial orientation (x,y,z) of the rigid body.  
                Default: current orientation.  
                Properties: create, query, edit
        particleCollision (bool?): Turns the ability for a rigid body to collide with particles  
                on and off.  The particles will exert a force on the rigid body.  
                Default: off  
                Properties: create, query, edit
        passive (bool?): Creates a rigid body that is passive.  A passive rigid body does not  
                react to collisions but active rigid bodies can collide with it.  
                Dynamic Fields will not effect a passive rigid body.  Only passive  
                rigid bodies can be keyframed.  
                Properties: create, query, edit
        position (Queryable[Tuple[float, float, float]]?): Sets the initial position (x,y,z) of the rigid body.  
                Default: current position.  
                Properties: create, query, edit
        removeShape (Queryable[str]?): Remove the named shape.  
                Properties: create, query, edit
        solver (Queryable[str]?): The name of the solver which this rigid node is to resided.  If the  
                solver does not exists then the rigid body will not be created.  If the  
                edit flag is thrown add the solver exists, the rigid body will be moved  
                to that solver.  
                Properties: create, query, edit
        spinImpulse (Tuple[float, float, float]?): Applies an spin impulse (instantaneous rotational) force on a rigid body.  
                Default: 0.0 0.0 0.0  
                Properties: create, edit
        standInObject (Queryable[str]?): Causes the simulator to use a stand in object for the simulation.  
                The choices are none | cube | sphere. The default is none.  
                Default: none  
                Properties: create, query, edit
        staticFriction (Queryable[float]?): Sets the static friction for the rigid body.  
                Range:   0.0. 1.0  
                Default: 0.2  
                Properties: create, query, edit
        tesselationFactor (Queryable[int]?): Sets the tesselation factor for a rigid body surface.  
                Range:   >= 10  
                Default: 200.  
                Properties: create, query
        velocity (bool?): Current velocity of rigid body.  
                Properties: query

    Returns:
        str: New rigid body name.

    Example:
    """

def rigidSolver(*args: str, edit: bool = ..., query: bool = ..., autoTolerances: bool = ..., bounciness: bool = ..., cacheData: bool = ..., collide: bool = ..., collisionTolerance: Queryable[float] = ..., contactData: bool = ..., create: bool = ..., current: bool = ..., deleteCache: bool = ..., displayCenterOfMass: bool = ..., displayConstraint: bool = ..., displayVelocity: bool = ..., dynamics: bool = ..., friction: bool = ..., interpenetrate: bool = ..., interpenetrationCheck: bool = ..., name: Queryable[str] = ..., rigidBodies: bool = ..., rigidBodyCount: bool = ..., showCollision: bool = ..., showInterpenetration: bool = ..., solverMethod: Queryable[int] = ..., startTime: Queryable[float] = ..., state: bool = ..., statistics: bool = ..., stepSize: Queryable[float] = ..., velocityVectorScale: Queryable[float] = ...) -> Union[bool, float, str, int]:
    """This command sets the attributes for the rigid solver
    Args:
        autoTolerances (bool?): Turns the auto tolerance calculation on and off.  The auto tolerances  
                calculation will override the default or user defined values of the  
                step size and collision tolerance value that is calculated based  
                on the objects in the scene.  
                Default: 0 (off)  
                Properties: query, edit
        bounciness (bool?): Turns bounciness on and off for the an the objects in the  
                simulation.  
                Default value: on  
                Properties: query, edit
        cacheData (bool?): Turns the cache on fall all rigid bodies in the system.  
                Default value: off  
                Properties: query, edit
        collide (bool?): Disallows the interpenetration of the two rigid bodies listed.  
                Default: Collide is on for all bodies.  
                Properties: query, edit
        collisionTolerance (Queryable[float]?): Sets the collision tolerance.  This is the error at which two objects  
                are considered to have collided.  
                Range:   0.0005. 1.000  
                Default: 0.02  
                Properties: query, edit
        contactData (bool?): Turns the contact data information on/off for all rigid bodies.  
                Default value: off  
                Properties: query, edit
        create (bool?): Creates a new rigid solver.  
                Properties: create
        current (bool?): Sets rigid solver as the current solver.  
                Properties: create
        deleteCache (bool?): Deletes the cache for all rigid bodies in the system.  
                Properties: query, edit
        displayCenterOfMass (bool?): Displays the center of mass icon.  
                Default value: on  
                Properties: query, edit
        displayConstraint (bool?): Displays the constraint vectors.  
                Default value: on  
                Properties: query, edit
        displayVelocity (bool?): Displays the velocity vectors.  
                Default value: off  
                Properties: query, edit
        dynamics (bool?): Turns dynamics on and off for the an the objects in the simulation.  
                Default value: on  
                Properties: query, edit
        friction (bool?): Turns friction on and off for the an the objects in the simulation.  
                Default value: on  
                Properties: query, edit
        interpenetrate (bool?): Allows the two rigid bodies listed to interpenetrate.  
                Default: interpenetration is off for all bodies.  
                Properties: query, edit
        interpenetrationCheck (bool?): Checks for interpenetrating rigid bodies in the scene.  
                Properties: edit
        name (Queryable[str]?): Name of the new object  
                Properties: create, query, edit
        rigidBodies (bool?): Returns a list of rigid bodies in the solver.  
                Properties: query
        rigidBodyCount (bool?): Returns the number of rigid bodies in the solver.  
                Properties: query
        showCollision (bool?): Displays the colliding objects in a different color.  
                Properties: query, edit
        showInterpenetration (bool?): Displays the interpenetrating objects in a different color.  
                Properties: query, edit
        solverMethod (Queryable[int]?): Sets the solver method.  The choices are 0 | 1 | 2.  
                0 = Euler (fastest/least acurate),  
                1 = Runge-Kutta ( slower/more acurate),  
                2 = adaptive Runge-Kutta  
                (slowest/most acurate).  
                The default is 2 (adaptive Runge-Kutta)  
                Properties: query, edit
        startTime (Queryable[float]?): Sets the start time for the solver.  
                Properties: create, query, edit
        state (bool?): Turns the rigid solver on or off.  
                Properties: query, edit
        statistics (bool?): Turns the statistic information on/off for all rigid bodies.  
                Default value: off  
                Properties: query, edit
        stepSize (Queryable[float]?): Sets the solvers step size.  This is the maximum size of a single step  
                the  
                solver will take at one time.  
                Range:   0.0004. 0.100  
                Default: 0.0333  
                Properties: query, edit
        velocityVectorScale (Queryable[float]?): scales the velocity vector display.  
                Default value: 1.0  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def roll(arg0: str = ..., /, *, absolute: bool = ..., degree: float = ..., relative: bool = ...) -> bool:
    """The roll command rotates a camera about its viewing direction, a
    positive angle produces clockwise camera rotation, while a
    negative angle produces counter-clockwise camera rotation.The default mode is relative and the rotation is applied with
    respect to the current orientation of the camera. When mode is set
    to absolute, the rotation is applied with respect to the plane
    constructed from the following three vectors in the world space:
    the world up vector, the camera view vector, and the camera up
    vector.The rotation angle is specified in degrees.The roll command can be applied to either a perspective or an
    orthographic camera.This command may be applied to more than one camera; objects that
    are not cameras are ignored. When no camera name supplied, this command
    is applied to all currently active cameras.
    Args:
        absolute (bool?): Set to absolute mode.  
                Properties: create
        degree (float?): Set the amount of the rotation angle.  
                Properties: create
        relative (bool?): Set to relative mode.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def rollCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., rollScale: Queryable[float] = ..., toolName: Queryable[str] = ...) -> Union[str, bool, float]:
    """Create, edit, or query a roll context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        rollScale (Queryable[float]?): In degrees of rotation per 100 pixels of cursor drag.  
                Properties: create, query, edit
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query

    Returns:
        str: The name of the context

    Example:
    """

def rotate(arg0: float = ..., arg1: float = ..., arg2: float = ..., /, *args: str, absolute: bool = ..., centerPivot: bool = ..., componentSpace: bool = ..., constrainAlongNormal: bool = ..., deletePriorHistory: bool = ..., euler: bool = ..., forceOrderXYZ: bool = ..., objectCenterPivot: bool = ..., objectSpace: bool = ..., orientAxes: Tuple[float, float, float] = ..., pivot: Tuple[float, float, float] = ..., preserveChildPosition: bool = ..., preserveGeometryPosition: bool = ..., preserveUV: bool = ..., reflection: bool = ..., reflectionAboutBBox: bool = ..., reflectionAboutOrigin: bool = ..., reflectionAboutX: bool = ..., reflectionAboutY: bool = ..., reflectionAboutZ: bool = ..., reflectionTolerance: float = ..., relative: bool = ..., rotateX: bool = ..., rotateXY: bool = ..., rotateXYZ: bool = ..., rotateXZ: bool = ..., rotateY: bool = ..., rotateYZ: bool = ..., rotateZ: bool = ..., symNegative: bool = ..., translate: bool = ..., worldSpace: bool = ..., xformConstraint: str = ...) -> bool:
    """The rotate command is used to change the rotation of
    geometric objects. The rotation values are specified as
    Euler angles (rx, ry, rz). The values are interpreted based
    on the current working unit for Angular measurements. Most
    often this is degrees.The default behaviour, when no objects or flags are passed,
    is to do a absolute rotate on each currently selected object
    in the world space.
    Args:
        absolute (bool?): Perform an absolute operation.  
                Properties: create
        centerPivot (bool?): Let the pivot be the center of the bounding box of all objects  
                Properties: create
        componentSpace (bool?): Rotate in local component space  
                Properties: create
        constrainAlongNormal (bool?): When true, transform constraints are applied along the vertex normal first  
                and only use the closest point when no intersection is found along the normal.  
                Properties: create
        deletePriorHistory (bool?): If true then delete the history prior to the current operation.  
                Properties: create
        euler (bool?): Modifer for -relative flag that specifies rotation  
                values should be added to current XYZ rotation values.  
                Properties: create
        forceOrderXYZ (bool?): When true, euler rotation value will be understood in XYZ rotation order not per transform node basis.  
                Properties: create
        objectCenterPivot (bool?): Let the pivot be the center of the bounding box of each object  
                Properties: create
        objectSpace (bool?): Perform rotation about object-space axis.  
                Properties: create
        orientAxes (Tuple[float, float, float]?): Euler axis for orientation.  
                Properties: create
        pivot (Tuple[float, float, float]?): Define the pivot point for the transformation  
                Properties: create
        preserveChildPosition (bool?): When true, transforming an object will apply an opposite transform to its  
                child transform to keep them at the same world-space position.  
                Default is false.  
                Properties: create
        preserveGeometryPosition (bool?): When true, transforming an object will apply an opposite transform to its  
                geometry points to keep them at the same world-space position.  
                Default is false.  
                Properties: create
        preserveUV (bool?): When true, UV values on rotated components are projected across the rotation  
                in 3d space. For small edits, this will freeze the world space texture mapping  
                on the object.  
                When false, the UV values will not change for a selected vertices.  
                Default is false.  
                Properties: create
        reflection (bool?): To move the corresponding symmetric components also.  
                Properties: create
        reflectionAboutBBox (bool?): Sets the position of the reflection axis  at the geometry bounding box  
                Properties: create
        reflectionAboutOrigin (bool?): Sets the position of the reflection axis  at the origin  
                Properties: create
        reflectionAboutX (bool?): Specifies the X=0 as reflection plane  
                Properties: create
        reflectionAboutY (bool?): Specifies the Y=0 as reflection plane  
                Properties: create
        reflectionAboutZ (bool?): Specifies the Z=0 as reflection plane  
                Properties: create
        reflectionTolerance (float?): Specifies the tolerance to findout the corresponding reflected components  
                Properties: create
        relative (bool?): Perform a operation relative to the object's current position  
                Properties: create
        rotateX (bool?): Rotate in X direction  
                Properties: create
        rotateXY (bool?): Rotate in X and Y direction  
                Properties: create
        rotateXYZ (bool?): Rotate in all directions (default)  
                Properties: create
        rotateXZ (bool?): Rotate in X and Z direction  
                Properties: create
        rotateY (bool?): Rotate in Y direction  
                Properties: create
        rotateYZ (bool?): Rotate in Y and Z direction  
                Properties: create
        rotateZ (bool?): Rotate in Z direction  
                Properties: create
        symNegative (bool?): When set the component transformation is flipped so it is relative to the  
                negative side of the symmetry plane. The default (no flag) is to transform  
                components relative to the positive side of the symmetry plane.  
                Properties: create
        translate (bool?): When true, the command will modify the node's translate attribute instead of its  
                rotateTranslate attribute, when rotating around a pivot other than the object's  
                own rotate pivot.  
                Properties: create
        worldSpace (bool?): Perform rotation about global world-space axis.  
                Properties: create
        xformConstraint (str?): Apply a transform constraint to moving components.  
              
                none - no constraint  
                surface - constrain components to the surface  
                edge - constrain components to surface edges  
                live - constraint components to the live surface  
                Properties: create

    Returns:
        bool:

    Example:
    """

def rotationInterpolation(*args: str, query: bool = ..., convert: Queryable[str] = ...) -> Union[bool, str]:
    """The rotationInterpolation command converts the rotation curves to the
            desired rotation interpolation representation. For example, an
            Euler-angled representation can be converted to Quaternion.curve, rotation, interpolation, quaternion, euler
    Args:
        convert (Queryable[str]?): Specifies the rotation interpolation mode for the curves after converting.  
                Possible choices are "none" (unsynchronized Euler-angled curves which are  
                compatible with pre-4.0 Maya curves), "euler" (Euler-angled curves with  
                keyframes kept synchronized), "quaternion" (quaternion curves with  
                keyframes kept synchronized, but the exact interpolation depends on  
                individual tangents),  "quaternionSlerp" (applies quaternion slerp interpolation  
                to the curve, ignoring tangent settings), "quaternionSquad" (applied cubic interpolation  
                to the curve in quaternion space, ignoring tangent settings)  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def roundCRCtx(*args: Any, **kwargs: Any) -> None: ...
def roundConstantRadius(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., append: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., radiuss: Multiuse[float] = ..., side: Multiuse[Tuple[str, int]] = ..., sidea: Multiuse[int] = ..., sideb: Multiuse[int] = ...) -> List[str]:
    """This command generates constant radius NURBS fillets and NURBS
    corner surfaces for matching edge pairs on NURBS surfaces.  An
    edge pair is a matching pair of surface isoparms or trim edges.
    This command
    can handle more than one edge pair at a time.
    This command can also handleedges, which is where an edge
    pair is composed of more than two surfaces.  Use the "-sa" and "-sb"
    flags in this case.The results from this command are three surface var groups plus the
    name of the new roundConstantRadius dependency node, if history was on.
    The 1st var group contains trimmed copies of the original surfaces.  The 2nd
    var group contains the new NURBS fillet surfaces.  The 3rd var group
    contains the new NURBS corners (if any).A simple example of an edge pair is an edge of a NURBS cube,
    where two faces of the cube meet.  This command generates a NURBS
    fillet at the edge and trims back the faces.Another example is a NURBS cylinder with a planar trim surface cap.
    This command will create a NURBS fillet where the cap meets the
    the cylinder and will trim back the cap and the cylinder.Another example involves all 12 edges of a NURBS cube.  NURBS fillets
    are created where any face meets another face.  NURBS corners are
    created whenever 3 edges meet at a corner.
    Args:
        append (bool?): If true, then an edge pair is being added to an existing  
                round dependency node.  Default is false.  
                When this flag is true, an existing round dependency node  
                must be specified. See example below.  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        radiuss (Multiuse[float]?): Use this flag to specify radius.  This overrides the  
                "r/radius" flag.  If only one "rad" flag is used,  
                then it is applied to all edge pairs.  If more than one "rad" flag is used,  
                then the number of "-rad" flags must equal the number  
                of edge pairs.  For example, for four edge pairs,  
                zero, one or four "rad" flags must be specified.  
                Properties: create, multiuse
        side (Multiuse[Tuple[str, int]]?): Use this flag for compound edges.  It replaces the sidea/sideb flags and is  
                compatible with Python.  
              
                The first argument must be either "a" or "b".  
              
                The same number of "a" values as "b" values must be specified.  
                If no sides are specified with the "side" flag (or sidea/sideb flags), then  
                the edges are assumed to be in pairs.  
                See also examples below.  
                For example, two faces of a cube meet at an edge pair.  
                Suppose one of the faces is then split in two pieces  
                at the middle of the edge, so that there is one  
                face on side "A", and two pieces on side "B".  In this case  
                the flag combination: -side "a" 1. side "b" 2 would be used.  
                The edges must be specified in the corresponding order:  
                // MEL  
                roundConstantRadius -side "a" 1. side "b" 2 isoA isoB1 isoB2;  
                # Python  
                maya.cmds.roundConstantRadius( 'isoA', 'isoB1', 'isoB2', side=[("a",1), ("b",2)] )  
                Properties: create, multiuse
        sidea (Multiuse[int]?): Use this flag for compound edges in conjunction with the  
                following "-sb" flag.  
              
                This flag is not intended for use from Python.  Please see "side" flag instead.  
              
                The same number of "-sa" flags as "-sb" flags must be specified.  
                If no "-sa" nor "-sb" flags are specified, then the edges  
                are assumed to be in pairs.  
                See also examples below.  
                For example, two faces of a cube meet at an edge pair.  
                Suppose one of the faces is then split in two pieces  
                at the middle of the edge, so that there is one  
                face on side "A", and two pieces on side "B".  In this case,  
                the flag combination: -sidea 1. sideb 2 would be used.  
                The edges must be specified in the corresponding order:  
                roundConstantRadius -sidea 1. sideb 2 isoA isoB1 isoB2;  
                Properties: create, multiuse
        sideb (Multiuse[int]?): Use this flag for compound edges in conjunction with the  
                "-sa" flag.  See description for the "-sa" flag.  
              
                This flag is not intended for use from Python.  Please see "side" flag instead.  
                Properties: create, multiuse

    Returns:
        List[str]: (resulting NURBS surfaces' names and node name)

    Example:
    """

def rowColumnLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnOffset: Multiuse[Tuple[int, str, int]] = ..., columnSpacing: Multiuse[Tuple[int, int]] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfColumns: Queryable[int] = ..., numberOfPopupMenus: bool = ..., numberOfRows: Queryable[int] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAlign: Multiuse[Tuple[int, str]] = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., rowHeight: Multiuse[Tuple[int, int]] = ..., rowOffset: Multiuse[Tuple[int, str, int]] = ..., rowSpacing: Multiuse[Tuple[int, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a rowColumn layout. A rowColumn layout positions
    children in either a row or column format. A column layout, specified
    with theflag, allows you set text
    alignment, attachments and offsets for each column in the layout.
    Every member of a column will have the same alignment, attachment and
    offsets.  Likewise the row format, specified by
    theflag, allows
    setting of these attributes for each row in the layout. Every member
    of a row will have the same attributes. The layout must be either a
    row or column format. This layout does not support both, or the
    specification of attributes on an individual child basis.Some flags only make sense for one of either the row format or the
    column format.  For example theflag can only be
    specified in row format. In column format the row height is
    determined by the tallest child in the row, plus offsets.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes  
                with the sizing of the layout.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        columnAlign (Multiuse[Tuple[int, str]]?): Alignment for text and pixmaps in the specified  
                column.  Values are: "left", "right" and "center".  Only valid  
                for column format, ie. number of columns specified  
                with -nc/numberOfColumns flag.  
                Properties: create, edit, multiuse
        columnAttach (Multiuse[Tuple[int, str, int]]?): The attachments and offsets for the children in  
                the specified column.  The first argument is the 1. based column  
                index.  The second argument is the attachment, valid values are  
                "left", "right" and "both".  The third argument must be greater  
                than 0 and specifies the offset.  
                Properties: create, edit, multiuse
        columnOffset (Multiuse[Tuple[int, str, int]]?): The attachment offset for the specified column.  The first  
                argument is the 1. based column index.  The second argument is the  
                attachment, valid values are "left", "right" and "both".  The  
                third argument must be greater than 0 and specifies the offset.  
                Properties: create, edit, multiuse
        columnSpacing (Multiuse[Tuple[int, int]]?): The space between columns in pixels.  In column format  
                this flag specifies that the space be to the left of the  
                given column.  In row format it specifies the space between all  
                columns, however a valid column index is still required.  The  
                first argument is the 1. based column index.  The second argument  
                must be greater than 0 and specifies the spacing.  
                Properties: create, edit, multiuse
        columnWidth (Multiuse[Tuple[int, int]]?): Width of a column. This flag is valid only in column  
                format.  The column width must be greater than 0.  The first  
                argument is the 1. based column index.  The second argument must  
                be greater than 0 and specifies the column width.  
                Properties: create, edit, multiuse
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfColumns (Queryable[int]?): Number of columns. This flag is mutually exclusive to  
                the -nr/numRows flag.  Either one or the other can be  
                specified.  
                Properties: create, query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfRows (Queryable[int]?): Number of rows. This flag is mutually exclusive to  
                the -nc/numColumns flag. Either one or the other can be  
                specified.  
                Properties: create, query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAlign (Multiuse[Tuple[int, str]]?): Alignment for text and pixmaps in the specified row.  
                Values are: "left", "right" and "center".  Only valid for  
                row format, ie. number of rows specified  
                with -nr/numberOfRows flag.  
                Properties: create, edit, multiuse
        rowAttach (Multiuse[Tuple[int, str, int]]?): The attachments and offsets for the children in  
                the specified row.  The first argument is the 1. based row  
                index.  The second argument is the attachment, valid values are  
                "top", "bottom" and "both".  The third argument must be greater  
                than 0 and specifies the offset.  
                Properties: create, edit, multiuse
        rowHeight (Multiuse[Tuple[int, int]]?): Height of a row. This flag is only valid in row format.  
                The row height must be greater than 0. The first  
                argument is the 1. based row index.  The second argument must  
                be greater than 0 and specifies the row height.  
                Properties: create, edit, multiuse
        rowOffset (Multiuse[Tuple[int, str, int]]?): The attachment offset for the specified row.  The first  
                argument is the 1. based row index.  The second argument is the  
                attachment, valid values are "top", "bottom" and "both".  The  
                third argument must be greater than 0 and specifies the offset.  
                Properties: create, edit, multiuse
        rowSpacing (Multiuse[Tuple[int, int]]?): The space between rows, in pixels.  In row format this  
                specifies the space above the specified row.  In  
                column format it specifies the space between all rows, however  
                a valid row index is still required.  The first argument is the  
                1. based row index.  The second argument must be greater than 0 and  
                specifies the spacing.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def rowLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: Multiuse[int] = ..., adjustableColumn1: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., childArray: bool = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign1: str = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach1: str = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset1: int = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfColumns: Queryable[int] = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a layout capable of positioning children into
    a single horizontal row.
    Args:
        adjustableColumn (Multiuse[int]?): Specifies which column has an adjustable size that changes  
                with the sizing of the layout.  
                Properties: create, edit, multiuse
        adjustableColumn1 (int?): Specifies that the first column has an adjustable size that  
                changes with the size of the parent layout.  
                Ignored if there isn't exactly one column.  
                Properties: create
        adjustableColumn2 (int?): Specifies which of the two columns has an adjustable size  
                that changes with the size of the parent layout.  
                Ignored if there isn't exactly two columns.  
                Properties: create
        adjustableColumn3 (int?): Specifies which of the three columns has an adjustable size  
                that changes with the size of the parent layout.  
                Ignored if there isn't exactly three columns.  
                Properties: create
        adjustableColumn4 (int?): Specifies which of the four columns has an adjustable size  
                that changes with the size of the parent layout.  
                Ignored if there isn't exactly four columns.  
                Properties: create
        adjustableColumn5 (int?): Specifies which of the five columns has an adjustable size  
                that changes with the size of the parent layout.  
                Ignored if there isn't exactly five columns.  
                Properties: create
        adjustableColumn6 (int?): Specifies which of the six columns has an adjustable size  
                that changes with the size of the parent layout.  
                Ignored if there isn't exactly six columns.  
                Properties: create
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        columnAlign (Multiuse[Tuple[int, str]]?): Text alignment for the specified column.  
                Valid values are "left", "right", and "center"  
                Properties: create, edit, multiuse
        columnAlign1 (str?): Text alignment for the first column.  
                Valid values are "left", "right", and "center".  
                Ignored if there isn't exactly one column.  
                Properties: create
        columnAlign2 (Tuple[str, str]?): Text alignment for both columns.  
                Valid values are "left", "right", and "center".  
                Ignored if there isn't exactly two columns.  
                Properties: create
        columnAlign3 (Tuple[str, str, str]?): Text alignment for all three columns.  
                Valid values are "left", "right", and "center".  
                Ignored if there isn't exactly three columns.  
                Properties: create
        columnAlign4 (Tuple[str, str, str, str]?): Text alignment for all four columns.  
                Valid values are "left", "right", and "center".  
                Ignored if there isn't exactly four columns.  
                Properties: create
        columnAlign5 (Tuple[str, str, str, str, str]?): Text alignment for all five columns.  
                Valid values are "left", "right", and "center".  
                Ignored if there isn't exactly five columns.  
                Properties: create
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Text alignment for all six columns.  
                Valid values are "left", "right", and "center".  
                Ignored if there isn't exactly six columns.  
                Properties: create
        columnAttach (Multiuse[Tuple[int, str, int]]?): Horizontally attach a particular column.  The first  
                argument is a 1. based index specifying the column.  The second  
                argument is the attachment, valid values are "left", "right",  
                and "both".  The third argument is the offset value.  
                Properties: create, edit, multiuse
        columnAttach1 (str?): Attachment type for the first column.  Ignored if there isn't  
                exactly one column. Valid values are "left", "right", and "both".  
                Properties: create
        columnAttach2 (Tuple[str, str]?): Attachment type for both columns.  Ignored if there isn't  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create
        columnAttach3 (Tuple[str, str, str]?): Attachment type for all three columns.  Ignored if there  
                isn't exactly three columns. Valid values are "left", "right",  
                and "both".  
                Properties: create
        columnAttach4 (Tuple[str, str, str, str]?): Attachment type for all four columns.  Ignored if there isn't  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create
        columnAttach5 (Tuple[str, str, str, str, str]?): Attachment type for all five columns.  Ignored if there isn't  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Attachment type for all six columns.  Ignored if there isn't  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create
        columnOffset1 (int?): Used in conjunction with the -columnAttach1 flag.  If that  
                flag is not used then this flag will be ignored.  Sets the offset  
                for the first column.  The offsets applied are based on the  
                attachments specified with the -columnAttach1 flag.  
                Ignored if there isn't exactly one column.  
                Properties: create
        columnOffset2 (Tuple[int, int]?): Used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  Sets the offset  
                for both columns.  The offsets applied are based on the  
                attachments specified with the -columnAttach2 flag.  
                Ignored if there isn't exactly two columns.  
                Properties: create
        columnOffset3 (Tuple[int, int, int]?): Used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  Sets the offset  
                for all three columns.  The offsets applied are based on the  
                attachments specified with the -columnAttach3 flag.  
                Ignored if there isn't exactly three columns.  
                Properties: create
        columnOffset4 (Tuple[int, int, int, int]?): Used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  Sets the offset  
                for all four columns.  The offsets applied are based on the  
                attachments specified with the -columnAttach4 flag.  
                Ignored if there isn't exactly four columns.  
                Properties: create
        columnOffset5 (Tuple[int, int, int, int, int]?): Used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  Sets the offset  
                for all five columns.  The offsets applied are based on the  
                attachments specified with the -columnAttach5 flag.  
                Ignored if there isn't exactly five columns.  
                Properties: create
        columnOffset6 (Tuple[int, int, int, int, int, int]?): Used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  Sets the offset  
                for all six columns.  The offsets applied are based on the  
                attachments specified with the -columnAttach6 flag.  
                Ignored if there isn't exactly six columns.  
                Properties: create
        columnWidth (Multiuse[Tuple[int, int]]?): Width of a particular column.  The first argument is a  
                1. based index specifying the column.  The second argument is the  
                width value.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Width for the first column.  Ignored if there isn't exactly  
                one column.  
                Properties: create
        columnWidth2 (Tuple[int, int]?): Widths for both columns.  Ignored if there isn't  
                exactly two columns.  
                Properties: create
        columnWidth3 (Tuple[int, int, int]?): Widths for all three columns.  Ignored if there isn't  
                exactly three columns.  
                Properties: create
        columnWidth4 (Tuple[int, int, int, int]?): Widths for all four columns.  Ignored if there isn't  
                exactly four columns.  
                Properties: create
        columnWidth5 (Tuple[int, int, int, int, int]?): Widths for all five columns.  Ignored if there isn't  
                exactly five columns.  
                Properties: create
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Widths for all six columns.  Ignored if there isn't  
                exactly six columns.  
                Properties: create
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfColumns (Queryable[int]?): Number of columns in the row.  The specified number of  
                columns must be a value greater than 0.  
                Properties: create, query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Vertically attach a particular column.  The first argument  
                is a 1. based index specifying the column.  The second argument is  
                the attachment, valid values are "top", "bottom", and "both".  The  
                third argument is the offset value.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def runTimeCommand(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addKeyword: Multiuse[str] = ..., addTag: Multiuse[str] = ..., annotation: Queryable[str] = ..., category: Queryable[str] = ..., categoryArray: bool = ..., command: Queryable[Callable[..., Any]] = ..., commandArray: bool = ..., commandLanguage: Queryable[str] = ..., default: bool = ..., defaultCommandArray: bool = ..., delete: bool = ..., exists: bool = ..., helpUrl: Queryable[str] = ..., hotkeyCtx: Queryable[str] = ..., image: Queryable[str] = ..., keywords: Queryable[str] = ..., label: Queryable[str] = ..., longAnnotation: Queryable[str] = ..., numberOfCommands: bool = ..., numberOfDefaultCommands: bool = ..., numberOfUserCommands: bool = ..., plugin: Queryable[str] = ..., save: bool = ..., showInHotkeyEditor: bool = ..., tags: Queryable[str] = ..., userCommandArray: bool = ...) -> Union[str, bool, Callable[..., Any]]:
    """Create a MEL command given the specified name. Once the command is created
    you can invoke it like any other MEL command.  When the command is invoked
    it will execute the string attached to theflag.Note that the resulting command takes no arguments, has no flags and
    may not be queried or edited.The command name you provide must be unique. The name itself must
    begin with an alphabetic character or underscore followed by
    alphanumeric characters or underscores.If you create your run time commands in a script which is automatically
    sourced at startup then set theflag to true.  This
    will prevent the application from attempting to save these commands.
    Args:
        addKeyword (Multiuse[str]?): Append one keyword to the keyboard list, which is used by the Search user interface  
                Properties: create, edit, multiuse
        addTag (Multiuse[str]?): Append one keyword to the tag list, which is used by the Search user interface  
                Properties: create, edit, multiuse
        annotation (Queryable[str]?): Description of the command.  
                Properties: create, query, edit
        category (Queryable[str]?): Category for the command.  
                Properties: create, query, edit
        categoryArray (bool?): Return all the run time command categories.  
                Properties: query
        command (Queryable[Callable[..., Any]]?): Command to be executed when runTimeCommand is invoked.  
                Properties: create, query, edit
        commandArray (bool?): Returns an string array containing the names of all the run  
                time commands.  
                Properties: query
        commandLanguage (Queryable[str]?): In edit or create mode, this flag allows the caller to choose a scripting  
                language for a command passed to the "-command" flag.  If this flag is not  
                specified, then the callback will be assumed to be in the language from which  
                the runTimeCommand command was called.  In query mode, the language for this  
                runTimeCommand is returned.  The possible values are "mel" or "python".  
                Properties: create, query, edit
        default (bool?): Indicate that this run time command is a default command.  
                Default run time commands will not be saved to preferences.  
                Properties: create, query
        defaultCommandArray (bool?): Returns an string array containing the names of all the  
                default run time commands.  
                Properties: query
        delete (bool?): Delete the specified user run time command.  
                Properties: edit
        exists (bool?): Returns true|false depending upon whether the specified object  
                exists. Other flags are ignored.  
                Properties: create
        helpUrl (Queryable[str]?): Custom URL for the online documentation of this command. Used in the Search user interface.  
                Properties: create, query, edit
        hotkeyCtx (Queryable[str]?): hotkey Context for the command.  
                Properties: create, query, edit
        image (Queryable[str]?): Image filename for the command.  
                Properties: create, query, edit
        keywords (Queryable[str]?): Keywords for the command. Used for searching for commands in the Search user interface.  
                When multiple keywords, use ; as a separator. (Example: "keyword1;keyword2")  
                Properties: create, query, edit
        label (Queryable[str]?): Label for the command.  
                Properties: create, query, edit
        longAnnotation (Queryable[str]?): Extensive, multi-line description of the command.  
                This will show up in the Search user interface's 'more info' page in addition to the annotation.  
                Properties: create, query, edit
        numberOfCommands (bool?): Return the number of run time commands.  
                Properties: query
        numberOfDefaultCommands (bool?): Return the number of default run time commands.  
                Properties: query
        numberOfUserCommands (bool?): Return the number of user run time commands.  
                Properties: query
        plugin (Queryable[str]?): Name of the plugin this command requires to be loaded.  
                This flag wraps the script provided into a safety check and automatically loads the  
                plugin referenced on execution if it hasn't been loaded.  
                If the plugin fails to load, the command won't be executed.  
                Properties: create, query, edit
        save (bool?): Save all the user run time commands.  
                Properties: edit
        showInHotkeyEditor (bool?): Indicate that this run time command should be shown in the Hotkey Editor.  
                Default value is true.  
                Properties: create, query, edit
        tags (Queryable[str]?): Tags for the command. Used for grouping commands in the Search user interface.  
                When more than one tag, use ; as a separator. (Example: "tag1;tag2")  
                Properties: create, query, edit
        userCommandArray (bool?): Returns an string array containing the names of all the  
                user run time commands.  
                Properties: query

    Returns:
        str: The name of the command on.

    Example:
    """

def runup(*, cache: bool = ..., fromPreviousFrame: bool = ..., fromStartFrame: bool = ..., maxFrame: int = ..., state: bool = ...) -> str:
    """runup plays the scene through a frame of frames, forcing
    dynamic objects to evaluate as it does so.   If no max frame
    is specified, runup runs up to the current time.
    Args:
        cache (bool?): Cache the state after the runup.  
                Properties: create
        fromPreviousFrame (bool?): Run up the animation from the previously evaluated frame.  
                If no flag is supplied this is the default.  
                Properties: create
        fromStartFrame (bool?): Run up the animation from the start frame.  
                If no flag is supplied -fromPreviousFrame is the default.  
                Properties: create
        maxFrame (int?): Ending time for runup, in current user time units.  
                The runup will always start at the  
                minimum start frame for all dynamic objects.  
                Properties: create
        state (bool?): Turns runup and cache on/off.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def safemodecheckhash() -> None: ...
def sampleImage(*args: Any, fastSample: bool = ..., resolution: Tuple[int, str] = ...) -> bool:
    """The sampleImage command is used to control parameters of
    sample images, such as swatches in the multilister.
    The fast option turns on or off some rendering cheats which speed up the
    render but may cause edges to look ragged.
    The resolution option specifies the width in pixels of the image which will
    be rendered for the specified node. Note that the width of the image
    is also the height of the image since sample images are square.
    Args:
        fastSample (bool?): If fast but rough rendering for sampleImage is to be used  
                Properties: create
        resolution (Tuple[int, str]?): The first argument to this flag specifies a resolution in pixels.  
                The second argument specifies a dependency node. The effect of this  
                flag is that further sample image renderings for the specified node  
                will be made at the specified resolution.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def saveAllShelves() -> bool:
    """This command writes all shelves that are immediate children of the specified
    control layout to the prefs directory.
    Returns:
        bool: True if successful, otherwise issues an error message and returns false.

    Example:
    """

def saveFluid(*args: str, edit: bool = ..., query: bool = ..., currentTime: Queryable[int] = ..., endTime: Queryable[int] = ..., startTime: Queryable[int] = ...) -> Union[bool, int]:
    """A command to save the current state of the fluid to the
    initial state cache. The grids to be saved are determined
    by the cache attributes: cacheDensity, cacheVelocity, etc.
    These attributes are normally set from the options on
    Set Initial State. The cache must be set up before
    invoking this command.fluid
    Args:
        currentTime (Queryable[int]?): cache state of fluid at current time  
                Properties: create, query, edit
        endTime (Queryable[int]?): end Time for cacheing  
                Properties: create, query, edit
        startTime (Queryable[int]?): start Time for cacheing  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def saveImage(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., currentView: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., objectThumbnail: str = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., sceneFile: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a static image for non-xpm files.
    Any image file format supported by the file texture node is supported by
    this command.This command creates a static image control for non-xpm files used to
    display a thumbnail image of the scene file.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        currentView (bool?): Generate the image from the current view.  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): Sets the image given the file name.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        objectThumbnail (str?): Use an image of the named object, if possible.  
                Properties: edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        sceneFile (str?): The name of the file that the icon is to be associated with.  
                Properties: edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the image created.
        str: The name of the saveImage control created.

    Example:
    """

def saveInitialState(*args: str, attribute: Multiuse[str] = ..., saveall: bool = ...) -> str:
    """saveInitialState saves the current state of dynamics objects as
    the initial state.  A dynamic object is a particle shape, rigid body, rigid
    constraint or rigid solver.  If no objects are specified, it saves the
    initial state for any selected objects.
    It returns the names of the objects for which initial state was saved.
    Args:
        attribute (Multiuse[str]?): Save the initial state of the specified attribute only.  
                This is a multi-use flag.  
                Properties: create, multiuse
        saveall (bool?): Save the initial state for all dynamics objects in the scene.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def saveMenu(arg0: str = ..., arg1: str = ..., /) -> str:
    """This command is used for saving the contents of a menu, so that
    another instance of the menu may be recreated later. The command
    writes out a file which, when run as a script, will rebuild the
    menuItems contained in the original menu. Note that the fileName
    is relative to the user's marking menu preference directory.Note that this command is used solely by the Marking Menu Editor
    and is not intended to be used for general purposes.Note that this command doesn't work well with controls that have
    mixed mel and python command callbacks.  Also, because it saves the menu
    state to a mel file, it does not work with callbacks that are python
    callable objects.The first argument is the name of the manu to save, the second one is
    the name of the file.
    Returns:
        str: The name of the saved file.

    Example:
    """

def savePrefObjects() -> bool:
    """This command saves preference dependency nodes to "userPrefObjects.ma" in
    the user preference directory.
    Returns:
        bool: True if successful.

    Example:
    """

def saveShelf(arg0: str = ..., arg1: str = ..., /) -> bool:
    """This command saves the specified shelf (first argument) to the
    specified file (second argument).Note that this command doesn't work well with controls that have
    mixed mel and python command callbacks.  Also, because it saves the
    state to a mel file, it does not work with callbacks that are python
    callable objects.
    Returns:
        bool: True if successful.

    Example:
    """

def saveToolSettings() -> bool:
    """This command causes all the tools not on the
    shelf to save their settings as optionVars.  This
    is called automatically by the system when Maya exits.
    Returns:
        bool:

    Example:
    """

def saveViewportSettings() -> bool:
    """This command causes all the 3d views to save their settings as optionVar's.
    This is called automatically by the system when Maya exits.
    Returns:
        bool:

    Example:
    """

def scale(arg0: float = ..., arg1: float = ..., arg2: float = ..., /, *args: str, absolute: bool = ..., centerPivot: bool = ..., componentSpace: bool = ..., constrainAlongNormal: bool = ..., deletePriorHistory: bool = ..., distanceOnly: bool = ..., localSpace: bool = ..., objectCenterPivot: bool = ..., objectSpace: bool = ..., orientAxes: Tuple[float, float, float] = ..., pivot: Tuple[float, float, float] = ..., preserveChildPosition: bool = ..., preserveGeometryPosition: bool = ..., preserveUV: bool = ..., reflection: bool = ..., reflectionAboutBBox: bool = ..., reflectionAboutOrigin: bool = ..., reflectionAboutX: bool = ..., reflectionAboutY: bool = ..., reflectionAboutZ: bool = ..., reflectionTolerance: float = ..., relative: bool = ..., scaleX: bool = ..., scaleXY: bool = ..., scaleXYZ: bool = ..., scaleXZ: bool = ..., scaleY: bool = ..., scaleYZ: bool = ..., scaleZ: bool = ..., symNegative: bool = ..., worldSpace: bool = ..., xformConstraint: str = ...) -> bool:
    """The scale command is used to change the sizes of geometric
    objects.The default behaviour, when no objects or flags are passed,
    is to do a relative scale on each currently selected object
    object using each object's existing scale pivot point.
    Args:
        absolute (bool?): Perform an absolute operation.  
                Properties: create
        centerPivot (bool?): Let the pivot be the center of the bounding box of all objects  
                Properties: create
        componentSpace (bool?): Move in local component space  
                Properties: create
        constrainAlongNormal (bool?): When true, transform constraints are applied along the vertex normal first  
                and only use the closest point when no intersection is found along the normal.  
                Properties: create
        deletePriorHistory (bool?): If true then delete the history prior to the current operation.  
                Properties: create
        distanceOnly (bool?): Scale only the distance between the objects.  
                Properties: create
        localSpace (bool?): Use local space for scaling  
                Properties: create
        objectCenterPivot (bool?): Let the pivot be the center of the bounding box of each object  
                Properties: create
        objectSpace (bool?): Use object space for scaling  
                Properties: create
        orientAxes (Tuple[float, float, float]?): Use the angles for the orient axes.  
                Properties: create
        pivot (Tuple[float, float, float]?): Define the pivot point for the transformation  
                Properties: create
        preserveChildPosition (bool?): When true, transforming an object will apply an opposite transform to its  
                child transform to keep them at the same world-space position.  
                Default is false.  
                Properties: create
        preserveGeometryPosition (bool?): When true, transforming an object will apply an opposite transform to its  
                geometry points to keep them at the same world-space position.  
                Default is false.  
                Properties: create
        preserveUV (bool?): When true, UV values on scaled components are projected along the axis of  
                scaling in 3d space. For small edits, this will freeze the world space texture  
                mapping on the object.  
                When false, the UV values will not change for a selected vertices.  
                Default is false.  
                Properties: create
        reflection (bool?): To move the corresponding symmetric components also.  
                Properties: create
        reflectionAboutBBox (bool?): Sets the position of the reflection axis  at the geometry bounding box  
                Properties: create
        reflectionAboutOrigin (bool?): Sets the position of the reflection axis  at the origin  
                Properties: create
        reflectionAboutX (bool?): Specifies the X=0 as reflection plane  
                Properties: create
        reflectionAboutY (bool?): Specifies the Y=0 as reflection plane  
                Properties: create
        reflectionAboutZ (bool?): Specifies the Z=0 as reflection plane  
                Properties: create
        reflectionTolerance (float?): Specifies the tolerance to findout the corresponding reflected components  
                Properties: create
        relative (bool?): Perform a operation relative to the object's current position  
                Properties: create
        scaleX (bool?): Scale in X direction  
                Properties: create
        scaleXY (bool?): Scale in X and Y direction  
                Properties: create
        scaleXYZ (bool?): Scale in all directions (default)  
                Properties: create
        scaleXZ (bool?): Scale in X and Z direction  
                Properties: create
        scaleY (bool?): Scale in Y direction  
                Properties: create
        scaleYZ (bool?): Scale in Y and Z direction  
                Properties: create
        scaleZ (bool?): Scale in Z direction  
                Properties: create
        symNegative (bool?): When set the component transformation is flipped so it is relative to the  
                negative side of the symmetry plane. The default (no flag) is to transform  
                components relative to the positive side of the symmetry plane.  
                Properties: create
        worldSpace (bool?): Use world space for scaling  
                Properties: create
        xformConstraint (str?): Apply a transform constraint to moving components.  
              
                none - no constraint  
                surface - constrain components to the surface  
                edge - constrain components to surface edges  
                live - constraint components to the live surface  
                Properties: create

    Returns:
        bool:

    Example:
    """

def scaleComponents(arg0: float = ..., arg1: float = ..., arg2: float = ..., /, *args: str, pivot: Tuple[float, float, float] = ..., rotation: Tuple[float, float, float] = ...) -> bool:
    """This is a limited version of the scale command.  First, it
    only works on selected components. You provide a pivot in
    world space, and you can provide a rotation.  This rotation
    affects the scaling, so that rather than scaling in X, Y, Z,
    this is scaling in X, Y, and Z after they have been rotated
    by the given rotation.This allows selected components to be scaled in any arbitrary
    space, not just object or world space as the regular scale
    allows.Scale values are always relative, not absolute.
    Args:
        pivot (Tuple[float, float, float]?): The pivot position in world space (default is origin)  
                Properties: create
        rotation (Tuple[float, float, float]?): The rotational offset for the scaling (default is none)  
                Properties: create

    Returns:
        bool:

    Example:
    """

def scaleConstraint(*args: str, edit: bool = ..., query: bool = ..., layer: str = ..., maintainOffset: bool = ..., name: Queryable[str] = ..., offset: Queryable[Tuple[float, float, float]] = ..., remove: bool = ..., scaleCompensate: bool = ..., skip: Multiuse[str] = ..., targetList: bool = ..., weight: Queryable[float] = ..., weightAliasList: bool = ...) -> Union[List[str], str, Tuple[float, float, float], bool, float]:
    """Constrain an object's scale to the scale of the target object or
    to the average scale of a number of targets.A scaleConstraint takes as input one or more "target" DAG
    transform nodes to which to scale the single "constraint
    object" DAG transform node.  The scaleConstraint scales the
    constrained object at the weighted geometric mean of the
    world space target scale factors.
    Args:
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        maintainOffset (bool?): The offset necessary to preserve the constrained  
                object's initial scale will be calculated and used as the  
                offset.  
                Properties: create
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        offset (Queryable[Tuple[float, float, float]]?): Sets or queries the value of the offset. Default is 1,1,1.  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        scaleCompensate (bool?): Used only when constraining a joint. It specify if a scaleCompensate will be applied on constrained joint.  
                If true it will connect Tjoint.aCompensateForParentScale to scaleContraint.aConstraintScaleCompensate.  
                Properties: create, edit
        skip (Multiuse[str]?): Specify the axis to be skipped. Valid values are "x", "y", "z" and "none". During creation, "none" is the default. This flag is multi-use.  
                Properties: create, edit, multiuse
        targetList (bool?): Return the list of target objects.  
                Properties: query
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def scaleKey(*args: str, animation: str = ..., attribute: Multiuse[str] = ..., autoSnap: bool = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., floatPivot: float = ..., floatScale: float = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., newEndFloat: float = ..., newEndTime: int = ..., newStartFloat: float = ..., newStartTime: int = ..., scaleSpecifiedKeys: bool = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ..., timePivot: int = ..., timeScale: float = ..., valuePivot: float = ..., valueScale: float = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command takes keyframes at (or within) the specified times (or time ranges)
    and scales them.  If no times are specified, the scale is applied to active keyframes
    or (if no keys are active) all keys of active objects.This command has two sets of flags for scaling in time/x-axis. One set of flags is
    for time-based animation curves, and the other set of flags is for float-based (unitless) animation curves.
    Most animation curves in Maya are time-based. Unitless animation curves are less common.
    Use the set of flags that corresponds to the type of animation curves being scaled.To scale all selected animation curves regardless of their type, use both sets of flags.
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        autoSnap (bool?): Auto snap scaled keys if True.  
                Default value depend on scaleKeyAutoSnap option  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        floatPivot (float?): Scale pivot along the x-axis for float-based (unitless) animCurves  
                Properties: create
        floatScale (float?): Amount to scale along the x-axis for float-based (unitless) animation curves  
                animCurves  
                Properties: create
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        newEndFloat (float?): The end of the float range to which the float-based (unitless) animation curves should be scaled.  
                Properties: create
        newEndTime (int?): The end of the time range to which the time-based animation curves should be scaled.  
                Properties: create
        newStartFloat (float?): The start of the float range to which the float-based (unitless) animation curves should be scaled.  
                Properties: create
        newStartTime (int?): The start of the time range to which the time-based animation curves should be scaled.  
                Properties: create
        scaleSpecifiedKeys (bool?): Determines if only the specified keys are affected by the scale.  
                If false, other keys may be adjusted with the scale. The  
                default is true.  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        timePivot (int?): Scale pivot along the time-axis for time-based animation curves  
                Properties: create
        timeScale (float?): Amount to scale along the time-axis for time-based animation curves  
                Properties: create
        valuePivot (float?): Scale pivot along the value-axis  
                Properties: create
        valueScale (float?): Amount of scale along the value-axis  
                Properties: create

    Returns:
        int: Number of curves on which scale was performed

    Example:
    """

def scaleKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., scaleSpecifiedKeys: bool = ..., type: Queryable[str] = ...) -> Union[str, bool]:
    """This command creates a context which may be used to scale keyframes
    within the graph editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        scaleSpecifiedKeys (bool?): Determines if only the specified keys should be scaled. If false,  
                the non-selected keys will be adjusted during the scale. The default  
                is true.  
                Properties: query, edit
        type (Queryable[str]?): rect | manip  
                Specifies the type of scale manipulator to use  
                (Note: "rect" is a manipulator style context, and "manip"  
                is a gestural style context)  
                Properties: query, edit

    Returns:
        str: Scale type, if the type flag was queried
        bool: Whether specified keys should be scaled, if the scaleSpecifiedKeys flag was queried

    Example:
    """

def sceneEditor(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., onlyParents: bool = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., refreshReferences: bool = ..., selectCommand: Queryable[Callable[..., Any]] = ..., selectItem: Queryable[int] = ..., selectReference: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., shortName: bool = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., unresolvedName: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., withoutCopyNumber: bool = ...) -> Union[str, bool, Callable[..., Any], int]:
    """This creates an editor for managing the files in a scene.
    Args:
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        onlyParents (bool?): When used with the 'selectItem' or 'selectReference' queries it  
                indicates that, if both a parent and a child file or reference  
                are selected, only the parent will be returned.  
                Properties: query
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        refreshReferences (bool?): Force refresh of references  
                Properties: edit
        selectCommand (Queryable[Callable[..., Any]]?): A script to be executed when an item is selected.  
                Properties: create, query, edit
        selectItem (Queryable[int]?): Query or change the currently selected item. When queried, the  
                currently selected file name will be return.  
                Properties: query, edit
        selectReference (Queryable[str]?): Query the currently selected reference. Returns the name of the  
                currently selected reference node.  
                Properties: query
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        shortName (bool?): When used with the 'selectItem' query it indicates that the file name  
                returned will be the short name (i.e. just a file name without  
                any directory paths). If this flag is not present, the full name  
                and directory path will be returned.  
                Properties: query
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        unresolvedName (bool?): When used with the 'selectItem' query it indicates that the file name  
                returned will be unresolved (i.e. it will be the path originally  
                specified when the file was loaded into Maya; this path may  
                contain environment variables and may not exist on disk). If this  
                flag is not present, the resolved name will    be returned.  
                Properties: query
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        withoutCopyNumber (bool?): When used with the 'selectItem' query it indicates that the file name  
                returned will not have a copy number appended to the end. If this  
                flag is not present, the file name returned may have a copy number  
                appended to the end.  
                Properties: query

    Returns:
        str: Name of editor.

    Example:
    """

def sceneLint(*args: Any, query: bool = ..., issueType: Queryable[Multiuse[str]] = ..., verbose: bool = ...) -> Union[str, List[str], Multiuse[str], bool]:
    """{
            "sceneLint" : {
                    "ISSUE_CODE" : {
                            "description" : "DETAILED_DESCRIPTION_OF_ISSUE",
                            "mitigation" : [        // List of mitigations that can be applied
                                    {
                                            "objects"     : [ LIST_OF_STRINGS_NAMING_OBJECTS_TO_WHICH_IT_APPLIES ],
                                            "benefit"     : DESCRIPTION_OF_HOW_THE_CODE_MAKES_THE_SCENE_BETTER,
                                            "description" : DESCRIPTION_OF_WHAT_THE_CODE_DOES,
                                            "code"        : PYTHON_MITIGATION_CODE_WITH_LOOP_OVER_INSTANCES
                                    }
                            ]
                    }
            }
    }Thecommand is used to analyze the currently loaded scene
    to find potential areas for improvement in performance, memory use, or reduction
    of clutter.In the query mode it will report back the list of available checks it can do.
    Each check will have an associated short-form which can be passed to the command
    to run specific checks.In create mode the returned string is a JSON format list of issues and mitigations
    that suggest a way to solve the problem it describes.Mitigation can be automatically performed by extracting the mitigation code and arguments
    then running the Python codedebug, performance
    Args:
        issueType (Queryable[Multiuse[str]]?): Specify a set of issue types to be checked. If omitted then all known issue types are checked.  
                In query mode returns a description of what a particular issue type is checking.  
                			In query mode, this flag can accept a value.  
                Properties: create, query, multiuse
        verbose (bool?): If set then include both name and description when querying the list of available issue types.  
                Properties: create, query

    Returns:
        str: JSON formatted results showing the issues that could potentially cause problems in the scene.
        List[str]: When querying issueType shows the description, and benefit values for the named scene issue.
        List[str]: When querying returns the list of all issueTypes by name.

    Example:
    """

def sceneUIReplacement(*, clear: bool = ..., deleteRemaining: bool = ..., getNextFilter: Tuple[str, str] = ..., getNextPanel: Tuple[str, str] = ..., getNextScriptedPanel: Tuple[str, str] = ..., update: str = ...) -> str:
    """This command returns existing scene based UI that can be utilized by
    the scene that is being loaded. It can also delete any such UI that is
    not used by the loading scene.
    Args:
        clear (bool?): Frees any resources allocated by the command.  
                Properties: create
        deleteRemaining (bool?): Delete any UI that is scene dependent and has not been referenced by  
                this command since the last update.  
                Properties: create
        getNextFilter (Tuple[str, str]?): Returns the next filter of the specified type with the specified name.  
                Properties: create
        getNextPanel (Tuple[str, str]?): Returns the next panel of the specified type, preferably with the  
                specified label.  
                Properties: create
        getNextScriptedPanel (Tuple[str, str]?): Returns the next scripted panel of the specified scripted panel type,  
                preferably with the specified label.  
                Properties: create
        update (str?): Updates the state of the command to reflect the current state  
                of the application.  The string argument is the name of the  
                main window pane layout holding the panels.  
                Properties: create

    Returns:
        str: When used with getNextScriptedPanel, getNextPanel, or getNextFilter

    Example:
    """

def scmh(arg0: float = ..., arg1: float = ..., arg2: float = ..., arg3: float = ..., arg4: float = ..., arg5: float = ..., /, *args: str, absolute: bool = ..., ignore: Multiuse[int] = ..., quiet: bool = ..., relative: bool = ...) -> bool:
    """Set the current manipulator handle value(s).  In UI units (where
    applicable), though the syntax is set to handle the unit type
    of the current manipulator handle (if available).
    Args:
        absolute (bool?): The values are absolute  
                Properties: create
        ignore (Multiuse[int]?): This is a multiuse flag which specifies that the index-th (1. based)  
                entry is to be ignored  
                Properties: create, multiuse
        quiet (bool?): This flag suppresses all error messages  
                Properties: create
        relative (bool?): The values are relative  
                Properties: create

    Returns:
        bool:

    Example:
    """

def scriptCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allComponents: Queryable[Multiuse[bool]] = ..., allObjects: Queryable[Multiuse[bool]] = ..., animBreakdown: Queryable[Multiuse[bool]] = ..., animCurve: Queryable[Multiuse[bool]] = ..., animInTangent: Queryable[Multiuse[bool]] = ..., animKeyframe: Queryable[Multiuse[bool]] = ..., animOutTangent: Queryable[Multiuse[bool]] = ..., baseClassName: Queryable[str] = ..., camera: Queryable[Multiuse[bool]] = ..., cluster: Queryable[Multiuse[bool]] = ..., collisionModel: Queryable[Multiuse[bool]] = ..., controlVertex: Queryable[Multiuse[bool]] = ..., cumulativeLists: bool = ..., curve: Queryable[Multiuse[bool]] = ..., curveKnot: Queryable[Multiuse[bool]] = ..., curveOnSurface: Queryable[Multiuse[bool]] = ..., curveParameterPoint: Queryable[Multiuse[bool]] = ..., dimension: Queryable[Multiuse[bool]] = ..., dynamicConstraint: Queryable[Multiuse[bool]] = ..., edge: Queryable[Multiuse[bool]] = ..., editPoint: Queryable[Multiuse[bool]] = ..., emitter: Queryable[Multiuse[bool]] = ..., enableRootSelection: bool = ..., escToQuit: bool = ..., exists: bool = ..., exitUponCompletion: bool = ..., expandSelectionList: bool = ..., facet: Queryable[Multiuse[bool]] = ..., field: Queryable[Multiuse[bool]] = ..., finalCommandScript: Queryable[Callable[..., Any]] = ..., fluid: Queryable[Multiuse[bool]] = ..., follicle: Queryable[Multiuse[bool]] = ..., forceAddSelect: bool = ..., hairSystem: Queryable[Multiuse[bool]] = ..., handle: Queryable[Multiuse[bool]] = ..., history: bool = ..., hull: Queryable[Multiuse[bool]] = ..., ignoreInvalidItems: bool = ..., ikEndEffector: Queryable[Multiuse[bool]] = ..., ikHandle: Queryable[Multiuse[bool]] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imagePlane: Queryable[Multiuse[bool]] = ..., implicitGeometry: Queryable[Multiuse[bool]] = ..., isoparm: Queryable[Multiuse[bool]] = ..., joint: Queryable[Multiuse[bool]] = ..., jointPivot: Queryable[Multiuse[bool]] = ..., lastAutoComplete: bool = ..., lattice: Queryable[Multiuse[bool]] = ..., latticePoint: Queryable[Multiuse[bool]] = ..., light: Queryable[Multiuse[bool]] = ..., localRotationAxis: Queryable[Multiuse[bool]] = ..., locator: Queryable[Multiuse[bool]] = ..., locatorUV: Queryable[Multiuse[bool]] = ..., locatorXYZ: Queryable[Multiuse[bool]] = ..., nCloth: Queryable[Multiuse[bool]] = ..., nParticle: Queryable[Multiuse[bool]] = ..., nParticleShape: Queryable[Multiuse[bool]] = ..., nRigid: Queryable[Multiuse[bool]] = ..., name: str = ..., nonlinear: Queryable[Multiuse[bool]] = ..., nurbsCurve: Queryable[Multiuse[bool]] = ..., nurbsSurface: Queryable[Multiuse[bool]] = ..., objectComponent: bool = ..., orientationLocator: Queryable[Multiuse[bool]] = ..., particle: Queryable[Multiuse[bool]] = ..., particleShape: Queryable[Multiuse[bool]] = ..., plane: Queryable[Multiuse[bool]] = ..., polymesh: Queryable[Multiuse[bool]] = ..., polymeshEdge: Queryable[Multiuse[bool]] = ..., polymeshFace: Queryable[Multiuse[bool]] = ..., polymeshFreeEdge: Queryable[Multiuse[bool]] = ..., polymeshUV: Queryable[Multiuse[bool]] = ..., polymeshVertex: Queryable[Multiuse[bool]] = ..., polymeshVtxFace: Queryable[Multiuse[bool]] = ..., rigidBody: Queryable[Multiuse[bool]] = ..., rigidConstraint: Queryable[Multiuse[bool]] = ..., rotatePivot: Queryable[Multiuse[bool]] = ..., scalePivot: Queryable[Multiuse[bool]] = ..., sculpt: Queryable[Multiuse[bool]] = ..., selectHandle: Queryable[Multiuse[bool]] = ..., setAllowExcessCount: Multiuse[bool] = ..., setAutoComplete: Multiuse[bool] = ..., setAutoToggleSelection: Multiuse[bool] = ..., setDoneSelectionPrompt: Multiuse[str] = ..., setNoSelectionHeadsUp: Multiuse[str] = ..., setNoSelectionPrompt: Multiuse[str] = ..., setSelectionCount: Multiuse[int] = ..., setSelectionHeadsUp: Multiuse[str] = ..., setSelectionPrompt: Multiuse[str] = ..., showManipulators: bool = ..., spring: Queryable[Multiuse[bool]] = ..., springComponent: Queryable[Multiuse[bool]] = ..., stroke: Queryable[Multiuse[bool]] = ..., subdiv: Queryable[Multiuse[bool]] = ..., subdivMeshEdge: Queryable[Multiuse[bool]] = ..., subdivMeshFace: Queryable[Multiuse[bool]] = ..., subdivMeshPoint: Queryable[Multiuse[bool]] = ..., subdivMeshUV: Queryable[Multiuse[bool]] = ..., surfaceEdge: Queryable[Multiuse[bool]] = ..., surfaceFace: Queryable[Multiuse[bool]] = ..., surfaceKnot: Queryable[Multiuse[bool]] = ..., surfaceParameterPoint: Queryable[Multiuse[bool]] = ..., surfaceRange: Queryable[Multiuse[bool]] = ..., surfaceUV: Queryable[Multiuse[bool]] = ..., texture: Queryable[Multiuse[bool]] = ..., title: Queryable[str] = ..., toolCursorType: Queryable[str] = ..., toolFinish: Queryable[Callable[..., Any]] = ..., toolStart: Queryable[Callable[..., Any]] = ..., totalSelectionSets: Queryable[int] = ..., vertex: Queryable[Multiuse[bool]] = ...) -> Union[str, Multiuse[bool], bool, Callable[..., Any], int]:
    """This command allows a user to create their own tools based on
    the selection tool. A number of selection lists can be collected,
    the behaviour of the selection and the selection masks are fully
    customizable, etc.The command is processed prior to being executed.  The keyword
    "$Selection#" where # is a number 1 or greater specifies
    a selection set.  The context can specify several selection sets
    which are substituted in place of the $Selection# keyword in the form
    of a Mel string array.  Items that are specific per set need to
    be specified in each set, if they are going to be specified for any of
    the sets.  See examples below.In addition, in order to specify the type of selection you need
    to be making, any of the selection type flags from "selectType" command
    can be used here.
    Args:
        allComponents (Queryable[Multiuse[bool]]?): Set all component selection masks on/off  
                Properties: create, query, multiuse
        allObjects (Queryable[Multiuse[bool]]?): Set all object selection masks on/off  
                Properties: create, query, multiuse
        animBreakdown (Queryable[Multiuse[bool]]?): Set animation breakdown selection mask on/off.  
                Properties: create, query, multiuse
        animCurve (Queryable[Multiuse[bool]]?): Set animation curve selection mask on/off.  
                Properties: create, query, multiuse
        animInTangent (Queryable[Multiuse[bool]]?): Set animation in-tangent selection mask on/off.  
                Properties: create, query, multiuse
        animKeyframe (Queryable[Multiuse[bool]]?): Set animation keyframe selection mask on/off.  
                Properties: create, query, multiuse
        animOutTangent (Queryable[Multiuse[bool]]?): Set animation out-tangent selection mask on/off.  
                Properties: create, query, multiuse
        baseClassName (Queryable[str]?): This string will be used to produce MEL function names for  
                the property sheets for the tool.  For example, if  
                "myScriptTool" was given, the functions "myScriptToolValues"  
                and "myScriptToolProperties" will be used for the  
                property sheets.  The default is "scriptTool".  
                Properties: create, query, edit
        camera (Queryable[Multiuse[bool]]?): Set camera selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        cluster (Queryable[Multiuse[bool]]?): Set cluster selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        collisionModel (Queryable[Multiuse[bool]]?): Set collision model selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        controlVertex (Queryable[Multiuse[bool]]?): Set control vertex selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        cumulativeLists (bool?): If set, the selection lists will be cumulative.  For example,  
                the second list will contain all the items from the first list,  
                the third all the items from the second list etc.  Make sure  
                your script specified above takes that into account.  Relevant  
                if there is more than one selection set.  
                Properties: create, query, edit
        curve (Queryable[Multiuse[bool]]?): Set curve selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        curveKnot (Queryable[Multiuse[bool]]?): Set curve knot selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        curveOnSurface (Queryable[Multiuse[bool]]?): Set curve-on-surface selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        curveParameterPoint (Queryable[Multiuse[bool]]?): Set curve parameter point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        dimension (Queryable[Multiuse[bool]]?): Set dimension shape selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        dynamicConstraint (Queryable[Multiuse[bool]]?): Set dynamicConstraint selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        edge (Queryable[Multiuse[bool]]?): Set mesh edge selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        editPoint (Queryable[Multiuse[bool]]?): Set edit-point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        emitter (Queryable[Multiuse[bool]]?): Set emitter selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        enableRootSelection (bool?): If set, the items to be selected are at their root transform  
                level. Default is false.  
                Properties: create, query, edit
        escToQuit (bool?): If set to true, exit the tool when press "Esc". Default is false.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        exitUponCompletion (bool?): If set, completing the last selection set will exit the  
                tool.  Default is true.  
                Properties: create, query, edit
        expandSelectionList (bool?): If set, the selection lists will expand to have a single  
                component in each item.  You probably want this as a default, otherwise  
                two isoparms on the same surface will show up as 1 item.  
              
                To ensure that components on the same object are returned in the order in  
                which they are selected, use the selectPref -trackSelectionOrder on  
                command in your -toolStart script to enable ordered  
                selection, then restore it to its original value in your  
                -toolFinish script.  
                Properties: create, query, edit
        facet (Queryable[Multiuse[bool]]?): Set mesh face selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        field (Queryable[Multiuse[bool]]?): Set field selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        finalCommandScript (Queryable[Callable[..., Any]]?): Supply the script that will be run when the user presses the  
                enter key and the context is completed.  Depending on the  
                number of selection sets you have, the script can make use  
                of variables string $Selection1[], $Selection2[], ...  
                Properties: create, query, edit
        fluid (Queryable[Multiuse[bool]]?): Set fluid selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        follicle (Queryable[Multiuse[bool]]?): Set follicle selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        forceAddSelect (bool?): If set to true, together with -setAutoToggleSelection (see  
                below) on the first selection set, causes the first selection after  
                the computation of the previous result to be "shift" selection,  
                unless a modifier key is pressed.  Default is false.  
                Flags for each selection set.  These flags are multi-use.  
                Properties: create, query, edit
        hairSystem (Queryable[Multiuse[bool]]?): Set hairSystem selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        handle (Queryable[Multiuse[bool]]?): Set object handle selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        hull (Queryable[Multiuse[bool]]?): Set hull selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        ignoreInvalidItems (bool?): If you have multiple selection sets, the state of the  
                selection set is recorded at the time you "complete it".  You could  
                then delete some of the items in that list and end up with  
                invalid items in one or more of your selection sets.  If this  
                flag is set, those items will be detected and ignored.  You will  
                never know it happened.  Its as if they were never selected in  
                the first place, except that your selection set now does not  
                have as many items as it may need.  If this flag is not set,  
                you will get a warning and your final command callback script  
                will likely not execute because of an error condition.  
                Properties: create, query, edit
        ikEndEffector (Queryable[Multiuse[bool]]?): Set ik end effector selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        ikHandle (Queryable[Multiuse[bool]]?): Set ik handle selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        imagePlane (Queryable[Multiuse[bool]]?): Set image plane selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        implicitGeometry (Queryable[Multiuse[bool]]?): Set implicit geometry selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        isoparm (Queryable[Multiuse[bool]]?): Set surface iso-parm selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        joint (Queryable[Multiuse[bool]]?): Set ik handle selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        jointPivot (Queryable[Multiuse[bool]]?): Set joint pivot selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        lastAutoComplete (bool?): True if auto complete is set for the last selection set,  
                false otherwise.  Mostly used for query, but if present in conjuction  
                with -sac/setAutoComplete flag, -sac flag takes precedence.  
                Properties: create, query, edit
        lattice (Queryable[Multiuse[bool]]?): Set lattice selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        latticePoint (Queryable[Multiuse[bool]]?): Set lattice point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        light (Queryable[Multiuse[bool]]?): Set light selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        localRotationAxis (Queryable[Multiuse[bool]]?): Set local rotation axis selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        locator (Queryable[Multiuse[bool]]?): Set locator (all types) selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        locatorUV (Queryable[Multiuse[bool]]?): Set uv locator selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        locatorXYZ (Queryable[Multiuse[bool]]?): Set xyz locator selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        nCloth (Queryable[Multiuse[bool]]?): Set nCloth selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        nParticle (Queryable[Multiuse[bool]]?): Set nParticle point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        nParticleShape (Queryable[Multiuse[bool]]?): Set nParticle shape selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        nRigid (Queryable[Multiuse[bool]]?): Set nRigid selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        nonlinear (Queryable[Multiuse[bool]]?): Set nonlinear selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        nurbsCurve (Queryable[Multiuse[bool]]?): Set nurbs-curve selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        nurbsSurface (Queryable[Multiuse[bool]]?): Set nurbs-surface selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        objectComponent (bool?): Component flags apply to object mode.  
                Properties: create, query
        orientationLocator (Queryable[Multiuse[bool]]?): Set orientation locator selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        particle (Queryable[Multiuse[bool]]?): Set particle point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        particleShape (Queryable[Multiuse[bool]]?): Set particle shape selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        plane (Queryable[Multiuse[bool]]?): Set sketch plane selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        polymesh (Queryable[Multiuse[bool]]?): Set poly-mesh selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        polymeshEdge (Queryable[Multiuse[bool]]?): Set poly-mesh edge selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        polymeshFace (Queryable[Multiuse[bool]]?): Set poly-mesh face selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        polymeshFreeEdge (Queryable[Multiuse[bool]]?): Set poly-mesh free-edge selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        polymeshUV (Queryable[Multiuse[bool]]?): Set poly-mesh UV point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        polymeshVertex (Queryable[Multiuse[bool]]?): Set poly-mesh vertex selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        polymeshVtxFace (Queryable[Multiuse[bool]]?): Set poly-mesh vertexFace selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        rigidBody (Queryable[Multiuse[bool]]?): Set rigid body selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        rigidConstraint (Queryable[Multiuse[bool]]?): Set rigid constraint selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        rotatePivot (Queryable[Multiuse[bool]]?): Set rotate pivot selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        scalePivot (Queryable[Multiuse[bool]]?): Set scale pivot selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        sculpt (Queryable[Multiuse[bool]]?): Set sculpt selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        selectHandle (Queryable[Multiuse[bool]]?): Set select handle selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        setAllowExcessCount (Multiuse[bool]?): If set, the number if items is to be interpreted as the minimum.  
                Properties: create, edit, multiuse
        setAutoComplete (Multiuse[bool]?): If set to true, as soon as the specified number of items is  
                selected the tool will start the next selection set or run the command.  
                Properties: create, edit, multiuse
        setAutoToggleSelection (Multiuse[bool]?): If set to true, it is as if "shift" key is pressed when there  
                are no modifiers pressed.  That means that you get the "toggle select"  
                behaviour by default.  This only applies to the 3D view, and the  
                selection done in the hypergraph, outliner or elsewhere is still  
                a subject to the usual rules.  
                Properties: create, edit, multiuse
        setDoneSelectionPrompt (Multiuse[str]?): If setAutoComplete is not set (see below) this string will be  
                shown as soon as the tool has enough items for a particular selection  
                set.  If this is not set, but is needed, the same string as set with  
                -setSelectionPrompt flag will be used.  
                Properties: create, edit, multiuse
        setNoSelectionHeadsUp (Multiuse[str]?): Supply a string that will be shown as a heads up prompt when  
                there is nothing selected.  This must be set separately for each  
                selection set.  
                Properties: create, edit, multiuse
        setNoSelectionPrompt (Multiuse[str]?): Supply a string that will be shown as help when there is  
                nothing selected.  This must be set separately for each  
                selection set.  
                Properties: create, edit, multiuse
        setSelectionCount (Multiuse[int]?): The number of items in this selection set.  0 means as many as  
                you need until completion.  
                Properties: create, edit, multiuse
        setSelectionHeadsUp (Multiuse[str]?): Supply a string that will be shown as a heads up prompt when  
                there is something selected.  This must be set separately for each  
                selection set.  
                Properties: create, edit, multiuse
        setSelectionPrompt (Multiuse[str]?): Supply a string that will be shown as help when there is  
                something selected.  This must be set separately for each  
                selection set.  
                Properties: create, edit, multiuse
        showManipulators (bool?): If set, the manipulators will be shown for any active objects.  
                Basically, it is as if you are in the Show Manipulator tool.  
                Properties: create, query, edit
        spring (Queryable[Multiuse[bool]]?): Set spring shape selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        springComponent (Queryable[Multiuse[bool]]?): Set individual spring selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        stroke (Queryable[Multiuse[bool]]?): Set the Paint Effects stroke selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        subdiv (Queryable[Multiuse[bool]]?): Set subdivision surfaces selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        subdivMeshEdge (Queryable[Multiuse[bool]]?): Set subdivision surfaces mesh edge selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        subdivMeshFace (Queryable[Multiuse[bool]]?): Set subdivision surfaces mesh face selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        subdivMeshPoint (Queryable[Multiuse[bool]]?): Set subdivision surfaces mesh point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        subdivMeshUV (Queryable[Multiuse[bool]]?): Set subdivision surfaces mesh UV map selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        surfaceEdge (Queryable[Multiuse[bool]]?): Set surface edge selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        surfaceFace (Queryable[Multiuse[bool]]?): Set surface face selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        surfaceKnot (Queryable[Multiuse[bool]]?): Set surface knot selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        surfaceParameterPoint (Queryable[Multiuse[bool]]?): Set surface parameter point selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        surfaceRange (Queryable[Multiuse[bool]]?): Set surface range selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        surfaceUV (Queryable[Multiuse[bool]]?): Set surface uv selection mask on/off. (component flag)  
                Properties: create, query, multiuse
        texture (Queryable[Multiuse[bool]]?): Set texture selection mask on/off. (object flag)  
                Properties: create, query, multiuse
        title (Queryable[str]?): Supply a string that will be used as a precursor to all the  
                messages; i.e., the "name" of the tool.  
                Properties: create, query, edit
        toolCursorType (Queryable[str]?): Supply the string identifier to set the tool cursor type  
                when inside of tool. The following are the valid ids:  
                "create", "dolly", "edit", "pencil", "track", "trackHorizontal",  
                "trackVertical", "transformation", "tumble", "zoom", "zoomIn",  
                "zoomOut", "flyThrough", "dot", "fleur",  
                "leftArrow", "question", "doubleHorizArrow", "doubleVertArrow",  
                "sizing", "dollyIn", "dollyOut", "brush", "camera", "noAccess",  
                "input", "output", "leftCycle", "rightCycle", "rightExpand",  
                "knife".  
                Properties: create, query, edit
        toolFinish (Queryable[Callable[..., Any]]?): Supply the script that will be run when the user exits  
                the script.  
                Properties: create, query, edit
        toolStart (Queryable[Callable[..., Any]]?): Supply the script that will be run when the user first  
                enters the script  
                Properties: create, query, edit
        totalSelectionSets (Queryable[int]?): Total number of selection sets.  
                Properties: create, query, edit
        vertex (Queryable[Multiuse[bool]]?): Set mesh vertex selection mask on/off. (component flag)  
                Properties: create, query, multiuse

    Returns:
        str: Context name

    Example:
    """

def scriptEditorInfo(*, edit: bool = ..., query: bool = ..., clearHistory: bool = ..., clearHistoryFile: bool = ..., historyFilename: Queryable[str] = ..., input: str = ..., suppressErrors: bool = ..., suppressInfo: bool = ..., suppressResults: bool = ..., suppressStackWindow: bool = ..., suppressWarnings: bool = ..., writeHistory: bool = ...) -> Union[str, bool]:
    """Use this command to directly manipulate and query the contents of the
    Command Window window.
    Args:
        clearHistory (bool?): Clears the read-only text in the upper field of the Command Window.  
                Properties: edit
        clearHistoryFile (bool?): Clear the file defined by the -hf/historyFilename flag, but only  
                if -wh/writeHistory is true. Use this flag to start a new history file,  
                since the default behaviour of the Command Window is to append to  
                the existing file.  
                Properties: edit
        historyFilename (Queryable[str]?): Sets or returns the name of the file that the Command Window will  
                use to echo all of its history to. If this is an empty string when  
                the -wh/writeHistory flag is set to true, then it will automatically be  
                set to the default file.  
                Properties: query, edit
        input (str?): Sets the text in the lower field of the Command Window.  
                Set this value to an empty string to clear the field.  
              
                Note: this flag only affects the Command Window and not the new script editor.  
                To find out how to manipulate the new script editor please refer to the documentation  
                on the cmdScrollFieldExecuter and cmdScrollFieldReporter.  
                Properties: edit
        suppressErrors (bool?): When true, Command Window and Script Editor will not display error messages.  
                Properties: query, edit
        suppressInfo (bool?): When true, Command Window and Script Editor will not display info messages  
                generated by Maya.  
                Properties: query, edit
        suppressResults (bool?): When true, Command Window and Script Editor will not display command results.  
                Properties: query, edit
        suppressStackWindow (bool?): When true and when the stackTrace mechanism is on, this  
                flag will suppress the display of the stack window. If stack  
                trace is enabled then results will be returned to the output  
                window instead of a separate stack window.  
                Properties: query, edit
        suppressWarnings (bool?): When true, Command Window and Script Editor will not display warning messages.  
                Properties: query, edit
        writeHistory (bool?): When true, Command Window will echo all of its  
                history to the file defined by the -hf/historyFilename flag. This  
                flag effectively turns file writing on/off.  
                Properties: query, edit

    Returns:
        str: The name of the Command Window window is returned.

    Example:
    """

def scriptJob(*, allChildren: bool = ..., attributeAdded: Tuple[str, Callable[..., Any]] = ..., attributeChange: Tuple[str, Callable[..., Any]] = ..., attributeDeleted: Tuple[str, Callable[..., Any]] = ..., compressUndo: bool = ..., conditionChange: Tuple[str, Callable[..., Any]] = ..., conditionFalse: Tuple[str, Callable[..., Any]] = ..., conditionTrue: Tuple[str, Callable[..., Any]] = ..., connectionChange: Tuple[str, Callable[..., Any]] = ..., disregardIndex: bool = ..., event: Tuple[str, Callable[..., Any]] = ..., exists: int = ..., force: bool = ..., idleEvent: Callable[..., Any] = ..., kill: Multiuse[int] = ..., killAll: bool = ..., killWithScene: bool = ..., listConditions: bool = ..., listEvents: bool = ..., listJobs: bool = ..., nodeDeleted: Tuple[str, Callable[..., Any]] = ..., nodeNameChanged: Tuple[str, Callable[..., Any]] = ..., optionVarChanged: Tuple[str, Callable[..., Any]] = ..., parent: str = ..., permanent: bool = ..., protected: bool = ..., replacePrevious: bool = ..., runOnce: bool = ..., timeChange: Callable[..., Any] = ..., uiDeleted: Tuple[str, Callable[..., Any]] = ...) -> Union[int, List[str], None, bool]:
    """This command creates a "script job", which is a MEL command
    or script.  This job is attached to
    the named condition, event, or attribute. Each time the condition
    switches to the desired state (or the trigger is triggered, etc),
    the script is run.Script jobs are tied to the event loop in the interactive application.
    They are run during idle events.  This means that script jobs do not
    exist in the batch application.  The scriptJob command does nothing
    in batch mode.This triggering happens very frequently so for speed considerations
    no events are forwarded during playback.  This means that you cannot
    useto alter animation behaviour.
    Use an expression instead, or the rendering callbacks "preRenderMel"
    and "postRenderMel".When setting up jobs for conditions, it is invalid to setup jobs for
    the true state, false state, and state change at the same time.  The
    behaviour is undefined.  The user can only setup jobs for the true
    and/or false state, or only for the state change, but not three at
    the same time. i.e. if you do:This command can also be used to list available conditions
    and events, and to kill running jobs.
    Args:
        allChildren (bool?): This flag can only be used in conjunction with  
                the -ac/attributeChange flag.  If it is specified, and the job  
                is attached to a compound attribute, then the  
                job will run due to changes to the specified attribute  
                as well as changes to its children.  
                Properties: create
        attributeAdded (Tuple[str, Callable[..., Any]]?): Run the script when the named attribute is added.  
                The string must identify both the dependency node and the  
                particular attribute.  If the dependency node is deleted,  
                this job is killed (even if the deletion is undoable).  
                Properties: create
        attributeChange (Tuple[str, Callable[..., Any]]?): Run the script when the named attribute changes value.  
                The string must identify both the dependency node and the  
                particular attribute.  If the dependency node is deleted,  
                this job is killed (even if the deletion is undoable).  
                Properties: create
        attributeDeleted (Tuple[str, Callable[..., Any]]?): Run the script when the named attribute is deleted.  
                The string must identify both the dependency node and the  
                particular attribute.  If the dependency node is deleted,  
                this job is killed (even if the deletion is undoable).  
                Properties: create
        compressUndo (bool?): If this is set to true, and the scriptJob is undoable, then  
                its action will be bundled with the last user action for undo  
                purposes.  For example; if the scriptJob was triggered by a selection  
                change, then pressing undo will undo both the scriptJob and the  
                selection change at the same time.  
                Properties: create
        conditionChange (Tuple[str, Callable[..., Any]]?): Run the script when the named condition changes state.  
                The string must be the name of a pre-defined, or a  
                user-defined boolean condition.  To get a list of what  
                conditions exist, use the -listConditions flag.  
                Properties: create
        conditionFalse (Tuple[str, Callable[..., Any]]?): Run the script when the named condition becomes false.  
                The string must be the name of a pre-defined, or a  
                user-defined boolean condition.  To get a list of what  
                conditions exist, use the -listConditions flag.  
                Properties: create
        conditionTrue (Tuple[str, Callable[..., Any]]?): Run the script when the named condition becomes true.  
                The string must be the name of a pre-defined, or a  
                user-defined boolean condition.  To get a list of what  
                conditions exist, use the -listConditions flag.  
                Properties: create
        connectionChange (Tuple[str, Callable[..., Any]]?): Run the script when the named attribute changes its  
                connectivity.  The string must identify both the dependency  
                node and the particular attribute.  If the dependency node  
                is deleted, this job is killed (even if the deletion is undoable).  
                Properties: create
        disregardIndex (bool?): This flag can only be used in conjunction with  
                the -ac/attributeChange flag.  If it is specified, and the job  
                is attached to a multi (indexed) attribute, then the  
                job will run no matter which attribute in the multi changes.  
                Properties: create
        event (Tuple[str, Callable[..., Any]]?): Run the script when the named event occurs.  This string  
                must be the name of a pre-defined maya event.  To get a list  
                of what events exist, use the -listEvents flag.  
                Properties: create
        exists (int?): Returns true if a scriptJob with the specified "job  
                number" exists, and false otherwise. The "job number"  
                should be a value that was returned on creation of a new  
                scriptJob.  
                Properties: create
        force (bool?): This flag can only be used with -kill, -killAll,  
                or -replacePrevious. It enables the deletion of protected jobs.  
                Properties: create
        idleEvent (Callable[..., Any]?): Run the script every time maya is idle.  WARNING,  
                as long as an idle event is is registered, the application  
                will keep calling it and will use up all available CPU time.  
                Use idleEvents with caution.  
                Properties: create
        kill (Multiuse[int]?): Kills the job with the specified job number. Permanent jobs  
                cannot be killed, however, and protected jobs can only be killed  
                if the -force flag is used in the command.  
                Properties: create, multiuse
        killAll (bool?): Kills all jobs. Permanent jobs will not be deleted, and  
                protected jobs will only be deleted if the -force flag is used.  
                Properties: create
        killWithScene (bool?): Attaches the job to the current scene, and when the scene is  
                emptied. The current scene is emptied by opening a new or  
                existing scene.  
                Properties: create
        listConditions (bool?): This causes the command to return a string array containing  
                the names of all existing conditions.  Below is the descriptions  
                for all the existing conditions:  
                Events Based on Available Maya Features  
                These events are true when the given feature is available.  
              
                Event Name  
                 Maya Feature  
                AnimationExists  
                 Animation   
                AnimationUIExists  
                User Interface for Animation  
                BaseMayaExists  
                 Any Basic Maya   
                BaseUIExists  
                 Any Interactive Maya  
                DatabaseUIExists  
              
                DeformersExists  
                 Deformer Functions   
                DeformersUIExists  
                User Interface for Deformers  
                DevicesExists  
                Device Support  
                DimensionsExists  
                Dimensioning  
                DynamicsExists  
                 Dynamics   
                DynamicsUIExists  
                User Interface for Dynamics  
                ExplorerExists  
                 Explorer   
                ImageUIExists  
                User Interface for Imaging  
                KinematicsExists  
                 Kinematics   
                KinematicsUIExists  
                User Interface for Kinematics  
                ManipsExists  
                Manipulators  
                ModelExists  
                 Basic Modeling Tools  
                ModelUIExists  
                User Interface for Basic Modeling  
                NurbsExists  
                 Nurbs Modeling Tools  
                NurbsUIExists  
                User Interface for Nurbs Modeling  
                PolyCoreExists  
                Basic Polygonal Support  
                PolygonsExists  
                 Polygonal Modeling   
                PolygonsUIExists  
                User Interface for Polygonal Modeling  
                PolyTextureExists  
                 Polygonal Texturing   
                RenderingExists  
                 Built-in Rendering   
                RenderingUIExists  
                User Interface for Rendering  
              
              
                Other Events  
                 autoKeyframeState:  
                true when Maya has autoKeyframing enabled  
                busy:  
                true when Maya is busy.  
                deleteAllCondition:  
                true when in the middle of a delete-all operation  
                flushingScene:  
                true while the scene is being flushed out  
                GoButtonEnabled:  
                true when the Go button in the panel context is enabled.   
                hotkeyListChange:  
                true when the list of hotkey definitions has changed  
                playingBack:  
                true when Maya is playing back animation keyframes.  
                playbackIconsCondition:  
                instance of the playingBack condition used on the  
                time slider  
                readingFile:  
                true when Maya is reading a file.  
                RedoAvailable:  
                true when there are commands available for redo.   
                SomethingSelected:  
                true when some object(s) is selected.  
                UndoAvailable:  
                true when there are commands available for undo.  
                Properties: create
        listEvents (bool?): This causes the command to return a string array containing  
                the names of all existing events.  Below is the descriptions  
                for all the existing events:  
              
                angularToleranceChanged:  
                when the tolerance on angular units is changed.  
                This tolerance can be changed by:  
                 using the MEL command, "tolerance" with the "-angular" flag  
                 changing the pref under Options->GeneralPreferences->  
                Modeling tab->Tangential Tolerance  
              
                angularUnitChanged:  
                when the user changes the angular unit.  
                axisAtOriginChanged:  
                when the axis changes at the origin.  
                  axisInViewChanged:  
                when the axis changes at a particular view.  
                ColorIndexChanged:  
                when the color index values change.  
                constructionHistoryChanged:   
                when construction history is turned on or off.  
                currentContainerChanged:   
                when the user set or unset the current container.  
                currentSoundNodeChanged:  
                whenever the sound displayed in the time slider changes  
                due to:  
                 the sound being removed (or no longer displayed)  
                [RMB in the time slider]  
                a new sound being displayed [RMB in the time slider]  
                sound display being toggled [animation options]  
                sound display mode being changed [animation options]  
              
                DagObjectCreated:  
                when a new DAG object is created.  
                deleteAll:  
                when a file new occurs  
                DisplayColorChanged:  
                when the display color changes.  
                displayLayerChange:  
                when a layer has been created or destroyed.  
                displayLayerManagerChange:  
                when the display layer manager has changed.  
                DisplayRGBColorChanged:  
                when the RGB display color changes.  
                glFrameTrigger:  
                for internal use only.  
                ChannelBoxLabelSelected:  
                when Channel Box label(first column) selection changes.  
                gridDisplayChanged:  
                for internal use only.  
                idle:   
                when Maya is idle and there are no high priority idle tasks  
                idleHigh:   
                when Maya is idle.  This is called before low priority idle  
                tasks.  You should almost always use "idle" instead.  
                lightLinkingChanged:  
                when any change occurs which modifies light linking  
                relationships.  
                lightLinkingChangedNonSG:  
                when any change occurs which modifies light linking  
                relationships, except when the change is a change of shading  
                assignment.  
                linearToleranceChanged:  
                 when the linear tolerance has been changed.  This tolerance  
                can be changed by:  
                 using the MEL command, "tolerance" with the  "-linear" flag  
                 changing the pref under Options->GeneralPreferences->  
                Modeling tab->Positional Tolerance  
              
                linearUnitChanged:   
                when the user changes the linear unit through the Options menu.  
                MenuModeChanged:   
                when the user changes the menu set for the menu bar in the main Maya window  
                (for example, from "Modeling" to "Animation").  
                RecentCommandChanged:   
                for internal use only.  
                NewSceneOpened:  
                when a new scene has been opened.  
                PostSceneRead:  
                after a scene has been read. Specifically after a file open, import or all child  
                references have been read.  
                nurbsToPolygonsPrefsChanged:  
                 when any of the nurbs-to-polygons prefs have changed.  These  
                prefs can be changed by:  
                 using the Mel command, "nurbsToPolygonsPref"  
                 changing the prefs under Polygons->Nurbs To  
                Polygons->Option Box  
              
                playbackRangeChanged:  
                when the playback keyframe range changes.  
                playbackRangeSliderChanged:  
                when the animation start/end range (i.e. the leftmost  
                or rightmost entry cells in the time slider range, the inner  
                ones adjust the playback range) change  
                preferredRendererChanged:  
                when the preferred renderer changes.  
                quitApplication:  
                when the user has chosen to quit, either through the quit MEL  
                command, or through the Exit menu item.  
                Redo:  
                when user has selected redo from the menu and there was something  
                to redo.  This callback can be used for updating UI or local  
                storage.  Do not change the state of the scene or DG during this  
                callback.  
                renderLayerChange:  
                when creation or deletion of a render layer node has occured.  
                renderLayerManagerChange:  
                when the current render layer has changed.  
                RebuildUIValues:  
                for internal use only.  
                SceneOpened:  
                when a scene has been opened.  
                SceneSaved:  
                when a scene has been saved.  
                SelectionChanged:   
                when a new selection is made.  
                UFESelectionChanged:   
                when a new UFE selection is made.  
                SelectModeChanged:   
                when the selection mode changes.  
                SelectPreferenceChanged:   
                for internal use only.  
                SelectPriorityChanged:  
                when the selection priority changes.  
                SelectTypeChanged:   
                when the selection type changes.  
                setEditorChanged:  
                obsolete.  No longer used.  
                SetModified:  
                when the set command is used to modify a set  
                SequencerActiveShotChanged:   
                when the active sequencer shot is changed.  
                snapModeChanged:  
                when the snap mode changes. E.g. changes to grid snapping.   
                timeChanged:  
                when the time changes.  
                timeUnitChanged:   
                when the user changes the time unit.  
                ToolChanged:   
                when the user changes the tool/context.  
                PostToolChanged:   
                after the user changes the tool/context.  
                NameChanged:   
                when the user changes the name of an object with the rename command.  
                Undo:  
                when user has selected undo from the menu and there was  
                something to undo.  This callback can be used for updating UI or local  
                storage.  Do not change the state of the scene or DG during this  
                callback.  
                modelEditorChanged:   
                when the user changes the options of a model editor.  
                colorMgtEnabledChanged:   
                when the global per-scene color management enabled flag changes.  
                colorMgtConfigFileEnableChanged:   
                when the global per-scene color management OCIO configuration enabled  
                flag changes.  
                colorMgtPrefsViewTransformChanged:   
                when the global per-scene color management view transform preferences  
                transform changes.  
                colorMgtWorkingSpaceChanged:   
                when the global per-scene color management working space changes.  
                colorMgtConfigFilePathChanged:   
                when the global per-scene color management OCIO configuration file path  
                changes.  
                colorMgtConfigChanged:   
                when the color management mode changes from native to OCIO, or when  
                a different OCIO configuration is loaded.  
                colorMgtPrefsReloaded:   
                when all the global per-scene color management settings are reloaded.  
                colorMgtUserPrefsChanged:   
                when any user-level color management preference has changed.  
                colorMgtOutputChanged:   
                when the color management transform, or its enabled state, has changed.  
                colorMgtOCIORulesChanged:   
                when the type of rules in OCIO mode has changed.  
                colorMgtRefreshed:   
                when the color management is refreshed to trap environment variable changes.  
                metadataVisualStatusChanged:   
                for internal use only.  
                shapeEditorTreeviewSelectionChanged:   
                when a new selection in shape editor's treeview is made .  
                RenderViewCameraChanged:   
                when the Render View's current camera is changed.  
                tabletModeChanged:   
                Windows only: if your device is a Tablet PC, then the convertible mode has  
                changed.  You can use command about -tabletMode to query if your device  
                is currently running in tablet or laptop (keyboard attached) mode.  
                Properties: create
        listJobs (bool?): This causes the command to return a string array containing  
                a description of all existing jobs, along with their job  
                numbers.  These numbers can be used to kill the jobs later.  
                Properties: create
        nodeDeleted (Tuple[str, Callable[..., Any]]?): Run the script when the named node is deleted  
                Properties: create
        nodeNameChanged (Tuple[str, Callable[..., Any]]?): Run the script when the name of the named node changes  
                Properties: create
        optionVarChanged (Tuple[str, Callable[..., Any]]?): Run the script when the named optionVar changes value.  
                If the optioNVar is deleted, this job is killed (even if the deletion is undoable).  
                Properties: create
        parent (str?): Attaches this job to a piece of maya UI.  When the UI is  
                destroyed, the job will be killed along with it.  
                Properties: create
        permanent (bool?): Makes the job un-killable. Permanent jobs exist for the life  
                of the application, or for the life of their parent object.  
                The -killWithScene flag does apply to permanent jobs.  
                Properties: create
        protected (bool?): Makes the job harder to kill. Protected jobs must be killed  
                or replaced intentionally by using the -force flag.  
                The -killWithScene flag does apply to protected jobs.  
                Properties: create
        replacePrevious (bool?): This flag can only be used with the -parent flag.  Before  
                the new scriptJob is created, any existing scriptJobs that have  
                the same parent are first deleted.  
                Properties: create
        runOnce (bool?): If this is set to true, the script will only be run a single  
                time.  If false (the default) the script will run every time  
                the triggering condition/event occurs.  If the -uid or -nd flags  
                are used, runOnce is turned on automatically.  
                Properties: create
        timeChange (Callable[..., Any]?): Run the script whenever the current time changes. The  
                script will not be executed if the time is changed by clicking on  
                the time slider, whereas scripts triggered by the "timeChanged"  
                condition will be executed.  
                Properties: create
        uiDeleted (Tuple[str, Callable[..., Any]]?): Run the script when the named piece of UI is deleted.  
                Properties: create

    Returns:
        int: The job number, which can be used to kill the job. The job
            number will be a value greater than or equal to zero
        List[str]: A string list when the list flag is used
        None: For the kill flag.
        bool: For the exists flag.

    Example:
    """

def scriptNode(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., afterScript: Queryable[str] = ..., beforeScript: Queryable[str] = ..., executeAfter: bool = ..., executeBefore: bool = ..., ignoreReferenceEdits: bool = ..., name: str = ..., scriptType: Queryable[int] = ..., sourceType: Queryable[str] = ...) -> Union[bool, str, int]:
    """scriptNodes contain scripts that are executed when a file is loaded or
    when the script node is deleted. If a script modifies a referenced node,
    the changes will be tracked as reference edits unless the scriptNode was
    created with the ignoreReferenceEdits flag. The scriptNode command is used
    to create, edit, query, and test scriptNodes.
    Args:
        afterScript (Queryable[str]?): The script executed when the script node is deleted.   
                C: The default is an empty string.   
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        beforeScript (Queryable[str]?): The script executed during file load.   
                C: The default is an empty string.   
                Q: When queried, this flag returns a string.  
                Properties: create, query, edit
        executeAfter (bool?): Execute the script stored in the .after attribute of the  
                scriptNode. This script is normally executed when the script node  
                is deleted.  
                Properties: create
        executeBefore (bool?): Execute the script stored in the .before attribute of the  
                scriptNode. This script is normally executed when the file  
                is loaded.  
                Properties: create
        ignoreReferenceEdits (bool?): Sets whether changes made to referenced nodes during the execution of the  
                script should be recorded as reference edits. This flag must be set when  
                the scriptNode is created. If this flag is not set, changes to referenced  
                nodes will be recorded as edits by default.  
                Properties: create
        name (str?): When creating a new scriptNode, this flag specifies the name  
                of the node. If a non-unique name is used, the name will be  
                modified to ensure uniqueness.  
                Properties: create
        scriptType (Queryable[int]?): Specifies when the script is executed. The following  
                values may be used:  
              
              
                0 Execute on demand.  
              
              
                1 Execute on file load or on node deletion.  
              
              
                2 Execute on file load or on node deletion  
                when not in batch mode.   
              
              
                3 Internal  
              
              
                4 Execute on software render  
              
              
                5 Execute on software frame render  
              
              
                6 Execute on scene configuration  
              
              
                7 Execute on time changed  
              
              
                C: The default value is 0.   
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit
        sourceType (Queryable[str]?): Sets the language type for both the attached scripts.  
                Valid values are "mel" (enabled by default), and "python".  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def scriptTable(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., afterCellChangedCmd: Callable[..., Any] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., cellBackgroundColorCommand: Callable[..., Any] = ..., cellChangedCmd: Callable[..., Any] = ..., cellForegroundColorCommand: Callable[..., Any] = ..., cellIndex: Tuple[int, int] = ..., cellValue: Queryable[str] = ..., clearRow: int = ..., clearTable: bool = ..., columnFilter: Tuple[int, str] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columns: Queryable[int] = ..., defineTemplate: str = ..., deleteRow: int = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., excludingHeaders: bool = ..., exists: bool = ..., fullPathName: bool = ..., getCellCmd: Callable[..., Any] = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., insertRow: int = ..., isObscured: bool = ..., label: Multiuse[Tuple[int, str]] = ..., manage: bool = ..., multiEditEnabled: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowHeight: Queryable[int] = ..., rows: Queryable[int] = ..., rowsRemovedCmd: Callable[..., Any] = ..., rowsToBeRemovedCmd: Callable[..., Any] = ..., selectedCells: Queryable[List[int]] = ..., selectedColumns: Queryable[List[int]] = ..., selectedRow: bool = ..., selectedRows: Queryable[List[int]] = ..., selectionBehavior: Queryable[int] = ..., selectionChangedCmd: Callable[..., Any] = ..., selectionMode: Queryable[int] = ..., sortEnabled: bool = ..., statusBarMessage: str = ..., underPointerColumn: bool = ..., underPointerRow: bool = ..., useDoubleClickEdit: bool = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, bool, List[int], Callable[..., Any]]:
    """This command creates/edits/queries the script table control.
    Args:
        afterCellChangedCmd (Callable[..., Any]?): Sets the script to call after the value of a cell has been  
                changed. The procedure is called with  
                2 integer arguments specifying the row and column for  
                which the value was changed. The 3rd argument is the string  
                which was entered into that cell. The procedure does not need to  
                return any value.  
                The row and column numbers passed in are 1. based  
                (i.e. (1,1) is the upper left cell). The procedure should be  
                of the form:  
              
                global proc procedureName(int $row, int $column, string $value)  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        cellBackgroundColorCommand (Callable[..., Any]?): Sets the script to call when it requires  
                the background color of a cell.  
                The procedure is called with  
                2 integer arguments specifying the row and column for  
                which the value is required. The procedure should return  
                an array of ints which is the RGB color value for the cell.  
                The row and column numbers passed in are 1. based  
                (i.e. (1,1) is the upper left cell).  
                The procedure should be of the form:  
              
                global proc int[] procedureName(int $row, int $column) {  
                return {255,0,0}; // return Red as cell background color  
                }  
                Properties: create, edit
        cellChangedCmd (Callable[..., Any]?): Sets the script to call when somebody has  
                changed the value of a cell. The procedure is called with  
                2 integer arguments specifying the row and column for  
                which the value was changed. The 3rd argument is the string  
                which was entered into that cell. The procedure should return  
                an integer value which indicates whether that value should be  
                accepted (return 1 if yes, and 0 if no).  
                The row and column numbers passed in are 1. based  
                (i.e. (1,1) is the upper left cell). The procedure should be  
                of the form:  
              
                global proc int procedureName(int $row, int $column, string $value)  
                Properties: create, edit
        cellForegroundColorCommand (Callable[..., Any]?): Sets the script to call when it requires  
                the foreground color of a cell.  
                The procedure is called with  
                2 integer arguments specifying the row and column for  
                which the value is required. The procedure should return  
                an array of ints which is the RGB color value for the cell.  
                The row and column numbers passed in are 1. based  
                (i.e. (1,1) is the upper left cell).  
                The procedure should be of the form:  
              
                global proc int[] procedureName(int $row, int $column) {  
                return {0,0,0}; // return Black as Text color  
                }  
                Properties: create, edit
        cellIndex (Tuple[int, int]?): used with cellValue , to give the index of row and column  
                This flag and its argument must be passed to the command before the  
                -q flag (see examples).  
                      In query mode, this flag needs a value.  
                Properties: query, edit
        cellValue (Queryable[str]?): query and set the cell value on the table by the index of row and column referred in  
                flag -cellIndex.  
                In edit mode, if flag -multiEditEnabled is True and any cell is selected,  
                the flag -cellIndex is not used and the selected cells will be changed.  
                Properties: query, edit
        clearRow (int?): Clear the contents for all the cells on the specified  
                row. Any procedure specified by the -gcc flag will be  
                called to populate the cleared cells  
                The row number is 1. based (i.e. the first row is 1 not 0).  
                Properties: edit
        clearTable (bool?): Clears the contents of all the cells in the table.  
                Any procedure specified by the -gcc flag will be  
                called to populate the cleared cells  
                Properties: edit
        columnFilter (Tuple[int, str]?): Filter the specified column with the string value provided.  
                Set filter to columns 0 will apply the filter to all columns.  
                The filter is case insensitive and support wildcards.  
                Wildcard Matching: Wildcard matching is much simpler than full regexps and has only four features:  
                c	Any character represents itself apart from those mentioned below. Thus c matches the character c.  
                ?	Matches any single character. It is the same as . in full regexps.  
                *	Matches zero or more of any characters. It is the same as .* in full regexps.  
                [...]	Sets of characters can be represented in square brackets, similar to full regexps.  
                Within the character class, backslash has no special meaning.  
                (i.e. you can search for "MyValue" with "y*u" or "??Val??" or "[MyThe]Value" or any letters in "MyValue"  
                The column number is 1. based (i.e. the first row is 1 not 0).  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Set the width of the specified column  
                The column number is 1. based (ie. the first column is 1 not 0).  
                Properties: create, edit, multiuse
        columns (Queryable[int]?): Set the number of columns in the table  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteRow (int?): Delete the specified row  
                The row number is 1. based (i.e. the first row is 1 not 0).  
                Properties: edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the table.  
                By default, this flag is set to true, and the table can be edited.  
                If false, then the table is 'read only' and cannot be typed into.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        excludingHeaders (bool?): when querying the count for the rows or the columns , the number returned will not include the headers  
                Properties: query
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        getCellCmd (Callable[..., Any]?): Sets the script to call when it requires  
                the contents of a cell. The procedure is called with  
                2 integer arguments specifying the row and column for  
                which the value is required. The procedure should return  
                a string which is the value for the cell.  
                The row and column numbers passed in are 1. based  
                (ie. (1,1) is the upper left cell). The procedure should be  
                of the form:  
              
                global proc string procedureName(int $row, int $column)  
                Properties: create, edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        insertRow (int?): Insert an empty row before the specified row. Any  
                procedure specified by the -gcc flag will be called to  
                populate the new new cells.  
                The row number is 1. based (i.e. the first row is 1 not 0).  
                Properties: edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Multiuse[Tuple[int, str]]?): Set the label of the specified column.  
                The column number is 1. based (ie. the first column is 1 not 0).  
                Properties: create, edit, multiuse
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        multiEditEnabled (bool?): True: scriptTable support multi-editing function  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowHeight (Queryable[int]?): Sets the height for each row in the scriptTable  
                Properties: create, query, edit
        rows (Queryable[int]?): Set the number of rows in the table  
                Properties: create, query, edit
        rowsRemovedCmd (Callable[..., Any]?): Sets the script to call after rows are removed by pressing 'delete' or  
                'backspace' key. The procedure is called with one argument  
                specifying that selected rows have been removed.  
                The rows passed in are 1. based. The procedure should be  
                of the form:  
              
                global proc procedureName(int $rows[])  
                Properties: create, edit
        rowsToBeRemovedCmd (Callable[..., Any]?): Sets the script to call when 'delete' or 'backspace' key is  
                pressed. The procedure is called with one argument  
                specifying the selected rows to be removed. The procedure  
                should return an integer value which indicates whether the  
                selected rows should be removed (return 1 if yes, and 0 if no).  
                The rows passed in are 1. based. The procedure should be  
                of the form:  
              
                global proc int procedureName(int $rows[])  
                Properties: create, edit
        selectedCells (Queryable[List[int]]?): Select the cells or return  the cells currently selected.  
                This returns a list of indices, the first of each pair is the row, the second is the column, repeated for each cell selected  
                The returned cell numbers are 1. based (ie. the first row is 1 not 0, the first column is 1 not 0).  
                Properties: query, edit
        selectedColumns (Queryable[List[int]]?): select the columns or return the columns currently selected.  
                This returns a list of indices of each column completely selected  
                The returned column numbers are 1. based  
                Properties: query, edit
        selectedRow (bool?): The current row selected.  
                The returned row number is 1. based (ie. the first row is 1 not 0).  
                Properties: query
        selectedRows (Queryable[List[int]]?): In edit mode, select the rows given as argument.  
                In query mode, return a list of indices of completely selected rows.  
                The row numbers are 1. based  
                Properties: query, edit
        selectionBehavior (Queryable[int]?): Set the selection behavior, valid values are from 0 to 2 (inclusive)  
                0. Selecting single items.  
                1. Selecting only rows.  
                2. Selecting only columns.  
                Properties: create, query, edit
        selectionChangedCmd (Callable[..., Any]?): Sets the script to call when a complete selection  
                operation triggered by the user has occurred successfully.  
                The script does not pass any parameters and does not need to  
                return any value (i.e. It is simply a notification mechanism).  
                Properties: create, edit
        selectionMode (Queryable[int]?): Set the selection Mode, valid values are from 0 to 4 (inclusive)  
                0. Items cannot be selected.  
                1. When the user selects an item, any already-selected item becomes unselected, and the user cannot unselect the selected item by clicking on it.  
                2. When the user selects an item in the usual way, the selection status of that item is toggled and the other items are left alone. Multiple items can be toggled by dragging the mouse over them.  
                3. When the user selects an item in the usual way, the selection is cleared and the new item selected. However, if the user presses the Ctrl key when clicking on an item, the clicked item gets toggled and all other items are left untouched. If the user presses the Shift key while clicking on an item, all items between the current item and the clicked item are selected or unselected, depending on the state of the clicked item. Multiple items can be selected by dragging the mouse over them.  
                4. When the user selects an item in the usual way, the selection is cleared and the new item selected. However, if the user presses the Shift key while clicking on an item, all items between the current item and the clicked item are selected or unselected, depending on the state of the clicked item.  
                Properties: create, query, edit
        sortEnabled (bool?): enable scriptTable sorted by column  
                default value is false and the whole row will be sorted  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        underPointerColumn (bool?): The column under the pointer.  
                The returned column number is 1. based (i.e. the first column is 1 not 0).  
                Properties: query
        underPointerRow (bool?): The row under the pointer.  
                The returned row number is 1. based (i.e. the first row is 1 not 0).  
                Properties: query
        useDoubleClickEdit (bool?): this controls the cell edit mode  
                False: Click in the cell to select (in Row selection, the last cell of the row is edited, in Column selection, the last cell of the column is edited)(default)   
                True:  Clicked in cell is edited when double-clicked only  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full path name to the created script table control.

    Example:
    """

def scriptedPanel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., type: Queryable[str] = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command will create an instance of the specified
    scriptedPanelType. A panel is a collection of UI objects (buttons,
    fields, graphical views) that are grouped together. A panel can be
    moved around as a group within the application interface, and torn off
    to exist in its own window. The panel takes care of maintaining the
    state of its UI when it is relocated, or recreated. A scripted panel
    is a panel that is defined in MEL, with all of the required callbacks
    available as MEL proc's.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        type (Queryable[str]?): This flag specifies the type of scripted panel to create.  
                Properties: create, query
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the scripted panel.

    Example:
    """

def scriptedPanelType(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addCallback: Queryable[str] = ..., copyStateCallback: Queryable[str] = ..., createCallback: Queryable[str] = ..., customView: bool = ..., defineTemplate: str = ..., deleteCallback: Queryable[str] = ..., exists: bool = ..., hotkeyCtxClient: Queryable[str] = ..., initCallback: Queryable[str] = ..., label: Queryable[str] = ..., obsolete: bool = ..., removeCallback: Queryable[str] = ..., retainOnFileOpen: bool = ..., saveStateCallback: Queryable[str] = ..., unique: bool = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command defines the callbacks for a type of scripted panel.  The panel type
    created by this command is then used when creating a scripted panel.  See also
    the 'scriptedPanel' command.
    Args:
        addCallback (Queryable[str]?): This flag specifies the callback procedure for adding the panel  
                to a particular control layout.  The parent layout is guaranteed to be  
                the current default layout when the proc is called.  If its name is  
                required then it can be queried with 'setParent -q'.  Any editors should  
                be parented here.  
                global proc procName (string $panelName) { .... }  
                Properties: create, query, edit
        copyStateCallback (Queryable[str]?): This flag specifies the callback procedure for copying the state of  
                the panel when a tear-off copy of the panel is made.  The callback proc has the form:  
                global proc procName (string $panelName, string $newPanelName) { .... }  
                This procedure will be executed immediately after the addCallback  
                procedure has finished executing. At that point, the copied panel will be  
                fully created and accessible to facilitate copying of panel settings.  
                Note: the addCallback procedure is called after the createCallback  
                procedure has been called.  
                Properties: create, query, edit
        createCallback (Queryable[str]?): This flag specifies the callback procedure for initially creating  
                the panel object.  No UI should be created here.  Any editors owned  
                by the panel should be created here unparented.  
                The callback proc has the form:  
                global proc procName (string $panelName) { .... }  
                Properties: create, query, edit
        customView (bool?): This flag specifies if this view is a custom 3d view for  
                MPx3dModelView types. This flag should only be used for  
                MPx3dModelView types.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteCallback (Queryable[str]?): This flag specifies the callback procedure for final deletion of  
                the panel.  The callback proc has the form:  
                global proc procName (string $panelName) { .... }  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        hotkeyCtxClient (Queryable[str]?): This flag is used to specify the name of the hotkey context client for this panel type.  
                By default, it is the same as the panel type.  
                Properties: create, query, edit
        initCallback (Queryable[str]?): This flag specifies the callback procedure for the initialize  
                callback.  This will be called on file -new and file -open to give the  
                panel an opportunity to re-initialize to a starting state, if required.  
                The panel may be parented or unparented at this time.  
                The callback proc has the form:  
                global proc procName (string $panelName) { .... }  
                Properties: create, query, edit
        label (Queryable[str]?): Label for the panel  
                Properties: create, query, edit
        obsolete (bool?): This flag specifies that this type is no longer used in Maya.  
                Properties: create, query, edit
        removeCallback (Queryable[str]?): This flag specifies the callback procedure for removing the panel  
                from its current control layout.  Any editors should be unparented here.  
                The callback proc has the form:  
                global proc procName (string $panelName) { .... }  
                Properties: create, query, edit
        retainOnFileOpen (bool?): This flag specifies if panels of this type should be retained after  
                restoring panel cofiguration during file open. Default value is false.  
                Properties: create, query, edit
        saveStateCallback (Queryable[str]?): This flag specifies the callback procedure for saving the state of  
                the panel.  The callback proc has the form:  
                global proc string procName (string $panelName) { .... }  
                Note that the proc returns a string.  This string will be executed after  
                the createCallback has been called to facilitate restoring the panel  
                state.  
                Properties: create, query, edit
        unique (bool?): This flag specifies if only one instance of this type of panel can exist  
                at a given time.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the scripted panel type.

    Example:
    """

def scrollField(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., clear: bool = ..., command: str = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enterCommand: Callable[..., Any] = ..., exists: bool = ..., font: Queryable[str] = ..., fontPointSize: Queryable[int] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., insertText: str = ..., insertionPosition: Queryable[int] = ..., isObscured: bool = ..., keyPressCommand: Callable[..., Any] = ..., manage: bool = ..., noBackground: bool = ..., numberOfLines: Queryable[int] = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., selection: bool = ..., statusBarMessage: str = ..., text: Queryable[str] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., wordWrap: bool = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a scrolling field that handles multiple lines
    of text.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the value changes. This command  
                is executed whenever the field loses focus.  
                Properties: create, edit
        clear (bool?): Removes all text in the field.  
                Properties: create, edit
        command (str?): Obsolete - use "enterCommand" instead  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is  
                set to true and the field value may be changed by typing into it.  
                If false then the field is 'read only' and can not be typed into.  
                The text in the field can always be changed with the -tx/text flag  
                regardless of the state of the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enterCommand (Callable[..., Any]?): Command executed when the enter key is pressed.  
                This applies to the enter key on the numeric keypad only.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fontPointSize (Queryable[int]?): The font point size for the text.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        insertText (str?): Insert text into the field at the current insertion  
                position (specified by the -ip/insertionPosition flag).  
                Properties: create, edit
        insertionPosition (Queryable[int]?): The insertion position for inserted text.  This is a  
                1 based value where position 1 specifies the beginning of the  
                field.  Position 0 may be used to specify the end of the field.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        keyPressCommand (Callable[..., Any]?): Command executed when any key is pressed.  
                Properties: create, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfLines (Queryable[int]?): Number of lines in the scroll field.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        selection (bool?): The selected text in the field.  An empty string is returned  
                if there is no selected text.  
                Properties: query
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        text (Queryable[str]?): The field text.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        wordWrap (bool?): Specify true to break lines at spaces, tabs, or newlines.  Text  
                will continue on the following line.  A value of false will not  
                break text between words, in which case text may disappear beyond  
                the edge of the field.  This flag must be set at create time.  
                Lines do not word wrap by default.  
                Properties: create

    Returns:
        str: Full path name to the control.

    Example:
    """

def scrollLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., borderVisible: bool = ..., childArray: bool = ..., childResizable: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontalScrollBarThickness: int = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., minChildWidth: Queryable[int] = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., panEnabled: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., resizeCommand: Callable[..., Any] = ..., scrollAreaHeight: bool = ..., scrollAreaValue: bool = ..., scrollAreaWidth: bool = ..., scrollByPixel: Tuple[str, int] = ..., scrollPage: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., verticalScrollBarAlwaysVisible: bool = ..., verticalScrollBarThickness: int = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a scroll layout.  A scroll layout is useful
    for when you have a number of controls which cannot all be visible
    at a time.  This layout will display a horizontal and/or vertical
    scroll bar when necessary to bring into view the hidden controls.
    Since the scroll layout provides no real positioning of children you
    should use another control layout as the immediate child.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        borderVisible (bool?): Visibility of the border.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        childResizable (bool?): Set to true if you want the child of the control layout to be  
                as wide as the scroll area.  You may also indicate a minimum  
                width for the child using the -mcw/minChildWidth flag.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontalScrollBarThickness (int?): Thickness of the horizontal scroll bar.  Specify an  
                integer value of pixels greater than or equal to 0. Other  
                than setting the value to 0 to hide the scrollbar, this  
                flag has no effect on Windows systems.  
                Properties: create, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        minChildWidth (Queryable[int]?): A positive non-zero integer value indicating the  
                minimum width the scroll layout's child.  This flag only has  
                meaning when the -cr/childResizable flag is set to true.  
                Properties: create, query
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        panEnabled (bool?): Set to true if you want to pan the scroll layout using ALT + MMB.  
                On OSX, in one button and two button mode, you could use  
                command+alt+LMB to pan it. The pan effect is disabled by default.  
                Properties: query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        resizeCommand (Callable[..., Any]?): The command invoked when the scroll layout is resized.  
                Properties: create, edit
        scrollAreaHeight (bool?): Return the height of the scroll area (in pixels).  
                Properties: query
        scrollAreaValue (bool?): Return the vertical and horizontal values of the scroll  
                area (in pixels).  
                Properties: query
        scrollAreaWidth (bool?): Return the width of the scroll area (in pixels).  
                Properties: query
        scrollByPixel (Tuple[str, int]?): Scroll the client area in the direction of the string.  
                The int specifies the number of pixels.  
                Properties: edit
        scrollPage (str?): Scroll the client area in the direction of the string.  
                Valid values are "up", "down", "left" or "right".  
                Properties: edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalScrollBarAlwaysVisible (bool?): Set to true if you want to always have the vertical scroll bar visible.  
                Properties: create
        verticalScrollBarThickness (int?): Thickness of the vertical scroll bar.  Specify an  
                integer value of pixels greater than or equal to 0.  
                This flag has no effect on Windows systems.  
                Properties: create, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def sculpt(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., deformerTools: bool = ..., dropoffDistance: Queryable[float] = ..., dropoffType: Queryable[str] = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., groupWithLocator: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., insideMode: Queryable[str] = ..., maxDisplacement: Queryable[float] = ..., mode: Queryable[str] = ..., name: str = ..., objectCentered: bool = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., sculptTool: str = ..., selectedComponents: bool = ..., split: bool = ..., useComponentTags: bool = ...) -> Union[List[str], bool, float, str, Multiuse[str]]:
    """This command creates/edits/queries a sculpt object deformer. By default
    for creation mode an implicit sphere will be used as the sculpting
    object if no sculpt tool is specified. The name of the created/edited
    object is returned.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        dropoffDistance (Queryable[float]?): Specifies the distance from the surface of the sculpt  
                object at which the sculpt object produces no deformation  
                effect. Default is 1.0. When queried, this flag returns a float.  
                Properties: create, query, edit
        dropoffType (Queryable[str]?): Specifies how the deformation effect drops off from  
                maximum effect at the surface of the sculpt object to no effect  
                at dropoff distance limit. Valid values are: linear | none.  
                Default is linear. When queried, this flag returns a string.  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        groupWithLocator (bool?): Groups the sculptor and its locator together under  
                a single transform. Default is off.  
                Properties: create
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        insideMode (Queryable[str]?): Specifies how the deformation algorithm deals with  
                points that are inside the sculpting primitve. The choices are:  
                ring | even. The default is even. When queried, this flag  
                returns a string. Ring mode will tend to produce a contour like  
                ring of points around the sculpt object as it passes through an  
                object while even mode will try to spread the points out as  
                evenly as possible across the surface of the sculpt object.  
                Properties: create, query, edit
        maxDisplacement (Queryable[float]?): Defines the maximum amount the sculpt object may move  
                a point on an object which it is deforming. Default is 1.0. When  
                queried, this flag returns a float.  
                Properties: create, query, edit
        mode (Queryable[str]?): Specifies which deformation algorithm the sculpt  
                object should use. The choices are: flip | project | stretch.  
                The default is stretch. When queried, this flag returns a string.  
                Properties: create, query, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        objectCentered (bool?): Places the sculpt and locator in the center of the  
                bounding box of the selected object(s) or  
                components. Default is off which centers the  
                sculptor and locator at the origin.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        sculptTool (str?): Use the specified NURBS object as the sculpt tool instead  
                of the default implicit sphere.  
                Properties: create
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        List[str]: Sculpt algorithm node name, sculpt sphere name, and sculpt stretch origin name

    Example:
    """

def sculptKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeMode: Queryable[int] = ..., brushScaling: Queryable[int] = ..., editingRadius: bool = ..., editingStrength: bool = ..., exists: bool = ..., falloffCurve: Queryable[str] = ..., falloffCurveAll: Queryable[str] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., minRadius: Queryable[float] = ..., minStrength: Queryable[float] = ..., minStrengthAll: Queryable[str] = ..., mode: Queryable[int] = ..., modeMinStrength: Multiuse[Tuple[int, float]] = ..., modeStrength: Multiuse[Tuple[int, float]] = ..., name: str = ..., radius: Queryable[float] = ..., reset: bool = ..., strength: Queryable[float] = ..., strengthAll: Queryable[str] = ...) -> Union[str, int, float, bool]:
    """This command creates a context which may be used to
    deform key frames with a sculpt brush. This context
    only works in the graph editor.
    Args:
        activeMode (Queryable[int]?): Used to query the current active sculpt mode. This can differ from the base  
                mode if the user is holding down the shift hotkey to temporarily switch to  
                smooth mode.  
                Properties: query
        brushScaling (Queryable[int]?): Specifies how the sculpt brush scales relative to the Graph Editor.  
                1 = no scaling,  
                2 = scaling based on time,  
                3 = scaling based on value  
                Properties: create, query, edit
        editingRadius (bool?): Enables or disables interactive radius scaling.  
                Properties: create, edit
        editingStrength (bool?): Enables or disables interactive strength scaling.  
                Properties: create, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        falloffCurve (Queryable[str]?): Specifies the falloff curve of the sculpting effect.  
                Properties: create, query, edit
        falloffCurveAll (Queryable[str]?): Internal flag used to save/restore falloff curves for all modes.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        minRadius (Queryable[float]?): Specifies the minumum radius the sculpt brush will take due to stylus pressure.  
                Cannot be more than the base brush radius.  
                Properties: create, query, edit
        minStrength (Queryable[float]?): Specifies the minumum strength of sculpting due to stylus pressure.  
                Cannot be more than the base strength.  
                Properties: create, query, edit
        minStrengthAll (Queryable[str]?): Internal flag used to save/restore min strength for all modes.  
                Properties: create, query, edit
        mode (Queryable[int]?): Specifies the base sculpt mode.  
                0 = grab,  
                1 = smooth  
                2 = smear  
                Properties: create, query, edit
        modeMinStrength (Multiuse[Tuple[int, float]]?): Specifies the min strength for the specified mode.  
                Properties: create, edit, multiuse
        modeStrength (Multiuse[Tuple[int, float]]?): Specifies the strength for the specified mode.  
                Properties: create, edit, multiuse
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        radius (Queryable[float]?): Specifies the radius of the sculpt brush.  
                Properties: create, query, edit
        reset (bool?): Internal flag used to reset current tool mode settings.  
                Properties: query, edit
        strength (Queryable[float]?): Specifies the strength of the sculpting effect for the current mode.  
                Each mode can have a different strength.  
                Properties: create, query, edit
        strengthAll (Queryable[str]?): Internal flag used to save/restore strength for all modes.  
                Properties: create, query, edit

    Returns:
        str: Context name

    Example:
    """

def sculptMeshCacheChangeCloneSource(*args: Any, edit: bool = ..., query: bool = ..., blendShape: Queryable[str] = ..., target: Queryable[str] = ...) -> Union[bool, str]:
    """This command changes the source blend shape and target for the
    clone target tool. Used internally for undo/redo, and should not be called directly.
    Args:
        blendShape (Queryable[str]?): Set which blend shape should be used as the source when using the clone tool. When queried,  
                returns the current blend shape name as a string.  
                Properties: create, query, edit
        target (Queryable[str]?): Set which blend shape should be used as the target when using the clone tool. When queried,  
                returns the current blend shape target name as a string.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def sculptMeshCacheCtx(*args: Any, edit: bool = ..., query: bool = ..., adjustSize: bool = ..., adjustStrength: bool = ..., affectAllLayers: bool = ..., brushDirection: Queryable[int] = ..., brushSize: Queryable[float] = ..., brushStrength: Queryable[float] = ..., buildUpRate: Queryable[float] = ..., cloneHideSource: bool = ..., cloneMethod: Queryable[int] = ..., cloneShapeSource: Queryable[str] = ..., cloneTargetSource: Queryable[str] = ..., constrainToSurface: bool = ..., direction: Queryable[int] = ..., displayFrozen: bool = ..., displayMask: bool = ..., displayWireframe: bool = ..., falloffType: Queryable[int] = ..., flood: float = ..., floodFreeze: float = ..., frame: bool = ..., freezeSelection: bool = ..., grabFollowPath: bool = ..., grabSilhouette: bool = ..., grabTwist: bool = ..., inverted: bool = ..., lastMode: Queryable[str] = ..., lockShellBorder: bool = ..., makeStroke: Multiuse[Tuple[int, int, int, float, float]] = ..., minSize: Queryable[float] = ..., minStrength: Queryable[float] = ..., mirror: Queryable[int] = ..., mode: Queryable[str] = ..., orientToSurface: bool = ..., recordStroke: bool = ..., sculptFalloffCurve: Queryable[str] = ..., size: Queryable[float] = ..., stampDistance: Queryable[float] = ..., stampFile: Queryable[str] = ..., stampFlipX: bool = ..., stampFlipY: bool = ..., stampOrientToStroke: bool = ..., stampPlacement: Queryable[int] = ..., stampRandomization: bool = ..., stampRandomizationSeed: int = ..., stampRandomizeFlipX: bool = ..., stampRandomizeFlipY: bool = ..., stampRandomizePosX: Queryable[float] = ..., stampRandomizePosY: Queryable[float] = ..., stampRandomizeRotation: Queryable[float] = ..., stampRandomizeScale: Queryable[float] = ..., stampRandomizeStrength: Queryable[float] = ..., stampRotation: Queryable[float] = ..., steadyStrokeDistance: Queryable[float] = ..., strength: Queryable[float] = ..., updatePlane: bool = ..., useGlobalSize: bool = ..., useScreenSpace: bool = ..., useStampDistance: bool = ..., useStampImage: bool = ..., useSteadyStroke: bool = ..., wholeStroke: bool = ..., wireframeAlpha: Queryable[float] = ..., wireframeColor: Queryable[Tuple[float, float, float]] = ...) -> Union[bool, int, float, str, Tuple[float, float, float]]:
    """This is a tool context command for mesh cache sculpting tool.
    Args:
        adjustSize (bool?): If true, puts the tool into the mode where dragging the mouse will edit the brush size.  
                If false, puts the tool back into the previous sculpt mode.  
                Properties: edit
        adjustStrength (bool?): If true, puts the tool into the mode where dragging the mouse will edit the brush strength.  
                If false, puts the tool back into the previous sculpt mode.  
                Properties: edit
        affectAllLayers (bool?): If true, the brush affects all layers at once.  
                Properties: create, query, edit
        brushDirection (Queryable[int]?): Specifies the direction of the named brush.  
                Properties: query, edit
        brushSize (Queryable[float]?): Specifies the world-space size of the named brush.  
                Properties: query, edit
        brushStrength (Queryable[float]?): Specifies the world-space strength of the named brush.  
                Properties: query, edit
        buildUpRate (Queryable[float]?): Specifies the brush strength increasing along the stroke.  
                Properties: query, edit
        cloneHideSource (bool?): True if the cloned source should be hidden.  
                Properties: create, query, edit
        cloneMethod (Queryable[int]?): Controls how the source delta vectors should change the target. 0=copy 1=add  
                Properties: create, query, edit
        cloneShapeSource (Queryable[str]?): Name of the shape source to clone.  
                Properties: create, query, edit
        cloneTargetSource (Queryable[str]?): Name of the target source of the clone.  
                Properties: create, query, edit
        constrainToSurface (bool?): If true, the modification keeps the surface curvature.  
                Properties: create, query, edit
        direction (Queryable[int]?): Specifies the direction in which the vertices are moved.  
                Properties: query, edit
        displayFrozen (bool?): If false, turns off the display of frozen area on the object.  
                Properties: create, query, edit
        displayMask (bool?): If false, turns off the display of masked area on the object.  
                Properties: create, query, edit
        displayWireframe (bool?): If false, turns off the wireframe display of the object.  
                Properties: create, query, edit
        falloffType (Queryable[int]?): Specifies how the brush determines which vertices to affect.  
                Properties: query, edit
        flood (float?): Sets the brush effect for each vertex to the given value.  
                Properties: create, edit
        floodFreeze (float?): Sets the freeze value for each vertex to the given value.  
                Properties: create, edit
        frame (bool?): Frames on the sculpted area.  
                Properties: create, edit
        freezeSelection (bool?): Freezes selected components.  
                Properties: create, edit
        grabFollowPath (bool?): If true, the grab brush effect follows mouse movement.  
                Properties: create, query, edit
        grabSilhouette (bool?): If true, the grab brush uses paint-through mode.  
                Properties: create, query, edit
        grabTwist (bool?): If true, the grab brush twists the vertices.  
                Properties: create, query, edit
        inverted (bool?): If true, inverts the effect of the brush.  
                Properties: create, query, edit
        lastMode (Queryable[str]?): Specifies the type of the last active sculpting brush.  
                Properties: query, edit
        lockShellBorder (bool?): Lock the shell borders so that they won't be moved by a UV texture brush.  
                Properties: create, query, edit
        makeStroke (Multiuse[Tuple[int, int, int, float, float]]?): Specify a surface point patch for a brush stroke. Multiple patches can be specified to form a brush stroke.  
                The first argument is the mesh index.  
                The second argument is the side index. use 0 for the original side, and 1 for the mirrored side  
                The third argument is the face index within the specified mesh.  
                The fourth and fifth arguments are the face coordinates within the specified face.  
                Properties: edit, multiuse
        minSize (Queryable[float]?): Specifies the minimum size percentage of the current brush.  
                Properties: query, edit
        minStrength (Queryable[float]?): Specifies the minimum strength percentage of the current brush.  
                Properties: query, edit
        mirror (Queryable[int]?): Specifies the mirror mode of the brush.  
                Properties: query, edit
        mode (Queryable[str]?): Specifies the type of sculpting effect the brush will perform.  
                Properties: query, edit
        orientToSurface (bool?): If true, aligns the brush display to the surface of the mesh.  
                Properties: create, query, edit
        recordStroke (bool?): Set this flag to true to enable stroke recording that can be later played back with the makeStroke flag.  
                Properties: query, edit
        sculptFalloffCurve (Queryable[str]?): Specifies the falloff curve of sculpting effect the brush will perform.  
                Properties: query, edit
        size (Queryable[float]?): Specifies the world-space size of the current brush.  
                Properties: query, edit
        stampDistance (Queryable[float]?): Specifies the stamping distance of the brush.  
                Properties: query, edit
        stampFile (Queryable[str]?): Specifies an image file to use as stamp.  
                Properties: query, edit
        stampFlipX (bool?): Specifies if the brush stamp is flipped on the X axis.  
                Properties: create, query, edit
        stampFlipY (bool?): Specifies if the brush stamp is flipped on the Y axis.  
                Properties: create, query, edit
        stampOrientToStroke (bool?): Specifies if the brush stamp is aligned to the stroke direction.  
                Properties: create, query, edit
        stampPlacement (Queryable[int]?): Specifies the placement mode of the stamp image.  
                Properties: query, edit
        stampRandomization (bool?): Specifies if the brush stamp is randomized.  
                Properties: create, query, edit
        stampRandomizationSeed (int?): Specifies the stamp randomization seed value. Use a value of 0 to generate a random seed value.  
                Properties: edit
        stampRandomizeFlipX (bool?): Specifies if the brush stamp flipping is randomized on the X axis.  
                Properties: create, query, edit
        stampRandomizeFlipY (bool?): Specifies if the brush stamp flipping is randomized on the Y axis.  
                Properties: create, query, edit
        stampRandomizePosX (Queryable[float]?): Specifies the stamp X position value is randomized.  
                Properties: query, edit
        stampRandomizePosY (Queryable[float]?): Specifies the stamp Y position value is randomized.  
                Properties: query, edit
        stampRandomizeRotation (Queryable[float]?): Specifies the stamp rotation value is randomized.  
                Properties: query, edit
        stampRandomizeScale (Queryable[float]?): Specifies the stamp scale value is randomized.  
                Properties: query, edit
        stampRandomizeStrength (Queryable[float]?): Specifies the stamp strength value is randomized.  
                Properties: query, edit
        stampRotation (Queryable[float]?): Specifies the rotation value of the stamp image.  
                Properties: query, edit
        steadyStrokeDistance (Queryable[float]?): Specifies the distance for the steady stroke.  
                Properties: query, edit
        strength (Queryable[float]?): Specifies the world-space strength of the current brush.  
                Properties: query, edit
        updatePlane (bool?): Recalculates the underlying tool plane for each stamp in a stroke.  
                Properties: create, query, edit
        useGlobalSize (bool?): If true, all the brushes have a shared size property; otherwise size is local.  
                Properties: create, query, edit
        useScreenSpace (bool?): If true, the brush size is in screen space pixels.  
                Properties: create, query, edit
        useStampDistance (bool?): Force the stamps to be spread out along the stroke, rather than building up continually.  
                Properties: create, query, edit
        useStampImage (bool?): Specifies if the brush uses a stamp image.  
                Properties: create, query, edit
        useSteadyStroke (bool?): Turns using steady stroke on/off.  
                Properties: create, query, edit
        wholeStroke (bool?): Continuously recalculates the underlying tool plane from all the vertices affected during the stroke.  
                Properties: create, query, edit
        wireframeAlpha (Queryable[float]?): Sets the alpha value of the wireframe for the object that is being sculpted.  
                Properties: create, query, edit
        wireframeColor (Queryable[Tuple[float, float, float]]?): Sets the color of the wireframe for the object that is being sculpted.  
                Values should be 0. 1 RGB.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def sculptTarget(*args: str, edit: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., deformerTools: bool = ..., exclusive: str = ..., frontOfChain: bool = ..., geometry: Multiuse[str] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., inbetweenWeight: float = ..., includeHiddenSelections: bool = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., regenerate: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., snapshot: int = ..., split: bool = ..., target: int = ..., useComponentTags: bool = ...) -> bool:
    """This command is used to specify the blend shape target to be
    modified by the sculpting tools and transform manipulators.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...
        exclusive (str?): Puts the deformation set in a deform partition.  
                Properties: create
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Multiuse[str]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        inbetweenWeight (float?): Specifies the in between target weight of the blend shape node that will be  
                made editable by the sculpting and transform tools.  
                Properties: edit
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        regenerate (bool?): When this flag is specified a new shape is created for the specified  
                blend shape target, if the shape does not already exist.  
                The name of the new shape is returned.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.
        snapshot (int?): This flag should only be used internally to add in-between target.  
                When this flag is specified a snapshot of the shape will be  
                taken for the specified in-between target when it does not  
                exist yet.  
                This flag specifies the base shape index and must be used with the  
                -target and -inbetweenWeight flags, which specify the in-between  
                target.  
                Properties: edit
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        target (int?): Specifies the target index of the blend shape node that will be  
                made editable by the sculpting and transform tools.  
                Properties: edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def selLoadSettings(*args: str, edit: bool = ..., query: bool = ..., activeProxy: Queryable[str] = ..., deferReference: bool = ..., fileName: Queryable[str] = ..., numSettings: Queryable[int] = ..., proxyManager: Queryable[str] = ..., proxySetFiles: Queryable[str] = ..., proxySetTags: Queryable[str] = ..., proxyTag: Queryable[str] = ..., referenceNode: Queryable[str] = ..., shortName: bool = ..., unresolvedName: bool = ...) -> Union[str, bool, int]:
    """This command is used to edit and query information about the implicit load
    settings. Currently this is primarily intended for internal use within the
    Preload Reference Editor.
    selLoadSettings acts on load setting IDs. When implict load settings are
    built for a target scene, there will be one load setting for each reference
    in the target scene. Each load setting has a numerical ID which is its index
    in a pre-order traversal of the target reference hierarchy (with the root
    scenefile being assigned an ID of 0). Although the IDs are numerical they must
    be passed to the command as string array.
    Example:
    Given the scene:where:
    a references b and c
    c references d and e
    the IDs will be as follows:
    a = 0
    b = 1
    c = 2
    d = 3
    e = 4
    selLoadSettings can be used to change the load state of a reference:
    whether it will be loaded or unloaded (deferred) when the target scene is
    opened.
    Note: selLoadSettings can accept multiple command parameters, but the order
    must be selected carefully such that no reference is set to the loaded state
    while its parent is in the unlaoded state.
    Given the scene:where:
    a references b
    b references c
    a = 0
    b = 1
    c = 2
    and b and c are currently in the unloaded state.
    The following command will succeed and change both b and c to the loaded state:
    selLoadSettings -e -deferReference 0 "1" "2";
    whereas the following command will fail and leave both b and c in the unloaded
    state:
    selLoadSettings -e -deferReference 0 "2" "1";
    Bear in mind that the following command will also change both b and c to the
    loaded state:
    selLoadSettings -e -deferReference 0 "1";
    This is because setting a reference to the loaded state automatically sets all
    child references to the loaded state as well. And vice versa, setting a reference
    the the unloaded state automatically sets all child reference to the unloaded state.selective, load, setting, preload, reference
    Args:
        activeProxy (Queryable[str]?): Change or query the active proxy of a proxy set. In query mode, returns the  
                proxyTag of the active proxy; in edit mode, finds the proxy in the proxySet  
                with the given tag and makes it the active proxy.  
                Properties: create, query, edit
        deferReference (bool?): Change or query the load state of a reference.  
                Properties: create, query, edit
        fileName (Queryable[str]?): Return the file name reference file(s) associated with the indicated load setting(s).  
                Properties: create, query
        numSettings (Queryable[int]?): Return the number of settings in the group of implicit load settings. This is  
                equivalent to number of references in the scene plus 1.  
                Properties: create, query
        proxyManager (Queryable[str]?): Return the name(s) of the proxy manager(s) associated with the indicated load setting(s).  
                Properties: create, query
        proxySetFiles (Queryable[str]?): Return the name(s) of the proxy(ies) available in the proxy set associated with the indicated load setting(s).  
                Properties: create, query
        proxySetTags (Queryable[str]?): Return the name(s) of the proxy tag(s) available in the proxy set associated with the indicated load setting(s).  
                Properties: create, query
        proxyTag (Queryable[str]?): Return the name(s) of the proxy tag(s) associated with the indicated load setting(s).  
                Properties: create, query
        referenceNode (Queryable[str]?): Return the name(s) of the reference node(s) associated with the indicated load setting(s).  
                Properties: create, query
        shortName (bool?): Formats the return value of the 'fileName' query flag to only return the short  
                name(s) of the reference file(s).  
                Properties: create, query
        unresolvedName (bool?): Formats the return value of the 'fileName' query flag to return the unresolved  
                name(s) of the reference file(s). The unresolved file name is the file name  
                used when the reference was created, whether or not that file actually exists  
                on disk. When Maya encounters a file name which does not exist on disk it  
                attempts to resolve the name by looking for the file in a number of other  
                locations. By default the 'fileName' flag will return this resolved value.  
                Properties: create, query

    Returns:
        str: For query execution.

    Example:
    """

def select(*args: str, add: bool = ..., addFirst: bool = ..., all: bool = ..., allDagObjects: bool = ..., allDependencyNodes: bool = ..., clear: bool = ..., containerCentric: bool = ..., deselect: bool = ..., hierarchy: bool = ..., noExpand: bool = ..., replace: bool = ..., symmetry: bool = ..., symmetrySide: int = ..., toggle: bool = ..., visible: bool = ...) -> bool:
    """This command is used to put objects onto or off of the active list.
    If none of the five flags [-add, -af, -r, -d, -tgl] are specified, the
    default is to replace the objects on the active list with the
    given list of objects.When selecting a set as in "select set1", the behaviour is for all
    the members of the set to become selected instead of the set itself.
    If you want to select a set, the "-ne/noExpand" flag must be used.With the advent of namespaces, selection by name may be
    confusing.  To clarify, without a qualified namespace, name
    lookup is limited to objects in the root namespace ":". There
    are really two parts of a name: the namespace and the name
    itself which is unique within the namespace. If you want to
    select objects in a specific namespace, you need to include
    the namespace separator ":".For example, 'select -r "foo*"' is trying to look for an
    object with the "foo" prefix in the root namespace. It is not
    trying to look for all objects in the namespace with the "foo"
    prefix. If you want to select all objects in a namespace
    (foo), use 'select "foo:*"'.Note: When the application starts up, there are several dependency nodes
    created by the system which must exist. These objects are not deletable
    but are selectable.  All objects (dag and dependency nodes) in the scene
    can be obtained using the "ls" command without any arguments. When using
    the "-all", "adn/allDependencyNodes" or "-ado/allDagObjects" flags, only
    the deletable objects are selected.  The non deletable object can still
    be selected by explicitly specifying their name as in "select time1;".
    Args:
        add (bool?): Indicates that the specified items should be  
                added to the active list without removing existing  
                items from the active list.  
                Properties: create
        addFirst (bool?): Indicates that the specified items should be  
                added to the front of the active list without  
                removing existing items from the active list.  
                Properties: create
        all (bool?): Indicates that all deletable root level dag objects  
                and all deletable non-dag dependency nodes should be  
                selected.  
                Properties: create
        allDagObjects (bool?): Indicates that all deletable root level dag objects  
                should be selected.  
                Properties: create
        allDependencyNodes (bool?): Indicates that all deletable dependency nodes  
                including all deletable dag objects should be selected.  
                Properties: create
        clear (bool?): Clears the active list.  This is more efficient than  
                "select -d;".  Also "select -d;" will not remove sets  
                from the active list unless the "-ne" flag is also  
                specified.  
                Properties: create
        containerCentric (bool?): Specifies that the same selection rules as apply to selection in the main  
                viewport will also be applied to the select command. In particular, if  
                the specified objects are members of a black-boxed container and are not  
                published as nodes, Maya will not select them. Instead, their first parent  
                valid for selection will be selected.  
                Properties: create
        deselect (bool?): Indicates that the specified items should  
                be removed from the active list if they are on the  
                active list.  
                Properties: create
        hierarchy (bool?): Indicates that all children, grandchildren, ...  
                of the specified dag objects should also be selected.  
                Properties: create
        noExpand (bool?): Indicates that any set which is among the specified  
                items should not be expanded to its list of members.  
                This allows sets to be selected as opposed to  
                the members of sets which is the default behaviour.  
                Properties: create
        replace (bool?): Indicates that the specified items should  
                replace the existing items on the active list.  
                Properties: create
        symmetry (bool?): Specifies that components should be selected symmetrically using the  
                current symmetricModelling command settings. If symmetric modeling  
                is not enabled then this flag has no effect.  
                Properties: create
        symmetrySide (int?): Indicates that components involved in the current symmetry  
                object should be selected, according to the supplied parameter.  
                Valid values for the parameter are:  
                -1. Select components in the unsymmetrical region.  
                0. Select components on the symmetry seam.  
                1. Select components on side 1.  
                2. Select components on side 2.  
                If symmetric modeling is not enabled then this flag has no effect.  
                Note: currently only works for topological symmetry.  
                Properties: create
        toggle (bool?): Indicates that those items on the given list which  
                are on the active list should be removed from the active  
                list and those items on the given list which are not on  
                the active list should be added to the active list.  
                Properties: create
        visible (bool?): Indicates that of the specified items only those  
                that are visible should be affected.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def selectContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Creates a context to perform selection.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: Name of the context created

    Example:
    """

def selectKey(*args: str, addTo: bool = ..., animation: str = ..., attribute: Multiuse[str] = ..., clear: bool = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., inTangent: bool = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., keyframe: bool = ..., outTangent: bool = ..., remove: bool = ..., replace: bool = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ..., toggle: bool = ..., unsnappedKeys: float = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command places keyframes and/or keyframe tangents
    on the active list.
    Args:
        addTo (bool?): Add to the current selection of keyframes/tangents  
                Properties: create
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        clear (bool?): Remove all keyframes and tangents from the active list.  
                Properties: create
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        inTangent (bool?): Select in-tangents of keyframes in the specified time range  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        keyframe (bool?): select only keyframes (cannot be combined with -in/-out)  
                Properties: create
        outTangent (bool?): Select out-tangents of keyframes in the specified time range  
                Properties: create
        remove (bool?): Remove from the current selection of keyframes/tangents  
                Properties: create
        replace (bool?): Replace the current selection of keyframes/tangents  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        toggle (bool?): Toggle the picked state of the specified keyset  
                Properties: create
        unsnappedKeys (float?): Select only keys that have times that are not a multiple of  
                the specified numeric value.  
                Properties: create

    Returns:
        int: The number of curves on which keys were
            selected (or deselcted).

    Example:
    """

def selectKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> Union[bool, str]:
    """This command creates a context which may be used to select keyframes
    within the graph editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def selectKeyframe(*args: str, animation: str = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., index: Multiuse[int] = ..., includeUpperBound: bool = ..., shape: bool = ..., selectionWindow: Tuple[float, float, float, float] = ..., time: Multiuse[NullableRange[float]] = ...) -> None: ...
def selectKeyframeRegionCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> Union[bool, str]:
    """This command creates a context which may be used to select keyframes
    within the keyframe region of the dope sheet editor
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def selectMode(*, query: bool = ..., component: bool = ..., hierarchical: bool = ..., leaf: bool = ..., object: bool = ..., preset: bool = ..., root: bool = ..., template: bool = ...) -> bool:
    """Thecommand is used to change the selection
    mode.  Object, component, root, leaf and template modes are
    mutually exclusive.
    Args:
        component (bool?): Set component selection on. Component selection mode allows  
                filtered selection based on the component selection mask.  
                The component selection mask is the set of selection masks  
                related to objects that indicate which components are  
                selectable.  
                Properties: create, query
        hierarchical (bool?): Set hierarchical selection on. There are  
                three types of hierarchical selection: root, leaf and  
                template.  Hierarchical mode is set if root, leaf or  
                template mode is set. Setting to hierarchical mode  
                will set the mode to whichever of root, leaf, or  
                template was last on.  
                Properties: create, query
        leaf (bool?): Set leaf selection mode on.  This mode allows the leaf  
                level objects to be selected.  It is similar to object  
                selection mode but ignores the object selection mask.  
                Properties: create, query
        object (bool?): Set object selection on. Object selection mode allows  
                filtered selection based on the object selection mask.  
                The object selection mask is the set of selection masks  
                related to objects that indicate which objects are  
                selectable.  The masks are controlled by the "selectType"  
                command.  Object selection mode selects the leaf level  
                objects.  
                Properties: create, query
        preset (bool?): Allow selection of anything with the mask set,  
                independent of it being an object or a component.  
                Properties: create, query
        root (bool?): Set root selection mode on.  This mode allows  
                the root of a hierarchy to be selected by selecting  
                any of its descendents.  It ignores the object selection  
                mask.  
                Properties: create, query
        template (bool?): Set template selection mode on.  This mode allows  
                selection of templated objects.  It selects the templated  
                object closest to the root of the hierarchy.  
                Properties: create, query

    Returns:
        bool: if a query operation

    Example:
    """

def selectPref(*, query: bool = ..., affectsActive: bool = ..., allowHiliteSelection: bool = ..., autoSelectContainer: bool = ..., autoSelectOutlinerSetMembers: bool = ..., autoUseDepth: bool = ..., clickBoxSize: Queryable[int] = ..., clickDrag: bool = ..., containerCentricSelection: bool = ..., disableComponentPopups: bool = ..., expandPopupList: bool = ..., ignoreSelectionPriority: bool = ..., manipClickBoxSize: Queryable[int] = ..., paintSelect: bool = ..., paintSelectWithDepth: bool = ..., popupMenuSelection: bool = ..., preSelectBackfacing: bool = ..., preSelectClosest: bool = ..., preSelectDeadSpace: Queryable[int] = ..., preSelectHilite: bool = ..., preSelectHiliteSize: Queryable[float] = ..., preSelectTweakDeadSpace: Queryable[int] = ..., selectTypeChangeAffectsActive: bool = ..., selectionChildHighlightMode: Queryable[int] = ..., singleBoxSelection: bool = ..., straightLineDistance: bool = ..., trackSelectionOrder: bool = ..., useDepth: bool = ..., xformNoSelect: bool = ...) -> Union[bool, int, float]:
    """This command controls state variables used to selection UI behavior.
    Args:
        affectsActive (bool?): Set affects-active toggle which when on  
                causes the active list to be affected when  
                changing between object and component  
                selection mode.  
                Properties: create, query
        allowHiliteSelection (bool?): When in component selection mode, allow selection of  
                objects for editing.  If an object is selected for  
                editing, it appears in the hilite color and its  
                selectable components are automatically displayed.  
                Properties: create, query
        autoSelectContainer (bool?): When enabled, with container centric selection also on, whenever the root transform is selected in the viewport, the container node will automatically be selected as well.  
                Properties: query
        autoSelectOutlinerSetMembers (bool?): When enabled selecting a set in the Outliner will automatically select the set members instead.  
                Properties: query
        autoUseDepth (bool?): When enabled, useDepth and paintSelectWithDepth will be automatically enabled  
                in shaded display mode and disabled in wireframe display mode.  
                Properties: query
        clickBoxSize (Queryable[int]?): When click selecting, this value defines the size of  
                square picking region surrounding the cursor. The size of  
                the square is twice the specified value. That is, the  
                value defines the amount of space on all four sides of the  
                cursor position. The size must be positive.  
                Properties: create, query
        clickDrag (bool?): Set click/drag selection interaction on/off  
                Properties: create, query
        containerCentricSelection (bool?): When enabled, selecting any DAG node in a container in the viewport will select the container's  
                root transform if there is one.  If there is no root transform then the highest  
                DAG node in the container will be selected.  There is no effect when selecting  
                nodes which are not in a container.  
                Properties: query
        disableComponentPopups (bool?): A separate preference to allow users to disable popup  
                menus when selecting components.  This pref is only meaningful  
                if the popupMenuSelection pref is enabled.  
                Properties: create, query
        expandPopupList (bool?): When in popup selection mode, if this is set then  
                all selection items that contain multiple objects or  
                components will be be expanded such that each object or  
                component will be a single new selection item.  
                Properties: create, query
        ignoreSelectionPriority (bool?): If this is set, selection priority will be ignored  
                when performing selection.  
                Properties: create, query
        manipClickBoxSize (Queryable[int]?): When selecting a manipulator, this value defines the size of  
                square picking region surrounding the cursor. The size of  
                the square is twice the specified value. That is, the  
                value defines the amount of space on all four sides of the  
                cursor position. The size must be positive.  
                Properties: create, query
        paintSelect (bool?): When enabled, the select tool will use drag selection instead of marquee selection.  
                Properties: query
        paintSelectWithDepth (bool?): When enabled, paint selection will not select components that are behind the surface  
                in the current camera view.  
                Properties: query
        popupMenuSelection (bool?): If this is set, a popup menu will be displayed  
                and used to determine the object to select. The menu  
                lists the current user box (marquee) of selected  
                candidate objects.  
                Properties: create, query
        preSelectBackfacing (bool?): When enabled preselection will highlight backfacing components whose normals face away from the camera.  
                Properties: query
        preSelectClosest (bool?): When enabled and the cursor is over a surface, preselection highlighting will try  
                to preselect the closest component to the cursor regardless of distance.  
                Properties: query
        preSelectDeadSpace (Queryable[int]?): This value defines the size of the region around the cursor used for preselection highlighting  
                when the cursor is outside the surface.  
                Properties: query
        preSelectHilite (bool?): When enabled, the closest component under the cursor will be highlighted to indicate that  
                clicking will select that component.  
                Properties: query
        preSelectHiliteSize (Queryable[float]?): This value defines the size of the region around the cursor used for preselection highlighting.  
                Within this region the closest component to the cursor will be highlighted.  
                Properties: query
        preSelectTweakDeadSpace (Queryable[int]?): This value defines the size of the region around the cursor used for preselection highlighting  
                when the cursor is outside the surface in tweak mode.  
                Properties: query
        selectTypeChangeAffectsActive (bool?): If true then the active list will be updated according to the new selection preferences.  
                Properties: query
        selectionChildHighlightMode (Queryable[int]?): Controls the highlighting of the children of a selected object. Valid modes are:  
              
                0. Always highlight children  
                1. Never highlight children  
                2. Use per-object "Selection Child Highlight" setting.  
              
                Default mode is (0): Always highlight children.  
              
                For (2), each DAG object has an individual "Selection Child Highlight" boolean flag.  
                By default, this flag will be TRUE. When mode (2) is enabled, the control is deferred  
                to the selected object's "Selection Child Highlight" flag.  
                Properties: create, query
        singleBoxSelection (bool?): Set single box selection on/off.  
                This flag indicates whether just single object  
                will be selected when the user box (marquee) selects  
                several objects if flag set to true.  Otherwise, all  
                those objects inside the box will be selected.  
                Properties: create, query
        straightLineDistance (bool?): If true then use straight line distances for selection proximity.  
                Properties: query
        trackSelectionOrder (bool?): When enabled, the order of selected objects and components will be tracked.  The 'ls' command will be able  
                to return the active list in the order of selection which will allow scripts to be written that depend  
                on the order.  
                Properties: query
        useDepth (bool?): When enabled, marquee selection will not select components that are behind the surface  
                in the current camera view.  
                Properties: query
        xformNoSelect (bool?): Disable selection in xform tools  
                Properties: create, query

    Returns:
        bool: in the query mode.

    Example:
    """

def selectPriority(*, query: bool = ..., allComponents: Queryable[int] = ..., allObjects: Queryable[int] = ..., animBreakdown: Queryable[int] = ..., animCurve: Queryable[int] = ..., animInTangent: Queryable[int] = ..., animKeyframe: Queryable[int] = ..., animOutTangent: Queryable[int] = ..., byName: Multiuse[Tuple[str, bool]] = ..., camera: Queryable[int] = ..., cluster: Queryable[int] = ..., collisionModel: Queryable[int] = ..., controlVertex: Queryable[int] = ..., curve: Queryable[int] = ..., curveKnot: Queryable[int] = ..., curveOnSurface: Queryable[int] = ..., curveParameterPoint: Queryable[int] = ..., dimension: Queryable[int] = ..., dynamicConstraint: Queryable[int] = ..., edge: Queryable[int] = ..., editPoint: Queryable[int] = ..., emitter: Queryable[int] = ..., facet: Queryable[int] = ..., field: Queryable[int] = ..., fluid: Queryable[int] = ..., follicle: Queryable[int] = ..., hairSystem: Queryable[int] = ..., handle: Queryable[int] = ..., hull: Queryable[int] = ..., ikEndEffector: Queryable[int] = ..., ikHandle: Queryable[int] = ..., imagePlane: Queryable[int] = ..., implicitGeometry: Queryable[int] = ..., isoparm: Queryable[int] = ..., joint: Queryable[int] = ..., jointPivot: Queryable[int] = ..., lattice: Queryable[int] = ..., latticePoint: Queryable[int] = ..., light: Queryable[int] = ..., localRotationAxis: Queryable[int] = ..., locator: Queryable[int] = ..., locatorUV: Queryable[int] = ..., locatorXYZ: Queryable[int] = ..., meshUVShell: Queryable[int] = ..., motionTrailPoint: Queryable[int] = ..., motionTrailTangent: Queryable[int] = ..., nCloth: Queryable[int] = ..., nParticle: Queryable[int] = ..., nParticleShape: Queryable[int] = ..., nRigid: Queryable[int] = ..., nonlinear: Queryable[int] = ..., nurbsCurve: Queryable[int] = ..., nurbsSurface: Queryable[int] = ..., orientationLocator: Queryable[int] = ..., particle: Queryable[int] = ..., particleShape: Queryable[int] = ..., plane: Queryable[int] = ..., polymesh: Queryable[int] = ..., polymeshEdge: Queryable[int] = ..., polymeshFace: Queryable[int] = ..., polymeshFreeEdge: Queryable[int] = ..., polymeshUV: Queryable[int] = ..., polymeshVertex: Queryable[int] = ..., polymeshVtxFace: Queryable[int] = ..., queryByName: str = ..., rigidBody: Queryable[int] = ..., rigidConstraint: Queryable[int] = ..., rotatePivot: Queryable[int] = ..., scalePivot: Queryable[int] = ..., sculpt: Queryable[int] = ..., selectHandle: Queryable[int] = ..., spring: Queryable[int] = ..., springComponent: Queryable[int] = ..., stroke: Queryable[int] = ..., subdiv: Queryable[int] = ..., subdivMeshEdge: Queryable[int] = ..., subdivMeshFace: Queryable[int] = ..., subdivMeshPoint: Queryable[int] = ..., subdivMeshUV: Queryable[int] = ..., surfaceEdge: Queryable[int] = ..., surfaceFace: Queryable[int] = ..., surfaceKnot: Queryable[int] = ..., surfaceParameterPoint: Queryable[int] = ..., surfaceRange: Queryable[int] = ..., texture: Queryable[int] = ..., vertex: Queryable[int] = ...) -> int:
    """Thecommand is used to change the selection
    priority of particular types of objects that can be selected when using
    the select tool. It accepts no other arguments besides the flags.
    These flags are the same as used by the 'selectType' command.
    Args:
        allComponents (Queryable[int]?): Set all component selection priority  
                Properties: create, query
        allObjects (Queryable[int]?): Set all object selection priority  
                Properties: create, query
        animBreakdown (Queryable[int]?): Set animation breakdown selection priority  
                Properties: create, query
        animCurve (Queryable[int]?): Set animation curve selection priority  
                Properties: create, query
        animInTangent (Queryable[int]?): Set animation in-tangent selection priority  
                Properties: create, query
        animKeyframe (Queryable[int]?): Set animation keyframe selection priority  
                Properties: create, query
        animOutTangent (Queryable[int]?): Set animation out-tangent selection priority  
                Properties: create, query
        byName (Multiuse[Tuple[str, bool]]?): Set selection priority for the specified user-defined selection type  
                Properties: create, multiuse
        camera (Queryable[int]?): Set camera selection priority  
                Properties: create, query
        cluster (Queryable[int]?): Set cluster selection priority  
                Properties: create, query
        collisionModel (Queryable[int]?): Set collision model selection priority  
                Properties: create, query
        controlVertex (Queryable[int]?): Set control vertex selection priority  
                Properties: create, query
        curve (Queryable[int]?): Set curve selection priority  
                Properties: create, query
        curveKnot (Queryable[int]?): Set curve knot selection priority  
                Properties: create, query
        curveOnSurface (Queryable[int]?): Set curve-on-surface selection priority  
                Properties: create, query
        curveParameterPoint (Queryable[int]?): Set curve parameter point selection priority  
                Properties: create, query
        dimension (Queryable[int]?): Set dimension shape selection priority  
                Properties: create, query
        dynamicConstraint (Queryable[int]?): Set dynamicConstraint selection priority  
                Properties: create, query
        edge (Queryable[int]?): Set mesh edge selection priority  
                Properties: create, query
        editPoint (Queryable[int]?): Set edit-point selection priority  
                Properties: create, query
        emitter (Queryable[int]?): Set emitter selection priority  
                Properties: create, query
        facet (Queryable[int]?): Set mesh face selection priority  
                Properties: create, query
        field (Queryable[int]?): Set field selection priority  
                Properties: create, query
        fluid (Queryable[int]?): Set fluid selection priority  
                Properties: create, query
        follicle (Queryable[int]?): Set follicle selection priority  
                Properties: create, query
        hairSystem (Queryable[int]?): Set hairSystem selection priority  
                Properties: create, query
        handle (Queryable[int]?): Set object handle selection priority  
                Properties: create, query
        hull (Queryable[int]?): Set hull selection priority  
                Properties: create, query
        ikEndEffector (Queryable[int]?): Set ik end effector selection priority  
                Properties: create, query
        ikHandle (Queryable[int]?): Set ik handle selection priority  
                Properties: create, query
        imagePlane (Queryable[int]?): Set image plane selection mask priority  
                Properties: create, query
        implicitGeometry (Queryable[int]?): Set implicit geometry selection priority  
                Properties: create, query
        isoparm (Queryable[int]?): Set surface iso-parm selection priority  
                Properties: create, query
        joint (Queryable[int]?): Set ik handle selection priority  
                Properties: create, query
        jointPivot (Queryable[int]?): Set joint pivot selection priority  
                Properties: create, query
        lattice (Queryable[int]?): Set lattice selection priority  
                Properties: create, query
        latticePoint (Queryable[int]?): Set lattice point selection priority  
                Properties: create, query
        light (Queryable[int]?): Set light selection priority  
                Properties: create, query
        localRotationAxis (Queryable[int]?): Set local rotation axis selection priority  
                Properties: create, query
        locator (Queryable[int]?): Set locator (all types) selection priority  
                Properties: create, query
        locatorUV (Queryable[int]?): Set uv locator selection priority  
                Properties: create, query
        locatorXYZ (Queryable[int]?): Set xyz locator selection priority  
                Properties: create, query
        meshUVShell (Queryable[int]?): Set uv shell component mask on/off.  
                Properties: create, query
        motionTrailPoint (Queryable[int]?): Set motion point selection priority  
                Properties: create, query
        motionTrailTangent (Queryable[int]?): Set motion point tangent priority  
                Properties: create, query
        nCloth (Queryable[int]?): Set nCloth selection priority  
                Properties: create, query
        nParticle (Queryable[int]?): Set nParticle point selection priority  
                Properties: create, query
        nParticleShape (Queryable[int]?): Set nParticle shape selection priority  
                Properties: create, query
        nRigid (Queryable[int]?): Set nRigid selection priority  
                Properties: create, query
        nonlinear (Queryable[int]?): Set nonlinear selection priority  
                Properties: create, query
        nurbsCurve (Queryable[int]?): Set nurbs-curve selection priority  
                Properties: create, query
        nurbsSurface (Queryable[int]?): Set nurbs-surface selection priority  
                Properties: create, query
        orientationLocator (Queryable[int]?): Set orientation locator selection priority  
                Properties: create, query
        particle (Queryable[int]?): Set particle point selection priority  
                Properties: create, query
        particleShape (Queryable[int]?): Set particle shape selection priority  
                Properties: create, query
        plane (Queryable[int]?): Set sketch plane selection priority  
                Properties: create, query
        polymesh (Queryable[int]?): Set poly-mesh selection priority  
                Properties: create, query
        polymeshEdge (Queryable[int]?): Set poly-mesh edge selection priority  
                Properties: create, query
        polymeshFace (Queryable[int]?): Set poly-mesh face selection priority  
                Properties: create, query
        polymeshFreeEdge (Queryable[int]?): Set poly-mesh free-edge selection priority  
                Properties: create, query
        polymeshUV (Queryable[int]?): Set poly-mesh UV point selection priority  
                Properties: create, query
        polymeshVertex (Queryable[int]?): Set poly-mesh vertex selection priority  
                Properties: create, query
        polymeshVtxFace (Queryable[int]?): Set poly-mesh vtxFace selection priority  
                Properties: create, query
        queryByName (str?): Query selection priority for the specified user-defined selection type  
                      In query mode, this flag needs a value.  
                Properties: query
        rigidBody (Queryable[int]?): Set rigid body selection priority  
                Properties: create, query
        rigidConstraint (Queryable[int]?): Set rigid constraint selection priority  
                Properties: create, query
        rotatePivot (Queryable[int]?): Set rotate pivot selection priority  
                Properties: create, query
        scalePivot (Queryable[int]?): Set scale pivot selection priority  
                Properties: create, query
        sculpt (Queryable[int]?): Set sculpt selection priority  
                Properties: create, query
        selectHandle (Queryable[int]?): Set select handle selection priority  
                Properties: create, query
        spring (Queryable[int]?): Set spring shape selection priority  
                Properties: create, query
        springComponent (Queryable[int]?): Set individual spring selection priority  
                Properties: create, query
        stroke (Queryable[int]?): Set stroke selection priority  
                Properties: create, query
        subdiv (Queryable[int]?): Set subdivision surface selection priority  
                Properties: create, query
        subdivMeshEdge (Queryable[int]?): Set subdivision surface mesh edge selection priority  
                Properties: create, query
        subdivMeshFace (Queryable[int]?): Set subdivision surface mesh face selection priority  
                Properties: create, query
        subdivMeshPoint (Queryable[int]?): Set subdivision surface mesh point selection priority  
                Properties: create, query
        subdivMeshUV (Queryable[int]?): Set subdivision surface mesh UV map selection priority  
                Properties: create, query
        surfaceEdge (Queryable[int]?): Set surface edge selection priority  
                Properties: create, query
        surfaceFace (Queryable[int]?): Set surface face selection priority  
                Properties: create, query
        surfaceKnot (Queryable[int]?): Set surface knot selection priority  
                Properties: create, query
        surfaceParameterPoint (Queryable[int]?): Set surface parameter point selection priority  
                Properties: create, query
        surfaceRange (Queryable[int]?): Set surface range selection priority  
                Properties: create, query
        texture (Queryable[int]?): Set texture selection priority  
                Properties: create, query
        vertex (Queryable[int]?): Set mesh vertex selection priority  
                Properties: create, query

    Returns:
        int: if a query operation

    Example:
    """

def selectType(*, query: bool = ..., allComponents: bool = ..., allObjects: bool = ..., animBreakdown: bool = ..., animCurve: bool = ..., animInTangent: bool = ..., animKeyframe: bool = ..., animOutTangent: bool = ..., byName: Multiuse[Tuple[str, bool]] = ..., camera: bool = ..., cluster: bool = ..., collisionModel: bool = ..., controlVertex: bool = ..., curve: bool = ..., curveKnot: bool = ..., curveOnSurface: bool = ..., curveParameterPoint: bool = ..., dimension: bool = ..., dynamicConstraint: bool = ..., edge: bool = ..., editPoint: bool = ..., emitter: bool = ..., facet: bool = ..., field: bool = ..., fluid: bool = ..., follicle: bool = ..., hairSystem: bool = ..., handle: bool = ..., hull: bool = ..., ikEndEffector: bool = ..., ikHandle: bool = ..., imagePlane: bool = ..., implicitGeometry: bool = ..., isoparm: bool = ..., joint: bool = ..., jointPivot: bool = ..., lattice: bool = ..., latticePoint: bool = ..., light: bool = ..., localRotationAxis: bool = ..., locator: bool = ..., locatorUV: bool = ..., locatorXYZ: bool = ..., meshUVShell: bool = ..., motionTrailPoint: bool = ..., motionTrailTangent: bool = ..., nCloth: bool = ..., nParticle: bool = ..., nParticleShape: bool = ..., nRigid: bool = ..., nonlinear: bool = ..., nurbsCurve: bool = ..., nurbsSurface: bool = ..., objectComponent: bool = ..., orientationLocator: bool = ..., particle: bool = ..., particleShape: bool = ..., plane: bool = ..., polymesh: bool = ..., polymeshEdge: bool = ..., polymeshFace: bool = ..., polymeshFreeEdge: bool = ..., polymeshUV: bool = ..., polymeshVertex: bool = ..., polymeshVtxFace: bool = ..., queryByName: str = ..., rigidBody: bool = ..., rigidConstraint: bool = ..., rotatePivot: bool = ..., scalePivot: bool = ..., sculpt: bool = ..., selectHandle: bool = ..., spring: bool = ..., springComponent: bool = ..., stroke: bool = ..., subdiv: bool = ..., subdivMeshEdge: bool = ..., subdivMeshFace: bool = ..., subdivMeshPoint: bool = ..., subdivMeshUV: bool = ..., surfaceEdge: bool = ..., surfaceFace: bool = ..., surfaceKnot: bool = ..., surfaceParameterPoint: bool = ..., surfaceRange: bool = ..., surfaceUV: bool = ..., texture: bool = ..., vertex: bool = ...) -> bool:
    """Thecommand is used to change the set of
    allowable types of objects that can be selected when using
    the select tool. It accepts no other arguments besides the flags.There are basically two different types of items that are selectable
    when interactively selecting objects in the 3D views.  They are
    classified as objects (entire objects) or components (parts of
    objects).  Theandcommand flags
    control which class of objects are selectable.It is possible to select components while in the object selection mode.
    To set the components which are selectable in object
    selection mode you must use the -ocm flag when specifying the component
    flags.
    Args:
        allComponents (bool?): Set all component selection masks on/off  
                Properties: create, query
        allObjects (bool?): Set all object selection masks on/off  
                Properties: create, query
        animBreakdown (bool?): Set animation breakdown selection mask on/off.  
                Properties: create, query
        animCurve (bool?): Set animation curve selection mask on/off.  
                Properties: create, query
        animInTangent (bool?): Set animation in-tangent selection mask on/off.  
                Properties: create, query
        animKeyframe (bool?): Set animation keyframe selection mask on/off.  
                Properties: create, query
        animOutTangent (bool?): Set animation out-tangent selection mask on/off.  
                Properties: create, query
        byName (Multiuse[Tuple[str, bool]]?): Set the specified user-defined selection mask on/off. (object flag)  
                Properties: create, multiuse
        camera (bool?): Set camera selection mask on/off. (object flag)  
                Properties: create, query
        cluster (bool?): Set cluster selection mask on/off. (object flag)  
                Properties: create, query
        collisionModel (bool?): Set collision model selection mask on/off. (object flag)  
                Properties: create, query
        controlVertex (bool?): Set control vertex selection mask on/off. (component flag)  
                Properties: create, query
        curve (bool?): Set curve selection mask on/off. (object flag)  
                Properties: create, query
        curveKnot (bool?): Set curve knot selection mask on/off. (component flag)  
                Properties: create, query
        curveOnSurface (bool?): Set curve-on-surface selection mask on/off. (object flag)  
                Properties: create, query
        curveParameterPoint (bool?): Set curve parameter point selection mask on/off. (component flag)  
                Properties: create, query
        dimension (bool?): Set dimension shape selection mask on/off. (object flag)  
                Properties: create, query
        dynamicConstraint (bool?): Set dynamicConstraint selection mask on/off. (object flag)  
                Properties: create, query
        edge (bool?): Set mesh edge selection mask on/off. (component flag)  
                Properties: create, query
        editPoint (bool?): Set edit-point selection mask on/off. (component flag)  
                Properties: create, query
        emitter (bool?): Set emitter selection mask on/off. (object flag)  
                Properties: create, query
        facet (bool?): Set mesh face selection mask on/off. (component flag)  
                Properties: create, query
        field (bool?): Set field selection mask on/off. (object flag)  
                Properties: create, query
        fluid (bool?): Set fluid selection mask on/off. (object flag)  
                Properties: create, query
        follicle (bool?): Set follicle selection mask on/off. (object flag)  
                Properties: create, query
        hairSystem (bool?): Set hairSystem selection mask on/off. (object flag)  
                Properties: create, query
        handle (bool?): Set object handle selection mask on/off. (object flag)  
                Properties: create, query
        hull (bool?): Set hull selection mask on/off. (component flag)  
                Properties: create, query
        ikEndEffector (bool?): Set ik end effector selection mask on/off. (object flag)  
                Properties: create, query
        ikHandle (bool?): Set ik handle selection mask on/off. (object flag)  
                Properties: create, query
        imagePlane (bool?): Set image plane selection mask on/off. (component flag)  
                Properties: create, query
        implicitGeometry (bool?): Set implicit geometry selection mask on/off. (object flag)  
                Properties: create, query
        isoparm (bool?): Set surface iso-parm selection mask on/off. (component flag)  
                Properties: create, query
        joint (bool?): Set ik handle selection mask on/off. (object flag)  
                Properties: create, query
        jointPivot (bool?): Set joint pivot selection mask on/off. (component flag)  
                Properties: create, query
        lattice (bool?): Set lattice selection mask on/off. (object flag)  
                Properties: create, query
        latticePoint (bool?): Set lattice point selection mask on/off. (component flag)  
                Properties: create, query
        light (bool?): Set light selection mask on/off. (object flag)  
                Properties: create, query
        localRotationAxis (bool?): Set local rotation axis selection mask on/off. (component flag)  
                Properties: create, query
        locator (bool?): Set locator (all types) selection mask on/off. (object flag)  
                Properties: create, query
        locatorUV (bool?): Set uv locator selection mask on/off. (object flag)  
                Properties: create, query
        locatorXYZ (bool?): Set xyz locator selection mask on/off. (object flag)  
                Properties: create, query
        meshUVShell (bool?): Set uv shell component mask on/off.  
                Properties: create, query
        motionTrailPoint (bool?): Set motion point selection mask on/off.  
                Properties: create, query
        motionTrailTangent (bool?): Set motion point tangent mask on/off.  
                Properties: create, query
        nCloth (bool?): Set nCloth selection mask on/off. (object flag)  
                Properties: create, query
        nParticle (bool?): Set nParticle point selection mask on/off. (component flag)  
                Properties: create, query
        nParticleShape (bool?): Set nParticle shape selection mask on/off. (object flag)  
                Properties: create, query
        nRigid (bool?): Set nRigid selection mask on/off. (object flag)  
                Properties: create, query
        nonlinear (bool?): Set nonlinear selection mask on/off. (object flag)  
                Properties: create, query
        nurbsCurve (bool?): Set nurbs-curve selection mask on/off. (object flag)  
                Properties: create, query
        nurbsSurface (bool?): Set nurbs-surface selection mask on/off. (object flag)  
                Properties: create, query
        objectComponent (bool?): Component flags apply to object mode.  
                Properties: create, query
        orientationLocator (bool?): Set orientation locator selection mask on/off. (object flag)  
                Properties: create, query
        particle (bool?): Set particle point selection mask on/off. (component flag)  
                Properties: create, query
        particleShape (bool?): Set particle shape selection mask on/off. (object flag)  
                Properties: create, query
        plane (bool?): Set sketch plane selection mask on/off. (object flag)  
                Properties: create, query
        polymesh (bool?): Set poly-mesh selection mask on/off. (object flag)  
                Properties: create, query
        polymeshEdge (bool?): Set poly-mesh edge selection mask on/off. (component flag)  
                Properties: create, query
        polymeshFace (bool?): Set poly-mesh face selection mask on/off. (component flag)  
                Properties: create, query
        polymeshFreeEdge (bool?): Set poly-mesh free-edge selection mask on/off. (component flag)  
                Properties: create, query
        polymeshUV (bool?): Set poly-mesh UV point selection mask on/off. (component flag)  
                Properties: create, query
        polymeshVertex (bool?): Set poly-mesh vertex selection mask on/off. (component flag)  
                Properties: create, query
        polymeshVtxFace (bool?): Set poly-mesh vertexFace selection mask on/off. (component flag)  
                Properties: create, query
        queryByName (str?): Query the specified user-defined selection mask. (object flag)  
                      In query mode, this flag needs a value.  
                Properties: query
        rigidBody (bool?): Set rigid body selection mask on/off. (object flag)  
                Properties: create, query
        rigidConstraint (bool?): Set rigid constraint selection mask on/off. (object flag)  
                Properties: create, query
        rotatePivot (bool?): Set rotate pivot selection mask on/off. (component flag)  
                Properties: create, query
        scalePivot (bool?): Set scale pivot selection mask on/off. (component flag)  
                Properties: create, query
        sculpt (bool?): Set sculpt selection mask on/off. (object flag)  
                Properties: create, query
        selectHandle (bool?): Set select handle selection mask on/off. (component flag)  
                Properties: create, query
        spring (bool?): Set spring shape selection mask on/off. (object flag)  
                Properties: create, query
        springComponent (bool?): Set individual spring selection mask on/off. (component flag)  
                Properties: create, query
        stroke (bool?): Set the Paint Effects stroke selection mask on/off. (object flag)  
                Properties: create, query
        subdiv (bool?): Set subdivision surfaces selection mask on/off. (object flag)  
                Properties: create, query
        subdivMeshEdge (bool?): Set subdivision surfaces mesh edge selection mask on/off. (component flag)  
                Properties: create, query
        subdivMeshFace (bool?): Set subdivision surfaces mesh face selection mask on/off. (component flag)  
                Properties: create, query
        subdivMeshPoint (bool?): Set subdivision surfaces mesh point selection mask on/off. (component flag)  
                Properties: create, query
        subdivMeshUV (bool?): Set subdivision surfaces mesh UV map selection mask on/off. (component flag)  
                Properties: create, query
        surfaceEdge (bool?): Set surface edge selection mask on/off. (component flag)  
                Properties: create, query
        surfaceFace (bool?): Set surface face selection mask on/off. (component flag)  
                Properties: create, query
        surfaceKnot (bool?): Set surface knot selection mask on/off. (component flag)  
                Properties: create, query
        surfaceParameterPoint (bool?): Set surface parameter point selection mask on/off. (component flag)  
                Properties: create, query
        surfaceRange (bool?): Set surface range selection mask on/off. (component flag)  
                Properties: create, query
        surfaceUV (bool?): Set surface uv selection mask on/off. (component flag)  
                Properties: create, query
        texture (bool?): Set texture selection mask on/off. (object flag)  
                Properties: create, query
        vertex (bool?): Set mesh vertex selection mask on/off. (component flag)  
                Properties: create, query

    Returns:
        bool: if a query operation

    Example:
    """

def selectedNodes() -> None:
    """This command is obsolete now.In MEL, useinstead.In Python, use"""

def selectionConnection(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeCacheList: bool = ..., activeCharacterList: bool = ..., activeList: bool = ..., addScript: Queryable[Callable[..., Any]] = ..., addTo: str = ..., characterList: bool = ..., clear: bool = ..., connectionList: bool = ..., defineTemplate: str = ..., deselect: str = ..., editor: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., findObject: Queryable[str] = ..., g: bool = ..., highlightList: bool = ..., identify: bool = ..., keyframeList: bool = ..., lock: bool = ..., modelList: bool = ..., object: Queryable[str] = ..., parent: Queryable[str] = ..., remove: str = ..., removeScript: Queryable[Callable[..., Any]] = ..., select: str = ..., setList: bool = ..., switch: bool = ..., useTemplate: str = ..., worldList: bool = ...) -> Union[str, Callable[..., Any], bool]:
    """This command creates a named selectionConnection object. This object
    is simply a shared selection list. It may be used by editors to
    share their highlight data. For example, an outliner may attach its
    selected list to one of these objects, and a graph editor may use the
    same object as a list source. Then, the graph editor would only
    display objects that are selected in the outliner.Selection connections are UI objects which contain a list of model
    objects. Selection connections are useful for specifying which objects
    are to be displayed within a particular editor. Editor's have threewhere a selection connection may be attached.
    They are:There are several different types of selection connections that may be
    created. They include:Below is an example selectionConnection network between two
    editors. Editor 1 is setup to display objects on the activeList.
    Editor 2 is setup to display objects which are selected within Editor
    1, and objects that are selected in Editor 2 are highlighted within
    Editor 1:The following commands will establish this network:Note: to delete ause the deleteUI commandNote: commands which expect objects may be given a selection connection
    instead, and the command will operate upon the objects wrapped by the
    selection connectionNote: the graph editor and the dope sheet are the only editors which can use the
    editor connection to the highlightConnection of another editorWARNING: some flag combinations may not behave as you expect.  The command
    is really intended for internal use for managing the outliner used by
    the various editors.
    Args:
        activeCacheList (bool?): Specifies that this connection should reflect the cache that objects  
                on the active list belong to.  
                Properties: create
        activeCharacterList (bool?): Specifies that this connection should reflect the characters that objects  
                on the active list belong to.  
                Properties: create
        activeList (bool?): Specifies that this connection should reflect the active  
                list (geometry objects and keys).  
                Properties: create
        addScript (Queryable[Callable[..., Any]]?): Specify a script to be called when something is added to the  
                selection.  
                Properties: create, query, edit
        addTo (str?): The name of a selection connection that should be added to this  
                list of connections.  
                Properties: create, edit
        characterList (bool?): Specifies that this connection should reflect all the characters in  
                the world.  
                Properties: create
        clear (bool?): Remove everything from the selection connection.  
                Properties: create, edit
        connectionList (bool?): Specifies that this connection should contain a list of selection  
                connections.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deselect (str?): Remove something from the selection.  
                Properties: create, edit
        editor (Queryable[str]?): Specifies that this connection should reflect the -mainListConnection  
                of the specified editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Optionally specifies an itemFilter for this connection.  
                An empty string ("") clears the current filter.  
                If a filter is specified, all the information going into  
                the selectionConnection must first pass through the filter  
                before being accepted.  
              
                NOTE: filters can only be attached to regular selectionConnections.  
                They cannot be attached to any connection created using  
                the -act, -mdl, -key, -wl, -sl, -cl, -lst, -obj, or -ren flags.  
                We strongly recommend that you do not attach filters to a  
                selectionConnection --- it is better to attach your filter  
                to the editor that is using the selectionConnection instead.  
                Properties: create, query, edit
        findObject (Queryable[str]?): Find a selection connection in this list that wraps the specified  
                object.  
                Properties: query
        g (bool?): A global selection connection cannot be deleted by any script  
                commands.  
                Properties: create, query, edit
        highlightList (bool?): Specifies that this connection is being used as a highlight list.  
                Properties: create
        identify (bool?): Find out what type of selection connection this is.  May be:  
                activeList | modelList | keyframeList | worldList | objectList  
                listList | editorList | connection | unknown  
                Properties: query
        keyframeList (bool?): Specifies that this connection should reflect the animation  
                portion of the active list.  
                Properties: create
        lock (bool?): For activeList connections, locking the connection means that  
                it will not listen to activeList changes.  
                Properties: create, query, edit
        modelList (bool?): Specifies that this connection should reflect the modeling  
                (i.e. excluding keys) portion of the active list.  
                Properties: create
        object (Queryable[str]?): Specifies that this connection should wrap around the specified  
                object (which may be a set).  Query will return all the members of the  
                selection connection (if the connection wraps a set, the set members will  
                be returned)  
                Properties: create, query, edit
        parent (Queryable[str]?): The name of a UI object this should be attached to.  When the  
                parent is destroyed, the selectionConnection will auto-delete.  
                If no parent is specified, the connection is created in the  
                current controlLayout.  
                Properties: create, query, edit
        remove (str?): The name of a selection connection that should be removed from  
                this list of connections.  
                Properties: create, edit
        removeScript (Queryable[Callable[..., Any]]?): Specify a script to be called when something is removed from  
                the selection.  
                Properties: create, query, edit
        select (str?): Add something to the selection. This does not replace the  
                existing selection.  
                Properties: create, edit
        setList (bool?): Specifies that this connection should reflect all the sets in  
                the world.  
                Properties: create
        switch (bool?): Acts as a modifier to -connectionList which sets the list of objects  
                to be the first non-empty selection connection.  selection connections  
                are tested in the order in which they are added.  
                Properties: create, query
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        worldList (bool?): Specifies that this connection should reflect all objects  
                in the world.  
                Properties: create

    Returns:
        str: Value of the queried flag

    Example:
    """

def separator(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a separator widget in a variety of drawing styles.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Specify the orientation of the separator.  True for  
                horizontal and false for vertical.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): Specify the style of the separator.  Valid values are  
                "none", "single", "in", "out" and "shelf".  Note: the values  
                "double", "singleDash" and "doubleDash" and no longer  
                supported.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def sequenceManager(*, edit: bool = ..., query: bool = ..., addSequencerAudio: str = ..., attachSequencerAudio: str = ..., currentShot: Queryable[str] = ..., currentTime: Queryable[int] = ..., listSequencerAudio: str = ..., listShots: bool = ..., modelPanel: Queryable[str] = ..., node: Queryable[str] = ..., writableSequencer: Queryable[str] = ...) -> Union[bool, str, int]:
    """The sequenceManager command manages sequences, shots, and their related scenes.shot, sequence
    Args:
        addSequencerAudio (str?): Add an audio clip to the sequencer by specifying a filename  
                Properties: create
        attachSequencerAudio (str?): Add an audio clip to the sequencer by specifying an audio node  
                Properties: create
        currentShot (Queryable[str]?): Returns the shot that is being used at the current sequence time.  
                Properties: query
        currentTime (Queryable[int]?): Set the current sequence time  
                Properties: create, query
        listSequencerAudio (str?): List the audio clips added to the sequencer  
                Properties: create
        listShots (bool?): List all the currently defined shots across all scene segments  
                Properties: create
        modelPanel (Queryable[str]?): Sets a dedicated modelPanel to be used as the panel that the sequencer will control.  
                Properties: create, query
        node (Queryable[str]?): Returns the SequenceManager node, of which there is only ever one.  
                Properties: query
        writableSequencer (Queryable[str]?): Get the writable sequencer node.  Create it if it doesn't exist.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def setAttr(*args: str, edit: bool = ..., query: bool = ..., alteredValue: bool = ..., caching: bool = ..., capacityHint: int = ..., channelBox: bool = ..., clamp: bool = ..., keyable: bool = ..., lock: bool = ..., size: int = ..., type: str = ...) -> bool:
    """Sets the value of a dependency node attribute.  No value for
    the attribute is needed when theflags are used.
    Theflag is only required when setting a non-numeric attribute.For Ufe attributes, the input attribute string should be
    "<ufe_path_string>.<ufe_attribute_name>".The following chart outlines the syntax of setAttr for non-numeric
    data types:In order to run its examples, first execute these commands to
    create the sample attribute types:
    Args:
        alteredValue (bool?): The value is only the current value, which may change in the  
                next evalution (if the attribute has an incoming connection).  
                This flag is only used during file I/O, so that attributes  
                with incoming connections do not have their data overwritten  
                during the first evaluation after a file is opened.  
                Not supported for Ufe attributes.  
                Properties: create
        caching (bool?): Sets the attribute's internal caching on or off. Not all attributes  
                can be defined as caching. Only those attributes that are not defined  
                by default to be cached can be made caching.  As well, multi attribute  
                elements cannot be made caching. Caching also affects child attributes  
                for compound attributes.  
                Not supported for Ufe attributes.  
                Properties: create
        capacityHint (int?): Used to provide a memory allocation hint to attributes  
                where the -size flag cannot provide enough information.  
                This flag is optional and is primarily intended to be  
                used during file I/O.  
                Only certain attributes make use of this flag, and  
                the interpretation of the flag value varies per attribute.  
                Not supported for Ufe attributes.  
                This flag is currently used by (node.attribute):  
              
                mesh.face - hints the total number of elements in the face edge lists  
                Properties: create
        channelBox (bool?): Sets the attribute's display in the channelBox on or off.  
                Keyable attributes are always display in the channelBox regardless of  
                the channelBox settting.  
                Not supported for Ufe attributes. The display of Ufe attributes in  
                the Channel Box is controlled using the channelBox command flag  
                -ual/ufeFixedAttrList.  
                Properties: create
        clamp (bool?): For numeric attributes, if the value is outside the  
                range of the attribute, clamp it to the min or max instead  
                of failing.  
                Not supported for Ufe attributes.  
                Properties: create
        keyable (bool?): Sets the attribute's keyable state on or off.  
                Not supported for Ufe attributes.  
                Properties: create
        lock (bool?): Sets the attribute's lock state on or off.  
                Properties: create
        size (int?): Defines the size of a multi-attribute array. This is only a hint,  
                used to help allocate memory as efficiently as possible.  
                Not supported for Ufe attributes.  
                Properties: create
        type (str?): Identifies the type of data.  If the -type flag  
                is not present, a numeric type is assumed.  
                Not supported for Ufe attributes.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def setAttrMapping(*args: Any, query: bool = ..., absolute: bool = ..., attribute: Multiuse[str] = ..., axis: str = ..., clutch: str = ..., device: str = ..., offset: float = ..., relative: bool = ..., scale: float = ..., selection: bool = ...) -> bool:
    """This command applies an offset and scale to a specified device
    attachment. This command is different than the setInputDeviceMapping
    command, which applies a mapping to a device axis.The value from the device is multiplied by the scale and the
    offset is added to this product. With an absolute mapping, the
    attached attribute gets the resulting value. If the mapping is
    relative, the resulting value is added to the previous calculated
    value. The calculated value will also take into account the
    setInputDeviceMapping, if it was defined.As an example, if the space ball is setup with absolute attachment
    mappings, pressing in one direction will cause the
    attached attribute to get a constant value. If a relative mapping
    is used, and the spaceball is pressed in one direction, the
    attached attribute will get a constantly increasing (or constantly
    decreasing) value.Note that the definition of relative is different than the definition
    used by the setInputDeviceMapping command. In general, both
    a relative attachment mapping (this command) and a relative
    device mapping (setInputDeviceMapping) should not be used together
    one the same axis.
    Args:
        absolute (bool?): Make the mapping absolute.  
                Properties: create
        attribute (Multiuse[str]?): The attribute used in the attachment.  
                Properties: create, multiuse
        axis (str?): The axis on the device used in the attachment.  
                Properties: create
        clutch (str?): The clutch button used in the attachment.  
                Properties: create
        device (str?): The device used in the attachment.  
                Properties: create
        offset (float?): Specify the offset value.  
                Properties: create
        relative (bool?): Make the mapping relative.  
                Properties: create
        scale (float?): Specify the scale value.  
                Properties: create
        selection (bool?): This flag specifies the mapping should be on the selected  
                objects  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def setDefaultShadingGroup(arg0: str = ..., /) -> bool:
    """The setDefaultShadingGroup command is used to change which shading
    group is considered the current default shading group. Subsequently
    created objects will be assigned to the new default group.
    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def setDrivenKeyframe(*args: str, edit: bool = ..., query: bool = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., count: bool = ..., currentDriver: Queryable[str] = ..., driven: bool = ..., driver: bool = ..., driverValue: Multiuse[float] = ..., hierarchy: str = ..., inTangentType: str = ..., insert: bool = ..., insertBlend: bool = ..., outTangentType: str = ..., shape: bool = ..., value: float = ...) -> Union[int, bool, str]:
    """This command sets a driven keyframe.  A driven keyframe is similar
    to a regular keyframe. However, while a standard keyframe always has
    an x-axis of time in the graph editor, for a drivenkeyframe the
    user may choose any attribute as the x-axis of the graph editor.For example, you can keyframe the emission of a faucet so that
    so that it emits whenever the faucet handle is rotated around y.
    The faucet emission in this example is called the driven attribute.
    The handle rotation is called the driver. Once you have used
    setDrivenKeyframe to set up the relationship between the emission
    and the rotation, you can go to the graph editor and modify the
    relationship between the attributes just as you would modify the
    animation curve on any keyframed object.In the case of an attribute driven by a single driver, the
    dependency graph is connected like this:driver attribute ---> animCurve ---> driven attributeYou can set driven keyframes with more than a single driver.
    The effects of the multiple drivers are combined together by
    a blend node.
    Args:
        attribute (Multiuse[str]?): Attribute name to set keyframes on.  
                Properties: create, multiuse
        controlPoints (bool?): Explicitly specify whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  
                Properties: create
        count (bool?): Returns the count of driven/drivers attributes for the selected item  
                instead of the names  
                Properties: query
        currentDriver (Queryable[str]?): Set the driver to be used for the current driven keyframe to the  
                attribute passed as an argument.  
                Properties: create, query
        driven (bool?): Returns list of driven attributes for the selected item.  
                Properties: query
        driver (bool?): Returns list of available drivers for the attribute.  
                Properties: query
        driverValue (Multiuse[float]?): Value of the driver to use for this keyframe.  
                Default value is the current value.  
                Properties: create, multiuse
        hierarchy (str?): Controls the objects this command acts on, relative to the specified  
                (or active) target objects.  
                Valid values are "above," "below," "both," and "none."  
                Default is "hierarchy -query"  
                Properties: create
        inTangentType (str?): The in tangent type for keyframes set by this command.  
                Valid values are: "auto", clamped", "fast", "flat", "linear", "plateau", "slow", "spline", and "stepnext"  
                Default is "keyTangent -q -g -inTangentType"  
                Properties: create
        insert (bool?): Insert keys at the given time(s) and preserve  
                the shape of the animation curve(s). Note: the tangent  
                type on inserted keys will be fixed so that the  
                curve shape can be preserved.  
                Properties: create
        insertBlend (bool?): If true, a pairBlend node will be inserted for channels that have  
                nodes other than animCurves driving them, so that such channels can  
                have blended animation. If false, these channels will not have keys  
                inserted. If the flag is not specified, the blend will be inserted based  
                on the global preference for blending animation.  
                Properties: create
        outTangentType (str?): The out tangent type for keyframes set by this command.  
                Valid values are: "auto", "clamped", "fast", "flat", "linear", "plateau", "slow", "spline", "step", and "stepnext".  
                Default is "keyTangent -q -g -outTangentType"  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true  
                Properties: create
        value (float?): Value to set the keyframe at. Default is the current value.  
                Properties: create

    Returns:
        int: Number of keyframes set.

    Example:
    """

def setDynStartState() -> None: ...
def setDynamic(*args: str, allOnWhenRun: bool = ..., disableAllOnWhenRun: bool = ..., setAll: bool = ..., setOff: bool = ..., setOn: bool = ...) -> str:
    """setDynamic sets the isDynamic attribute of particle objects
    on or off.  If no objects are specified, it sets the
    attribute for any selected objects.  If -all is thrown, it
    sets the attribute for all particle objects in the scene.
    By default it sets the attribute true (on); if the -off flag is
    thrown, it sets the attribute false (off).WARNING: setDynamic is obsolescent.  This is the last version of
    Maya in which it will be supported.
    Args:
        allOnWhenRun (bool?): Obsolete, no longer suppported or necessary.  
                Properties: create
        disableAllOnWhenRun (bool?): Obsolete, no longer suppported or necessary.  
                Properties: create
        setAll (bool?): Set for all objects.  
                Properties: create
        setOff (bool?): Sets isDynamic false.  
                Properties: create
        setOn (bool?): Sets isDynamic true.  This flag is set by default.  
                Properties: create

    Returns:
        str: array

    Example:
    """

def setEditCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command creates a tool that can be used to
    modify set membership.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: The name of the context

    Example:
    """

def setFluidAttr(*args: str, addValue: bool = ..., attribute: str = ..., clear: bool = ..., floatRandom: float = ..., floatValue: float = ..., lowerFace: bool = ..., reset: bool = ..., vectorRandom: Tuple[float, float, float] = ..., vectorValue: Tuple[float, float, float] = ..., xIndex: int = ..., xvalue: bool = ..., yIndex: int = ..., yvalue: bool = ..., zIndex: int = ..., zvalue: bool = ...) -> bool:
    """Sets values of built-in fluid attributes such as density, velocity, etc.,
    for individual grid cells or for all cells in the grid.fluid
    Args:
        addValue (bool?): Add specified value to attribute
        attribute (str?): Specifies the fluid attribute for which to set values.  Valid  
                attributes are "velocity", "density", "fuel", "color", "falloff", and "temperature".  
                Properties: create
        clear (bool?): Set this attribute to 0
        floatRandom (float?): If this was a scalar (e.g. density) attribute, use a random value in +-VALUE  
                If fv is specified, it is used as the base value and combined with the  
                random value. If the fv flag is not specified, the  base is assumed to be 0.
        floatValue (float?): If this was a scalar (e.g. density) attribute, use this value
        lowerFace (bool?): Only valid with "-at velocity".  Since velocity values are stored on the edges  
                of each voxel and not at the center, using voxel based indices to set velocity  
                necessarily affects neighboring voxels.  Use this flag to only set velocity  
                components on the lower left three faces of a voxel, rather than all six.  
                Properties: create
        reset (bool?): Set this attribute to default value
        vectorRandom (Tuple[float, float, float]?): If this was a vector (e.g. velocity) attribute, use a random value in +-VALUE  
                If vv is specified, it is used as the base value and combined with the  
                random value. If the vv flag is not specified, the  base is assumed to be 0,0,0.
        vectorValue (Tuple[float, float, float]?): If this was a vector (e.g. velocity) attribute, use this value
        xIndex (int?): Only return values for cells with this X index  
                Properties: create
        xvalue (bool?): Only set the first component of the vector-valued attribute specified by  
                the "-at/attribute" flag.
        yIndex (int?): Only return values for cells with this Y index  
                Properties: create
        yvalue (bool?): Only set the second component of the vector-valued attribute specified by  
                the "-at/attribute" flag.
        zIndex (int?): Only return values for cells with this Z index  
                Properties: create
        zvalue (bool?): Only set the third component of the vector-valued attribute specified by  
                the "-at/attribute" flag.

    Returns:
        bool:

    Example:
    """

def setFocus(arg0: str = ..., /) -> bool:
    """Give keyboard focus to a specific control or panel, passed
    as an argument.
    Returns:
        bool:

    Example:
    """

def setInfinity(*args: str, edit: bool = ..., query: bool = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., hierarchy: str = ..., postInfinite: Queryable[str] = ..., preInfinite: Queryable[str] = ..., shape: bool = ...) -> Union[bool, str]:
    """Set the infinity type before (after) a paramCurve's first
    (last) keyframe.
    Args:
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        postInfinite (Queryable[str]?): Set the infinity type after a paramCurve's last keyframe. Valid  
                values are "constant", "linear", "cycle", "cycleRelative", "oscillate".  
                Properties: create, query
        preInfinite (Queryable[str]?): Set the infinity type before a paramCurve's first keyframe. Valid  
                values are "constant", "linear", "cycle", "cycleRelative", "oscillate".  
                Properties: create, query
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def setInputDeviceMapping(*args: Any, absolute: bool = ..., axis: Multiuse[str] = ..., device: str = ..., offset: float = ..., relative: bool = ..., scale: float = ..., view: bool = ..., world: bool = ...) -> bool:
    """The command sets a scale and offset for all attachments made
    to a specified device axis. Any attachment made to a mapped
    device axis will have the scale and offset applied to its values.The value from the device is multiplied by the scale and the
    offset is added to this product. With an absolute mapping, the
    attached attribute gets the resulting value. If the mapping is
    relative, the final value is the offset added to the scaled
    difference between the current device value and the previous
    device value.This mapping will be applied to the device data before any
    mappings defined by the setAttrMapping command. A typical use
    would be to scale a device's input so that it is within a usable
    range. For example, the device mapping can be used to calibrate
    a spaceball to work in a specific section of a scene.As an example, if the space ball is setup with absolute device
    mappings, constantly pressing in one direction will cause the
    attached attribute to get a constant value. If a relative mapping
    is used, and the spaceball is pressed in one direction, the
    attached attribute will jump a constantly increasing (or constantly
    decreasing) value and will find a rest value equal to the offset.There are important differences between how the relative flag
    is handled by this command and the setAttrMapping command. (See
    the setAttrMapping documentation for specifics on how it calculates
    relative values). In general,
    both a relative device mapping (this command) and a relative
    attachment mapping (setAttrMapping) should not be used together
    on the same axis.
    Args:
        absolute (bool?): report absolute axis values  
                Properties: create
        axis (Multiuse[str]?): specify the axis to map  
                Properties: create, multiuse
        device (str?): specify which device to map  
                Properties: create
        offset (float?): specify the axis offset value  
                Properties: create
        relative (bool?): report the change in axis value since  
                the last sample  
                Properties: create
        scale (float?): specify the axis scale value  
                Properties: create
        view (bool?): translate the device coordinates into the coordinates  
                of the active camera  
                Properties: create
        world (bool?): translate the device coordinates into world space  
                coordinates  
                Properties: create

    Returns:
        bool:

    Example:
    """

def setKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., breakdown: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., preserveTangent: bool = ...) -> Union[bool, str]:
    """This command creates a context which may be used to set keys
    within the graph editor
    Args:
        breakdown (bool?): Specifies whether or not to create breakdown keys  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        preserveTangent (bool?): Specifies whether or not to preserve tangent  
                Properties: query, edit

    Returns:
        bool: Value of the breakdown flag, when queried

    Example:
    """

def setKeyPath(*args: str) -> List[str]:
    """The setKeyPath command either creates or edits the path (a nurbs curve)
    based on the current position of the selected object at the current time.
    Returns:
        List[str]: (Names of the created curve node and motionPath node)

    Example:
    """

def setKeyframe(*args: str, edit: bool = ..., query: bool = ..., adjustTangent: bool = ..., animLayer: str = ..., animated: bool = ..., attribute: Multiuse[str] = ..., breakdown: bool = ..., clip: str = ..., controlPoints: bool = ..., dirtyDG: bool = ..., float: Multiuse[float] = ..., hierarchy: str = ..., identity: bool = ..., inTangentType: str = ..., insert: bool = ..., insertBlend: bool = ..., minimizeRotation: bool = ..., noResolve: bool = ..., outTangentType: str = ..., preserveCurveShape: bool = ..., respectKeyable: bool = ..., shape: bool = ..., time: Multiuse[int] = ..., useCurrentLockedWeights: bool = ..., value: float = ...) -> Union[int, bool]:
    """This command creates keyframes for the specified objects,
    or the active objects if none are specified on the command line.The default time for the new keyframes is the current time.
    Override this behavior with the "-t" flag on the command line.The default value for the keyframe is the current value
    of the attribute for which a keyframe is set.  Override
    this behavior with the "-v" flag on the command line.When setting keyframes on animation curves that do not have
    "time" as an input attribute (ie, they are unitless animation curves),
    use "-f/-float" to specify the unitless value at which to set a
    keyframe.The -time and -float flags may be combined in one command.This command sets up Dependency Graph relationships for
    proper evaluation of a given attribute at a given time.
    Args:
        adjustTangent (bool?): Adjsut tangent if insert keys  
                Properties: create
        animLayer (str?): Specifies that the new key should be placed in the specified animation layer.  
                Note that if the objects being keyframed are not already part of the  
                layer, this flag will be ignored.  
                Properties: create
        animated (bool?): Add the keyframe only to the attribute(s) that have already a keyframe on. Default: false  
                Properties: create
        attribute (Multiuse[str]?): Attribute name to set keyframes on.  
                Properties: create, multiuse
        breakdown (bool?): Sets the breakdown state for the key.  Default is false  
                Properties: create, query, edit
        clip (str?): Specifies that the new key should be placed in the specified clip.  
                Note that if the objects being keyframed are not already part of the  
                clip, this flag will be ignored.  
                Properties: create
        controlPoints (bool?): Explicitly specify whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  
                Properties: create
        dirtyDG (bool?): Allow dirty messages to be sent out when a keyframe is set.  
                Properties: create
        float (Multiuse[float]?): Float time at which to set a keyframe on float-based  
                animation curves.  
                Properties: create, multiuse
        hierarchy (str?): Controls the objects this command acts on, relative to the specified  
                (or active) target objects.  
                Valid values are "above," "below," "both," and "none."  
                Default is "hierarchy -query"  
                Properties: create
        identity (bool?): Sets an identity key on an animation layer.  An identity key is one that  
                nullifies the effect of the anim layer.  This flag has effect only when the  
                attribute being keyed is being driven by animation layers.  
                Properties: create
        inTangentType (str?): The in tangent type for keyframes set by this command.  
                Valid values are: "auto", clamped", "fast", "flat", "linear", "plateau", "slow", "spline", and "stepnext"  
                Default is "keyTangent -q -g -inTangentType"  
                Properties: create
        insert (bool?): Insert keys at the given time(s) and preserve  
                the shape of the animation curve(s). Note: the tangent  
                type on inserted keys will be fixed so that the  
                curve shape can be preserved.  
                Properties: create
        insertBlend (bool?): If true, a pairBlend node will be inserted for channels that have  
                nodes other than animCurves driving them, so that such channels can  
                have blended animation. If false, these channels will not have keys  
                inserted. If the flag is not specified, the blend will be inserted based  
                on the global preference for blending animation.  
                Properties: create
        minimizeRotation (bool?): For rotations, ensures that the key that is set is a minimum distance  
                away from the previous key.  Default is false  
                Properties: create
        noResolve (bool?): When used with the -value flag, causes the specified value to be set  
                directly onto the animation curve, without attempting to resolve the value  
                across animation layers.  
                Properties: create
        outTangentType (str?): The out tangent type for keyframes set by this command.  
                Valid values are: "auto", "clamped", "fast", "flat", "linear", "plateau", "slow", "spline", "step", and "stepnext".  
                Default is "keyTangent -q -g -outTangentType"  
                Properties: create
        preserveCurveShape (bool?): Sets the preserve curve shape when inserting keys.  
                Default value depend on your keySetPreserveCurveShape option.  
                Properties: create
        respectKeyable (bool?): When used with the -attribute flag, prevents the keying of the non keyable attributes.  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true  
                Properties: create
        time (Multiuse[int]?): Time at which to set a keyframe on time-based  
                animation curves.  
                Properties: create, multiuse
        useCurrentLockedWeights (bool?): If we are setting a key over an existing key, use that key tangent's locked weight value for the new  
                locked weight value.  Default is false  
                Properties: create
        value (float?): Value at which to set the keyframe. Using the value flag will not  
                cause the keyed attribute to change to the specified value until the  
                scene re-evaluates. Therefore, if you want the attribute to update  
                to the new value immediately, use the setAttr command  
                in addition to setting the key.  
                Properties: create

    Returns:
        int: Number of keyframes set by this command.

    Example:
    """

def setKeyframeBlendshapeTargetWts(*args: str) -> int:
    """This command can be used to keyframe per-point blendshape target weights. It operates
    on the currently selected objects as follows.
    When the base object is selected, then the target weights are keyed for all
    targets. When only target
    shapes are selected, then the weights for thoses targets are keyframed.setKeyframe, blendShape
    Returns:
        int: number of vertices for which the targets weights are keyed

    Example:
    """

def setMenuMode(arg0: str = ..., /) -> str:
    """Optionally sets a new Menu Mode for the menu bar in the main Maya window.
    Returns the current Menu Mode, and if a new one is specified, then the previous
    Menu Mode is returned.
    Note that due to recent changes to the menu set architecture (8.0+), this function now
    takes a menu set as a parameter instead of a label.menu, menus, menubar
    Returns:
        str: The current Menu Mode for the menu bar in the main Maya window.

    Example:
    """

def setNClothStartState() -> None: ...
def setNodeTypeFlag(arg0: str = ..., /, *, query: bool = ..., display: bool = ..., threadSafe: bool = ...) -> bool:
    """This command sets static data on the specified node type. This will affect the
    class of node type as a whole.  The argument passed may be the name of the node
    type or the node type tag.  Node type tags may be found using the objectType
    command.
    Args:
        display (bool?): Sets whether the node type will appear in the UI or not.  Setting  
                display to false will cause the node type to not appear in the UI.  
                Query mode to obtain the value of the display flag.  
                Properties: create, query
        threadSafe (bool?): This flag is obsolete.  Has no effect.  
                Properties: create, query

    Returns:
        bool: Did the command succeed?

    Example:
    """

def setParent(arg0: str = ..., /, *, query: bool = ..., defineTemplate: str = ..., menu: bool = ..., topLevel: bool = ..., upLevel: bool = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command changes the default parent to be the specified parent.
    Two special parents are "|" which indicates the top level layout of the
    window hierarchy, or ".." which indicates one level up in the hierarchy.
    Trying to move above the top level has no effect.A control must be parented to a control layout.  A control layout may
    be parented to another control layout or a window.  A menu may be parented
    to a window or a menu bar layout.  For all of these cases
    thecommand (with no flags) will indicate the current
    default parent.A menu item must be parented to a menu.  To specify the default menu
    parent use the command.  Note that all menu item
    objects created using themay also be treated as menu
    objects.The default parent is ignored by any object that explicitly sets theflag when it is created.
    Args:
        defineTemplate (str?): Put a command in a mode where any other flags and args  
                are parsed and added to the command template with the given name.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        menu (bool?): Parent menu for menu items.  
                Properties: create, query
        topLevel (bool?): Move to the top level layout in the hierarchy. Equivalent to use "|"  
                Properties: create
        upLevel (bool?): Move up one level in the hierarchy. Equivalent to use ".."  
                Properties: create
        useTemplate (str?): Will force the command to use a command template given by the name other than  
                the current one.  
                Properties: create

    Returns:
        str: Name of the parent if the parent changes. Empty string if the parent
            doesn't change.

    Example:
    """

def setParticleAttr(*args: str, attribute: str = ..., floatValue: float = ..., object: str = ..., randomFloat: float = ..., randomVector: Tuple[float, float, float] = ..., relative: bool = ..., vectorValue: Tuple[float, float, float] = ...) -> bool:
    """This action will set the value of the chosen attribute for every
    particle or selected component in the selected or passed particle object.
    Components should not be passed to the command line.
    For setting the values of components, the components must be
    selected and only the particle object's names should be passed to
    this action.
    If the attribute is a vector attribute and the -vv flag is passed,
    then the three floats passed will be used to set the values.  If
    the attribute is a vector and the -fv flag is pass and the -vv flag
    is not passed, then the float will be repeated for each of the
    X, Y, and Z values of the attribute.  Similarly, if the attribute is
    a float attribute and a vector value is passed, then the length of
    the vector passed will be used for the value.
    Note:  The attribute passed must be a Per-Particle attribute.
    Args:
        attribute (str?): Tells the action which attribute you want to set  
                Properties: create
        floatValue (float?): Tells what you want the value to be set to of a float attribute  
                Properties: create
        object (str?): If this flag is passed and the STRING is the name of a particle object's transform or shape,  
                then ONLY that object will be edited, ignoring the selection list or command line, and  
                ALL of its particles' values will be changed for the specified attribute.  
                Properties: create
        randomFloat (float?): Tells the command to add a random value from -FLOAT to +FLOAT to  
                the results of each particle.  The default is 0.0.  
                Properties: create
        randomVector (Tuple[float, float, float]?): Tells the command to add a random value from <<-x,-y,-z>> to <<x,y,z>> to  
                the results of each particle. The default 0 0 0.  
                Properties: create
        relative (bool?): If this is set to TRUE (the default is FALSE), then the float or vector value will be added to the current value  
                for each particle.  
                Properties: create
        vectorValue (Tuple[float, float, float]?): Tells what you want the value to be set to of a vector  
                attribute  
                Properties: create

    Returns:
        bool:

    Example:
    """

def setRenderPassType(*args: str, defaultDataType: bool = ..., numChannels: int = ..., type: str = ...) -> bool:
    """This command will set the passID of a renderPass node and
    create the custom attributes specified by the corresponding render pass
    definition.  If the render pass
    node already has a passID assigned to it, attributes that are no longer
    required become hidden, and new attributes are unhidden and/or created as
    needed.  This allows passIDs to be changed back and forth without losing
    attribute data.  It also allows common attributes to be transported from one
    render pass type to another.render, layer,, pass
    Args:
        defaultDataType (bool?): If set, the render pass will use its default data type.  
                Properties: create
        numChannels (int?): Specify the number of channels to use in the render pass. Note that  
                this flag is only valid if there is an implementation supporting the  
                requested number of channels.  
                Properties: create
        type (str?): Specify the pass type to assign to the pass node(s).  
                Properties: create

    Returns:
        bool: true/false

    Example:
    """

def setStartupMessage(arg0: str = ..., /) -> bool:
    """Update the startup window message.  Also know as the 'Splash Screen',
    this is the window that appears while the application is starting up.
    Returns:
        bool:

    Example:
    """

def setToolTo(arg0: str = ..., /) -> bool:
    """This command switches control to the named context.
    Returns:
        bool:

    Example:
    """

def setUITemplate(arg0: str = ..., /, *, query: bool = ..., popTemplate: bool = ..., pushTemplate: bool = ...) -> str:
    """This command sets the current(default) command template
    for the ELF commands.  The special name NONE can be used to set no templates
    current. See "uiTemplate" command also.
    Args:
        popTemplate (bool?): Pop the current template off of the stack and sets the next template  
                on the stack to be current.  
                Properties: create
        pushTemplate (bool?): Push the current template onto a stack that can later be popped.  
                Properties: create

    Returns:
        str: The name of the currently selected command template.

    Example:
    """

def setXformManip(*args: Any, query: bool = ..., showUnits: bool = ..., suppress: bool = ..., useRotatePivot: bool = ..., worldSpace: bool = ...) -> bool:
    """This command changes some of the settings of the xform manip,
    to control its appearance.
    Args:
        showUnits (bool?): If set to true, the xform manip displays current units;  
                otherwise, the manip hides them.  
                Properties: query
        suppress (bool?): If set to true, the xform manip is suppressed and therefore  
                not visible or usable.  
                Properties: query
        useRotatePivot (bool?): If set to true, the xform manip uses the rotate pivot;  
                otherwise, the manip uses the bounding-box center. Defaults false.  
                Properties: query
        worldSpace (bool?): If set to true, the xform manip is always in world space.  
                If false, the manip is in object space. (Note: when multiple  
                objects are selected the manip is always in world space, no  
                matter what this is set to)  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def sets(*args: str, edit: bool = ..., query: bool = ..., addElement: str = ..., afterFilters: bool = ..., anyMember: str = ..., clear: str = ..., color: Queryable[int] = ..., copy: str = ..., edges: bool = ..., editPoints: bool = ..., empty: bool = ..., facets: bool = ..., flatten: str = ..., forceElement: str = ..., include: str = ..., intersection: str = ..., isIntersecting: str = ..., isMember: str = ..., layer: bool = ..., name: str = ..., noIntermediate: bool = ..., noSurfaceShader: bool = ..., noWarnings: bool = ..., nodesOnly: bool = ..., remove: str = ..., renderable: bool = ..., size: bool = ..., split: str = ..., subtract: str = ..., text: Queryable[str] = ..., union: str = ..., vertices: bool = ...) -> Union[str, List[str], bool, int]:
    """This command is used to create a set, query some state of
    a set, or perform operations to update the membership of a set.
    A set is a logical grouping of an arbitrary collection of objects,
    attributes, or components of objects. Sets are dependency nodes.
    Connections from objects to a set define membership in the set.Sets are used throughout Maya in a multitude of ways. They are used
    to define an association of material properties to objects, to define
    an association of lights to objects, to define a bookmark or named
    collection of objects, to define a character, and to define the
    components to be deformed by some deformation operation.Sets can be connected to any number of partitions. A partition is
    a node which enforces mutual exclusivity amoung the sets in the
    partition. That is, if an object is in a
    set which is in a partition, that object cannot be a member of any
    other set that is in the partition.Without any flags, thecommand will create a set with a
    default name of "set#" (where # is an integer). If no items are
    specified on the command line, the currently selected items are added
    to the set. The -em/empty flag can be used to create an empty
    set and not have the selected items added to the set.Sets can be created to have certain restrictions on membership. There
    can be "renderable" sets which only allow renderable objects (such as
    nurbs geometry or polymesh faces) to be members of the set. There can
    also be vertex (or control point), edit point, edge, or face sets
    which only allow those types of components to be members of a set.
    Note that for these sets, if an object with a valid type of component
    is to be added to a set, the components of the object are
    added to the set instead.Sets can have an associated color which is only of use
    when creating vertex sets. The color can be one of the eight user
    defined colors defined in the color preferences. This color can
    be used, for example to distinguish which vertices are being deformed
    by a particular deformation.Objects, components, or attributes can be added to a set using one of
    three flags. The -add/addElement flag will add the objects to a set as
    long as this won't break any mutual exclusivity constraints. If there
    are any items which can't be added, the command will fail. The
    -in/include flag will only add those items which can be added and
    warn of those which can't. The -fe/forceElement flag will add all the
    items to the set but will also remove any of those items that are in
    any other set which is in the same partition as the set.There are several operations on sets that can be performed with thecommand. Membership can be queried. Tests for whether
    an item is in a set or whether two sets share the same item
    can be performed. Also, the union, intersection and
    difference of sets can be performed which returns a list of members
    of the sets which are a result of the operation.
    Args:
        addElement (str?): Adds the list of items to the given set.  If some of the  
                items cannot be added to the set because they are in another  
                set which is in the same partition as the set to edit, the  
                command will fail.  
                Properties: edit
        afterFilters (bool?): Default state is false. This flag is valid in edit mode only.  
                This flag is for use on sets that are acted on by deformers  
                such as sculpt, lattice, blendShape. The default edit mode  
                is to edit the membership of the group acted on by the deformer.  
                If you want to edit the group but not change the membership of  
                the deformer, set the flag to true.  
                Properties: edit
        anyMember (str?): An operation which tests whether any of the given items  
                are members of the given set.  
                Properties: create
        clear (str?): An operation which removes all items from the given set making  
                the set empty.  
                Properties: edit
        color (Queryable[int]?): Defines the hilite color of the set. Must be a value in  
                range [-1, 7] (one of the user defined colors).  -1 marks the  
                color has being undefined and therefore not having any affect.  
                Only the vertices of a vertex set will be displayed in this  
                color.  
                Properties: create, query, edit
        copy (str?): Copies the members of the given set to a new set.  
                This flag is for use in creation mode only.  
                Properties: create
        edges (bool?): Indicates the new set can contain edges only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query
        editPoints (bool?): Indicates the new set can contain editPoints only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query
        empty (bool?): Indicates that the set to be created should be empty. That is,  
                it ignores any arguments identifying objects to be added to  
                the set. This flag is only valid for operations that create a new set.  
                Properties: create
        facets (bool?): Indicates the new set can contain facets only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query
        flatten (str?): An operation that flattens the structure of the given set.  
                That is, any sets contained by the given set will be replaced by  
                its members so that the set no longer contains other sets but  
                contains the other sets' members.  
                Properties: edit
        forceElement (str?): For use in edit mode only. Forces addition of the items  
                to the set. If the items are in another set which is in the  
                same partition as the given set, the items will be removed  
                from the other set in order to keep the sets in the partition  
                mutually exclusive with respect to membership.  
                Properties: edit
        include (str?): Adds the list of items to the given set.  If some of the  
                items cannot be added to the set, a warning will be issued.  
                This is a less strict version of the -add/addElement operation.  
                Properties: edit
        intersection (str?): An operation that returns a list of items which are members of  
                all the sets in the list.  
                Properties: create
        isIntersecting (str?): An operation which tests whether the sets in the list have  
                common members.  
                Properties: create
        isMember (str?): An operation which tests whether all the given items  
                are members of the given set.  
                Properties: create
        layer (bool?): OBSOLETE. DO NOT USE.  
                Properties: create
        name (str?): Assigns string as the name for a new set. This flag is  
                only valid for operations that create a new set.  
                Properties: create
        noIntermediate (bool?): Excludes intermediate objects when querying set members or  
                using the subtract, union, itersection, or isIntersecting  
                flags.  
                Properties: create, query
        noSurfaceShader (bool?): If set is renderable, do not connect it to the default surface  
                shader.  Flag has no meaning or effect for non renderable sets.  
                This flag is for use in creation mode only.  
                The default value is false.  
                Properties: create
        noWarnings (bool?): Indicates that warning messages should not be reported such  
                as when trying to add an invalid item to a set. (used by UI)  
                Properties: create
        nodesOnly (bool?): This flag is usable with the -q/query flag but is ignored if  
                used with another queryable flags. This flag modifies the results  
                of the set membership query such that  
                when there are attributes (e.g. sphere1.tx) or components of  
                nodes included in the set, only the nodes will be listed.  
                Each node will only be listed once, even if more than one attribute  
                or component of the node exists in the set.  
                Properties: query
        remove (str?): Removes the list of items from the given set.  
                Properties: edit
        renderable (bool?): This flag indicates that a special type of set should  
                be created. This type of set (shadingEngine as opposed to  
                objectSet) has certain restrictions on its membership in that  
                it can only contain renderable elements such as lights and  
                geometry. These sets are referred to as shading groups and  
                are automatically connected to the "renderPartition" node when  
                created (to ensure mutual exclusivity of the set's members with  
                the other sets in the partition).  
                This flag is for use in creation or query mode only.  
                The default value is false which means a normal set is  
                created.  
                Properties: create, query
        size (bool?): Use the size flag to query the length of the set.  
                Properties: query
        split (str?): Produces a new set with the list of items and removes  
                each item in the list of items from the given set.  
                Properties: create
        subtract (str?): An operation between two sets which returns the members of the  
                first set that are not in the second set.  
                Properties: create
        text (Queryable[str]?): Defines an annotation string to be stored with the set.  
                Properties: create, query, edit
        union (str?): An operation that returns a list of all the members of all sets  
                listed.  
                Properties: create
        vertices (bool?): Indicates the new set can contain vertices only.  
                This flag is for use in creation or query mode only.  
                The default value is false.  
                Properties: create, query

    Returns:
        str: For creation operations (name of the set that was created or edited)
        List[str]: For query operation (names of items in the set)
        bool: For isIntersecting and isMember operations

    Example:
    """

def shadingConnection(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., connectionState: bool = ...) -> bool:
    """Sets the connection state of a connection between nodes that are used
    in shading. Specify the destination attribute of the connection.
    Args:
        connectionState (bool?): Specifies the state of the connection.  
                On/True/1 means the connection is still active.  
                Off/False/0 means the connection is inactive.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def shadingGeometryRelCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., offCommand: Queryable[str] = ..., onCommand: Queryable[str] = ..., shadingCentric: bool = ...) -> Union[str, bool]:
    """This command creates a context that can be used for associating geometry
    to shading groups.  You can put the context into shading-centric mode
    by using the -shadingCentric flag and specifying true.  This means that the
    shading group is selected first then geometry associated with the shading
    group are highlighted.  Subsequent selections result in assignments.Specifying -shadingCentric false means that the geometry is to be selected
    first.  The shading group associated with the geometry will then be selected
    and subsequent selections will result in assignments being made.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        offCommand (Queryable[str]?): command to be issued when context is turned on  
                Properties: create, query, edit
        onCommand (Queryable[str]?): command to be issued when context is turned on  
                Properties: create, query, edit
        shadingCentric (bool?): shading-centric mode.  
                Properties: create, query, edit

    Returns:
        str: Name of the context created.

    Example:
    """

def shadingLightRelCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., offCommand: Queryable[str] = ..., onCommand: Queryable[str] = ..., shadingCentric: bool = ...) -> Union[str, bool]:
    """This command creates a context that can be used for associating lights
    to shading groups.  You can put the context into shading-centric mode
    by using the -shadingCentric flag and specifying true.  This means that the
    shading group is selected first then lights associated with the shading
    group are highlighted.  Subsequent selections result in assignments.Specifying -shadingCentric false means that the light is to be selected
    first. The shading groups associated with the light will then be selected
    and subsequent selections will result in assignments being made.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        offCommand (Queryable[str]?): command to be issued when context is turned on  
                Properties: create, query, edit
        onCommand (Queryable[str]?): command to be issued when context is turned on  
                Properties: create, query, edit
        shadingCentric (bool?): shading-centric mode.  
                Properties: create, query, edit

    Returns:
        str: Name of the context created.

    Example:
    """

def shadingNetworkCompare(*args: str, query: bool = ..., byName: bool = ..., byValue: bool = ..., delete: bool = ..., equivalent: bool = ..., network1: bool = ..., network2: bool = ..., upstreamOnly: bool = ...) -> Union[Union[List[str], str, int], bool]:
    """This command allows you to compare two shading networks.shader, shading, network
    Args:
        byName (bool?): Indicates whether the comparison should consider node names.  
                If true, two shading networks will be considered equivalent only  
                if the names of corresponding nodes are the same, ignoring namespaces.  
                If false, two shading networks will be considered equivalent even  
                if corresponding nodes are named differently.  
                Default is 'false'.  
                Properties: create
        byValue (bool?): Indicates whether the comparison should consider the values of  
                unconnected attributes.  
                If true, two shading networks will be considered equivalent only  
                if corresponding, unconnected attributes are the same type and have the  
                same value. Only attributes of type 'int', 'bool', 'float', and 'string'  
                will have their values compared.  
                If false, two shading networks will be considered equivalent even  
                if corresponding, unconnected attributes have different values or  
                are different types.  
                Default is 'true'.  
                Properties: create
        delete (bool?): Deletes the specified comparison from memory.  
                Properties: create
        equivalent (bool?): Returns an int. 1 if the shading networks in the specified comparison are  
                equivalent. 0 otherwise.  
                Properties: query
        network1 (bool?): Returns a string[]. Returns an empty string array if the shading networks  
                in the specified comparison are not equivalent. Otherwise returns the nodes  
                in the first shading network.  
                Properties: query
        network2 (bool?): Returns a string[]. Returns an empty string array if the shading networks  
                in the specified comparison are not equivalent. Otherwise returns the nodes  
                in the second shading network.  
                Properties: query
        upstreamOnly (bool?): Indicates whether the comparison should consider nodes which are  
                connected downstream from shading network nodes.  
                If true, only those nodes which are upstream from the shading  
                group will be considered. If, following only downstream connections,  
                there is no connection path from a node to one of the shader attributes on the  
                shading group, the node will not be considered.  
                If false, a node will be considered if a connection path can found, following  
                either upstream or downstream connections, which terminates with an input  
                connection to one of the shading groups shader attributes. These dangling nodes  
                do not directly contribute to the color, displacement, or volume  
                characteristics of the shading group.  
                Default is 'false'.  
                Properties: create

    Returns:
        Union[List[str], str, int]: Command result

    Example:
    """

def shadingNode(*args: Any, asLight: bool = ..., asPostProcess: bool = ..., asRendering: bool = ..., asShader: bool = ..., asTexture: bool = ..., asUtility: bool = ..., isColorManaged: bool = ..., name: str = ..., parent: str = ..., shared: bool = ..., skipSelect: bool = ...) -> str:
    """This command creates a new node in the dependency graph of the
    specified type.The shadingNode command classifies any DG node as a shader, texture
    light, post process, or utility so that it can be properly organized
    in the multi-lister.  Recall that any DG node can be used a part of a
    a shader, texture or light - regardless of how it is classified by this.
    command. These classifications are provided for convenience in the UI.
    Args:
        asLight (bool?): classify the current DG node as a light  
                Properties: create
        asPostProcess (bool?): classify the current DG node as a post process  
                Properties: create
        asRendering (bool?): classify the current DG node as a rendering node  
                Properties: create
        asShader (bool?): classify the current DG node as a shader  
                Properties: create
        asTexture (bool?): classify the current DG node as a texture  
                Properties: create
        asUtility (bool?): classify the current DG node as a utility  
                Properties: create
        isColorManaged (bool?): classify the current DG node as being color managed  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace doesn't exist, we  
                will create the namespace.  
                Properties: create
        parent (str?): Specifies the parent in the DAG under which the new node belongs.  
                Properties: create
        shared (bool?): This node is shared across multiple files, so only create it if  
                it does not already exist.  
                Properties: create
        skipSelect (bool?): This node is not to be selected after creation, the original selection  
                will be preserved.  
                Properties: create

    Returns:
        str: The name of the new node.
        str: (the name of the new node)

    Example:
    """

def shapeCompare(*args: str) -> int:
    """Compares two shapes.
    If no shapes are specified in the command line, then the
    shapes from the active list are used.
    Returns:
        int: 0 if successful, 1 if both shapes are not determined to be equal
            based on requested flags.

    Example:
    """

def shapeEditor(*args: Any, edit: bool = ..., query: bool = ..., clearSelection: bool = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., lockMainConnection: bool = ..., lowestSelection: bool = ..., mainListConnection: Queryable[str] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., stateString: bool = ..., targetControlList: bool = ..., targetList: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ..., verticalSliders: bool = ...) -> Union[str, bool]:
    """This command creates an editor that derives from the base editor
    class that has controls for deformer, control nodes.
    Args:
        clearSelection (bool?): Clear the shape editor selection.  
                Properties: edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lowestSelection (bool?): Query the lowest selection item.  
                Properties: query
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        targetControlList (bool?): Query the target control list.  
                Properties: query
        targetList (bool?): Query the target list.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalSliders (bool?): Should the sliders be vertical?  
                Properties: create, query, edit

    Returns:
        str: The name of the editor

    Example:
    """

def shapePanel(*args: Any, edit: bool = ..., query: bool = ..., control: bool = ..., copy: str = ..., createString: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., editString: bool = ..., exists: bool = ..., init: bool = ..., isUnique: bool = ..., label: Queryable[str] = ..., menuBarRepeatLast: bool = ..., menuBarVisible: bool = ..., needsInit: bool = ..., parent: str = ..., popupMenuProcedure: Queryable[Callable[..., Any]] = ..., replacePanel: str = ..., shapeEditor: bool = ..., tearOff: bool = ..., tearOffCopy: str = ..., tearOffRestore: bool = ..., unParent: bool = ..., useTemplate: str = ...) -> Union[str, bool, Callable[..., Any]]:
    """This command creates a panel that derives from the base panel
    class that houses a shapeEditor.
    Args:
        control (bool?): Returns the top level control for this panel.  
                Usually used for getting a parent to attach popup menus.  
                CAUTION: panels may not have controls at times.  This  
                flag can return "" if no control is present.  
                Properties: query
        copy (str?): Makes this panel a copy of the specified panel.  Both  
                panels must be of the same type.  
                Properties: edit
        createString (bool?): Command string used to create a panel  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the Maya panel.  
                Properties: create, query, edit
        editString (bool?): Command string used to edit a panel  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        init (bool?): Initializes the panel's default state.  This is usually done  
                automatically on file -new and file -open.  
                Properties: create, edit
        isUnique (bool?): Returns true if only one instance of this panel type is allowed.  
                Properties: query
        label (Queryable[str]?): Specifies the user readable label for the panel.  
                Properties: query, edit
        menuBarRepeatLast (bool?): Controls whether clicking on the menu header with the middle mouse button would repeat the last selected menu item.  
                Properties: create, query, edit
        menuBarVisible (bool?): Controls whether the menu bar for the panel is displayed.  
                Properties: create, query, edit
        needsInit (bool?): (Internal) On Edit will mark the panel as requiring initialization.  
                Query will return whether the panel is marked for initialization.  Used  
                during file -new and file -open.  
                Properties: query, edit
        parent (str?): Specifies the parent layout for this panel.  
                Properties: create
        popupMenuProcedure (Queryable[Callable[..., Any]]?): Specifies the procedure called for building the panel's popup menu(s).  
                The default value is "buildPanelPopupMenu".  The procedure should take  
                one string argument which is the panel's name.  
                Properties: query, edit
        replacePanel (str?): Will replace the specified panel with this panel.  If the  
                target panel is within the same layout it will perform a swap.  
                Properties: edit
        shapeEditor (bool?): Query only flag that returns the name of an editor to be associated with the panel.  
                Properties: query
        tearOff (bool?): Will tear off this panel into a separate window with a paneLayout  
                as the parent of the panel. When queried this flag will return if the  
                panel has been torn off into its own window.  
                Properties: query, edit
        tearOffCopy (str?): Will create this panel as a torn of copy of the specified source panel.  
                Properties: create
        tearOffRestore (bool?): Restores panel if it is torn off and focus is given to it.  
                If docked, becomes the active panel in the docked window.  
                This should be the default flag that is added to all panels  
                instead of -to/-tearOff flag which should only be used to tear off the panel.  
                Properties: create, edit
        unParent (bool?): Specifies that the panel should be removed from its layout.  
                This (obviously) cannot be used with query.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the panel

    Example:
    """

def shelfButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., command: Queryable[Callable[..., Any]] = ..., commandRepeatable: bool = ..., defineTemplate: str = ..., disabledImage: Queryable[str] = ..., docTag: Queryable[str] = ..., doubleClickCommand: Queryable[Callable[..., Any]] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableCommandRepeat: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., flat: bool = ..., flexibleWidthType: Queryable[int] = ..., flexibleWidthValue: Queryable[int] = ..., flipX: bool = ..., flipY: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., handleNodeDropCallback: Callable[..., Any] = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightImage: Queryable[str] = ..., image: Queryable[str] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., label: Queryable[str] = ..., labelEditingCallback: Callable[..., Any] = ..., labelOffset: Queryable[int] = ..., manage: bool = ..., marginHeight: Queryable[int] = ..., marginWidth: Queryable[int] = ..., menuItem: Multiuse[Tuple[str, str]] = ..., menuItemPython: Multiuse[int] = ..., menuItemWithOptionBox: Multiuse[Tuple[str, str, str]] = ..., noBackground: bool = ..., noDefaultPopup: bool = ..., numberOfPopupMenus: bool = ..., overlayLabelBackColor: Queryable[Tuple[float, float, float, float]] = ..., overlayLabelColor: Queryable[Tuple[float, float, float]] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rotation: Queryable[float] = ..., scaleIcon: bool = ..., selectionImage: Queryable[str] = ..., sourceType: Queryable[str] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useAlpha: bool = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int, Tuple[float, float, float, float], float]:
    """This control supports up to 3 icon images and 4 different display
    styles.  The icon image displayed is the one that best fits the
    current size of the control given its current style.This command creates anthat is designed to be on
    the shelf. The button contains a command that can be drag'n'dropped.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center". By default, the label is aligned "center".  
                Currently only available when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        command (Queryable[Callable[..., Any]]?): Command executed when the control is pressed.  
                Properties: create, query, edit
        commandRepeatable (bool?): Set if the MEL command specified in the command flag should be repeatable  
                or not.  The "g" key, by default, is the shortcut to repeat the last executed command.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disabledImage (Queryable[str]?): Image used when the button is disabled. Image size must  
                be the same as the image specified with the i/image flag.  
                This is a Windows only flag.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Queryable[Callable[..., Any]]?): Command executed when the control is double clicked.  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableCommandRepeat (bool?): This flag only affects menu items to which a command can be  
                attached.  Specify true and the command may be repeated by  
                executing the command repeatLast.  This flag is true by  
                default for all items except for option box items.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        flat (bool?): Sets whether the control will be a flat button (0 false, 1 true).  
                Properties: create, query, edit
        flexibleWidthType (Queryable[int]?): This flag is used to have the shelf button have a wider or thinner width.  
                The valid values are: Standard = 1, Custom = 2, Automatic = 3.  
                The Standard type will resize, keeping the aspect ratio, to 32x32 pixels.  
                The Automatic type will adjust the button width to make sure wide images are used properly.  
                The Custom type will allow the user to choose the desired width for the icon.  
                Default value is 3.  
                Properties: create, query, edit
        flexibleWidthValue (Queryable[int]?): This flag is only useful when the Custom flexibleWidthType is chosen.  
                The value is a width in pixels.  
                Properties: create, query, edit
        flipX (bool?): Is the image flipped horizontally?  
                Properties: create, query, edit
        flipY (bool?): Is the image flipped vertically?  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        handleNodeDropCallback (Callable[..., Any]?): Specify a script callback which is called when a node is dropped  
                on the control.  The name of the node being dropped will be  
                passed to the function  (python callable) or appended to the end  
                (script) to form the command to be executed.  
                Properties: create, edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlightImage (Queryable[str]?): Highlight image displayed while the cursor is over the  
                control. Image size must be the same as the image specified with  
                the -i/image flag. This is a Windows only flag.  
                Properties: create, query, edit
        image (Queryable[str]?): If you are not providing images with different sizes then you may  
                use this flag for the control's image. If the "iconOnly" style is  
                set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        image1 (Queryable[str]?): First of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons. The icon that best fits the  
                current size of the control will be displayed.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string, up to 6 characters, representing a label that will be displayed  
                on top of the image.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The text that appears in the control.  
                Properties: create, query, edit
        labelEditingCallback (Callable[..., Any]?): Specify a callback which is called after the user  
                double clicks the label of the control to give it a new label.  
                The new label string will be passed to the callback.  
                Properties: create, edit
        labelOffset (Queryable[int]?): The label offset. Default is 0. Currently only available  
                when -st/style is set to "iconAndTextCentered".  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        marginHeight (Queryable[int]?): The number of pixels above and below the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        marginWidth (Queryable[int]?): The number of pixels on either side of the control content.  
                The default value is 1 pixel.  
                Properties: create, query, edit
        menuItem (Multiuse[Tuple[str, str]]?): Creates menu items for this button by passing in arguments for the menu item label and  
                command for each item.  These should be passed as strings: "label" "command" for each use  
                of this flag in the command.  
                Properties: create, edit, multiuse
        menuItemPython (Multiuse[int]?): This flag is used to specify that a menu item is in Python. The integer value is  
                the index of the menuItem that is modified by this flag. This is 0 based, so it  
                corresponds to the (index+1)th occurrence of the /-mi/-menuItem flag.  
                Properties: create, edit, multiuse
        menuItemWithOptionBox (Multiuse[Tuple[str, str, str]]?): Creates menu items that include an option box.  Arguments passed to the flag are "label"  
                "comand" "option box command";  
                Properties: create, edit, multiuse
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        noDefaultPopup (bool?): Disable the default popup menus.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        overlayLabelBackColor (Queryable[Tuple[float, float, float, float]]?): The RGBA color of the shadow behind the label defined by  
                imageOverlayLabel. Default is 50% transparent black: 0 0 0 .5  
                Properties: create, query, edit
        overlayLabelColor (Queryable[Tuple[float, float, float]]?): The RGB color of the label defined by imageOverlayLabel. Default is a  
                light grey: .8 .8 .8  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rotation (Queryable[float]?): The rotation value of the image in radians.  
                Properties: create, query, edit
        scaleIcon (bool?): For "textOnly" and "iconOnly" style, this flag has no effect.  
                For other styles, if the flag is specified, the icon will be scaled to the size of the control.  
                Properties: create, edit
        selectionImage (Queryable[str]?): Image displayed while the control is selected. Image size  
                must be the same as the image specified with the -i/image  
                flag. This is a Windows only flag.  
                Properties: create, query, edit
        sourceType (Queryable[str]?): Sets the language type for the command script. Can only be used in  
                conjunction with the c/command or dcc/doubleClickCommand flags.  
                Valid values are "mel" (enabled by default), and "python".  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal", "iconAndTextVertical", and  
                "iconAndTextCentered". (Note: "iconAndTextCentered" is only available on Windows).  
                If the "iconOnly" style is set, the icon will be scaled to the size of the control.  
                Properties: create, query, edit
        useAlpha (bool?): Is the image using alpha channel?  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the button.

    Example:
    """

def shelfLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alignment: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., cellHeight: Queryable[int] = ..., cellWidth: Queryable[int] = ..., cellWidthHeight: Queryable[Tuple[int, int]] = ..., childArray: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontal: bool = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., position: Multiuse[Tuple[str, int]] = ..., preventOverride: bool = ..., spacing: Queryable[int] = ..., statusBarMessage: str = ..., style: Queryable[str] = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], int, Tuple[int, int], bool, Callable[..., Any]]:
    """This command creates a new empty shelf layout.
    The shelf layout can accept drops of commands scripts.
    Use theMEL command to add a shelf to the top level shelves.
    Args:
        alignment (Queryable[str]?): Sets the alignment of the buttons in the layout.  
                When horizontal is true, valid options are "left" and "right".  
                When horizontal is false, valid options are "top" and "bottom".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        cellHeight (Queryable[int]?): Set or query the height of the items in the shelf.  
                Properties: create, query, edit
        cellWidth (Queryable[int]?): Set or query the width of the items in the shelf.  
                Properties: create, query, edit
        cellWidthHeight (Queryable[Tuple[int, int]]?): Set the width and height of the items in the shelf.  
                Properties: create, query, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the layout. This flag is true by default, which corresponds to a horizontally laid out shelf.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        position (Multiuse[Tuple[str, int]]?): Specify the name of a child control in the grid layout along with  
                a 1. based integer value indicating the desired  
                position of the child. Positions increase from left to right  
                within a row and then wrap around to the next row increasing from  
                top to bottom. For example, a grid layout with 3 columns and 2  
                rows has 6 visible positions where 1, 2 and 3 occupy the first row  
                and 4, 5 and 6 occupy the second.  
                Properties: create, edit, multiuse
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        spacing (Queryable[int]?): Sets the space between children.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (Queryable[str]?): Set or query the current style of the items in the shelf.  Valid  
                styles are "iconOnly", "textOnly", "iconAndTextHorizontal"  
                and "iconAndTextVertical".  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2014", "2015"). Currently only accepts major version  
                numbers (e.g. 2014.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the layout.

    Example:
    """

def shelfTabLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., borderStyle: Queryable[str] = ..., changeCommand: Callable[..., Any] = ..., childArray: bool = ..., childResizable: bool = ..., closeTab: int = ..., closeTabCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., doubleClickCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontalScrollBarThickness: int = ..., image: Queryable[str] = ..., imageVisible: bool = ..., innerMarginHeight: Queryable[int] = ..., innerMarginWidth: Queryable[int] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., minChildWidth: Queryable[int] = ..., moveTab: Tuple[int, int] = ..., newTabCommand: Callable[..., Any] = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., postMenuCommand: Callable[..., Any] = ..., preSelectCommand: Callable[..., Any] = ..., preventOverride: bool = ..., scrollable: bool = ..., scrollableTabs: bool = ..., selectCommand: Queryable[Callable[..., Any]] = ..., selectTab: Queryable[str] = ..., selectTabIndex: Queryable[int] = ..., showNewTab: bool = ..., statusBarMessage: str = ..., tabIcon: Queryable[Multiuse[Tuple[str, str]]] = ..., tabIconIndex: Queryable[Multiuse[Tuple[int, str]]] = ..., tabLabel: Queryable[Multiuse[Tuple[str, str]]] = ..., tabLabelIndex: Queryable[Multiuse[Tuple[int, str]]] = ..., tabPosition: Queryable[str] = ..., tabTooltip: Queryable[Multiuse[Tuple[str, str]]] = ..., tabTooltipIndex: Queryable[Multiuse[Tuple[int, str]]] = ..., tabsClosable: bool = ..., tabsVisible: bool = ..., useTemplate: str = ..., verticalScrollBarThickness: int = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any], Multiuse[Tuple[str, str]], Multiuse[Tuple[int, str]]]:
    """This command creates/edits/queries a shelf tab group which is essentially
    a normal tabLayout with some drop behaviour in the tab bar.  A garbage can
    icon can appear in the top right corner to dispose of buttons dragged to
    it from shelves.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        borderStyle (Queryable[str]?): Specify the style of the border for tab layout. Valid values are:  
                "none", "top", "notop" and "full". By default, it will use "full" to draw a simple frame  
                around the body area of the tab layout.  
              
                "none"  - Do not draw borders around the body area of the tab layout  
                "top"   - Only draw a simple line right below the tabs  
                "notop" - Draw a simple frame on the left/right/bottom (no top) of the tab layout  
                "full"  - Draw a simple frame around the body area of the tab layout  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when a tab is selected interactively.  
                This command is only invoked when the selected tab changes.  
                Re-selecting the current tab will not invoke this command.  
                Properties: create, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        childResizable (bool?): Set to true if you want the child of the control layout to be  
                as wide as the scroll area.  You may also indicate a minimum  
                width for the child using the -mcw/minChildWidth flag.  
                Properties: create, query
        closeTab (int?): Close the tab at the given index.  
                Properties: create, edit
        closeTabCommand (Callable[..., Any]?): Specify a script to be executed when one of the tabs are closed by clicking on the  
                header widget (MMB or X button).  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Callable[..., Any]?): Command executed when a tab is double clicked on.  Note  
                that the first click will select the tab and the second click  
                will execute the double click command.  Double clicking the  
                current tab will re-invoke the double click command.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontalScrollBarThickness (int?): Thickness of the horizontal scroll bar.  Specify an  
                integer value greater than or equal to zero. This flag has  
                no effect on Windows systems.  
                Properties: create, edit
        image (Queryable[str]?): Image appearing in top right corner of tab layout.  
                Properties: create, query, edit
        imageVisible (bool?): Visibility of tab image.  
                Properties: create, query, edit
        innerMarginHeight (Queryable[int]?): Margin height for all tab children.  
                Properties: create, query
        innerMarginWidth (Queryable[int]?): Margin width for all tab children.  
                Properties: create, query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        minChildWidth (Queryable[int]?): Specify a positive non-zero integer value indicating the  
                minimum width the tab layout's children.  This flag only has  
                meaning when the -cr/childResizable flag is set to true.  
                Properties: create, query
        moveTab (Tuple[int, int]?): Move the tab from the current index to a new index.  
                Properties: create, edit
        newTabCommand (Callable[..., Any]?): Command executed when the 'New Tab' button (on the tab bar)  
                is clicked.  Note: in order to show the new tab button use  
                the -snt/showNewTab flag.  Using this command will  
                override any internal Maya logic for adding a new tab (only  
                this command will be executed).  
                Properties: create, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        postMenuCommand (Callable[..., Any]?): Specify a script to be executed when the popup menu is about to be shown.  
                Properties: create, edit
        preSelectCommand (Callable[..., Any]?): Command executed when a tab is selected but before it's  
                contents become visible.  Re-selecting the current tab will not  
                invoke this command.  Note that this command is not executed by  
                using either of the -st/selectTab  
                or -sti/selectTabIndex flags.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        scrollable (bool?): Puts all children of this layout within a scroll area.  
                Properties: create, query
        scrollableTabs (bool?): If true, the active tab in the layout can be scrolled through with the mouse wheel.  
                Default is true.  
                Properties: create, query, edit
        selectCommand (Queryable[Callable[..., Any]]?): Command executed when a tab is selected interactively  This  
                command will be invoked whenever a tab is selected, ie.  
                re-selecting the current tab will invoke this command.  Note that  
                this command is not executed by using either of  
                the -st/selectTab or -sti/selectTabIndex flags.  
                Properties: create, query, edit
        selectTab (Queryable[str]?): The name, in short form, of the selected tab.  An empty  
                string is returned on query if there are no child tabs.  
                Properties: create, query, edit
        selectTabIndex (Queryable[int]?): Identical to the -st/selectTab flag except this  
                flag takes a 1. based index to identify the selected tab.  A value of  
                0 is returned on query if there are no child tabs.  
                Properties: create, query, edit
        showNewTab (bool?): Set to true if you want to have a 'New Tab' button shown at the end of  
                the tab bar.  Note: use the -ntc/newTabCommand flag to set the command  
                executed when this button is clicked.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        tabIcon (Queryable[Multiuse[Tuple[str, str]]]?): Set an icon for a tab.  The first argument is the name of a  
                control that must be a child of the tab layout.  The second  
                argument is the icon file name.  
                Properties: create, query, edit, multiuse
        tabIconIndex (Queryable[Multiuse[Tuple[int, str]]]?): Identical to the -ti/tabIcon flag except this  
                flag takes a 1. based index to identify the tab you want to set the  
                icon for. If this flag is queried the tab icons for all the  
                children are returned.  
                Properties: create, query, edit, multiuse
        tabLabel (Queryable[Multiuse[Tuple[str, str]]]?): Set a tab label.  The first argument is the name of a  
                control that must be a child of the tab layout.  The second  
                argument is the label for the tab associated with that child.  
                If this flag is queried then the tab labels for all the children  
                are returned.  
                Properties: create, query, edit, multiuse
        tabLabelIndex (Queryable[Multiuse[Tuple[int, str]]]?): Identical to the -tl/tabLabel flag except this  
                flag takes a 1. based index to identify the tab you want to set the  
                label for. If this flag is queried the tab labels for all the  
                children are returned.  
                Properties: create, query, edit, multiuse
        tabPosition (Queryable[str]?): Changes the tab position. The possible values are: "north", "east" and "west".  
                Properties: create, query, edit
        tabTooltip (Queryable[Multiuse[Tuple[str, str]]]?): Set a tab tooltip.  The first argument is the name of a  
                control that must be a child of the tab layout.  The second  
                argument is the tooltip for the tab associated with that child.  
                If this flag is queried then the tab tooltips for all the children  
                are returned.  
                Properties: create, query, edit, multiuse
        tabTooltipIndex (Queryable[Multiuse[Tuple[int, str]]]?): Identical to the -tt/tabTooltip flag except this  
                flag takes a 1. based index to identify the tab you want to set the  
                tooltip for. If this flag is queried the tab tooltips for all the  
                children are returned.  
                Properties: create, query, edit, multiuse
        tabsClosable (bool?): Set to true if you want to have a close button icon on all created tabs.  
                Properties: create, query
        tabsVisible (bool?): Visibility of the tab labels.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalScrollBarThickness (int?): Thickness of the vertical scroll bar.  Specify an  
                integer value greater than or equal to zero. This flag has  
                no effect on Windows systems.  
                Properties: create, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the shelfTabLayout.

    Example:
    """

def shot(arg0: str = ..., arg1: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., audio: Queryable[str] = ..., clip: Queryable[str] = ..., clipDuration: Queryable[int] = ..., clipOpacity: Queryable[float] = ..., clipSyncState: bool = ..., clipZeroOffset: Queryable[int] = ..., copy: bool = ..., createCustomAnim: bool = ..., currentCamera: Queryable[str] = ..., customAnim: bool = ..., deleteCustomAnim: bool = ..., determineTrack: bool = ..., endTime: Queryable[int] = ..., favorite: bool = ..., flag1: bool = ..., flag10: bool = ..., flag11: bool = ..., flag12: bool = ..., flag2: bool = ..., flag3: bool = ..., flag4: bool = ..., flag5: bool = ..., flag6: bool = ..., flag7: bool = ..., flag8: bool = ..., flag9: bool = ..., hasCameraSet: bool = ..., hasStereoCamera: bool = ..., imagePlaneVisibility: bool = ..., linkAudio: Queryable[str] = ..., lock: bool = ..., mute: bool = ..., paste: bool = ..., pasteInstance: bool = ..., postHoldTime: Queryable[int] = ..., preHoldTime: Queryable[int] = ..., scale: Queryable[float] = ..., selfmute: bool = ..., sequenceDuration: Queryable[int] = ..., sequenceEndTime: Queryable[int] = ..., sequenceStartTime: Queryable[int] = ..., shotName: Queryable[str] = ..., sourceDuration: Queryable[int] = ..., startTime: Queryable[int] = ..., track: Queryable[int] = ..., transitionInLength: Queryable[int] = ..., transitionInType: Queryable[int] = ..., transitionOutLength: Queryable[int] = ..., transitionOutType: Queryable[int] = ..., unlinkAudio: bool = ...) -> Union[str, int, float, bool]:
    """Use this command to create a shot node or manipulate that node.reference, sequencer, node
    Args:
        audio (Queryable[str]?): Specify the audio clip for this shot. Audio can be linked to a shot to allow playback of specific sounds when that shot is being displayed in the Sequencer. Refer to the shot node's documentation for details on how audio is used by shots and the Sequencer.  
                Properties: create, query, edit
        clip (Queryable[str]?): The clip associated with this shot. This clip will be posted to the currentCamera's imagePlane. Refer to the shot node's documentation for details on how cameras are used by shots and the Sequencer.  
                Properties: create, query, edit
        clipDuration (Queryable[int]?): Length of clip. This is used for the display of the clip indicator bar in the Sequencer.  
                Properties: create, query, edit
        clipOpacity (Queryable[float]?): Opacity for the shot's clip, this value is assigned to the currentCamera's imagePlane. Refer to the shot node's documentation for details on how cameras are used by shots and the Sequencer.  
                Properties: create, query, edit
        clipSyncState (bool?): The viewport synchronization status of the clip associated with this shot.  
                Return values are,  
                0 = no clip associated with this shot  
                1 = clip is fully in sync with viewport, and frames are 1. 1 with sequencer  
                2 = clip is partially in sync with viewport, movie may be scaled to match sequencer  
                3 = clip not in sync with viewport (i.e. could have scale/time/camera differences)  
                Properties: create, query, edit
        clipZeroOffset (Queryable[int]?): Specify which time of the clip corresponds to the beginning of the shot. This is used to properly align splitted clips.  
                Properties: create, query, edit
        copy (bool?): This flag is used to copy a shot to the clipboard. In query mode, this flag allows you to query what, if anything, has been copied into the shot clipboard.  
                Properties: create, query, edit
        createCustomAnim (bool?): Creates an animation layer and links the shot node's customAnim attr to the weight  
                attr of the animation layer  
                Properties: edit
        currentCamera (Queryable[str]?): The camera associated with this shot. Refer to the shot node's documentation for details on how cameras are used by shots and the Sequencer.  
                Properties: create, query, edit
        customAnim (bool?): Returns the name of the animation layer node linked to this shot node's customAnim attr  
                Properties: query
        deleteCustomAnim (bool?): Disconnects the animation layer from this shot's customAnim attr and deletes the  
                animation layer node  
                Properties: edit
        determineTrack (bool?): Determines an available track for the shot. Returns a new track number or the  
                existing track number if the current track is available.  
                Properties: query, edit
        endTime (Queryable[int]?): The shot end time in the Maya timeline. Changing the startTime will extend the duration of a shot.  
                Properties: create, query, edit
        favorite (bool?): Make the shot a favorite. This is a UI indicator only to streamline navigation in the Sequencer panel  
                Properties: create, query, edit
        flag1 (bool?): User specified state flag 1/12 for this shot  
                Properties: create, query, edit
        flag10 (bool?): User specified state flag 10/12 for this shot  
                Properties: create, query, edit
        flag11 (bool?): User specified state flag 11/12 for this shot  
                Properties: create, query, edit
        flag12 (bool?): User specified state flag 12/12 for this shot  
                Properties: create, query, edit
        flag2 (bool?): User specified state flag 2/12 for this shot  
                Properties: create, query, edit
        flag3 (bool?): User specified state flag 3/12 for this shot  
                Properties: create, query, edit
        flag4 (bool?): User specified state flag 4/12 for this shot  
                Properties: create, query, edit
        flag5 (bool?): User specified state flag 5/12 for this shot  
                Properties: create, query, edit
        flag6 (bool?): User specified state flag 6/12 for this shot  
                Properties: create, query, edit
        flag7 (bool?): User specified state flag 7/12 for this shot  
                Properties: create, query, edit
        flag8 (bool?): User specified state flag 8/12 for this shot  
                Properties: create, query, edit
        flag9 (bool?): User specified state flag 9/12 for this shot  
                Properties: create, query, edit
        hasCameraSet (bool?): Returns true if the camera associated with this shot is a camera set.  
                Properties: create, query, edit
        hasStereoCamera (bool?): Returns true if the camera associated with this shot is a stereo camera.  
                Properties: create, query, edit
        imagePlaneVisibility (bool?): Visibility of the shot imageplane, this value is assigned to the currentCamera's imagePlane.  
                Properties: create, query, edit
        linkAudio (Queryable[str]?): Specify an audio clip to link to this shot. Any currently linked audio will be unlinked.  
                Properties: create, query, edit
        lock (bool?): Lock a specific shot. This is different than locking an entire track, which is done via the shotTrack command  
                Properties: create, query, edit
        mute (bool?): Mute a specific shot. This is different than muting an entire track, which is done via the shotTrack command. Querying this attribute will return true if the shot is muted due to its own mute, its shot being muted, or its shot being unsoloed. See flag "selfmute" to query only the shot's own state.  
                Properties: create, query, edit
        paste (bool?): This flag is used to paste a shot or shots from the clipboard to the sequence timeline. Shots are added to the clipboard using the c/copy flag.  
                Properties: create, query, edit
        pasteInstance (bool?): This flag is used to paste an instance of a shot or shots from the clipboard to the sequence timeline. Unlike the p/paste flag, which duplicates the camera and image plane from the original source shot, the pi/pasteInstance flag shares the camera and image plane from the source shot. The audio node is duplicated.  
                Properties: create, query, edit
        postHoldTime (Queryable[int]?): Specify the time length to append to the shot in the sequence timeline. This repeats the last frame of the shot, in sequence time, over the specified duration.  
                Properties: create, query, edit
        preHoldTime (Queryable[int]?): Specify the time length to prepend to the shot in the sequence timeline. This repeats the first frame of the shot, in sequence time, over the specified duration.  
                Properties: create, query, edit
        scale (Queryable[float]?): Specify an amount to scale the Maya frame range of the shot. This will affect the sequenceEndFrame, leaving the sequenceStartFrame unchanged.  
                Properties: create, query, edit
        selfmute (bool?): Query if this individual shot's own mute state is set. This is different from the flag "mute", which will return true if this shot is muted due to the track being muted or another track being soloed. Editing this flag will set this shot's own mute status (identical behavior as the flag "mute").  
                Properties: create, query, edit
        sequenceDuration (Queryable[int]?): Return the sequence duration of the shot, which will include the holds and scale. This flag can only be queried.  
                Properties: query, edit
        sequenceEndTime (Queryable[int]?): The shot end in the sequence timeline. Changing the endTime of a shot will scale it in sequence time.  
                Properties: create, query, edit
        sequenceStartTime (Queryable[int]?): The shot start in the sequence timeline. Changing the startTime of a shot will shift it in sequence time.  
                Properties: create, query, edit
        shotName (Queryable[str]?): Specify a user-defined name for this shot. This allows the assignment of names that are not valid as node names within Maya. Whenever the shotName attribute is defined its value is used in the UI.  
                Properties: create, query, edit
        sourceDuration (Queryable[int]?): Return the number of source frames in the shot. This flag can only be queried.  
                Properties: query, edit
        startTime (Queryable[int]?): The shot start time in the Maya timeline. Changing the startTime will extend the duration of a shot.  
                Properties: create, query, edit
        track (Queryable[int]?): Specify the track in which this shot resides.  
                Properties: query, edit
        transitionInLength (Queryable[int]?): Length of the transtion into the shot.  
                Properties: create, query, edit
        transitionInType (Queryable[int]?): Specify the the type of transition for the transition into the shot.  
                0 = Fade  
                1 = Dissolve  
                Properties: query, edit
        transitionOutLength (Queryable[int]?): Length of the transtion out of the shot.  
                Properties: create, query, edit
        transitionOutType (Queryable[int]?): Specify the the type of transition for the transition out of the shot.  
                0 = Fade  
                1 = Dissolve  
                Properties: query, edit
        unlinkAudio (bool?): COMMENT  
                Unlinks any currently linked audio.  
                Properties: query, edit

    Returns:
        str: Shot name

    Example:
    """

def shotRipple(arg0: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., deleted: bool = ..., endDelta: Queryable[int] = ..., endTime: Queryable[int] = ..., startDelta: Queryable[int] = ..., startTime: Queryable[int] = ...) -> Union[bool, int]:
    """When Ripple Edit Mode is enabled, neighboring shots to the shot that gets manipulated
    are moved in sequence time to either make way or close up gaps corresponding to that
    node's editing.
    Given some parameters about the shot edit that just took place, this command
    will choose which other shots to move, and move them the appropriate amounts
    If no shot name is provided, the command will attempt to use the first selected shot.reference, sequencer, node, shot, ripple
    Args:
        deleted (bool?): Specify whether this ripple edit is due to a shot deletion  
                Properties: create, query, edit
        endDelta (Queryable[int]?): Specify the change in the end time in frames  
                Properties: create, query, edit
        endTime (Queryable[int]?): Specify the initial shot end time in the sequence timeline.  
                Properties: create, query, edit
        startDelta (Queryable[int]?): Specify the change in the start time in frames  
                Properties: create, query, edit
        startTime (Queryable[int]?): Specify the initial shot start time in the sequence timeline.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def shotTrack(*args: str, edit: bool = ..., query: bool = ..., insertTrack: int = ..., lock: bool = ..., mute: bool = ..., numTracks: Queryable[int] = ..., removeEmptyTracks: bool = ..., removeTrack: int = ..., selfmute: bool = ..., solo: bool = ..., swapTracks: Tuple[int, int] = ..., title: Queryable[str] = ..., track: int = ..., unsolo: bool = ...) -> Union[bool, int, str]:
    """This command is used for inserting and removing tracks related to the shots displayed in the Sequencer. It can also be used to modify the track state, for example, to lock or mute a track.shot, sequencer, track
    Args:
        insertTrack (int?): This flag is used to insert a new empty track at the track index specified.  
                Properties: create
        lock (bool?): This flag specifies whether shots on a track are to be locked or not.  
                Properties: create, query, edit
        mute (bool?): This flag specifies whether shots on a track are to be muted or not.  
                Properties: create, query, edit
        numTracks (Queryable[int]?): To query the number of tracks  
                Properties: query
        removeEmptyTracks (bool?): This flag is used to remove all tracks that have no clips.  
                Properties: create
        removeTrack (int?): This flag is used to remove the track with the specified index.  The  
                track must have no clips on it before it can be removed.  
                Properties: create
        selfmute (bool?): This flag specifies whether shots on a track are to be muted or not (unlike mute, this disregards soloing).  
                Properties: create, query, edit
        solo (bool?): This flag specifies whether shots on a track are to be soloed or not.  
                Properties: create, query, edit
        swapTracks (Tuple[int, int]?): This flag is used to swap the contents of two specified tracks.  
                Properties: create
        title (Queryable[str]?): This flag specifies the title for the track.  
                Properties: create, query, edit
        track (int?): Specify the track on which to operate by using the track's trackNumber.  
                			In query mode, this flag needs a value.  
                Properties: create, query, edit
        unsolo (bool?): This flag specifies whether shots on a track are to be unsoloed or not.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def showHelp(arg0: str = ..., /, *, query: bool = ..., absolute: bool = ..., docs: bool = ..., helpTable: bool = ..., version: bool = ...) -> bool:
    """Invokes a web browser to open the on-line documentation and help files.
    It will open the help page for a given topic, or open a browser
    to a specific URL.browse, documentation, web, page, help
    Args:
        absolute (bool?): The specified "URL" is an absolute URL that should be passed directly  
                to the web browser.  
                Properties: create
        docs (bool?): Use this flag to directly specify a help file relative to the  
                on-line documentation root.  
                Properties: create, query
        helpTable (bool?): Use this flag to specify which file will be used to search for help  
                topics when the -d/docs and -a/absolute flags are not used. If only  
                a file name is specified and not a path, then the file is assumed to  
                be in the maya application directory.  
                If this flag does not accept an argument if it is queried.  
                The default value is "helpTable".  
                Properties: create, query
        version (bool?): Use this flag to get the Maya version that the showHelp command uses.  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def showHidden(*args: str, above: bool = ..., allObjects: bool = ..., below: bool = ..., lastHidden: bool = ...) -> bool:
    """Thecommand is used to make invisible
    objects visible.  If no flags are specified, only the objects
    given to the command will be made visible. If a parent of an object
    is invisible, the object will still be invisible. Invisibility
    is inherited. To ensure the object becomes visible, use the
    -a/above flag. This forces all invisible ancestors of the object(s)
    to be visible. If the -b/below flag is used, any invisible objects
    below the object will be made visible.  To make all objects visible,
    use the -all/allObjects flag.hide
    Args:
        above (bool?): Make objects and all their invisible ancestors visible.  
                Properties: create
        allObjects (bool?): Make all invisible objects visible.  
                Properties: create
        below (bool?): Make objects and all their invisible descendants visible.  
                Properties: create
        lastHidden (bool?): Show everything that was hidden with the last hide command.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def showManipCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addAttr: str = ..., currentNodeName: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., incSnap: Queryable[Multiuse[Tuple[int, bool]]] = ..., incSnapRelative: Queryable[Multiuse[Tuple[int, bool]]] = ..., incSnapUI: bool = ..., incSnapValue: Queryable[Multiuse[Tuple[int, float]]] = ..., iveVisible: bool = ..., lockSelection: bool = ..., moveActiveAttrDown: bool = ..., moveActiveAttrToTop: bool = ..., moveActiveAttrUp: bool = ..., name: str = ..., removeAttr: str = ..., resetActiveAttr: bool = ..., selectedAttributes: bool = ..., setAttrActive: str = ..., setNextAttrActive: bool = ..., setPreviousAttrActive: bool = ..., toggleIncSnap: bool = ..., toolFinish: Queryable[Callable[..., Any]] = ..., toolStart: Queryable[Callable[..., Any]] = ...) -> Union[str, bool, Multiuse[Tuple[int, bool]], Multiuse[Tuple[int, float]], Callable[..., Any]]:
    """This command can be used to create a show manip context.  The show manip
    context will display manips for all selected objects that have valid
    manips defined for them.
    Args:
        addAttr (str?): Add a specific attribute to the In View Editor attribute list.  
                Properties: edit
        currentNodeName (bool?): Returns the name of the first node that the context is attached to.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        incSnap (Queryable[Multiuse[Tuple[int, bool]]]?): If true, the manipulator owned by the context will use incremental snapping for specified mode.  
                Properties: create, query, edit, multiuse
        incSnapRelative (Queryable[Multiuse[Tuple[int, bool]]]?): If true, the manipulator owned by the context will use relative incremental snapping for specified mode.  
                Properties: create, query, edit, multiuse
        incSnapUI (bool?): Returns an array of elements indicating what kind of incremental snap UI is  
                required by the manipulator owned by the context.  
                If no UI is required, the result array will contain a single element  
                of with the value 0. The other values and their meanings are:  
              
                1. UI for linear incremental translate  
                2. UI for incremental rotate  
                3. UI for inclremental scale  
                Properties: query
        incSnapValue (Queryable[Multiuse[Tuple[int, float]]]?): Supply the step value which the manipulator owned by the context will use for specified mode.  
                Properties: create, query, edit, multiuse
        iveVisible (bool?): Set the In View Editor visible or not.  
                Properties: query, edit
        lockSelection (bool?): If true, this context will never change the current selection.  
                By default this is set to false.  
                Properties: create, query, edit
        moveActiveAttrDown (bool?): Move the In View Editor active attribute down one in the list.  
                Properties: edit
        moveActiveAttrToTop (bool?): Move the In View Editor active attribute to the top of the list.  
                Properties: edit
        moveActiveAttrUp (bool?): Move the In View Editor active attribute up one in the list.  
                Properties: edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        removeAttr (str?): Remove a specific attribute from the In View Editor attribute list.  
                Properties: edit
        resetActiveAttr (bool?): Reset the In View Editor active attribute to its default value.  
                Properties: edit
        selectedAttributes (bool?): Returns a list of the names of the attributes that are currently visible  
                in the In View Editor.  
                Properties: query
        setAttrActive (str?): Set a specific attribute from the In View Editor attribute list active.  
                Properties: edit
        setNextAttrActive (bool?): Set the next attribute in the In View Editor attribute list active.  
                Properties: edit
        setPreviousAttrActive (bool?): Set the previous attribute in the In View Editor attribute list active.  
                Properties: edit
        toggleIncSnap (bool?): Toggles (enables/disables) snapping for all modes.  
                Properties: create, edit
        toolFinish (Queryable[Callable[..., Any]]?): Supply the script that will be run when the user exits  
                the script.  
                Properties: create, query, edit
        toolStart (Queryable[Callable[..., Any]]?): Supply the script that will be run when the user first  
                enters the script  
                Properties: create, query, edit

    Returns:
        str: The name of the newly created context.

    Example:
    """

def showMetadata(*args: str, query: bool = ..., auto: bool = ..., dataType: Queryable[str] = ..., interpolation: bool = ..., isActivated: bool = ..., listAllStreams: bool = ..., listMembers: bool = ..., listValidMethods: bool = ..., listVisibleStreams: bool = ..., member: Queryable[str] = ..., method: Queryable[str] = ..., off: bool = ..., range: Queryable[Tuple[float, float]] = ..., rayScale: Queryable[float] = ..., stream: Queryable[str] = ...) -> Union[str, bool, Tuple[float, float], float]:
    """This command is used to show metadata values which is in the
    specified channels "vertex", "edge", "face", and "vertexFace" in
    the viewport. You can view the data by three ways:For example, if the metadata of "shape.vtx[1]" is (1, 0, 0), you can turn on
    the visualization with all three modes.
    On "color" mode, you can see a red vertex which is on the position of "shape.vtx[1]".
    On "ray" mode, you can see a ray with the direction (1, 0, 0).
    On "string" mode, you can see strings "1 0 0" below the vertex in the viewport.To use "color" or "ray" mode, you should make the member of the data structure
    with three or less items, such as float[3]. The three items are mapped to "RGB" as a color, or "XYZ"
    as a vector. The structure with two items works similarly. The only difference
    is that the third value will always be zero.
    However, if the structure has only one item, the value is mapped to all three variables.
    That means if the structure is "int" and its value is 1, the color will be white(1, 1, 1)
    and the vector will be (1, 1, 1).You can get the current status of the flags on the query mode (using "-query").
    But you can query only the status of one flag in a single command and
    you cannot set values on the query mode.You can use the command on some specified objects, or run it with no arguments
    to make changes on all objects in the scene. The object must be a mesh shape.
    Components are not allowed as the command arguments.metadata, component, stream, channel, association
    Args:
        auto (bool?): Similar to the flag "-range", but uses the min/max value from the metadata in the same stream  
                and member instead of the specified input value.  
                In query mode, you can use the flag to query if "auto" is on.  
                Properties: create, query
        dataType (Queryable[str]?): In create mode, when used with the flags "stream" and "member",  
                specify a member to show.  
                If the flag "off" is used, specify the member to turn off.  
                In query mode, when used with the flags "stream" and "member", query  
                the visualization state of the specified member.  
                Only one member of each shape can be visualized at a time.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        interpolation (bool?): In create mode, enable/disable interpolation for "color" method.  
                When interpolation is on, the components will be displayed in the interpolated color,  
                which is computed by averaging their metadata values.  
                In query mode, query the current state of interpolation flag of  
                the selected objects.  
                Properties: create, query
        isActivated (bool?): Used to check if the given stream is activated.  
                If some shapes are selected, query their states.  
                If no shape is selected, query the states of all shapes  
                in the scene.  
                Properties: create, query
        listAllStreams (bool?): Used with object names to list all streams of the specified objects.  
                no matter if they are visible in the viewport.  
                Or you can use the flag individually to list all streams in the scene.  
                Due to the fact that different objects may have the same stream name,  
                the returned list will merge the duplicated stream names automatically.  
                Properties: create, query
        listMembers (bool?): Used with the flag 'stream' to get the  
                member list in the specified stream.  
                Properties: create, query
        listValidMethods (bool?): List the valid visual methods that can be set for the current stream and member. Some data type cannot be displayed  
                by some methods. For example, if the data type is "string", it cannot be displayed by "color" or by "ray".  
                In other words, only the method "string" will be returned when you list the methods.  
                Properties: create, query
        listVisibleStreams (bool?): Used with object names to list the name of the current visible streams of  
                the specified object. Or you can use the flag with no object name to list  
                all visible streams in the scene.  
                Properties: create, query
        member (Queryable[str]?): In create mode, when used with the flags "stream" and "dataType",  
                specify a member to show.  
                If the flag "off" is on, specify the member to turn off.  
                In query mode, when used with the flags "stream" and "dataType", query  
                the visualization state of the specified member.  
                Only one member of each shape can be visualized at a time.  
                			In query mode, this flag can accept a value.  
                Properties: create, query
        method (Queryable[str]?): Determine the method of visualization:  
                "color"         convert metadata to a color value and draw the components with the color  
                "ray"           convert metadata to a vector and draw this vector line which starts from the center of the component  
                "string"        display the metadata through 2d string beside the component in the viewport  
                The argument must be a string and must be one of the three words. The default method is "color".  
                If the data type is string, you can only show it with "string" method.  
                In query mode, you can use the flag with no arguments to query the method of a specified stream and member.  
                Properties: create, query
        off (bool?): In create mode, turn off the member which is specified  
                by the flags "stream", "member" and "dataType".  
                Properties: create, query
        range (Queryable[Tuple[float, float]]?): Specify the range of data to use. The value which is out of the range will be clamped to  
                the min/max value.  
                If the method of visualization is "color", the range will be mapped to the color. That means  
                the min value will be displayed in black while the max value will be in white.  
                In query mode, you can use the flag individually to query the current range.  
                Properties: create, query
        rayScale (Queryable[float]?): Specify the scale of the ray to display it with a proper length.  
                Properties: create, query
        stream (Queryable[str]?): In create mode, when used with the flags "member" and "dataType", specify a member to show.  
                If the flag "off" is used, specify the member to turn off.  
                In query mode, when used with the flags "member" and "dataType", query  
                the visualization state of the specified member.  
                When used with the flag "listMembers", query the members in the  
                specified stream.  
                Only one member of each shape can be visualized at a time.  
                			In query mode, this flag can accept a value.  
                Properties: create, query

    Returns:
        str: result of the operation or the queried status

    Example:
    """

def showSelectionInTitle(arg0: str = ..., /) -> bool:
    """This command causes the title of the window specified as an argument
    to be linked to the current file and selection. When selection
    changes, the window title will change to show the current file name
    and the name of the last selected object.
    Returns:
        bool:

    Example:
    """

def showShadingGroupAttrEditor(*args: Any) -> bool:
    """The showShadingGroupAttrEditor command opens up the attribute
    editor for the current object's shading-group information.
    Returns:
        bool: true if a shading group is displayed, otherwise false.

    Example:
    """

def showWindow(arg0: str = ..., /) -> bool:
    """Make a window visible. If no window is specified then the current
    window (most recently created) is used. See also thecommand'sflag.If the specified window is iconified, it will be opened.
    Returns:
        bool:

    Example:
    """

def simplify(*args: str, animation: str = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., floatTolerance: float = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ..., timeTolerance: int = ..., valueTolerance: float = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command will simplify (reduce the number of keyframes) an animation
    curve.
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        floatTolerance (float?): Specify the x-axis tolerance (defaults to 0.05) for  
                float-input animCurves such as those created by "Set Driven Keyframe".  
                This flag is ignored on animCurves driven by time. Higher floatTolerance  
                values will result in sparser keys which may less accurately represent  
                the initial curve.  
                Properties: create
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        timeTolerance (int?): Specify the x-axis tolerance (defaults to 0.05 seconds)  
                for time-input animCurves. This flag is ignored on animCurves  
                driven by floats. Higher time tolerance values will result in  
                sparser keys which may less accurately represent  
                the initial curve.  
                Properties: create
        valueTolerance (float?): Specify the value tolerance (defaults to 0.01)  
                Properties: create

    Returns:
        int: Number of animation curves simplified

    Example:
    """

def singleProfileBirailSurface(arg0: str = ..., arg1: str = ..., /, *args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., tangentContinuityProfile1: bool = ..., transformMode: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], bool, int]:
    """This cmd creates a railed surface by sweeping the profile curve along
    the two rail curves. One of the requirements for surface creation is
    the profile curve must intersect the two rail curves. If the profile
    is a surface curve i.e. isoparm, curve on surface or trimmed edge then
    tangent continuity across the surface underlying the profile may be
    enabled using the flag -tp1 true.The first argument represetns the profile curve, the second and third
    the rails.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        tangentContinuityProfile1 (bool?): Need to be tangent continuous across the profile. The profile must be a surface curve.  
                Default: false  
                Properties: create, query, edit
        transformMode (Queryable[int]?): transform mode ( Non proportional, proportional ). Non proportional is default value.  
                Default: 0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def skeletonEmbed(*args: str, query: bool = ..., mergedMesh: bool = ..., segmentationMethod: int = ..., segmentationResolution: int = ...) -> bool:
    """This command is used to embed a skeleton inside meshes.geomBind
    Args:
        mergedMesh (bool?): When specified, the query command merges selected meshes together and returns a  
                Python object representing the merged mesh.  
                Properties: query
        segmentationMethod (int?): Specifies which segmentation algorithm to use to determine what is inside the mesh  
                and what is outside the mesh.  By default, boundary-and-fill-and-grow voxelization  
                will be used.  
              
                Available algorithms are:  
              
              
                0  : Perfect mesh (no voxelization).  
                This method works for "perfect meshes", i.e. meshes that are closed, watertight,  
                2. manifold and without self-intersection or interior/hidden geometry.  It segments  
                the interior region of the mesh from the exterior using a pseudo-normal test.  
                It does not use voxelization.  If mesh conditions are not respected, the segmentation  
                is likely to be wrong.  This can make the segmentation process significantly longer  
                and prevent successful skeleton embedding.  
              
              
                1. Watertight mesh (flood fill).  
                This method works for "watertight meshes", i.e. meshes for which faces completely  
                separate the interior region of the mesh from the exterior.  The mesh can have  
                degenerated faces, wrong face orientation, self-intersection, etc.  The method  
                uses surface voxelization to classify as part of the interior region all voxels  
                intersecting with a mesh face.  It then performs flood-filling from the outside,  
                marking all reached voxels as part of the exterior region of the model.  Finally,  
                all unreached voxels are marked as part of the interior region.  This method works  
                so long as the mesh is watertight, i.e. without holes up to the voxelization resolution.  
                Otherwise, flood-filling reaches the interior region and creates inaccurate segmentation.  
              
              
                2. Imperfect mesh (flood fill + growing).  
                This method works for meshes where holes could make the flood-filling step reach the  
                interior region of the mesh, but that have face orientation consistent enough so filling  
                them is possible.  First, it uses surface voxelization to classify as part of the interior  
                region all voxels intersecting with a mesh face.  It then alternates flood-filling and  
                growing steps.  The flood-filling tries to reach all voxels from the outside so that  
                unreached voxels are marked as part of the interior region.  The growing step uses a  
                relatively computation-intensive process to check for interior voxels in all neighbors  
                to those already identified.  Any voxel identified as interior is likely to fill holes,  
                allowing subsequent flood-filling steps to identify more interior voxels.  
              
              
                3. Polygon soup (repair).  
                This method has no manifold or face orientation requirements.  It reconstructs a mesh  
                that wraps the input mesh with a given offset (3 times the voxel size) and uses this  
                perfect 2. manifold mesh to segment the interior region from the exterior region of the model.  
                Because of the offset, it might lose some of the details and merge parts that are proximal.  
                However, this usually is not an issue with common models where body parts are not too close  
                to one another.  
              
              
                99. Direct skeleton (no embedding).  
                This method does not try to perform embedding.  It simply returns the skeleton in its initial  
                pose without any attempt at embedding inside the meshes, other than placing it in the meshes  
                bounding box.  
                Properties: create
        segmentationResolution (int?): Specifies which segmentation resolution to use for the voxel grid.  By default,  
                256x256x256 voxels will be used.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def skinBindCtx(*args: Any, edit: bool = ..., query: bool = ..., about: Queryable[str] = ..., axis: Queryable[str] = ..., colorRamp: Queryable[str] = ..., currentInfluence: Queryable[str] = ..., displayInactiveMode: Queryable[int] = ..., displayNormalized: bool = ..., exists: bool = ..., falloffCurve: Queryable[str] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., symmetry: bool = ..., tolerance: Queryable[float] = ...) -> Union[str, int, bool, float]:
    """This command creates a tool that can be used to edit volumes from an interactive bind.
    Args:
        about (Queryable[str]?): The space in which the axis should be mirrored. Valid values are: "world" and "object".  
                Properties: create, query, edit
        axis (Queryable[str]?): The mirror axis. Valid values are: "x","y", and "z".  
                Properties: create, query, edit
        colorRamp (Queryable[str]?): Set the values on the color ramp used to display the weight values.  
                Properties: create, query, edit
        currentInfluence (Queryable[str]?): Set the index of the current influence or volume to be adjusted by the manipulator.  
                Properties: create, query, edit
        displayInactiveMode (Queryable[int]?): Determines the display mode for drawing volumes that are not selected,  
                in particular which volume cages if any are displayed.  
                0. None  
                1. Nearby volumes  
                2. All volumes  
                Properties: create, query, edit
        displayNormalized (bool?): Display raw select weights (false) or finalized normalized weights (true).  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        falloffCurve (Queryable[str]?): Set the values on the falloff curve control.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        symmetry (bool?): Controls whether or not the tool operates in symmetric (mirrored) mode.  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance setting for determining whether another influence is symmetric to the the current influence.  
                Properties: create, query, edit

    Returns:
        str: The name of the context created

    Example:
    """

def skinCluster(*args: str, edit: bool = ..., query: bool = ..., addInfluence: Multiuse[str] = ..., addToSelection: bool = ..., after: bool = ..., afterReference: bool = ..., baseShape: Multiuse[str] = ..., before: bool = ..., bindMethod: Queryable[int] = ..., components: bool = ..., deformerTools: bool = ..., dropoffRate: Queryable[float] = ..., exclusive: Queryable[str] = ..., forceNormalizeWeights: bool = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., heatmapFalloff: float = ..., ignoreBindPose: bool = ..., ignoreHierarchy: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., influence: Queryable[str] = ..., lockWeights: bool = ..., maximumInfluences: Queryable[int] = ..., moveJointsMode: bool = ..., multi: bool = ..., name: str = ..., normalizeWeights: Queryable[int] = ..., nurbsSamples: int = ..., obeyMaxInfluences: bool = ..., parallel: bool = ..., polySmoothness: float = ..., prune: bool = ..., recacheBindMatrices: bool = ..., remove: Multiuse[bool] = ..., removeFromSelection: bool = ..., removeInfluence: Multiuse[str] = ..., removeUnusedInfluence: bool = ..., selectInfluenceVerts: str = ..., selectedComponents: bool = ..., skinMethod: Queryable[int] = ..., smoothWeights: float = ..., smoothWeightsMaxIterations: int = ..., split: bool = ..., toSelectedBones: bool = ..., toSkeletonAndTransforms: bool = ..., unbind: bool = ..., unbindKeepHistory: bool = ..., useComponentTags: bool = ..., useGeometry: bool = ..., volumeBind: float = ..., volumeType: int = ..., weight: float = ..., weightDistribution: Queryable[int] = ..., weightedInfluence: bool = ...) -> Union[str, int, bool, float, Multiuse[str]]:
    """The skinCluster command is used for smooth skinning in maya. It
    binds the selected geometry to the selected
    joints or skeleton by means of a skinCluster node.  Each point of the bound
    geometry can be affected by any number of joints.
    The extent to which each joint affects the motion of each point is
    regulated by a corresponding weight factor.  Weight factors can be
    modified using the skinPercent command.  The command returns the name
    of the new skinCluster.The skinCluster binds only a single geometry at a time. Thus, to bind
    multiple geometries, multiple skinCluster commands must be issued.Upon creation of a new skinCluster, the command can be used to add
    and remove transforms (not necessarily joints) that influence the
    motion of the bound skin points.The skinCluster command can also be used to adjust parameters such
    as the dropoff, nurbs samples, polygon smoothness on a particular
    influence object. Note: Any custom weights on a skin point that
    the influence object affects will be lost after adjusting these
    parameters.
    Args:
        addInfluence (Multiuse[str]?): The specified transform or joint will be added to the  
                list of transforms that influence the bound geometry.  
                The maximum number of influences will be observed  
                and only the weights of the cv's that the specified  
                transform effects will change.  
                This flag is multi-use.  
                Properties: edit, multiuse
        addToSelection (bool?): When used in conjunction with the selectInfluenceVerts flag, causes the vertices  
                afftected by the influence to be added to the current selection, without first  
                de-selecting other vertices.  
                Properties: edit
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        baseShape (Multiuse[str]?): This flag can be used in conjunction with  
                the -addInfluence flag to specify the shape that will  
                be used as the base shape when an influence object with  
                geometry is added to the skinCluster.  If the flag  
                is not used then the command will make a copy of the  
                influence object's shape and use that as a base shape.  
                Properties: edit, multiuse
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        bindMethod (Queryable[int]?): This flag sets the binding method.  
                0. Closest distance between a joint and a point of the geometry.  
                1. Closest distance between a joint, considering the skeleton  
                hierarchy, and a point of the geometry.  
                2. Surface heat map diffusion.  
                3. Geodesic voxel binding.  geomBind command must be called after creating a skinCluster with this method.  
                Properties: create, query
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        dropoffRate (Queryable[float]?): Sets the rate at which the influence of a transform  
                drops as the distance from that transform increases.  
                The valid range is between 0.1 and 10.0.  In Create  
                mode it sets the dropoff rate for all the bound  
                joints.  In Edit mode the flag is used together with the  
                inf/influence flag to set the dropoff rate of a  
                particular influence.  Note: When the flag is used in  
                Edit mode, any custom weights on the skin points the  
                given transform influences will be lost.  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        forceNormalizeWeights (bool?): If the normalization mode is none or post, it is possible (indeed likely) for the weights in the skin  
                cluster to no longer add up to 1.  This flag forces all weights to add back to 1 again.  
                Properties: edit
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        heatmapFalloff (float?): This flag sets the heatmap binding falloff. If set to 0.0 (default) the  
                deformation will be smoother due to many small weights spread over the mesh  
                surface per influence. However, if set to 1.0, corresponding to maximum falloff,  
                the number of influences per point will be reduced and points will tend to be  
                greatly influenced by their closest joint decreasing the overall spread of small  
                weights.  
                This flag only works when using heatmap binding.  
                Properties: create
        ignoreBindPose (bool?): This flag is deprecated and no longer used.  It will be ignored  
                if used.  
                Properties: create, edit
        ignoreHierarchy (bool?): Deprecated. Use bindMethod flag instead.  
                Disregard the place of the joints in the skeleton  
                hierarchy when computing the closest joints that influence  
                a point of the geometry.  
                Properties: create, query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        influence (Queryable[str]?): This flag specifies the influence object that  
                will be used for the current edit operation. In query  
                mode, returns a string array of the influence objects  
                (joints and transform).  
                      In query mode, this flag can accept a value.  
                Properties: query, edit
        lockWeights (bool?): Lock the weights of the specified influence object  
                to their current value or to the value specified by  
                the -weight flag.  
                Properties: query, edit
        maximumInfluences (Queryable[int]?): Sets the maximum number of transforms that can influence  
                a point (have non-zero weight for the point) when  
                the skinCluster is first created or a new influence  
                is added.  Note: When this flag is used in Edit mode  
                any custom weights will be lost and new weights will be  
                reassigned to the whole skin.  
                Properties: create, query, edit
        moveJointsMode (bool?): If set to true, puts the skin into a mode where joints can be moved  
                without modifying the skinning. If set to false, takes the skin out  
                of move joints mode.  
                Properties: edit
        multi (bool?): If true then the command will allow multiple skin clusters to be created  
                on the target geometry. If false the command will generate an error if  
                when trying to add a second skin cluster to the geometry.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        normalizeWeights (Queryable[int]?): This flag sets the normalization mode. 0. none,  
                1. interactive, 2. post (default)  
                Interactive normalization makes sure the weights on the influences add up to 1.0, always.  
                Everytime a weight is changed, the weights are automatically normalized.  This may make  
                it difficult to perform weighting operations, as the normalization may interfere with  
                the weights the user has set.  Post normalization leaves the weights the user has set  
                as is, and only normalizes the weights at the moment it is needed  
                (by dividing by the sum of the weights).  This makes it easier for users to weight their skins.  
                Properties: create, query, edit
        nurbsSamples (int?): Sets the number of sample points that will be used  
                along an influence curve or in each direction on an  
                influence NURBS surface to influence the bound skin.  
                The more the sample points the more closely the skin  
                follows the influence NURBS curve/surface.  
                Properties: create, edit
        obeyMaxInfluences (bool?): When true, the skinCluster will continue to enforce the maximum  
                influences each time the user modifies the weight, so that any  
                given point is only weighted by the number of influences in the  
                skinCluster's maximumInfluences attribute.  
                Properties: create, query, edit
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        polySmoothness (float?): This flag controls how accurately the skin control  
                points follow a given polygon influence object.  
                The higher the value of polySmoothnmess the  
                more rounded the deformation resulting from a polygonal  
                influence object will be.  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        recacheBindMatrices (bool?): Forces the skinCluster node to recache its bind matrices.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        removeFromSelection (bool?): When used in conjunction with the selectInfluenceVerts flag, causes the vertices  
                afftected by the influence to be removed from the current selection.  
                Properties: edit
        removeInfluence (Multiuse[str]?): Remove the specified transform or joint from the list of  
                transforms that influence the bound geometry  
                The weights for the affected points are renormalized.  
                This flag is multi-use.  
                Properties: edit, multiuse
        removeUnusedInfluence (bool?): If this flag is set to true then transform or joint whose weights are all zero  
                (they have no effect) will not be bound to the geometry.  Having this  
                option set will help speed-up the playback of animation. In query mode,  
                returns the number of transforms or joints whose weights are all zero.  
                Properties: create, query, edit
        selectInfluenceVerts (str?): Given the name of a transform, this will select the verts or control points  
                being influenced by this transform, so users may visualize which vertices are  
                being influenced by the transform.  
                Properties: edit
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        skinMethod (Queryable[int]?): This flag set the skinning method. 0. classical linear skinning (default).  
                1. dual quaternion (volume preserving), 2. a weighted blend between the two.  
                Properties: create, query, edit
        smoothWeights (float?): This flag is used to detect sudden jumps in skin weight values, which often  
                indicates bad weighting, and then smooth out those jaggies in skin weights.  
                The argument is the error tolerance ranging from 0 to 1.  A value of 1 means  
                that the algorithm will smooth a vertex only if there is a 100% change in  
                weight values from its neighbors.  The recommended default to use is 0.5  
                (50% change in weight value from the neighbors).  
                Properties: edit
        smoothWeightsMaxIterations (int?): This flag is valid only with the smooth weights flag.  It is possible that not  
                all the vertices detected as needing smoothing can be smoothed in 1 iteration  
                (because all of their neighbors also have bad weighting and need to be smoothed).  
                With more iterations, more vertices can be smoothed.  This flag controls the  
                maximum number of iterations the algorithm will attempt to smooth weights.  
                The default is 2 for this flag.  
                Properties: edit
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        toSelectedBones (bool?): geometry will be bound to the selected bones only.  
                Properties: create
        toSkeletonAndTransforms (bool?): geometry will be bound to the skeleton and any transforms in the hierarchy.  
                If any of the transforms are also bindable objects, assume that only the  
                last object passed to the command is the bindable object. The rest are  
                treated as influences.  
                Properties: create
        unbind (bool?): Unbinds the geometry from the skinCluster and deletes  
                the skinCluster node  
                Properties: edit
        unbindKeepHistory (bool?): Unbinds the geometry from the skinCluster, but keeps  
                the skinCluster node so that its weights can be used  
                when the skin is rebound. To rebind, use the skinCluster  
                command.  
                Properties: edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        useGeometry (bool?): When adding an influence to a skinCluster, use the geometry  
                parented under the influence transform to determine  
                the weight dropoff of that influence.  
                Properties: edit
        volumeBind (float?): Creates a volume bind node and attaches it to the new skin cluster node. This  
                node holds hull geometry parameters for a volume based weighting system. This system is  
                used in interactive skinning. The value passed will determine the minimum weight  
                value when initializing the volume. The volume in be increase to enclose all the vertices  
                that are above this value.  
                Properties: create
        volumeType (int?): Defines the initial shape of the binding volume (see volumeBind). 0. Default (currently set to a capsule)  
                1. Capsule, 2. Cylinder.  
                Properties: create
        weight (float?): This flag is only valid in conjunction with the -addInfluence flag.  
                It sets the weight for the influence object that is being added.  
                Properties: edit
        weightDistribution (Queryable[int]?): This flag sets the weight distribution mode.  
                0. distance (default), 1. neighbors  
                When normalizeWeights is in effect, and a weight has been reduced  
                or removed altogether, the sum is usually brought back up to 1.0  
                by increasing the contributions of the other non-zero weights.  
                However, if there are no other non-zero weights, the algorithm  
                has to create some weights from thin air and distribute the residual  
                weight between them.  
                This attribute controls how that is done.  
                "Distance" - the algorithm calculates weights from  
                the world-space distances from the component to the transforms.  
                "Neighbors" - the algorithm calculates weights from  
                the weights on the neighboring components.  
                Properties: create, query, edit
        weightedInfluence (bool?): This flag returns a string array of the influence objects  
                (joints and transform) that have non-zero weighting.  
                Properties: query

    Returns:
        str: (the skinCluster node name)

    Example:
    """

def skinPercent(arg0: str = ..., /, *args: str, query: bool = ..., ignoreBelow: float = ..., normalize: bool = ..., pruneWeights: float = ..., relative: bool = ..., resetToDefault: bool = ..., transform: Queryable[str] = ..., transformMoveWeights: Multiuse[str] = ..., transformValue: Multiuse[Tuple[str, float]] = ..., value: bool = ..., zeroRemainingInfluences: bool = ...) -> Union[bool, str]:
    """This command edits and queries the weight values on members of a
    skinCluster node, given as the first argument. If no object components
    are explicitly mentioned in the command line, the current selection
    list is used.Note that setting multiple weights in a single invocation of this
    command is far more efficient than calling it once per weighted
    vertex.
    Args:
        ignoreBelow (float?): Limits the output of the -value and -transform queries  
                to the entries whose weight values are over the specified  
                limit.  This flag has to be used before the -query flag.  
                      In query mode, this flag needs a value.  
                Properties: query
        normalize (bool?): If set, the weights not assigned by the -transformValue  
                flag are normalized so that the sum of the all weights  
                for the selected object component add up to 1. The default  
                is on. NOTE: The skinCluster has a normalizeWeights attribute  
                which when set to OFF overrides this attribute! If the  
                skinCluster.normalizeWeights attribute is OFF, you must  
                set it to Interactive in order to normalize weights using the  
                skinPercent command.  
                Properties: create
        pruneWeights (float?): Sets to zero any weight smaller than the given value for  
                all the selected components. To use this command to set  
                all the weights to zero, you must turn the -normalize flag  
                "off" or the skinCluster node will normalize the weights  
                to sum to one after pruning them. Weights for influences with  
                a true value on their "Hold Weights" attribute will not  
                be pruned.  
                Properties: create
        relative (bool?): Used with -transformValue to specify a relative setting of values.  
                If -relative is true, the value passed to -tv is added to the  
                previous value.  Otherwise, it replaces the previous value.  
                Properties: create
        resetToDefault (bool?): Sets the weights of the selected components to their  
                default values, overwriting any custom weights.  
                Properties: create
        transform (Queryable[str]?): In Mel, when used after the -query flag (without an argument)  
                the command returns an array of strings corresponding to  
                the names of the transforms influencing the selected object  
                components.  If used before the -query flag (with a  
                transform name), the command returns the weight of the  
                selected object component corresponding to the given  
                transform. The command will return an average weight if several  
                components have been selected.  
              
                In Python, when used with None instead of the name of the transform,  
                the command returns an array of strings corresponding to  
                the names of the transforms influencing the selected object  
                components. If used with a transform name, the command returns the weight of the  
                selected object. The command will return an average weight if several  
                components have been selected.  
              
                      In query mode, this flag can accept a value.  
                Properties: query
        transformMoveWeights (Multiuse[str]?): This flag is used to transfer weights from a source influence to one or more target influences. It acts on the selected vertices. The flag must be used at least twice to generate a valid command. The first flag usage indicates the source influence from which the weights will be copied. Subsequent flag usages indicate the target influences.  
                Properties: create, multiuse
        transformValue (Multiuse[Tuple[str, float]]?): Accepts a pair consisting of a transform name and a value  
                and assigns that value as the weight of the selected  
                object components corresponding to the given transform.  
                Properties: create, multiuse
        value (bool?): Returns an array of doubles corresponding to the  
                joint weights for the selected object component.  
                Properties: query
        zeroRemainingInfluences (bool?): If set, the weights not assigned by the -transformValue  
                flag are set to 0. The default is off.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def smoothCurve(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., smoothness: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, float]:
    """The smooth command smooths the curve at the given control points.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        smoothness (Queryable[float]?): smoothness factor  
                Default: 10.0  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def smoothTangentSurface(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., direction: Queryable[int] = ..., nodeState: Queryable[int] = ..., parameter: Queryable[Multiuse[float]] = ..., smoothness: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], bool, int, Multiuse[float]]:
    """The smoothTangentSurface command smooths the surface along
    an isoparm at each parameter value.
    The name of the surface is returned and
    if history is on, the name of the resulting dependency node is
    also returned.
    This command only applies to parameter values with a multiple knot
    value.
    (If the given parameter value has no multiple knot associated
    with it, then the dependency node is created but the surface
    doesn't change.)When would you use this?  If you have a surface consisting of
    a number of Bezier patches or any isoparms with more than a single
    knot multiplicity, you could get into a situation where a
    tangent break occurs.  So, it only makes sense to do this operation
    on the knot isoparms, and not anywhere in between, because the
    surface is already smooth everywhere in between.If you have a cubic or higher degree surface, asking for the maximal
    smoothness will give you tangent, curvature, etc. up to the degree-1
    continuity.  Asking for tangent will just give you tangent continuity.It should be mentioned that this is "C", not "G" continuity we're
    talking about, so technically, you can still see visual tangent breaks
    if the surface is degenerate.Note: A single smoothTangentSurface command cannot smooth in both directions
    at once; you must use two separate commands to do this.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        direction (Queryable[int]?): Direction in which to smooth knot:  
                0. V direction,  
                1. U direction  
                Default: 1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameter (Queryable[Multiuse[float]]?): Parameter value(s) where knots are added  
                Default: 0.0  
                Properties: create, query, edit, multiuse
        smoothness (Queryable[int]?): Smoothness to get:  
                0. Tangent,  
                1. Maximum (based on the degree)  
                Default: 1  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def snapKey(*args: str, animation: str = ..., attribute: Multiuse[str] = ..., controlPoints: bool = ..., float: Multiuse[Range[float]] = ..., hierarchy: str = ..., includeUpperBound: bool = ..., index: Multiuse[int] = ..., mergeDuplicate: bool = ..., shape: bool = ..., time: Multiuse[NullableRange[float]] = ..., timeMultiple: float = ..., valueMultiple: float = ...) -> int:
    """This command operates on a keyset.  A keyset is
    defined as a group of keys within a specified time range on one or
    more animation curves.The animation curves comprising a keyset depend on the value
    of the "-animation" flag:Note that the "-animation" flag can be used to override
    the curves uniquely identified by the multi-use
    "-attribute" flag, which takes an argument of the form
    attributeName, such as "translateX".Keys on animation curves are identified by either
    their time values or their indices.  Times and indices can
    be given individually or as part of a list or range (see Examples).This command "snaps" all target key times and/or values
    so that they have times and/or values that are multiples
    of the specified flag arguments.  If neither multiple is
    specified, default is time snapping with a multiple of 1.0.
    Note that this command will fail to move keys over other
    neighboring keys: a key's index will not change as a result
    of a snapKey operation.TbaseKeySetCmd.h
    Args:
        animation (str?): Where this command should get the animation to act  
                on.  Valid values are "objects," "keys," and  
                "keysOrObjects" Default: "keysOrObjects."  (See  
                Description for details.)  
                Properties: create
        attribute (Multiuse[str]?): List of attributes to select  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        controlPoints (bool?): This flag explicitly specifies whether or not to include the  
                control points of a shape (see "-s" flag) in the list of attributes.  
                Default: false.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        float (Multiuse[Range[float]]?): value uniquely representing a non-time-based  
                key (or key range) on a time-based animCurve.  Valid  
                floatRange include single values (-f 10) or a  
                string with a lower and upper bound, separated by a  
                colon (-f "10. 20")  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        hierarchy (str?): Hierarchy expansion options.  Valid values are "above,"  
                "below," "both," and "none." (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        includeUpperBound (bool?): When the -t/time or -f/float flags represent a range  
                of keys, this flag determines whether the keys at the  
                upper bound of the range are included in the keyset.  
                Default value: true.  This flag is only valid when  
                the argument to the -t/time flag is a time range with  
                a lower and upper bound.  (When used with the "pasteKey"  
                command, this flag refers only to the time range of the  
                target curve that is replaced, when using options such  
                as "replace," "fitReplace," or "scaleReplace."  This  
                flag has no effect on the curve pasted from the clipboard.)  
                Properties: create
        index (Multiuse[int]?): index of a key on an animCurve  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        mergeDuplicate (bool?): If this flag is present, keys with duplicated frame will be merged into 1.  
                Default false  
                Properties: create
        shape (bool?): Consider attributes of shapes below transforms as well,  
                except "controlPoints".  Default: true.  (Not valid for "pasteKey" cmd.)  
                In query mode, this flag needs a value.  
                Properties: create
        time (Multiuse[NullableRange[float]]?): time uniquely representing a key (or key  
                range) on a time-based animCurve. See the code  
                examples below on how to format for a single  
                frame or frame ranges.  
                      In query mode, this flag needs a value.  
                Properties: create, multiuse
        timeMultiple (float?): If this flag is present, key times will be snapped  
                to a multiple of the specified float value.  
                Properties: create
        valueMultiple (float?): If this flag is present, key values will be snapped  
                to a multiple of the specified float value.  
                Properties: create

    Returns:
        int: Number of animation curves
            with keys that were not snapped because of time-snapping
            conflicts.

    Example:
    """

def snapMode(*, query: bool = ..., curve: bool = ..., distanceIncrement: Queryable[float] = ..., edgeMagnet: Queryable[int] = ..., edgeMagnetTolerance: Queryable[float] = ..., grid: bool = ..., liveFaceCenter: bool = ..., livePoint: bool = ..., meshCenter: bool = ..., pixelCenter: bool = ..., pixelSnap: bool = ..., point: bool = ..., tolerance: Queryable[int] = ..., useTolerance: bool = ..., uvTolerance: Queryable[int] = ..., viewPlane: bool = ...) -> Union[bool, float, int]:
    """The snapMode command is used to control snapping.  It toggles the
    snapping modes in effect and sets information used for snapping.
    Args:
        curve (bool?): Set curve snap mode  
                Properties: create, query
        distanceIncrement (Queryable[float]?): Set the distance for the snapping to objects such as a lines or planes.  
                Properties: create, query
        edgeMagnet (Queryable[int]?): Number of extra magnets to snap onto, regularly spaced  
                along the edge.  
                Properties: create, query
        edgeMagnetTolerance (Queryable[float]?): Precision for edge magnet snapping.  
                Properties: create, query
        grid (bool?): Set grid snap mode  
                Properties: create, query
        liveFaceCenter (bool?): While moving on live polygon objects, snap to its  
                face centers.  
                Properties: create, query
        livePoint (bool?): While moving on live polygon objects, snap to its  
                vertices.  
                Properties: create, query
        meshCenter (bool?): While moving, snap on the center of the mesh that intersect the line from the camera to the cursor.  
                Properties: create, query
        pixelCenter (bool?): Snap UV to the center of the pixel instead of the corner.  
                Properties: create, query
        pixelSnap (bool?): Snap UVs to the nearest pixel center or corner.  
                Properties: create, query
        point (bool?): Set point snap mode  
                Properties: create, query
        tolerance (Queryable[int]?): Tolerance defines the size of the square region  
                in which points must lie in order to be snapped to. The  
                tolerance value is the distance from the cursor position  
                to the boundary of the square (in all four directions).  
                Properties: create, query
        useTolerance (bool?): If useTolerance is set, then point snapping  
                is limited to points that are within a square region  
                surrounding the cursor position. The size of the square  
                is determined by the tolerance value.  
                Properties: create, query
        uvTolerance (Queryable[int]?): uvTolerance defines the size of the square region  
                in which points must lie in order to be snapped to, in the  
                UV Editor.  The tolerance value is the distance  
                from the cursor position to the boundary of the square  
                (in all four directions).  
                Properties: create, query
        viewPlane (bool?): Set view-plane snap mode  
                Properties: create, query

    Returns:
        bool: if command is a query

    Example:
    """

def snapTogetherCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., clearSelection: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., setOrientation: bool = ..., snapPolygonFace: bool = ...) -> Union[str, bool]:
    """The snapTogetherCtx command creates a tool for snapping surfaces
    together.
    Args:
        clearSelection (bool?): Sets whether the tool should clear the selection  
                on entry to the tool. Default true.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        setOrientation (bool?): Sets whether the tool should orient as well as moving  
                an item. Default true.  
                Properties: create, query, edit
        snapPolygonFace (bool?): Sets whether the tool should snap the cursor to  
                polygon face centers. Default false.  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def snapshot(*args: str, edit: bool = ..., query: bool = ..., constructionHistory: bool = ..., endTime: Queryable[int] = ..., increment: Queryable[int] = ..., motionTrail: bool = ..., name: Queryable[str] = ..., startTime: Queryable[int] = ..., update: Queryable[str] = ...) -> Union[List[str], bool, int, str]:
    """This command can be used to create either a series of surfaces evaluated at
    the times specified by the command flags, or a motion trail displaying the
    trajectory of the object's pivot point at the times specified.If the constructionHistory flag is true, the output shapes or motion trail
    will re-update when modifications are made to the animation or construction
    history of the original shape. When construction history is used, the forceUpdate
    flag can be set to false to control when the snapshot recomputes, which will
    typically improve performance.
    Args:
        constructionHistory (bool?): update with changes to original geometry  
                Properties: create, query
        endTime (Queryable[int]?): time to stop copying target geometry  
                Default: 10.0  
                Properties: create, query, edit
        increment (Queryable[int]?): time increment between copies  
                Default: 1.0  
                Properties: create, query, edit
        motionTrail (bool?): Rather than create a series of surfaces, create a motion trail  
                displaying the location of the object's pivot point at the  
                specified time steps. Default is false.  
                Properties: create
        name (Queryable[str]?): the name of the snapshot node. Query returns string.  
                Properties: create, query, edit
        startTime (Queryable[int]?): time to begin copying target geometry  
                Default: 1.0  
                Properties: create, query, edit
        update (Queryable[str]?): This flag can only be used if the snapshot has  
                constructionHistory. It sets the snapshot node's update  
                value. The update value controls whether the snapshot updates  
                on demand (most efficient), when keyframes change (efficient),  
                or whenever any history changes (least efficient). Valid values  
                are "demand", "animCurve", "always".  
                Default: "always"  
                Properties: create, query, edit

    Returns:
        List[str]: names of nodes created or edited: transform-name [snapshot-node-name]

    Example:
    """

def snapshotBeadContext(*args: Any, **kwargs: Any) -> None: ...
def snapshotBeadCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., inTangent: bool = ..., name: str = ..., outTangent: bool = ...) -> Union[str, bool]:
    """Creates a context for manipulating in and/or out tangent beads on the motion trail
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        inTangent (bool?): Indicates that we will be showing beads for the in tangent when  
                entering the context  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        outTangent (bool?): Indicates that we will be showing beads for the out tangent when  
                entering the context  
                Properties: query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def snapshotModifyKeyCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """Creates a context for inserting/delete keys on an editable motion trail
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: (name of the new context)

    Example:
    """

def soft(*args: str, query: bool = ..., convert: bool = ..., duplicate: bool = ..., duplicateHistory: bool = ..., goal: float = ..., hideOriginal: bool = ..., name: str = ...) -> str:
    """Makes a soft body from the object(s) passed on the command
    line or in the selection list.  The geometry can be a NURBS, polygonal,
    lattice object.  The resulting soft body is made up of a hierarchy
    with a particle shape and a geometry shape, thus:Dynamics are applied to the particle shape and the resulting particle
    positions then drive the locations of the geometry's CVs, vertices, or
    lattice points.With the convert option, the particle shape and its transform are simply
    inserted below the original shape's hierarchy.
    With the duplicate option, the original geometry's transform and shape are
    duplicated underneath its parent, and the particle shape is placed under
    the duplicate.  Note that any animation on
    the hierarchy will affect the particle shape as well.  If you do not want
    then, then reparent the structure outside the hierarchy.When duplicating, the soft portion (the duplicate) is given the name
    "copyOf" + "original object name".  The particle portion is always
    given the name "original object name" + "Particles."None of the flags of the soft command can be queried.  The soft -q
    command is used only to identify when an object is a soft body,
    or when two objects are part of the same soft body.
    See the examples.
    Args:
        convert (bool?): This tells the command that you want the original object  
                to be the actual deformed object.  The particle shape portion of the  
                soft body will be inserted in the same hierarchy as the original,  
                under the same parent (with one additional intervening transform  
                which is initially the identity).  If no flags are passed, then this  
                is assumed.  The combination -c -h 1 is not valid; if you have  
                this in your scripts, remove the -h 1.  
                Properties: create
        duplicate (bool?): This tells the command that you want to make a copy of  
                the original object and use the copy as the deforming geometry.  
                Input connections to the original object are duplicated.  You would  
                do this if you wanted to keep the original object in your scene and  
                also have a copy of it that was a soft body.  
                This flag and -dh are mutually exclusive.  
                Properties: create
        duplicateHistory (bool?): This is the same as -d, except that upstream history,  
                is duplicated as well, instead of just input connections.  
                This flag and -d are mutually exclusive.  
                Properties: create
        goal (float?): This is the same as -d, but in addition it tells the command that  
                you want the resulting soft body to try to  
                follow the original geometry, using the set goal weight as the value  
                that controls how strongly it is to follow it.  A value of 1.0 will  
                try to follow exactly, and a value of 0.0 will not follow at all.  
                The default value is 0.5.  This value must be from 0.0 to 1.0.  
                You could use -d with -g, but it is redundant.  If you want history to  
                be duplicated, you can use -dh and -g together.  
                Properties: create
        hideOriginal (bool?): This flag is used only when duplicating (-d, -g, or -dh).  If set to true,  
                whichever of the two objects is NOT the soft object will be hidden.  
                In other words, with -d -h true, the original object will be hidden;  
                with -d -c -h 1 the duplicate object will be hidden.  
                You would typically do this if you want to use the non-dynamic object as  
                a goal for the soft one (see -g) but you do not want it visible in the scene.  
                The flags -h 1 and -c are mutually exclusive.  
                Properties: create
        name (str?): This flag is obsolete.  If you wish to give your new soft object a name,  
                use the rename command (or from the UI, use the outliner).

    Returns:
        str: array

    Example:
    """

def softMod(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., bindState: bool = ..., components: bool = ..., curveInterpolation: Multiuse[int] = ..., curvePoint: Multiuse[float] = ..., curveValue: Multiuse[float] = ..., deformerTools: bool = ..., envelope: Queryable[float] = ..., exclusive: Queryable[str] = ..., falloffAroundSelection: bool = ..., falloffBasedOnX: bool = ..., falloffBasedOnY: bool = ..., falloffBasedOnZ: bool = ..., falloffCenter: Tuple[float, float, float] = ..., falloffMasking: bool = ..., falloffMode: int = ..., falloffRadius: float = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., relative: bool = ..., remove: Multiuse[bool] = ..., resetGeometry: bool = ..., selectedComponents: bool = ..., split: bool = ..., useComponentTags: bool = ..., weightedNode: Queryable[Tuple[str, str]] = ...) -> Union[str, bool, float, Multiuse[str], Tuple[str, str]]:
    """The softMod command creates a softMod or edits the membership of
    an existing softMod. The command returns the name of the softMod
    node upon creation of a new softMod.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        bindState (bool?): Specifying this flag adds in a compensation to ensure  
                the softModed objects preserve their spatial position  
                when softModed. This is required to prevent the geometry  
                from jumping at the time the softMod is created  
                in situations when the  
                softMod transforms at softMod time are not identity.  
                Properties: create
        components (bool?): Returns the components used by the deformer  
                Properties: query
        curveInterpolation (Multiuse[int]?): Ramp interpolation corresponding to the specified curvePoint position.  
                Integer values of 0. 3 are valid, corresponding to "none", "linear", "smooth"  
                and "spline" respectively.  
                This flag may only be used in conjunction with the curvePoint and curveValue  
                flag.  
                Properties: create, multiuse
        curvePoint (Multiuse[float]?): Position of ramp value on normalized 0. 1 scale.  
                This flag may only be used in conjunction with the curveInterpolation and  
                curveValue flags.  
                Properties: create, multiuse
        curveValue (Multiuse[float]?): Ramp value corresponding to the specified curvePoint position. This flag  
                may only be used in conjunction with the curveInterpolation and curvePoint  
                flags.  
                Properties: create, multiuse
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        envelope (Queryable[float]?): Set the envelope value for the deformer. Default is 1.0  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        falloffAroundSelection (bool?): Falloff will be calculated around any selected components  
                Properties: create
        falloffBasedOnX (bool?): Falloff will be calculated using the X component.  
                Properties: create
        falloffBasedOnY (bool?): Falloff will be calculated using the Y component.  
                Properties: create
        falloffBasedOnZ (bool?): Falloff will be calculated using the Z component.  
                Properties: create
        falloffCenter (Tuple[float, float, float]?): Set the falloff center point of the softMod.  
                Properties: create
        falloffMasking (bool?): Deformation will be restricted to selected components  
                Properties: create
        falloffMode (int?): Set the falloff method used for the softMod.  
                Properties: create
        falloffRadius (float?): Set the falloff radius of the softMod.  
                Properties: create
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        relative (bool?): Enable relative mode for the softMod. In relative mode,  
                Only the transformations directly above the softMod are used  
                by the softMod. Default is off.  
                Properties: create
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        resetGeometry (bool?): Reset the geometry matrices for the objects being deformed  
                by the softMod. This flag is used to get rid of undesirable  
                effects that happen if you scale an object that  
                is deformed by a softMod.  
                Properties: edit
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        weightedNode (Queryable[Tuple[str, str]]?): Transform node in the DAG above the softMod to which all percents are  
                applied. The second node specifies the descendent of the first node  
                from where the transformation matrix is evaluated. Default is the  
                softMod handle.  
                Properties: create, query, edit

    Returns:
        str: [] (the softMod node name and the softMod handle name)

    Example:
    """

def softModContext(*args: Any, **kwargs: Any) -> None: ...
def softSelect(*args: str, edit: bool = ..., query: bool = ..., compressUndo: Queryable[int] = ..., enableFalseColor: Queryable[int] = ..., softSelectColorCurve: Queryable[str] = ..., softSelectCurve: Queryable[str] = ..., softSelectDistance: Queryable[float] = ..., softSelectEnabled: Queryable[int] = ..., softSelectFalloff: Queryable[int] = ..., softSelectReset: bool = ..., softSelectUVDistance: Queryable[float] = ...) -> Union[bool, int, str, float]:
    """This command allows you to change the soft modelling options.Soft modelling is an option that allows for reflection of basic
    manipulator actions such as move, rotate, and scale.
    Args:
        compressUndo (Queryable[int]?): Controls how soft selection settings behave in undo:  
              
                0 means all changes undo individually  
                1 means all consecutive changes undo as a group  
                2 means only interactive changes undo as a group  
              
                When queried, returns an int indicating the current undo behaviour.  
                Properties: create, query, edit
        enableFalseColor (Queryable[int]?): Set soft select color feedback on or off.  
                When queried, returns an int indicating whether color feedback  
                is currently enabled.  
                Properties: create, query, edit
        softSelectColorCurve (Queryable[str]?): Sets the color ramp used to display false color feedback for soft selected  
                components in the viewport. The color curve is encoded as a string of comma  
                separated floating point values representing the falloff curve CVs. Each  
                CV is represented by 5 successive values: 3 RGB values (the color to use),  
                an input value (the selection weight), and a curve interpolation type.  
                When queried, returns a string containing the encoded CVs of the current  
                color feedback curve.  
                Properties: create, query, edit
        softSelectCurve (Queryable[str]?): Sets the falloff curve used to calculate selection weights for components  
                within the falloff distance. The curve is encoded as a string of comma  
                separated floating point values representing the falloff curve CVs. Each  
                CV is represented by 3 successive values: an output value (the selection  
                weight at this point), an input value (the normalised falloff distance)  
                and a curve interpolation type.  
                When queried, returns a string containing the encoded CVs of the current  
                falloff curve.  
                Properties: create, query, edit
        softSelectDistance (Queryable[float]?): Sets the falloff distance (radius) used for world and object space soft selection.  
                When queried, returns a float indicating the current falloff distance.  
                Properties: create, query, edit
        softSelectEnabled (Queryable[int]?): Sets soft selection based modeling on or off.  
                When queried, returns an int indicating the current state of the option.  
                Properties: create, query, edit
        softSelectFalloff (Queryable[int]?): Sets the falloff mode:  
              
                0 for volume based falloff  
                1 for surface based falloff  
                2 for global falloff  
              
                When queried, returns an int indicating the falloff mode.  
                Properties: create, query, edit
        softSelectReset (bool?): Resets soft selection to its default settings.  
                Properties: create, edit
        softSelectUVDistance (Queryable[float]?): Sets the falloff distance (radius) used for UV space soft selection.  
                When queried, returns a float indicating the current falloff distance.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def softSelectOptionsCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., buttonDown: bool = ..., buttonUp: bool = ..., colorCurve: str = ..., condition: bool = ..., enableFalseColor: int = ..., enabled: bool = ..., exists: bool = ..., falloffCurve: str = ..., falloffMode: int = ..., image1: str = ..., image2: str = ..., image3: str = ..., size: float = ..., uvSize: float = ...) -> None: ...
def soloMaterial(*args: Any, query: bool = ..., attr: Queryable[str] = ..., last: bool = ..., node: Queryable[str] = ..., unsolo: bool = ...) -> Union[bool, str]:
    """Shows a preview of a specified material node output attribute.solo, material, rendering, shaders
    Args:
        attr (Queryable[str]?): The attr flag specifies a node attribute to solo.  
                Properties: create, query
        last (bool?): Whether to solo the last material node and attribute.  
                Properties: create, query
        node (Queryable[str]?): The node flag specifies the node to solo.  
                Properties: create, query
        unsolo (bool?): Whether to remove soloing.  
                Properties: create, query

    Returns:
        bool: Success or Failure

    Example:
    """

def sortCaseInsensitive(*args: str) -> List[str]:
    """This command sorts all the strings of an array in a case insensitive way.sort, case, insensitive
    Returns:
        List[str]: string to sort

    Example:
    """

def sound(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., endTime: Queryable[int] = ..., file: Queryable[str] = ..., length: bool = ..., mute: bool = ..., name: Queryable[str] = ..., offset: Queryable[int] = ..., sourceEnd: Queryable[int] = ..., sourceStart: Queryable[int] = ...) -> Union[str, int, bool]:
    """Creates an audio node which can be used with UI commands such
    as soundControl or timeControl which support sound scrubbing
    and sound during playback.
    Args:
        endTime (Queryable[int]?): Time at which to end the sound.  
                Properties: create, query, edit
        file (Queryable[str]?): Name of sound file.  
                Properties: create, query, edit
        length (bool?): Query the length (in the current time unit) of the sound.  
                Properties: query
        mute (bool?): Mute the audio clip.  
                Properties: create, query, edit
        name (Queryable[str]?): Name to give the resulting audio node.  
                Properties: create, query, edit
        offset (Queryable[int]?): Time at which to start the sound.  
                Properties: create, query, edit
        sourceEnd (Queryable[int]?): Time offset from the start of the sound file at which to end the sound.  
                Properties: create, query, edit
        sourceStart (Queryable[int]?): Time offset from the start of the sound file at which to start the sound.  
                Properties: create, query, edit

    Returns:
        str: Name of resulting audio node

    Example:
    """

def soundControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., beginScrub: bool = ..., defineTemplate: str = ..., displaySound: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., endScrub: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., maxTime: Queryable[int] = ..., minTime: Queryable[int] = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., pressCommand: str = ..., preventOverride: bool = ..., releaseCommand: str = ..., repeatChunkSize: Queryable[float] = ..., repeatOnHold: bool = ..., resample: bool = ..., sound: Queryable[str] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., waveform: Queryable[str] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, float, Callable[..., Any]]:
    """This command creates a control used for changing
    current time and scratching/scrubbing through sound files.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        beginScrub (bool?): Set this widget up for sound scrubbing.  
                Subsequent changes to current time will result  
                in "sound scrubbing" behavior, until the  
                "-endScrub" command is issued for this widget.  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displaySound (bool?): Turn sound display off.  Query returns int.  
                Properties: query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        endScrub (bool?): End sound scubbing for this widget.  This stops  
                sound scrubbing behavior and should be issued  
                before any subsequent "-beginScrub" flags  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        maxTime (Queryable[int]?): Controls the max time of the range displayed in the control.  
                Query returns float.  
                Properties: create, query, edit
        minTime (Queryable[int]?): Controls the min time of the range displayed in the control.  
                Query returns float.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        pressCommand (str?): script to run on mouse-down in this control.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        releaseCommand (str?): script to run on mouse-up in this control.  
                Properties: create, edit
        repeatChunkSize (Queryable[float]?): How much sound (in the current time unit) is repeated  
                when -repeatOnHold is true.  Default is 1.0.  
                Properties: query, edit
        repeatOnHold (bool?): Repeat sound during mouse-down events  
                Properties: query, edit
        resample (bool?): Resample the sound display to fit the widget  
                Properties: edit
        sound (Queryable[str]?): Name of audio depend node whose data should display in the  
                sound-display widget. Query returns string.  
                Properties: query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        waveform (Queryable[str]?): Determines what part of the sound waveform to display,  
                when -displaySound is "true". Valid values are "top", "bottom",  
                and "both".  Default is "top". Query returns string.  
                Properties: query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Name of created or edited control.

    Example:
    """

def soundPopup(arg0: str = ..., /, *, annotation: str = ..., backgroundColor: Tuple[float, float, float] = ..., defineTemplate: str = ..., docTag: str = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: int = ..., highlightColor: Tuple[float, float, float] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: str = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Callable[..., Any] = ..., width: int = ...) -> str:
    """Create a poup with sound slider control that accepts only float values and is bound
    by a minimum and maximum value.  The slider displays a marker
    indicating the current value of the slider relative to its minimum
    and maximum values.  Click and drag the marker, or on the slider itself
    to change the current value.
    Args:
        annotation (str?): Annotate the control with an extra string value.  
                Properties: create
        backgroundColor (Tuple[float, float, float]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (str?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: create
        height (int?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create
        highlightColor (Tuple[float, float, float]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: create
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: create
        parent (str?): The parent layout for this control.  
                Properties: create
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: create
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create
        visibleChangeCommand (Callable[..., Any]?): Command that gets executed when visible state of the control changes.  
                Properties: create
        width (int?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create

    Returns:
        str: Full path name to the control.

    Example:
    """

def spBirailCtx(*args: Any, **kwargs: Any) -> None: ...
def spaceLocator(*args: str, edit: bool = ..., query: bool = ..., absolute: bool = ..., name: str = ..., position: Queryable[Tuple[float, float, float]] = ..., relative: bool = ...) -> Union[List[str], Tuple[float, float, float]]:
    """The command creates a locator at the specified position
    in space. By default it is created at (0,0,0).
    Args:
        absolute (bool?): If set, the locator's position is in world space.  
                Properties: create, edit
        name (str?): Name for the locator.  
                Properties: create, edit
        position (Queryable[Tuple[float, float, float]]?): Location in  3. dimensional space where locator is to be created.  
                Properties: create, query, edit
        relative (bool?): If set, the locator's position is relative to its local space. The locator is created in relative mode by default.  
                Properties: create, edit

    Returns:
        List[str]: The name for the new locator in space.

    Example:
    """

def sphere(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., degree: Queryable[int] = ..., endSweep: Queryable[float] = ..., heightRatio: Queryable[float] = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., radius: Queryable[float] = ..., sections: Queryable[int] = ..., spans: Queryable[int] = ..., startSweep: Queryable[float] = ..., tolerance: Queryable[float] = ..., useTolerance: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The sphere command creates a new sphere. The number of spans
    in the in each direction of the sphere is determined by the
    useTolerance attribute. If -ut is true then the -tolerance
    attribute will be used. If -ut is false then the -sections
    attribute will be used.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): The primitive's axis  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface:  
                1. linear,  
                3. cubic  
                Default: 3  
                Properties: create, query, edit
        endSweep (Queryable[float]?): The angle at which to end the surface of revolution.  
                Default is 2Pi radians, or 360 degrees.  
                Default: 6.2831853  
                Properties: create, query, edit
        heightRatio (Queryable[float]?): Ratio of "height" to "width"  
                Default: 2.0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The primitive's pivot point  
                Properties: create, query, edit
        radius (Queryable[float]?): The radius of the object  
                Default: 1.0  
                Properties: create, query, edit
        sections (Queryable[int]?): The number of sections determines the resolution of the surface in the sweep direction.  
                Used only if useTolerance is false.  
                Default: 8  
                Properties: create, query, edit
        spans (Queryable[int]?): The number of spans determines the resolution of the surface in the opposite direction.  
                Default: 1  
                Properties: create, query, edit
        startSweep (Queryable[float]?): The angle at which to start the surface of revolution  
                Default: 0  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to build the surface.  
                Used only if useTolerance is true  
                Default: 0.01  
                Properties: create, query, edit
        useTolerance (bool?): Use the specified tolerance to determine resolution.  
                Otherwise number of sections will be used.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def spotLight(*args: str, edit: bool = ..., query: bool = ..., barnDoors: bool = ..., bottomBarnDoorAngle: Queryable[float] = ..., coneAngle: Queryable[float] = ..., decayRate: int = ..., discRadius: Queryable[float] = ..., dropOff: Queryable[float] = ..., exclusive: bool = ..., intensity: Queryable[float] = ..., leftBarnDoorAngle: Queryable[float] = ..., name: Queryable[str] = ..., penumbra: Queryable[float] = ..., position: Queryable[Tuple[float, float, float]] = ..., rgb: Queryable[Tuple[float, float, float]] = ..., rightBarnDoorAngle: Queryable[float] = ..., rotation: Queryable[Tuple[float, float, float]] = ..., shadowColor: Queryable[Tuple[float, float, float]] = ..., shadowDither: Queryable[float] = ..., shadowSamples: Queryable[int] = ..., softShadow: bool = ..., topBarnDoorAngle: Queryable[float] = ..., useRayTraceShadows: bool = ...) -> Union[str, List[float], int, bool, float, Tuple[float, float, float]]:
    """TlightCmd is the base class for other light commands.
    TnonAmbientLightCmd is a class that looks like a command but
    is not.  It is a base class for the extended/nonExtended
    lights.
    TnonExtendedLightCmd is a base class and not a real command. It is inherited by several
    lights: TpointLight, TdirectionalLight, TspotLight etc.
    The spotLight command is used to edit the parameters of
    existing spotLights, or to create new ones. The default
    behaviour is to create a new spotlight.
    Args:
        barnDoors (bool?): Are the barn doors enabled?  
                Properties: create, query, edit
        bottomBarnDoorAngle (Queryable[float]?): Angle of the bottom of the barn door.  
                Properties: create, query, edit
        coneAngle (Queryable[float]?): angle of the spotLight  
                Properties: create, query, edit
        decayRate (int?): Decay rate of the light (0. no decay, 1. slow, 2. realistic, 3. fast)  
                Properties: create
        discRadius (Queryable[float]?): Radius of shadow disc.  
                Properties: create, query
        dropOff (Queryable[float]?): dropOff of the spotLight  
                Properties: create, query, edit
        exclusive (bool?): True if the light is exclusively assigned  
                Properties: create, query
        intensity (Queryable[float]?): Intensity of the light  
                Properties: create, query
        leftBarnDoorAngle (Queryable[float]?): Angle of the left of the barn door.  
                Properties: create, query, edit
        name (Queryable[str]?): Name of the light  
                Properties: create, query
        penumbra (Queryable[float]?): specify penumbra region  
                Properties: create, query, edit
        position (Queryable[Tuple[float, float, float]]?): Position of the light  
                Properties: create, query
        rgb (Queryable[Tuple[float, float, float]]?): RGB colour of the light  
                Properties: create, query
        rightBarnDoorAngle (Queryable[float]?): Angle of the right of the barn door.  
                Properties: create, query, edit
        rotation (Queryable[Tuple[float, float, float]]?): Rotation of the light for orientation, where applicable  
                Properties: create, query
        shadowColor (Queryable[Tuple[float, float, float]]?): Color of the light's shadow  
                Properties: create, query
        shadowDither (Queryable[float]?): Shadow dithering value.  
                Properties: create, query
        shadowSamples (Queryable[int]?): Numbr of shadow samples to use  
                Properties: create, query
        softShadow (bool?): True if soft shadowing is to be enabled  
                Properties: create, query
        topBarnDoorAngle (Queryable[float]?): Angle of the top of the barn door.  
                Properties: create, query, edit
        useRayTraceShadows (bool?): True if ray trace shadows are to be used  
                Properties: create, query

    Returns:
        str: Light shape name
            boolean Barn door enabled state
            angle Left barn door angle
            angle Right barn door angle
            angle Top barn door angle
            angle Bottom barn door angle
            angle Cone angle
            angle Penumbra angle
            float Dropoff value
        List[float]: when querying the rgb or shadowColor flags
            double when querying the intensity flag
            boolean when querying the useRayTraceShadows or exclusive flags
            linear[] when querying the position flag
            angle[] when querying the rotation flag
            string when querying the name flag
        int: rate of light decay, when querying the decayRate flag
        int: Number of shadow samples, when querying the shadowSamples flag
            boolean True if soft shadows are enabled, when querying the softShadow flag
            float Shadow dithering value, when querying the shadowDither flag
            float Disc radius value, when querying the discRadius flag

    Example:
    """

def spotLightPreviewPort(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., spotLight: str = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., widthHeight: Tuple[int, int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a 3dPort that displays an image representing the
    illumination provided by the spotLight. It is a picture of a plane
    being illuminated by a light.The optional argument is the name of the 3dPort.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        spotLight (str?): Name of the spotLight.  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        widthHeight (Tuple[int, int]?): The width and height of the port.  
                Properties: create

    Returns:
        str: - the name of the port created or modified

    Example:
    """

def spreadSheetEditor(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allAttr: bool = ..., attrRegExp: Queryable[str] = ..., control: bool = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., execute: str = ..., exists: bool = ..., filter: Queryable[str] = ..., fixedAttrList: Queryable[List[str]] = ..., forceMainConnection: Queryable[str] = ..., highlightConnection: Queryable[str] = ..., keyableOnly: bool = ..., lockMainConnection: bool = ..., longNames: bool = ..., mainListConnection: Queryable[str] = ..., niceNames: bool = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., precision: Queryable[int] = ..., selectedAttr: bool = ..., selectionConnection: Queryable[str] = ..., showShapes: bool = ..., stateString: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, bool, List[str], int]:
    """This command creates a new spread sheet editor in the
    current layout.
    Args:
        allAttr (bool?): Returns a list of all the attribute names  
                currently being displayed.  This flag is ignored when not being queried.  
                Properties: query
        attrRegExp (Queryable[str]?): Filter the current displayed attribute names.  
                This expression matches the case-insensitive substring of attribute names.  
                Properties: create, query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        execute (str?): Immediately executes the command string once for every selected  
                cell in the spreadSheet.  Before the command is executed, "#A" is  
                substituted with the name of the cell's attribute, "#N" is substituted  
                with the name of the cell's node, and "#P" is substituted with the  
                full path name of the node.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        fixedAttrList (Queryable[List[str]]?): Forces the editor to only display attributes with the  
                specified names.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        keyableOnly (bool?): Limits the displayed attributes to be those that are keyable.  
                True by default  
                Properties: create, query, edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        longNames (bool?): Controls whether the attributes are displayed using their  
                long names or their short names.  
                Properties: create, query, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        niceNames (bool?): Controls whether the attribute names will be displayed in  
                a more user-friendly, readable way.  When this is on, the longNames  
                flag is ignored.  When this is off, attribute names will be displayed  
                either long or short, according to the longNames flag.  
                Default is on. Queried, returns a boolean.  
                Properties: create, query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        precision (Queryable[int]?): Specifies the maximum number of digits displayed to the right  
                of the decimal place.  Can be 0 to 20.  
                Properties: create, query, edit
        selectedAttr (bool?): Returns a list of all the attribute names  
                that are selected.  This flag is ignored when not being queried.  
                Properties: query
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        showShapes (bool?): If true, when transforms are selected their shapes will  
                be displayed instead.  
                Properties: create, query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the editor

    Example:
    """

def spring(*args: str, edit: bool = ..., query: bool = ..., addSprings: bool = ..., allPoints: bool = ..., count: bool = ..., damping: Queryable[float] = ..., dampingPS: Queryable[float] = ..., endForceWeight: Queryable[float] = ..., exclusive: bool = ..., length: Queryable[float] = ..., maxDistance: float = ..., minDistance: float = ..., minMax: bool = ..., name: Queryable[str] = ..., noDuplicate: bool = ..., restLength: Queryable[float] = ..., restLengthPS: Queryable[float] = ..., startForceWeight: Queryable[float] = ..., stiffness: Queryable[float] = ..., stiffnessPS: Queryable[float] = ..., useDampingPS: bool = ..., useRestLengthPS: bool = ..., useStiffnessPS: bool = ..., walkLength: int = ..., wireframe: bool = ...) -> Union[str, bool, float]:
    """The spring command can do any of the following:* create a new spring object (shape plus transform).  The shape
    contains springs between the points (particles, cvs, etc.)
    of the objects selected or listed on the command line.* create new springs and add them to an existing spring object* edit or query certain attributes of an existing spring objectOne "spring object" may have hundreds or even thousands of individual springs.
    Certain attributes of the spring object specify exactly where the springs
    are attached to which other objects.Springs may be attached to the following: particles, vertices of soft
    bodies, CVs or edit points of curves or surfaces, vertices of polygonal
    objects, and points of lattices. In the case where one endpoint of a
    spring is non-dynamic (a CV, edit point, etc.), the spring does not affect
    its motion, but the motion of the point affects the spring. A spring will
    be created only if at least one of the endpoints is dynamic: for example,
    a spring will never be created between two CVs. A single spring object can
    hold springs which are incident to any number of other objects.The spring has creation-only flags and editable flags.  Creation-only flags
    (minDistance, maxDistance, add, exclusive, all, wireframe, walklength,
    checkExisting) can be used only when creating new springs (including adding
    springs to existing spring object).  Editable flags modify attributes of an
    existing spring object.If a spring object is created, this command returns the names of
    the shape and transform.  If a spring object is queried, the command returns
    the results of the query.
    Args:
        addSprings (bool?): If specified, springs will be added to the existing selected set of springs.  
                (Default is to create a new spring object.)  
                Properties: create
        allPoints (bool?): If True, sets the mode of spring application to All.  This will add  
                springs between all points selected.  
                (Default is False.)  
                Properties: create, edit
        count (bool?): Return the number of springs in the shape.  Query-only.  
                We maintain this flag only for compatibility with earlier versions  
                of Maya.  To get the count of springs, it is much faster and simpler  
                to use the spring shape's count attribute: getAttr <shapeName>.count.  
                Properties: query
        damping (Queryable[float]?): Damping factor for the springs created in the spring object.  
                (Default = 0.2 )  
                Properties: create, query, edit
        dampingPS (Queryable[float]?): Damping factor for the springs created in the spring object. This will  
                initialize all the entries in dampingPS to the specified value.  
                In both the flag and the attribute name, "PS" stands for "per-spring."  
                (Default = 0.2 )  
                Properties: create, query, edit
        endForceWeight (Queryable[float]?): Amount of the force of the spring that gets applied to the point to which  
                the spring ends. Valid range is from 0.0 to 1.0. (Default = 1.0 )  
                Properties: create, query, edit
        exclusive (bool?): If true, tells the command to create springs only between pairs of  
                points which are not in the same object.  
                (Default is False.)  
                Properties: create
        length (Queryable[float]?): Vestigial form of "restLength." Please use "restLength" instead.  
                Properties: create, query, edit
        maxDistance (float?): Maximum distance between two points that a spring would be  
                considered.  
                Properties: create, edit
        minDistance (float?): Minimum distance between two points that a spring would be considered.  
                (Default = 0.0. See Defaults for more information on this flag's default.)  
                Properties: create
        minMax (bool?): If True, sets the mode of the spring application to Min/Max.  
                This will add springs between all points from the specified point groups  
                that are between the minimum and maximum distance values set with min and max.  
                (Default is False.)  
                Note: This gets automatically set if either the min or max flags are used.  
                Properties: create
        name (Queryable[str]?): Name of spring object.  
                Properties: create, query
        noDuplicate (bool?): Check for existing springs and don't add a new spring between  
                two points already connected by a spring in the same object.  
                Only the object the command is working on is checked.  This flag  
                is relevant only when using -add. (Default = false)  
                Properties: create
        restLength (Queryable[float]?): Per-object rest length for the new springs. Springs can use either  
                their per-object or per-spring rest length.  See the -lPS and -ulp flags.  
                Properties: create, query, edit
        restLengthPS (Queryable[float]?): Per-spring rest length for the new springs. This will  
                initialize all the entries in restLengthPS to the specified value.  
                If this flag is not thrown, each rest length will be initialized to  
                the distance between the two  points at the time the spring is created  
                (i.e., the initial length of the spring).   When playing back, springs  
                can use either their per-spring or per-object rest length.  See the  
                -rl and -urp flags.  
                In both the flag and the attribute name, "PS" stands for "per-spring."  
                Properties: create, query, edit
        startForceWeight (Queryable[float]?): Amount of the force of the spring that gets applied to the point from  
                which the spring starts. Valid range is from 0.0 to 1.0. (Default = 1.0 )  
                Properties: create, query, edit
        stiffness (Queryable[float]?): Stiffness of the springs created in the spring object. (Default = 1.0 )  
                -damp float  
                Vestigial form of "damping."  Please use "damping" instead.  
                Properties: create, query, edit
        stiffnessPS (Queryable[float]?): Stiffness of the springs created in the spring object. This will  
                initialize all the entries in stiffnessPS to the specified value.  
                In both the flag and the attribute name, "PS" stands for "per-spring."  
                (Default = 1.0 )  
                Properties: create, query, edit
        useDampingPS (bool?): Specifies whether to use dampingPS (per spring damping).  
                If set to false, the per object damping attribute value will be used.  
                This flag simply sets the useDampingPS attribute of the spring shape.  
                In both the flag and the attribute name, "PS" stands for "per-spring."  
                (Default = false )  
                Properties: create, query, edit
        useRestLengthPS (bool?): Specifies whether to use restLengthPS (per spring restLength).  
                If set to false, the per object restLength attribute value will be used.  
                This flag simply sets the useRestLengthPS attribute of the spring shape.  
                In both the flag and the attribute name, "PS" stands for "per-spring."  
                (Default = false )  
                Properties: create, query, edit
        useStiffnessPS (bool?): Specifies whether to use stiffnessPS (per spring stiffness).  
                If set to false, the per object stiffness attribute value will be used.  
                This flag simply sets the useStiffnessPS attribute of the spring shape.  
                In both the flag and the attribute name, "PS" stands for "per-spring."  
                (Default = false )  
                Properties: create, query, edit
        walkLength (int?): This flag is valid only when doing wireframe creation.  
                It will create springs between pairs of points connected by the specified  
                number of edges.  For example, if walk length is 2, each pair of points  
                separated by no more than 2 edges will get a spring.  Walk length measures  
                the distance between pairs of vertices just like the number of blocks measures  
                the distance between two intersections in a city.  
                Properties: create
        wireframe (bool?): If True, sets the mode of the spring application to Wireframe.  
                This is valid only for springs created on a soft body.  
                It will add springs along all edges connecting the adjacent points  
                (vertices or CV's) of curves and surfaces.  
                (Default is False.)  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def squareSurface(arg0: str = ..., arg1: str = ..., arg2: str = ..., arg3: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., continuityType1: Queryable[int] = ..., continuityType2: Queryable[int] = ..., continuityType3: Queryable[int] = ..., continuityType4: Queryable[int] = ..., curveFitCheckpoints: Queryable[int] = ..., endPointTolerance: Queryable[float] = ..., nodeState: Queryable[int] = ..., rebuildCurve1: bool = ..., rebuildCurve2: bool = ..., rebuildCurve3: bool = ..., rebuildCurve4: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], bool, int, float]:
    """This command produces a square surface given 3 or 4 curves.
    This resulting square surface is created within the intersecting
    region of the selected curves. The order of selection is important
    and the curves must intersect or their ends must meet.You must specify one continuity type flag for each selected curve.
    If continuity type is 1 (fixed, no tangent continuity) then the
    curveFitCheckpoints flag () is not required.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        continuityType1 (Queryable[int]?): Continuity type legal values for curve 1. 1. fixed boundary  
                2. tangent continuity  
                3. implied tangent continuity  
                Default: 2  
                Properties: create, query, edit
        continuityType2 (Queryable[int]?): Continuity type legal values for curve 2. 1. fixed boundary  
                2. tangent continuity  
                3. implied tangent continuity  
                Default: 2  
                Properties: create, query, edit
        continuityType3 (Queryable[int]?): Continuity type legal values for curve 3. 1. fixed boundary  
                2. tangent continuity  
                3. implied tangent continuity  
                Default: 2  
                Properties: create, query, edit
        continuityType4 (Queryable[int]?): Continuity type legal values for curve 4. 1. fixed boundary  
                2. tangent continuity  
                3. implied tangent continuity  
                Default: 2  
                Properties: create, query, edit
        curveFitCheckpoints (Queryable[int]?): The number of points per span to check the tangency deviation between the boundary curve and the created tangent square surface. Only available for the tangent continuity type.  
                Default: 5  
                Properties: create, query, edit
        endPointTolerance (Queryable[float]?): Tolerance for end points, only used if endPoint attribute is true.  
                Default: 0.1  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        rebuildCurve1 (bool?): A boolean to determine if input curve 1 should be rebuilt (with curvature continuity).  
                Default: false  
                Properties: create, query, edit
        rebuildCurve2 (bool?): A boolean to determine if input curve 2 should be rebuilt (with curvature continuity).  
                Default: false  
                Properties: create, query, edit
        rebuildCurve3 (bool?): A boolean to determine if input curve 3 should be rebuilt (with curvature continuity).  
                Default: false  
                Properties: create, query, edit
        rebuildCurve4 (bool?): A boolean to determine if input curve 4 should be rebuilt (with curvature continuity).  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def srtContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ...) -> str:
    """This command can be used to create a combined transform
    (translate/scale/rotate) context.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: - name of the newly created context

    Example:
    """

def stackTrace(*, query: bool = ..., dump: bool = ..., parameterCount: int = ..., parameterType: Tuple[int, int] = ..., parameterValue: Tuple[int, int] = ..., state: bool = ...) -> None: ...
def stitchSurface(*args: str, edit: bool = ..., query: bool = ..., bias: Queryable[float] = ..., caching: bool = ..., cvIthIndex: Queryable[Multiuse[int]] = ..., cvJthIndex: Queryable[Multiuse[int]] = ..., fixBoundary: bool = ..., nodeState: Queryable[int] = ..., parameterU: Queryable[Multiuse[float]] = ..., parameterV: Queryable[Multiuse[float]] = ..., positionalContinuity: Queryable[Multiuse[bool]] = ..., stepCount: Queryable[Multiuse[int]] = ..., tangentialContinuity: Queryable[Multiuse[bool]] = ..., togglePointNormals: bool = ..., togglePointPosition: bool = ..., toggleTolerance: Queryable[Multiuse[bool]] = ..., tolerance: Queryable[Multiuse[float]] = ..., cascade: bool = ..., constructionHistory: bool = ..., keepG0Continuity: bool = ..., keepG1Continuity: bool = ..., name: str = ..., numberOfSamples: int = ..., object: bool = ..., replaceOriginal: bool = ..., weight0: float = ..., weight1: float = ...) -> Union[List[str], float, bool, Multiuse[int], int, Multiuse[float], Multiuse[bool]]:
    """The stitchSurface command aligns two surfaces together to be
    G(0) and/or G(1) continuous by ajusting only the Control Vertices
    of the surfaces. The two surfaces can be stitched by specifying
    the two isoparm boundary edges that are to stitched together. The
    edge to which the two surfaces are stitched together is obtained
    by doing a weighted average of the two edges. The weights for the
    two edges is specified using the flags -wt0, -wt1 respectively.
    Args:
        bias (Queryable[float]?): Blend CVs in between input surface and result from stitch. A value of 0.0 returns the input surface.  
                Default: 1.0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        cvIthIndex (Queryable[Multiuse[int]]?): The ith boundary CV index on the input surface.  
                Default: -1  
                Properties: create, query, edit, multiuse
        cvJthIndex (Queryable[Multiuse[int]]?): The jth boundary CV index on the input surface.  
                Default: -1  
                Properties: create, query, edit, multiuse
        fixBoundary (bool?): Fix Boundary CVs while solving for any G1 constraints.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameterU (Queryable[Multiuse[float]]?): The U parameter value on surface for a point constraint.  
                Default: -10000  
                Properties: create, query, edit, multiuse
        parameterV (Queryable[Multiuse[float]]?): The V parameter value on surface for a point constraint.  
                Default: -10000  
                Properties: create, query, edit, multiuse
        positionalContinuity (Queryable[Multiuse[bool]]?): Toggle on (off) G0 continuity at edge corresponding to multi index.  
                Default: true  
                Properties: create, query, edit, multiuse
        stepCount (Queryable[Multiuse[int]]?): Step count for the number of discretizations.  
                Default: 20  
                Properties: create, query, edit, multiuse
        tangentialContinuity (Queryable[Multiuse[bool]]?): Toggle on (off) G1 continuity across edge corresponding to multi index.  
                Default: false  
                Properties: create, query, edit, multiuse
        togglePointNormals (bool?): Toggle on (off) normal point constraints on the surface.  
                Default: false  
                Properties: create, query, edit
        togglePointPosition (bool?): Toggle on (off) position point constraints on the surface.  
                Default: true  
                Properties: create, query, edit
        toggleTolerance (Queryable[Multiuse[bool]]?): Toggle on (off) so as to use Tolerance or specified steps for discretization.  
                Default: false  
                Properties: create, query, edit, multiuse
        tolerance (Queryable[Multiuse[float]]?): Tolerance to use while discretizing the edge.  
                Default: 0.1  
                Properties: create, query, edit, multiuse
        cascade (bool?): Cascade the created stitch node. (Only if the surface has a stitch  
                history)  
                Default is 'false'.  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        keepG0Continuity (bool?): Stitch together with positional continuity.  
                Default is 'true'.  
                Properties: create
        keepG1Continuity (bool?): Stitch together with tangent continuity.  
                Default is 'false'.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        numberOfSamples (int?): The number of samples on the edge.  
                Default is 20.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create
        weight0 (float?): The weighting factor for the first edge.  
                Default is 0.5.  
                Properties: create
        weight1 (float?): The weighting factor for the second edge.  
                Default is 0.5.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def stitchSurfaceCtx(*args: Any, **kwargs: Any) -> None: ...
def stitchSurfacePoints(*args: str, edit: bool = ..., query: bool = ..., bias: Queryable[float] = ..., caching: bool = ..., cvIthIndex: Queryable[Multiuse[int]] = ..., cvJthIndex: Queryable[Multiuse[int]] = ..., fixBoundary: bool = ..., nodeState: Queryable[int] = ..., parameterU: Queryable[Multiuse[float]] = ..., parameterV: Queryable[Multiuse[float]] = ..., positionalContinuity: Queryable[Multiuse[bool]] = ..., stepCount: Queryable[Multiuse[int]] = ..., tangentialContinuity: Queryable[Multiuse[bool]] = ..., togglePointNormals: bool = ..., togglePointPosition: bool = ..., toggleTolerance: Queryable[Multiuse[bool]] = ..., tolerance: Queryable[Multiuse[float]] = ..., cascade: bool = ..., constructionHistory: bool = ..., equalWeight: bool = ..., keepG0Continuity: bool = ..., keepG1Continuity: bool = ..., name: str = ..., object: bool = ..., replaceOriginal: bool = ...) -> Union[List[str], float, bool, Multiuse[int], int, Multiuse[float], Multiuse[bool]]:
    """The stitchSurfacePoints command aligns two or more surface points
    along the boundaries together to a single point. In the process, a
    node to average the points is created. The points are averaged
    together in a weighted fashion. The points may be control vertices
    along the boundaries. If the points are CVs then they are stitched
    together only with positional continuity.Note: No two points can lie on the same surface.
    Args:
        bias (Queryable[float]?): Blend CVs in between input surface and result from stitch. A value of 0.0 returns the input surface.  
                Default: 1.0  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        cvIthIndex (Queryable[Multiuse[int]]?): The ith boundary CV index on the input surface.  
                Default: -1  
                Properties: create, query, edit, multiuse
        cvJthIndex (Queryable[Multiuse[int]]?): The jth boundary CV index on the input surface.  
                Default: -1  
                Properties: create, query, edit, multiuse
        fixBoundary (bool?): Fix Boundary CVs while solving for any G1 constraints.  
                Default: false  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        parameterU (Queryable[Multiuse[float]]?): The U parameter value on surface for a point constraint.  
                Default: -10000  
                Properties: create, query, edit, multiuse
        parameterV (Queryable[Multiuse[float]]?): The V parameter value on surface for a point constraint.  
                Default: -10000  
                Properties: create, query, edit, multiuse
        positionalContinuity (Queryable[Multiuse[bool]]?): Toggle on (off) G0 continuity at edge corresponding to multi index.  
                Default: true  
                Properties: create, query, edit, multiuse
        stepCount (Queryable[Multiuse[int]]?): Step count for the number of discretizations.  
                Default: 20  
                Properties: create, query, edit, multiuse
        tangentialContinuity (Queryable[Multiuse[bool]]?): Toggle on (off) G1 continuity across edge corresponding to multi index.  
                Default: false  
                Properties: create, query, edit, multiuse
        togglePointNormals (bool?): Toggle on (off) normal point constraints on the surface.  
                Default: false  
                Properties: create, query, edit
        togglePointPosition (bool?): Toggle on (off) position point constraints on the surface.  
                Default: true  
                Properties: create, query, edit
        toggleTolerance (Queryable[Multiuse[bool]]?): Toggle on (off) so as to use Tolerance or specified steps for discretization.  
                Default: false  
                Properties: create, query, edit, multiuse
        tolerance (Queryable[Multiuse[float]]?): Tolerance to use while discretizing the edge.  
                Default: 0.1  
                Properties: create, query, edit, multiuse
        cascade (bool?): Cascade the created stitch node. (Only if the surface has a stitch  
                history)  
                Default is 'false'.  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        equalWeight (bool?): Assign equal weights to all the points being stitched together.  
                Default is 'true'. If false, the first point is assigned a weight of  
                1.0 and the rest are assigned 0.0.  
                Properties: create
        keepG0Continuity (bool?): Stitch together the points with positional continuity.  
                Default is 'true'.  
                Properties: create
        keepG1Continuity (bool?): Stitch together the points with tangent continuity.  
                Default is 'false'.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def stringArrayIntersector(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowDuplicates: bool = ..., defineTemplate: str = ..., exists: bool = ..., intersect: List[str] = ..., reset: bool = ..., useTemplate: str = ...) -> str:
    """The stringArrayIntersector command creates and edits an object which is
    able to efficiently intersect large string arrays. The intersector object
    maintains a sense of "the intersection so far", and updates the
    intersection when new string arrays are provided using the -i/intersect
    flag.Note that the string intersector object may be deleted using the deleteUI
    command.
    Args:
        allowDuplicates (bool?): Should the intersector allow duplicates in the input arrays (true),  
                or combine all duplicate entries into a single, unique entry (false).  
                This flag must be used when initially creating the intersector.  
                Default is 'false'.  
                Properties: create
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        intersect (List[str]?): Intersect the specified string array with the current intersection  
                being maintained by the intersector.  
                Properties: create, edit
        reset (bool?): Reset the intersector to begin a new intersection.  
                Properties: edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the intersector.

    Example:
    """

def stroke(*, name: str = ..., pressure: bool = ..., seed: int = ...) -> str:
    """The stroke command creates a new Paint Effects stroke node.
    Args:
        name (str?): Sets the name of the stroke to the input string  
                Properties: create
        pressure (bool?): On creation, allows the copying of the pressure  
                mapping settings from the Paint Effects Tool. Default  
                is false.  
                Properties: create
        seed (int?): Sets the random seed for this stroke.  
                Properties: create

    Returns:
        str: (The path to the new stroke or the replaced stroke)

    Example:
    """

def subdAutoProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., layout: Queryable[int] = ..., layoutMethod: Queryable[int] = ..., name: str = ..., optimize: Queryable[int] = ..., percentageSpace: Queryable[float] = ..., planes: Queryable[int] = ..., scale: Queryable[int] = ..., skipIntersect: bool = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Projects a texture map onto an object, using several orthogonal projections
    simultaneously.The argument is a face selection list.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        layout (Queryable[int]?): What layout algorithm should be used:  
                0 UV pieces are aligned along the U axis.  
                1 UV pieces are moved in a square shape.  
                Properties: create, query, edit
        layoutMethod (Queryable[int]?): Which layout method to use:  
                0 Block Stacking.  
                1 Shape Stacking.  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        optimize (Queryable[int]?): Use two different flavors for the cut generation.  
                0 Every face is assigned to the best plane. This optimizes the  
                map distortion.  
                1 Small UV pieces are incorporated into larger ones, when the  
                extra distortion introduced is reasonable. This tends to produce fewer  
                UV pieces.  
                Properties: create, query, edit
        percentageSpace (Queryable[float]?): When layout is set to square, this value is a percentage of  
                the texture area which is added around each UV piece. It can be  
                used to ensure each UV piece uses different pixels in the texture.  
                Maximum value is 5 percent.  
                Properties: create, query, edit
        planes (Queryable[int]?): Number of intermediate projections used. Valid numbers  
                are 4, 5, 6, 8, and 12.  
                C: Default is 6.  
                Properties: create, query, edit
        scale (Queryable[int]?): How to scale the pieces, after projections:  
                0 No scale is applied.  
                1 Uniform scale to fit in unit square.  
                2 Non proportional scale to fit in unit square.  
                Properties: create, query, edit
        skipIntersect (bool?): When on, self intersection of UV pieces are not  
                tested. This makes the projection faster and produces fewer pieces,  
                but may lead to overlaps in UV space.  
                Properties: create, query, edit
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is "off".  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def subdCleanTopology(*args: str) -> bool:
    """Command cleans topology of subdiv surfaces - at all levels. It cleans the
    geometry of vertices that satisfy the following conditions:
                    - Zero edits
                    - Default uvs (uvs obtained by subdividing parent face).
                    - No creases.subdivision, surface, refine, level, coarse, fine
    Returns:
        bool: Success or Failure.

    Example:
    """

def subdCollapse(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., level: Queryable[int] = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, int]:
    """This command converts a takes a subdivision surface, passed as the
    argument, and produces
    a subdivision surface with a number of hierarchy levels "removed".
    Returns the name of the subdivision surface created and optionally
    the DG node that does the conversion.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        level (Queryable[int]?): The level that will now become the base mesh.  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: The subd surface and optionally the dependency node name

    Example:
    """

def subdDisplayMode(*args: Any, **kwargs: Any) -> None: ...
def subdDuplicateAndConnect(*args: str) -> bool:
    """This command duplicates the input subdivision surface object, connects
    up the outSubdiv attribute of the original subd shape to
    the create attribute of the newly created duplicate shape and
    copies over the shader assignments from the original shape
    to the new duplicated shape.The command will fail if no objects are selected or sent as
    argument or if the object sent as argument is not a subdivision surface
    object.
    Returns:
        bool:

    Example:
    """

def subdEditUV(*args: str, query: bool = ..., angle: Queryable[float] = ..., pivotU: Queryable[float] = ..., pivotV: Queryable[float] = ..., relative: bool = ..., rotateRatio: Queryable[float] = ..., rotation: bool = ..., scale: bool = ..., scaleU: Queryable[float] = ..., scaleV: Queryable[float] = ..., uValue: Queryable[float] = ..., uvSetName: Queryable[str] = ..., vValue: Queryable[float] = ...) -> Union[bool, float, str]:
    """Command edits uvs on subdivision surfaces. When used with the query flag, it
    returns the uv values associated with the specified components.subdivision, editUV, tweakUV, uvEditing
    Args:
        angle (Queryable[float]?): Specifies the angle value (in degrees) that the uv values are to be rotated  
                by.  
                Properties: create, query
        pivotU (Queryable[float]?): Specifies the pivot value, in the u direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        pivotV (Queryable[float]?): Specifies the pivot value, in the v direction, about which the scale or  
                rotate is to be performed.  
                Properties: create, query
        relative (bool?): Specifies whether this command is editing the values relative to the currently  
                existing values. Default is true;  
                Properties: create, query
        rotateRatio (Queryable[float]?): Specifies the ratio value that the uv values are to be rotated by  
                Default is 1.0  
                Properties: create, query
        rotation (bool?): Specifies whether this command is editing the values with rotation values  
                Properties: create, query
        scale (bool?): Specifies whether this command is editing the values with scale values  
                Properties: create, query
        scaleU (Queryable[float]?): Specifies the scale value in the u direction.  
                Properties: create, query
        scaleV (Queryable[float]?): Specifies the scale value in the v direction.  
                Properties: create, query
        uValue (Queryable[float]?): Specifies the value, in the u direction - absolute if relative flag is false..  
                Properties: create, query
        uvSetName (Queryable[str]?): Specifies the name of the uv set to edit uvs on. If not specified  
                will use the current uv set if it exists.  
                Properties: create, query
        vValue (Queryable[float]?): Specifies the value, in the v direction - absolute if relative flag is false..  
                Properties: create, query

    Returns:
        bool: Success or Failure.

    Example:
    """

def subdLayoutUV(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., flipReversed: bool = ..., layout: Queryable[int] = ..., layoutMethod: Queryable[int] = ..., name: str = ..., percentageSpace: Queryable[float] = ..., rotateForBestFit: Queryable[int] = ..., scale: Queryable[int] = ..., separate: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, bool, int, float]:
    """Move UVs in the texture plane to avoid overlaps.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        flipReversed (bool?): If this flag is turned on, the reversed UV pieces are fliped.  
                Properties: create, query, edit
        layout (Queryable[int]?): How to move the UV pieces, after cuts are applied:  
                0 No move is applied.  
                1 Layout the pieces along the U axis.  
                2 Layout the pieces in a square shape.  
                Properties: create, query, edit
        layoutMethod (Queryable[int]?): Which layout method to use:  
                0 Block Stacking.  
                1 Shape Stacking.  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        percentageSpace (Queryable[float]?): When layout is set to square, this value is a percentage of  
                the texture area which is added around each UV piece. It can be  
                used to ensure each UV piece uses different pixels in the texture.  
                Maximum value is 5 percent.  
                Properties: create, query, edit
        rotateForBestFit (Queryable[int]?): 0 No rotation is applied.  
                1 Only allow 90 degree rotations.  
                2 Allow free rotations.  
                Properties: create, query, edit
        scale (Queryable[int]?): How to scale the pieces, after move and cuts:  
                0 No scale is applied.  
                1 Uniform scale to fit in unit square.  
                2 Non proportional scale to fit in unit square.  
                Properties: create, query, edit
        separate (Queryable[int]?): Which UV edges should be cut:  
                0 No cuts.  
                1 Cut only along folds.  
                2 Make all necessary cuts to avoid all intersections.  
                Properties: create, query, edit
        worldSpace (bool?): If true, performs the operation in world space coordinates as  
                opposed to local space.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def subdListComponentConversion(*args: Any, border: bool = ..., fromEdge: bool = ..., fromFace: bool = ..., fromUV: bool = ..., fromVertex: bool = ..., internal: bool = ..., toEdge: bool = ..., toFace: bool = ..., toUV: bool = ..., toVertex: bool = ..., uvShell: bool = ..., uvShellBorder: bool = ...) -> List[str]:
    """This command converts subdivision surface components from one or
    more types to another one or more types, and returns the list of the
    conversion. It does not change the currently selected objects.Use the "-in/internal" flag to specify conversion to
    "connected" vs. "contained" components.  For example,
    if the internal flag is specified when converting
    from subdivision surface vertices to faces, then
    only faces that are entirely contained by the vertices
    will be returned.  If the internal flag is not specified,
    then all faces that are connected to the vertices will
    be returned.
    Args:
        border (bool?): Convert to a border.  
                Properties: create
        fromEdge (bool?): Indicates the component type to convert  
                from: Edges  
                Properties: create
        fromFace (bool?): Indicates the component type to convert  
                from: Faces  
                Properties: create
        fromUV (bool?): Indicates the component type to convert  
                from: UVs  
                Properties: create
        fromVertex (bool?): Indicates the component type to convert  
                from: Vertex  
                Properties: create
        internal (bool?): Applicable when converting from  
                "smaller" component types to larger ones.  
                Specifies conversion to "connected" vs.  
                "contained" components.  
                See examples below.  
                Properties: create
        toEdge (bool?): Indicates the component type to convert  
                to: Edges  
                Properties: create
        toFace (bool?): Indicates the component type to convert  
                to: Faces  
                Properties: create
        toUV (bool?): Indicates the component type to convert  
                to: UVs  
                Properties: create
        toVertex (bool?): Indicates the component type to convert  
                to: Vertices  
                Properties: create
        uvShell (bool?): Will return UV components within the same UV  
                shell. Only works with -tuv and -fuv flags.  
                Properties: create
        uvShellBorder (bool?): Will return UV components on the border  
                within the same UV shell. Only works with  
                -tuv and -fuv flags.  
                Properties: create

    Returns:
        List[str]: List of subdivision surface components

    Example:
    """

def subdMapCut(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., constructionHistory: bool = ..., name: str = ..., nodeState: Queryable[int] = ...) -> Union[str, bool, int]:
    """Cut along edges of the texture mapping. The cut edges become map borders.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def subdMapSewMove(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., limitPieceSize: bool = ..., name: str = ..., numberFaces: Queryable[int] = ..., worldSpace: bool = ...) -> Union[str, bool, int]:
    """This command can be used to Move and Sew together separate UV pieces
    along geometric edges. UV pieces that correspond to the same geometric
    edge, are merged together by moving the smaller piece to the larger
    one.The argument is a UV selection list.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        limitPieceSize (bool?): When on, this flag specifies that the face number limit  
                described above should be used.  
                Properties: create, query, edit
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        numberFaces (Queryable[int]?): Maximum number of faces in a UV piece. When trying to  
                combine two UV pieces into a single one, the merge operation is  
                rejected if the smaller piece has more faces than the number specified  
                by this flag.  
                This flag is only used when limitPieceSize is set to on.  
                Properties: create, query, edit
        worldSpace (bool?): If true, performs the operation in world space coordinates as  
                opposed to local space.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def subdMatchTopology(*args: str, frontOfChain: bool = ...) -> bool:
    """Command matches topology across multiple subdiv surfaces - at all levels.subdivision, surface, deformers, refine, level, coarse, fine
    Args:
        frontOfChain (bool?): This command is used to specify that the new addTopology node should be  
                placed ahead (upstream) of existing deformer and skin nodes in the shape's  
                history (but not ahead of existing tweak nodes). The input to the addTopology  
                node will be the upstream shape rather than the visible downstream shape, so  
                the behavior of this flag is the most intuitive if the downstream deformers  
                are in their reset (hasNoEffect) position when the new deformer is added.  
                Properties: create

    Returns:
        bool: Success or Failure.

    Example:
    """

def subdMirror(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., xMirror: bool = ..., yMirror: bool = ..., zMirror: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, int]:
    """This command takes a subdivision surface, passed as the argument, and produces
    a subdivision surface that is a mirror.
    Returns the name of the subdivision surface created and optionally
    the DG node that does the mirroring.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        xMirror (bool?): Mirror the vertices in X  
                Default: false  
                Properties: create, query, edit
        yMirror (bool?): Mirror the vertices in Y  
                Default: false  
                Properties: create, query, edit
        zMirror (bool?): Mirror the vertices in Z  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: The subdivision surface and optionally the dependency node name

    Example:
    """

def subdPlanarProjection(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., createNewMap: bool = ..., imageCenter: Queryable[Tuple[float, float]] = ..., imageCenterX: Queryable[float] = ..., imageCenterY: Queryable[float] = ..., imageScale: Queryable[Tuple[float, float]] = ..., imageScaleU: Queryable[float] = ..., imageScaleV: Queryable[float] = ..., insertBeforeDeformers: bool = ..., keepImageRatio: bool = ..., mapDirection: str = ..., name: str = ..., projectionCenter: Queryable[Tuple[float, float, float]] = ..., projectionCenterX: Queryable[float] = ..., projectionCenterY: Queryable[float] = ..., projectionCenterZ: Queryable[float] = ..., projectionHeight: Queryable[float] = ..., projectionScale: Queryable[Tuple[float, float]] = ..., projectionWidth: Queryable[float] = ..., rotate: Queryable[Tuple[float, float, float]] = ..., rotateX: Queryable[float] = ..., rotateY: Queryable[float] = ..., rotateZ: Queryable[float] = ..., rotationAngle: Queryable[float] = ..., smartFit: bool = ..., worldSpace: bool = ...) -> Union[str, bool, int, Tuple[float, float], float, Tuple[float, float, float]]:
    """TsubProjCmdBase is a base class for the command to create a mapping on the selected subdivision faces.
    Projects a map onto an object, using an orthogonal projection. The
    piece of the map defined from isu, isv, icx, icy area, is placed at
    pcx, pcy, pcz location.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        createNewMap (bool?): This flag when set true will create a new map with  
                a the name passed in, if the map does not already exist.  
                Properties: create, query, edit
        imageCenter (Queryable[Tuple[float, float]]?): This flag specifies the center point of the 2D model layout.  
                C: Default is 0.5 0.5.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        imageCenterX (Queryable[float]?): This flag specifies X for the center point of the 2D model layout.  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        imageCenterY (Queryable[float]?): This flag specifies Y for the center point of the 2D model layout.  
                C: Default is 0.5.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        imageScale (Queryable[Tuple[float, float]]?): This flag specifies the UV scale : Enlarges or reduces the 2D version of the model in U or V space relative to the 2D centerpoint.  
                C: Default is 1.0 1.0.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        imageScaleU (Queryable[float]?): This flag specifies the U scale : Enlarges or reduces the 2D version of the model in U space relative to the 2D centerpoint.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        imageScaleV (Queryable[float]?): This flag specifies the V scale : Enlarges or reduces the 2D version of the model in V space relative to the 2D centerpoint.  
                C: Default is 1.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        insertBeforeDeformers (bool?): This flag specifies if the projection node should be inserted before  
                or after deformer nodes already applied to the shape. Inserting the  
                projection after the deformer leads to texture swimming during  
                animation and is most often undesirable.  
                C: Default is on.  
                Properties: create
        keepImageRatio (bool?): True means keep any image ratio  
                Properties: create
        mapDirection (str?): This flag specifies the mapping direction.  
                'x', 'y' and 'z' projects the map along the corresponding axis.  
                'c' projects along the current camera viewing direction.  
                'p' does perspective projection if current camera is perspective.  
                'b' projects along the best plane fitting the objects selected.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        projectionCenter (Queryable[Tuple[float, float, float]]?): This flag specifies the origin point from which the map is projected.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        projectionCenterX (Queryable[float]?): This flag specifies X for the origin point from which the map is projected.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionCenterY (Queryable[float]?): This flag specifies Y for the origin point from which the map is projected.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionCenterZ (Queryable[float]?): This flag specifies Z for the origin point from which the map is projected.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionHeight (Queryable[float]?): This flag specifies the height of the map relative to the 3D projection axis.  
                C: Default is 1.0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        projectionScale (Queryable[Tuple[float, float]]?): This flag specifies the width and the height of the map relative to the 3D projection axis.  
                C: Default is 1.0 1.0.  
                Q: When queried, this flag returns a float[2].  
                Properties: create, query, edit
        projectionWidth (Queryable[float]?): This flag specifies the width of the map relative to the 3D projection axis.  
                C: Default is 1.0  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotate (Queryable[Tuple[float, float, float]]?): This flag specifies the mapping rotate angles.  
                C: Default is 0.0 0.0 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        rotateX (Queryable[float]?): This flag specifies X mapping rotate angle.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float[3].  
                Properties: create, query, edit
        rotateY (Queryable[float]?): This flag specifies Y mapping rotate angle.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotateZ (Queryable[float]?): This flag specifies Z mapping rotate angle.  
                C: Default is 0.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        rotationAngle (Queryable[float]?): This flag specifies the rotation angle in the mapping space.  
                When the angle is positive, then the map rotates  
                counterclockwise on the mapped model, whereas when it is  
                negative then the map rotates lockwise on the mapped model.  
                C: Default is 10.0.  
                Q: When queried, this flag returns a float.  
                Properties: create, query, edit
        smartFit (bool?): True means use the smart fit algorithm  
                Properties: create
        worldSpace (bool?): This flag specifies which reference to use.  
                If "on" : all geometrical values are taken in world reference.  
                If "off" : all geometrical values are taken in object reference.  
                C: Default is "off".  
                Q: When queried, this flag returns an int.  
                Properties: create, query, edit

    Returns:
        str: The node name.

    Example:
    """

def subdToBlind(*args: Any, absolutePosition: bool = ..., includeCreases: bool = ..., includeZeroOffsets: bool = ...) -> bool:
    """The subdivision surface hierarchical edits will get copied into blind
    data on the given polygon.  The polygon face count and topology
    must match the subdivision surface base mesh face count and topology.
    If they don't, the blind data will still appear, but is not guaranteed
    to produce the same result when converted back to a subdivision surface.The command takes a single subdivision surface and a single polygonal
    object.  Additional subdivision surfaces or polygonal objects will be
    ignored.subdivision, surface, hierarchy, blind, data
    Args:
        absolutePosition (bool?): If set to true, the hierarchical edits are represented as the point positions,  
                not the point offsets.  Most of the time, this is not desirable, but if you're  
                just going to be merging/deleting a bunch of things and not move any vertices,  
                then you could set it to true.  False is the default and saves the offsets.  
                Properties: create
        includeCreases (bool?): If set, the creases get transfered as well.  With it false, the subdivision  
                surface created from the blind data + polygon will have lost all the craese  
                information.  The default is false.  
                Properties: create
        includeZeroOffsets (bool?): If set, the zero offset will get included in the blind data.  This will  
                greatly increase the size of the blind data, but will also let you keep  
                all created vertices in the conversion back to polys.  This flag does  
                not change the behaviour for the vertices up to and including level 2  
                as they're always created.  If not set, only the edited vertices will  
                be included in the blind data.  This will still maintain the shape of  
                your object faithfully.  The default is false.  
                Properties: create

    Returns:
        bool: Command result

    Example:
    """

def subdToNurbs(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., applyMatrixToResult: bool = ..., addUnderTransform: bool = ..., caching: bool = ..., constructionHistory: bool = ..., frozen: bool = ..., name: str = ..., nodeState: int = ..., object: bool = ..., outputType: int = ...) -> None: ...
def subdToPoly(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., applyMatrixToResult: bool = ..., caching: bool = ..., copyUVTopology: bool = ..., depth: Queryable[int] = ..., extractPointPosition: bool = ..., format: Queryable[int] = ..., inSubdCVId: Queryable[Multiuse[Tuple[int, int]]] = ..., inSubdCVIdLeft: Queryable[int] = ..., inSubdCVIdRight: Queryable[int] = ..., maxPolys: Queryable[int] = ..., nodeState: Queryable[int] = ..., outSubdCVId: Queryable[Multiuse[Tuple[int, int]]] = ..., outSubdCVIdLeft: Queryable[int] = ..., outSubdCVIdRight: Queryable[int] = ..., outv: Queryable[Multiuse[int]] = ..., preserveVertexOrdering: bool = ..., sampleCount: Queryable[int] = ..., shareUVs: bool = ..., subdNormals: bool = ..., addUnderTransform: bool = ..., connectShaders: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, int, Multiuse[Tuple[int, int]], Multiuse[int]]:
    """This command tessellates a subdivision surface and produces polygon.
    The name of the new polygon is returned.
    If construction history is ON, then the name of the new dependency
    node is returned as well.
    Args:
        applyMatrixToResult (bool?): If true, the matrix on the input geometry is applied to the object  
                and the resulting geometry will have identity matrix on it.  If false  
                the conversion is done on the local space object and the resulting  
                geometry has the input object's matrix on it.  
                Default: true  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        copyUVTopology (bool?): Copy over uv topology (shared/unshared) from the original subdivision  
                surface to the converted polygonal mesh.  
                Default: false  
                Properties: create, query, edit
        depth (Queryable[int]?): The depth at which constant-depth tessellates the surface  
                Default: 0  
                Properties: create, query, edit
        extractPointPosition (bool?): Determines how the position of a mesh point is calculated  
                If on the position of the mesh point is returned. If off the  
                position of the point of the surface is returned.  
                Default: false  
                Properties: create, query, edit
        format (Queryable[int]?): Format:  
              
                0. Uniform  
                1. Adaptive  
                2. Polygon Count  
                3. Vertices  
              
                Default: 0  
                Properties: create, query, edit
        inSubdCVId (Queryable[Multiuse[Tuple[int, int]]]?): Input CV Id  
                Properties: create, query, edit, multiuse
        inSubdCVIdLeft (Queryable[int]?): Higher 32 bit integer of the input CV Id  
                Properties: create, query, edit
        inSubdCVIdRight (Queryable[int]?): Lower 32 bit integer of the input CV Id  
                Properties: create, query, edit
        maxPolys (Queryable[int]?): The maximum number of polygons at which by polygons tessellates.  
                If this attribute is greater than zero, it will override the  
                sample count and depth attributes.  
                Default: 0  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        outSubdCVId (Queryable[Multiuse[Tuple[int, int]]]?): Output CV Id  
                Properties: create, query, edit, multiuse
        outSubdCVIdLeft (Queryable[int]?): Higher 32 bit integer of the output CV Id  
                Properties: create, query, edit
        outSubdCVIdRight (Queryable[int]?): Lower 32 bit integer of the output CV Id  
                Properties: create, query, edit
        outv (Queryable[Multiuse[int]]?): Out Vertices corresponding to the inSubDCVs.  
                Properties: create, query, edit, multiuse
        preserveVertexOrdering (bool?): Preserve vertex ordering in conversion  
                Default: true  
                Properties: create, query, edit
        sampleCount (Queryable[int]?): The number of samples per face  
                Default: 1  
                Properties: create, query, edit
        shareUVs (bool?): Force sharing of uvs on all common vertices - the value of this  
                attribute gets overridden by the value of the copyUVTopology attribute.  
                Default: false  
                Properties: create, query, edit
        subdNormals (bool?): Keep subdiv surface normals  
                Default: false  
                Properties: create, query, edit
        addUnderTransform (bool?): If true then add the result underneath a transform node  
                Properties: create, query
        connectShaders (bool?): If true, all shader assignment will be copied from the  
                original subdiv surface to the converted polygonal surface.  
                Default: true  
                Properties: create
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: The polygon and optionally the dependency node name

    Example:
    """

def subdTransferUVsToCache(*args: str) -> bool:
    """The subdivision surface finer level uvs will get copied to the polygonToSubd
    node sent in as argument.The command takes a single subdivision surface and a single polygonToSubd
    node as input. Additional inputs will be ignored.
    Please note that this command is an internal command and is to be used
    with care, directly by the usersubdivision, surface, hierarchy, blind, data
    Returns:
        bool: Command result

    Example:
    """

def subdiv(*args: Any, query: bool = ..., currentLevel: bool = ..., currentSubdLevel: bool = ..., deepestLevel: Queryable[int] = ..., displayLoad: bool = ..., edgeStats: bool = ..., faceStats: bool = ..., maxPossibleLevel: Queryable[int] = ..., proxyMode: Queryable[int] = ..., smallOffsets: bool = ...) -> Union[bool, int]:
    """Provides useful information about the selected subdiv or components, such
    as the deepest subdivided level, the children or parents of the currently
    selected components, etc.subdivision, surface, query, level
    Args:
        currentLevel (bool?): When queried, this flag returns an integer representing  
                the level of the currently selected subdiv surface component(s).  
                Returns -1, if there are more than one level of CVs are selected,  
                (even if they are from different objects)  
                Returns -2, if there are no input subdiv CVs to process.  
                Properties: create, query
        currentSubdLevel (bool?): When queried, this flag returns an integer representing  
                the level of the currently selected subdiv surface, regardless  
                of whether components are selected or not.  
                Returns -2, if there are no input subdiv CVs to process.  
                Properties: create, query
        deepestLevel (Queryable[int]?): When queried, this flag returns an integer representing the  
                deepest level to which the queried subdiv surface has  
                been subdivided.  
                Properties: create, query
        displayLoad (bool?): When queried, this flag prints the display load of selected subdiv  
                Properties: create, query
        edgeStats (bool?): When queried, this flag prints stats on the current subd.  
                Properties: create, query
        faceStats (bool?): When queried, this flag prints stats on the current subd.  
                Properties: create, query
        maxPossibleLevel (Queryable[int]?): When queried, this flag returns an integer representing  
                the maximum possible level to which the queried subdiv surface can  
                been subdivided.  
                Properties: create, query
        proxyMode (Queryable[int]?): When queried, this flag returns an integer representing  
                whether or not the subdivision surface is in "polygon proxy" mode.  
                "Proxy" mode allows the base mesh of a subdivision surface  
                without construction history to be edited using the polygonal  
                editing tools.  
                Returns 1, if the subdivision surface is in "polygon proxy" mode.  
                Returns 0, if the surface is not currently in "proxy" mode, but could  
                be put into "proxy" mode since it has no construction history.  (This state  
                is also known as "standard" mode.)  
                Returns 2, if the surface is not in "proxy" mode and cannot be put  
                into proxy mode, as it has construction history.  
                Properties: create, query
        smallOffsets (bool?): When queried, this flag prints the number of subdiv vertices in the  
                hierarchy that have a small enough offset so that the vertex is not required  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def subdivCrease(*args: Any, sharpness: bool = ...) -> bool:
    """Set the creasing on subdivision mesh edges or mesh points that are on
    the selection list.subdivision, surface, crease
    Args:
        sharpness (bool?): Specifies the sharpness value to set the crease to  
                Properties: create

    Returns:
        bool: Command result

    Example:
    """

def subdivDisplaySmoothness(*args: Any, query: bool = ..., all: bool = ..., smoothness: Queryable[int] = ...) -> Union[bool, int]:
    """Sets or querys the display smoothness of subdivision surfaces on the selection list or of all subdivision surfaces if the -all option is set.  Smoothness options are; rough, medium, or fine.  Rough is the default.subdivision, surface, display, smoothness
    Args:
        all (bool?): If set, change smoothness for all subdivision surfaces  
                Properties: create, query
        smoothness (Queryable[int]?): Smoothness - 1 rough, 2 medium, 3 fine  
                Properties: create, query

    Returns:
        bool: Command result

    Example:
    """

def subgraph(*args: Any, **kwargs: Any) -> None: ...
def substituteGeometry(*args: str, disableNonSkinDeformers: bool = ..., newGeometryToLayer: bool = ..., oldGeometryToLayer: bool = ..., reWeightDistTolerance: float = ..., retainOldGeometry: bool = ...) -> str:
    """This command can be used to replace the geometry which is already connected
    to deformers with a new geometry. The weights on the old geometry will be
    retargeted to the new geometry.deformers, replace, geometry, skin
    Args:
        disableNonSkinDeformers (bool?): This flag controls the state of deformers other than skin deformers after  
                the substitution has taken place. If the flag is true then non-skin deformer  
                nodes are left in a disabled state at the completion of the command.  
                Default value is false.  
                Properties: create
        newGeometryToLayer (bool?): Create a new layer for the new geometry.  
                Properties: create
        oldGeometryToLayer (bool?): Create a new layer and move the old geometry to this layer  
                Properties: create
        reWeightDistTolerance (float?): Specify the distance tolerance value to be used for retargeting weights.  
                While transferring weights the command tries to find the corresponding  
                vertices by overlapping the geometries with all deformers disabled. Sometimes  
                this results in selection of unrelated vertices. (Example when a hole in  
                the old geometry has been filled with new vertices in the new geometry.)  
                This distance tolerance value is used to detect this kind of faults and  
                either ignore these cases or to vary algorithm to find more corresponding  
                vertices.  
                Properties: create
        retainOldGeometry (bool?): A copy of the old geometry should be retained  
                Properties: create

    Returns:
        str: Name of shapes that were replaced

    Example:
    """

def suitePrefs(*, applyToSuite: str = ..., installedAsSuite: bool = ..., isCompleteSuite: bool = ...) -> bool:
    """This command sets the mouse and keyboard interaction mode
    for Maya and other Suites applications (if Maya is part of
    a Suites install).
    Args:
        applyToSuite (str?): Apply the mouse and keyboard interaction settings  
                for the given application to all applications in the  
                Suite (if Maya is part of a Suites install). Valid  
                values are "Maya", "3dsMax", or "undefined", which  
                signifies that each app is to use their own settings.  
                Properties: create
        installedAsSuite (bool?): Returns true if Maya is part of a Suites install, false  
                otherwise.  
                Properties: create
        isCompleteSuite (bool?): Returns true if the Suites install contains all Entertainment  
                Creation Suite products, false otherwise.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def superCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., attach: Multiuse[str] = ..., exists: bool = ..., image1: str = ..., image2: str = ..., image3: str = ...) -> None: ...
def surface(*args: str, degreeU: int = ..., degreeV: int = ..., formU: str = ..., formV: str = ..., knotU: Multiuse[float] = ..., knotV: Multiuse[float] = ..., name: str = ..., objectSpace: bool = ..., point: Multiuse[Tuple[float, float, float]] = ..., pointWeight: Multiuse[Tuple[float, float, float, float]] = ..., worldSpace: bool = ...) -> str:
    """The cmd creates a NURBS spline surface (rational or non rational).
    The surface is created by specifying control vertices (CV's) and
    knot sequences in the U and V direction.  You cannot query
    the properties of the surface using this command.  See examples
    below.
    Args:
        degreeU (int?): Degree in surface U direction.  Default is degree 3.  
                Properties: create
        degreeV (int?): Degree in surface V direction.  Default is degree 3.  
                Properties: create
        formU (str?): The string for open is "open" , for closed is "closed"  or  
                for periodic is "periodic" in U.  
                Properties: create
        formV (str?): The string for open is "open" , for closed is "closed"  or  
                for periodic is "periodic" in V.  
                Properties: create
        knotU (Multiuse[float]?): Knot value(s) in U direction.  One flag per knot value. There must  
                be (numberOfPointsInU + degreeInU - 1) knots and the knot  
                vector must be non-decreasing.  
                Properties: create, multiuse
        knotV (Multiuse[float]?): Knot value(s) in V direction.  One flag per knot value. There must  
                be (numberOfPointsInV + degreeInV - 1) knots and the knot  
                vector must be non-decreasing.  
                Properties: create, multiuse
        name (str?): Name to use for new transforms.  
                Properties: create
        objectSpace (bool?): Should the operation happen in objectSpace?  
                Properties: create
        point (Multiuse[Tuple[float, float, float]]?): To specify non rational CV with (x, y, z) values.  "linear" means  
                that this flag can take values with units.  Note that you  
                must specify (degree+1) surface points in any direction to create  
                a visible surface span.  eg.  if the surface is degree 3 in the U  
                direction, you must specify 4 CVs in the U direction.  
                Points are specified in rows of U and columns of V.  If you  
                want to incorporate units, add the unit name to the value, eg.  
                "-p 3.3in 5.5ft 6.6yd"  
                Properties: create, multiuse
        pointWeight (Multiuse[Tuple[float, float, float, float]]?): To specify rational CV with (x, y, z, w) values.  "linear" means  
                that this flag can take values with units.  Note that you  
                must specify (degree+1) surface points in any direction to create  
                a visible surface span.  eg.  if the surface is degree 3 in the U  
                direction, you must specify 4 CVs in the U direction.  
                Points are specified in rows of U and columns of V.  
                Properties: create, multiuse
        worldSpace (bool?): Should the operation happen in worldSpace?  
                Properties: create

    Returns:
        str: The path to the new surface

    Example:
    """

def surfaceSampler(*args: str, camera: str = ..., fileFormat: Multiuse[str] = ..., filename: Multiuse[str] = ..., filterSize: float = ..., filterType: int = ..., flipU: bool = ..., flipV: bool = ..., ignoreMirroredFaces: bool = ..., ignoreTransforms: bool = ..., mapHeight: Multiuse[int] = ..., mapMaterials: Multiuse[bool] = ..., mapOutput: Multiuse[str] = ..., mapSpace: Multiuse[str] = ..., mapWidth: Multiuse[int] = ..., maxSearchDistance: Multiuse[float] = ..., maximumValue: Multiuse[float] = ..., overscan: int = ..., searchCage: Multiuse[str] = ..., searchMethod: int = ..., searchOffset: Multiuse[float] = ..., shadows: Multiuse[bool] = ..., source: Multiuse[str] = ..., sourceUVSpace: Multiuse[str] = ..., superSampling: int = ..., target: Multiuse[str] = ..., targetUVSpace: Multiuse[str] = ..., useGeometryNormals: bool = ..., uvSet: Multiuse[str] = ...) -> bool:
    """Maps surface detail from a source surface to a new texture map on a target
    surface. Both objects must be selected when the command is invoked, with
    the source surface selected first, and the target last.
    Args:
        camera (str?): Specify the camera to use for camera specific lighting calculations such as  
                specular highlights or reflections.  
                Properties: create
        fileFormat (Multiuse[str]?): The image format as a file extension (e.g. "dds").  
                This must be included once for every output map specified.  
                Properties: create, multiuse
        filename (Multiuse[str]?): The filename to use when creating the map.  
                This must be included once for every output map specified.  
                Properties: create, multiuse
        filterSize (float?): The filter size to use in pixels. Larger values (e.g. over 2.0) will produce smoother/softer  
                results, while values closer to 1.0 will produce sharper results.  
                Properties: create
        filterType (int?): The filter type to use. 0 is a Guassian filter, 1 is a triangular filter, 2 is a box filter.  
                Properties: create
        flipU (bool?): Flip the U coordinate of the generated image.  
                Properties: create
        flipV (bool?): Flip the V coordinate of the generated image.  
                Properties: create
        ignoreMirroredFaces (bool?): Stops reverse wound (i.e. mirrored) faces from contributing to the map  
                generation.  
                Properties: create
        ignoreTransforms (bool?): Controls whether transforms are used (meaning the search is performed in worldspace),  
                or not (meaning the search is performed in object space).  
                Properties: create
        mapHeight (Multiuse[int]?): Pixel width of the generated map.  
                This must be included once for every output map specified.  
                Properties: create, multiuse
        mapMaterials (Multiuse[bool]?): Where appropriate (e.g. normal maps), this controls whether the material  
                should be included when sampling the map attribute.  
                This must be included once for every output map specified.  
                Properties: create, multiuse
        mapOutput (Multiuse[str]?): Specifies a new output map to create. One of "normal", "displacement"  
                "diffuseRGB", "litAndShadedRGB", or "alpha"  
                Properties: create, multiuse
        mapSpace (Multiuse[str]?): The space to generate the map in. Valid keyword is "object". Default  
                is tangent space.  
                This must be included once for every output map specified.  
                Properties: create, multiuse
        mapWidth (Multiuse[int]?): Pixel width of the generated map. Some output image formats require even or power of 2.  
                This must be included once for every output map specified.  
                Properties: create, multiuse
        maxSearchDistance (Multiuse[float]?): Controls the maximum distance away from a target surface that will  
                be searched for source surfaces. A value of 0 indicates no limit.  
                When generated maps include artifacts from the "other side" of an  
                object, try setting this value to a distance approximately equal to  
                the radius of the object.  
                If this flag is included, it must be included once for every target.  
                Properties: create, multiuse
        maximumValue (Multiuse[float]?): The maximum value to include in the map. This allows control of how floating  
                point values (like displacement) are quantised into integer image formats.  
                Properties: create, multiuse
        overscan (int?): The number of additional pixels to render around UV borders.  
                This will help to minimise texel filtering artifacts on  
                UV seams. When mipmaps are going to be generated for the texture  
                a higher value may be necessary (in addition to a filterSize  
                greater than 1).  
                Properties: create
        searchCage (Multiuse[str]?): Specifies a search envelope surface to use as a search guide  
                when looking for source surfaces.  
                If this flag is included, it must be included once for every target.  
                Properties: create, multiuse
        searchMethod (int?): Controls the search method used to match sample points on a target surface  
                to points on the sources. 0 is closest to envelope, 1 is prefer any intersection  
                inside envelope to intersections outside it, and 2 is only use intersections  
                inside envelope.  
                Properties: create
        searchOffset (Multiuse[float]?): Specifies a fixed offset from a target surface to use as the  
                starting point when looking for source surfaces. This value is  
                only used when no search cage is specified for a given target.  
                If this flag is included, it must be included once for every target.  
                Properties: create, multiuse
        shadows (Multiuse[bool]?): Where appropriate (e.g. lit and shaded), this controls whether  
                shadows are included in the calculation. Currently only depth  
                map shadows are supported.  
                Properties: create, multiuse
        source (Multiuse[str]?): Specifies a surface to use as a sampling source  
                Properties: create, multiuse
        sourceUVSpace (Multiuse[str]?): Specifies that the transfer of data between the surfaces should be  
                done in UV space and specifies the name of the UV set on the source  
                surface(s) that should be used as the transfer space.  
                Properties: create, multiuse
        superSampling (int?): Controls the number of sampling points calculated for each output value. The algorithm will  
                use 2 ^ n squared samples for each point (so a value of 0 will use a single sample, while a value  
                of 3 will calculate 64 samples for each point).  
                Properties: create
        target (Multiuse[str]?): Specified a surface to sample output information for.  
                Properties: create, multiuse
        targetUVSpace (Multiuse[str]?): Specifies that the transfer of data between the surfaces should be  
                done in UV space and specifies the name of the UV set on the target  
                surface(s) that should be used as the transfer space.  
                Properties: create, multiuse
        useGeometryNormals (bool?): Controls whether geometry or surface normals are used for surface searching.  
                Using geometry normals will ensure a smooth mapping but can introduce distorted  
                mappings where there are large distances between the source and target surfaces.  
                Surface normals can introduce overlapping or discontinuous mappings, but does  
                allow map distortion to be influenced by surface normal direction.  
                Properties: create
        uvSet (Multiuse[str]?): The name of the UV set to use when creating output maps.  
                If this flag is included, it must be included once for every target.  
                Properties: create, multiuse

    Returns:
        bool:

    Example:
    """

def surfaceShaderList(*args: str, edit: bool = ..., query: bool = ..., add: str = ..., remove: str = ...) -> bool:
    """Add/Remove a relationship between an object and the
    current shading group.
    Args:
        add (str?): add object(s) to shader group list.  
                Properties: create
        remove (str?): remove object(s) to shader group list.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def swatchDisplayPort(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., borderColor: Queryable[Tuple[float, float, float]] = ..., borderWidth: Queryable[int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., pressCommand: Callable[..., Any] = ..., preventOverride: bool = ..., renderPriority: int = ..., renderSize: Queryable[int] = ..., shadingNode: Queryable[str] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., widthHeight: Tuple[int, int] = ...) -> Union[str, Tuple[float, float, float], int, bool, Callable[..., Any]]:
    """This command creates a 3dPort that displays a swatch
    representing the shading node.The optional argument is the name of the 3dPort.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        borderColor (Queryable[Tuple[float, float, float]]?): The border color of the swatch.  
                Properties: create, query, edit
        borderWidth (Queryable[int]?): The border width of the swatch.  The value will be clamped  
                between 0 and 4.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        pressCommand (Callable[..., Any]?): Specifies the command to be run when the swatch is clicked on.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        renderPriority (int?): Specifies the priority to render the swatch.  
                This flag can only be used in parallel swatch rendering.  
                When more than one swatch are waiting in the render queue,  
                this flag can be used to specify which one has the higher priority to be rendered.  
                By default, the flag is set to 0. low priority.  
                The larger the number, the higher priority is used to render the swatch.  
              
                Maya pre-defined the render priority for the swatch in Node Editor, Attribute Editor and Hypershade as below:  
              
                0. The lowest render priority.  
                1. The render priority for the swatch in Node Editor.  
                2. The render priority for the swatch in the working area of HyperShade  
                3. The render priority for the swatch in Attribute Editor.  
              
                For example, when creating a display port in AE using the swatchDisplayPort command, option "-rp 3" is used.  
                Properties: create, edit
        renderSize (Queryable[int]?): The render size of the swatch.  The value will be clamped  
                between 32 and 512.  
                Properties: create, query, edit
        shadingNode (Queryable[str]?): Name of the shadingNode.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        widthHeight (Tuple[int, int]?): The width and height of the port.  
                Properties: create, edit

    Returns:
        str: - the name of the port created or modified

    Example:
    """

def swatchRefresh(*args: str) -> bool:
    """Thecommand causes image source node swatches to be
    refreshed on screen.  The purpose of this command is to provide a mechanism
    to trigger a swatch refresh in cases that are not subject to dirty propagation
    in the dependency graph.  This command only works with imageSource-derived
    node types. Invoking this command with no arguments will cause all imageSource
    swatches to be refreshed.swatch, renderPass, renderLayer, renderTarget
    Returns:
        bool: true if all arguments are valid image source nodes and the operation succeded.

    Example:
    """

def switchTable(*args: Any, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label1: str = ..., label2: str = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., selectedRow: bool = ..., statusBarMessage: str = ..., switchNode: Queryable[str] = ..., underPointerRow: bool = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates/edits/queries the switch table control.The optional argument is the name of the control.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label1 (str?): Set the label of the first column  
                Properties: edit
        label2 (str?): Set the label of the second column  
                Properties: edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        selectedRow (bool?): The current row selected.  
                Properties: query
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        switchNode (Queryable[str]?): The switch node to be displayed in the control.  
                Properties: query, edit
        underPointerRow (bool?): The row under the pointer.  
                Properties: query
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the switch table control.

    Example:
    """

def symbolButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., command: Queryable[Callable[..., Any]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], Callable[..., Any], bool, int]:
    """This command creates a symbol button.  A symbol button behaves like
    a regular button, the only difference is a symbol button displays
    an image rather that a text label.  A command may be attached to the
    button which will be executed when the button is pressed.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        command (Queryable[Callable[..., Any]]?): Command executed when the symbol button is pressed.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): Image for the button.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def symbolCheckBox(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., disableOffImage: Queryable[str] = ..., disableOnImage: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image: Queryable[str] = ..., innerMargin: bool = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., offCommand: Callable[..., Any] = ..., offImage: Queryable[str] = ..., onCommand: Callable[..., Any] = ..., onImage: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., value: bool = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a symbol check box.  A symbol check box is a
    simple control containing a pixmap and a state of either on or off.
    Commands can be attached to any or all of the following events:  when
    the symbol check box is turned on, turned off, or simply when it's
    state is changed.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the check box's state is changed.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of the check box from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disableOffImage (Queryable[str]?): Image displayed when the check box is off and disabled.  
                Properties: create, query, edit
        disableOnImage (Queryable[str]?): Image displayed when the check box is on and disabled.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image (Queryable[str]?): Image of the check box.  
                Properties: create, query, edit
        innerMargin (bool?): This flag will revert the symbolCheckBox to its pre Maya 2.5  
                behaviour of having a 2 pixel inner margin.  
                This flag is for backward compatibility on Linux only, and will  
                be removed in future releases.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Callable[..., Any]?): Command executed when the symbol check box is turned off.  
                Properties: create, edit
        offImage (Queryable[str]?): Image displayed when the check box is off.  
                Properties: create, query, edit
        onCommand (Callable[..., Any]?): Command executed when the symbol check box is turned on.  
                Properties: create, edit
        onImage (Queryable[str]?): Image displayed when the check box is on.  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (bool?): Value of the check box.  
                Properties: create, query, edit
        version (Queryable[str]?): Specify the version that this control feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2017", "2018"). Currently only accepts major version  
                numbers (e.g. 2017 Ext 1, or 2017.5 should be given as "2018").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def symmetricModelling(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., about: Queryable[str] = ..., allowPartial: bool = ..., axis: Queryable[str] = ..., preserveSeam: Queryable[int] = ..., reset: bool = ..., seamFalloffCurve: Queryable[str] = ..., seamTolerance: Queryable[float] = ..., symmetry: Queryable[int] = ..., tolerance: Queryable[float] = ..., topoSymmetry: bool = ...) -> Union[bool, str, int, float]:
    """This command allows you to change the symmetric modelling options.Symmetric modelling is an option that allows for reflection of basic
    manipulator actions such as move, rotate, and scale.
    Args:
        about (Queryable[str]?): Set the space in which symmetry should be calculated (object or world or topo).  
                When queried, returns a string which is the current space being used.  
                Properties: create, query, edit
        allowPartial (bool?): Specifies whether partial symmetry should be allowed when enabling topological symmetry.  
                Properties: create, query, edit
        axis (Queryable[str]?): Set the current axis to be reflected over.  
                When queried, returns a string which is the current axis.  
                Properties: create, query, edit
        preserveSeam (Queryable[int]?): Controls whether selection or symmetry should take priority on the plane  
                of symmetry.  
                When queried, returns an int for the option.  
                Properties: create, query, edit
        reset (bool?): Reset the redo information before starting.  
                Properties: create, edit
        seamFalloffCurve (Queryable[str]?): Set the seam's falloff curve, used to control the seam strength within the  
                seam tolerance. The string is a comma separated list of sets of 3 values  
                for each curve point.  
                When queried, returns a string which is the current space being used.  
                Properties: create, query, edit
        seamTolerance (Queryable[float]?): Set the seam tolerance used for reflection. When preserveSeam is enabled, this  
                tolerance controls the width of the enforced seam.  
                When queried, returns a float of the seamTolerance.  
                Properties: create, query, edit
        symmetry (Queryable[int]?): Set the symmetry option on or off.  
                When queried, returns an int for the option.  
                Properties: create, query, edit
        tolerance (Queryable[float]?): Set the tolerance of reflection.  
                When queried, returns a float of the tolerance.  
                Properties: create, query, edit
        topoSymmetry (bool?): Enable/disable topological symmetry.  
                When enabled, the supplied component/active list will be used to define the topological symmetry seam.  
                When queried, returns the name of the active topological symmetry object.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def syncSculptCache(*args: Any, **kwargs: Any) -> None: ...
def sysFile(arg0: str = ..., /, *, copy: str = ..., delete: bool = ..., makeDir: bool = ..., move: str = ..., removeEmptyDir: bool = ..., rename: str = ...) -> bool:
    """This command provides a system independent way to create a directory
    or to rename or delete a file.
    Args:
        copy (str?): Copy the file to the name given by the newFileName paramter.  
                Properties: create
        delete (bool?): Deletes the file.  
                Properties: create
        makeDir (bool?): Create the directory path given in the parameter.  
                This will create the entire path if more than one  
                directory needs to be created.  
                Properties: create
        move (str?): Behaves identically to the -rename flag and remains for  
                compatibility with old scripts  
                Properties: create
        removeEmptyDir (bool?): Delete the directory path given in the parameter if  
                the directory is empty. The command will not delete a directory  
                which is not empty.  
                Properties: create
        rename (str?): Rename the file to the name given by the newFileName parameter.  
                Properties: create

    Returns:
        bool: True if successful, false otherwise.

    Example:
    """

def tabLayout(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., borderStyle: Queryable[str] = ..., changeCommand: Callable[..., Any] = ..., childArray: bool = ..., childResizable: bool = ..., closeTab: int = ..., closeTabCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., doubleClickCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., generalSpacing: int = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., horizontalScrollBarThickness: int = ..., image: Queryable[str] = ..., imageVisible: bool = ..., innerMarginHeight: Queryable[int] = ..., innerMarginWidth: Queryable[int] = ..., isObscured: bool = ..., manage: bool = ..., margins: int = ..., minChildWidth: Queryable[int] = ..., moveTab: Tuple[int, int] = ..., newTabCommand: Callable[..., Any] = ..., noBackground: bool = ..., numberOfChildren: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., postMenuCommand: Callable[..., Any] = ..., preSelectCommand: Callable[..., Any] = ..., preventOverride: bool = ..., scrollable: bool = ..., scrollableTabs: bool = ..., selectCommand: Queryable[Callable[..., Any]] = ..., selectTab: Queryable[str] = ..., selectTabIndex: Queryable[int] = ..., showNewTab: bool = ..., statusBarMessage: str = ..., tabIcon: Queryable[Multiuse[Tuple[str, str]]] = ..., tabIconIndex: Queryable[Multiuse[Tuple[int, str]]] = ..., tabLabel: Queryable[Multiuse[Tuple[str, str]]] = ..., tabLabelIndex: Queryable[Multiuse[Tuple[int, str]]] = ..., tabPosition: Queryable[str] = ..., tabTooltip: Queryable[Multiuse[Tuple[str, str]]] = ..., tabTooltipIndex: Queryable[Multiuse[Tuple[int, str]]] = ..., tabsClosable: bool = ..., tabsVisible: bool = ..., useTemplate: str = ..., verticalScrollBarThickness: int = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any], Multiuse[Tuple[str, str]], Multiuse[Tuple[int, str]]]:
    """This command creates a tab group. Tab groups are a specialized form of
    control layouts that contain only control layouts.
    Whenever a control layout is added to a tab group it will have a tab
    provided for it that allows selection of that group
    from amongst other tabbed control groups. Only one child of a tab
    layout is visible at a time.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        borderStyle (Queryable[str]?): Specify the style of the border for tab layout. Valid values are:  
                "none", "top", "notop" and "full". By default, it will use "full" to draw a simple frame  
                around the body area of the tab layout.  
              
                "none"  - Do not draw borders around the body area of the tab layout  
                "top"   - Only draw a simple line right below the tabs  
                "notop" - Draw a simple frame on the left/right/bottom (no top) of the tab layout  
                "full"  - Draw a simple frame around the body area of the tab layout  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when a tab is selected interactively.  
                This command is only invoked when the selected tab changes.  
                Re-selecting the current tab will not invoke this command.  
                Properties: create, edit
        childArray (bool?): Returns a string array of the names of the layout's  
                immediate children.  
                Properties: query
        childResizable (bool?): Set to true if you want the child of the control layout to be  
                as wide as the scroll area.  You may also indicate a minimum  
                width for the child using the -mcw/minChildWidth flag.  
                Properties: create, query
        closeTab (int?): Close the tab at the given index.  
                Properties: create, edit
        closeTabCommand (Callable[..., Any]?): Specify a script to be executed when one of the tabs are closed by clicking on the  
                header widget (MMB or X button).  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Callable[..., Any]?): Command executed when a tab is double clicked on.  Note  
                that the first click will select the tab and the second click  
                will execute the double click command.  Double clicking the  
                current tab will re-invoke the double click command.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        generalSpacing (int?): Sets the spacing for this layout.  
                Properties: edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        horizontalScrollBarThickness (int?): Thickness of the horizontal scroll bar.  Specify an  
                integer value greater than or equal to zero. This flag has  
                no effect on Windows systems.  
                Properties: create, edit
        image (Queryable[str]?): Image appearing in top right corner of tab layout.  
                Properties: create, query, edit
        imageVisible (bool?): Visibility of tab image.  
                Properties: create, query, edit
        innerMarginHeight (Queryable[int]?): Margin height for all tab children.  
                Properties: create, query
        innerMarginWidth (Queryable[int]?): Margin width for all tab children.  
                Properties: create, query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        margins (int?): Sets the content margins for this layout.  
                Properties: edit
        minChildWidth (Queryable[int]?): Specify a positive non-zero integer value indicating the  
                minimum width the tab layout's children.  This flag only has  
                meaning when the -cr/childResizable flag is set to true.  
                Properties: create, query
        moveTab (Tuple[int, int]?): Move the tab from the current index to a new index.  
                Properties: create, edit
        newTabCommand (Callable[..., Any]?): Command executed when the 'New Tab' button (on the tab bar)  
                is clicked.  Note: in order to show the new tab button use  
                the -snt/showNewTab flag.  Using this command will  
                override any internal Maya logic for adding a new tab (only  
                this command will be executed).  
                Properties: create, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfChildren (bool?): Returns in an int the number of immediate children of the layout.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        postMenuCommand (Callable[..., Any]?): Specify a script to be executed when the popup menu is about to be shown.  
                Properties: create, edit
        preSelectCommand (Callable[..., Any]?): Command executed when a tab is selected but before it's  
                contents become visible.  Re-selecting the current tab will not  
                invoke this command.  Note that this command is not executed by  
                using either of the -st/selectTab  
                or -sti/selectTabIndex flags.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        scrollable (bool?): Puts all children of this layout within a scroll area.  
                Properties: create, query
        scrollableTabs (bool?): If true, the active tab in the layout can be scrolled through with the mouse wheel.  
                Default is true.  
                Properties: create, query, edit
        selectCommand (Queryable[Callable[..., Any]]?): Command executed when a tab is selected interactively  This  
                command will be invoked whenever a tab is selected, ie.  
                re-selecting the current tab will invoke this command.  Note that  
                this command is not executed by using either of  
                the -st/selectTab or -sti/selectTabIndex flags.  
                Properties: create, query, edit
        selectTab (Queryable[str]?): The name, in short form, of the selected tab.  An empty  
                string is returned on query if there are no child tabs.  
                Properties: create, query, edit
        selectTabIndex (Queryable[int]?): Identical to the -st/selectTab flag except this  
                flag takes a 1. based index to identify the selected tab.  A value of  
                0 is returned on query if there are no child tabs.  
                Properties: create, query, edit
        showNewTab (bool?): Set to true if you want to have a 'New Tab' button shown at the end of  
                the tab bar.  Note: use the -ntc/newTabCommand flag to set the command  
                executed when this button is clicked.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        tabIcon (Queryable[Multiuse[Tuple[str, str]]]?): Set an icon for a tab.  The first argument is the name of a  
                control that must be a child of the tab layout.  The second  
                argument is the icon file name.  
                Properties: create, query, edit, multiuse
        tabIconIndex (Queryable[Multiuse[Tuple[int, str]]]?): Identical to the -ti/tabIcon flag except this  
                flag takes a 1. based index to identify the tab you want to set the  
                icon for. If this flag is queried the tab icons for all the  
                children are returned.  
                Properties: create, query, edit, multiuse
        tabLabel (Queryable[Multiuse[Tuple[str, str]]]?): Set a tab label.  The first argument is the name of a  
                control that must be a child of the tab layout.  The second  
                argument is the label for the tab associated with that child.  
                If this flag is queried then the tab labels for all the children  
                are returned.  
                Properties: create, query, edit, multiuse
        tabLabelIndex (Queryable[Multiuse[Tuple[int, str]]]?): Identical to the -tl/tabLabel flag except this  
                flag takes a 1. based index to identify the tab you want to set the  
                label for. If this flag is queried the tab labels for all the  
                children are returned.  
                Properties: create, query, edit, multiuse
        tabPosition (Queryable[str]?): Changes the tab position. The possible values are: "north", "east" and "west".  
                Properties: create, query, edit
        tabTooltip (Queryable[Multiuse[Tuple[str, str]]]?): Set a tab tooltip.  The first argument is the name of a  
                control that must be a child of the tab layout.  The second  
                argument is the tooltip for the tab associated with that child.  
                If this flag is queried then the tab tooltips for all the children  
                are returned.  
                Properties: create, query, edit, multiuse
        tabTooltipIndex (Queryable[Multiuse[Tuple[int, str]]]?): Identical to the -tt/tabTooltip flag except this  
                flag takes a 1. based index to identify the tab you want to set the  
                tooltip for. If this flag is queried the tab tooltips for all the  
                children are returned.  
                Properties: create, query, edit, multiuse
        tabsClosable (bool?): Set to true if you want to have a close button icon on all created tabs.  
                Properties: create, query
        tabsVisible (bool?): Visibility of the tab labels.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalScrollBarThickness (int?): Thickness of the vertical scroll bar.  Specify an  
                integer value greater than or equal to zero. This flag has  
                no effect on Windows systems.  
                Properties: create, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def tangentConstraint(*args: str, edit: bool = ..., query: bool = ..., aimVector: Queryable[Tuple[float, float, float]] = ..., layer: str = ..., name: Queryable[str] = ..., remove: bool = ..., targetList: bool = ..., upVector: Queryable[Tuple[float, float, float]] = ..., weight: Queryable[float] = ..., weightAliasList: bool = ..., worldUpObject: Queryable[str] = ..., worldUpType: Queryable[str] = ..., worldUpVector: Queryable[Tuple[float, float, float]] = ...) -> Union[List[str], Tuple[float, float, float], str, bool, float]:
    """Constrain an object's orientation based on the tangent of the target
    curve[s] at the closest point[s] to the object.A tangentConstraint takes as input one or more NURBS curves (the
    targets) and a DAG transform node (the object).  The tangentConstraint
    orients the constrained object such that the aimVector (in the
    object's local coordinate system) aligns in world space to combined
    tangent vector.  The upVector (again the the object's local coordinate
    system) is aligned in world space with the worldUpVector.  The
    combined tangent vector is a weighted average of the tangent vector
    for each target curve at the point closest to the constrained object.
    Args:
        aimVector (Queryable[Tuple[float, float, float]]?): Set the aim vector.  This is the vector in local  
                coordinates that points at the target.  If not given at creation  
                time, the default value of (1.0, 0.0, 0.0) is used.  
                Properties: create, query, edit
        layer (str?): Specify the name of the animation layer where the constraint should be added.  
                Properties: create, edit
        name (Queryable[str]?): Sets the name of the constraint node to the specified  
                name.  Default name is constrainedObjectName_constraintType  
                Properties: create, query, edit
        remove (bool?): removes the listed target(s) from the constraint.  
                Properties: edit
        targetList (bool?): Return the list of target objects.  
                Properties: query
        upVector (Queryable[Tuple[float, float, float]]?): Set local up vector.  This is the vector in local  
                coordinates that aligns with the world up vector.  If not given  
                at creation time, the default value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit
        weight (Queryable[float]?): Sets the weight value for the specified target(s).  
                If not given at creation time, the default value of 1.0 is used.  
                Properties: create, query, edit
        weightAliasList (bool?): Returns the names of the attributes that control the weight  
                of the target objects. Aliases are returned in the same order  
                as the targets are returned by the targetList flag  
                Properties: query
        worldUpObject (Queryable[str]?): Set the DAG object use for worldUpType "object" and  
                "objectrotation". See worldUpType for greater detail.  
                The default value is no up object, which is interpreted  
                as world space.  
                Properties: create, query, edit
        worldUpType (Queryable[str]?): Set the type of the world up vector computation.  
                The worldUpType can have one of 5 values: "scene",  
                "object", "objectrotation", "vector", or "none".  
                If the value is "scene", the upVector is  
                aligned with the up axis of the scene and  
                worldUpVector and worldUpObject are ignored.  
                If the value is "object", the upVector is  
                aimed as closely as possible to the  
                origin of the space of the worldUpObject and  
                the worldUpVector is ignored.  
                If the value is "objectrotation" then the  
                worldUpVector is interpreted as being in  
                the coordinate space of the worldUpObject, transformed into  
                world space and the upVector is aligned as  
                closely as possible to the result.  
                If the value is "vector", the upVector  
                is aligned with worldUpVector as closely as  
                possible and worldUpMatrix is ignored.  
                Finally, if the value is "none" no twist calculation  
                is performed by the constraint, with the resulting "upVector"  
                orientation based previous orientation of the  
                constrained object, and the "great circle" rotation needed  
                to align the aim vector with its constraint.  
                The default worldUpType is "vector".  
                Properties: create, query, edit
        worldUpVector (Queryable[Tuple[float, float, float]]?): Set world up vector.  This is the vector in world  
                coordinates that up vector should align with.  
                See -wut/worldUpType (below)for greater detail.  
                If not given at creation time, the default  
                value of (0.0, 1.0, 0.0) is used.  
                Properties: create, query, edit

    Returns:
        List[str]: Name of the created constraint node

    Example:
    """

def targetWeldCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., mergeToCenter: bool = ..., preserveUV: bool = ...) -> Union[bool, str]:
    """Create a new context to weld vertices together on a poly object.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        mergeToCenter (bool?): If mergeToCenter is set to true then the source and target vertices's  
                will be moved to the center before doing the merge.  If set to false  
                the source vertex will be moved to the target vertex before doing the  
                merge.  
                Properties: create, query, edit
        preserveUV (bool?): When false, UVs are not changed when welding components.  
                When true, the UVs are modified to stop texture swimming  
                when welding components. Default is true.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def tension(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., deformerTools: bool = ..., envelope: Queryable[float] = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., inwardConstraint: Queryable[float] = ..., name: str = ..., outwardConstraint: Queryable[float] = ..., parallel: bool = ..., pinBorderVertices: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., smoothingIterations: Queryable[int] = ..., smoothingStep: Queryable[float] = ..., split: bool = ..., useComponentTags: bool = ...) -> Union[str, bool, float, Multiuse[str], int]:
    """This command is used to create, edit and query tension nodes.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        envelope (Queryable[float]?): Envelope of the tension node. The envelope determines the percent of  
                deformation. Value is clamped to [0, 1] range.  
                Default is 1.  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        inwardConstraint (Queryable[float]?): Constrains the movement of the vertex to not move inward from the input  
                deforming shape to preserve the contour. Value is in the [0,1] range.  
                Default is 0.0.  
                Properties: create, query, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        outwardConstraint (Queryable[float]?): Constrains the movement of the vertex to not move outward from the input  
                deforming shape to preserve the contour. Value is in the [0,1] range.  
                Properties: create, query, edit
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        pinBorderVertices (bool?): If enabled, vertices on mesh borders will be pinned to their current  
                position during smoothing. Default is true.  
                Properties: create, query, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        smoothingIterations (Queryable[int]?): Number of smoothing iterations performed by the tension node.  
                Default is 10.  
                Properties: create, query, edit
        smoothingStep (Queryable[float]?): Step amount used per smoothing iteration. Value is clamped to [0, 1] range.  
                A higher value may lead to instabilities but converges faster compared  
                to a lower value. Default is 0.5.  
                Properties: create, query, edit
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        str: Tension deformer node name

    Example:
    """

def testPa(arg0: str = ..., /) -> None: ...
def testPassContribution(*args: str, renderLayer: str = ..., renderPass: str = ...) -> None: ...
def texCutContext(*args: Any, edit: bool = ..., query: bool = ..., adjustSize: bool = ..., displayShellBorders: bool = ..., edgeSelectSensitive: Queryable[float] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., mode: Queryable[str] = ..., moveRatio: Queryable[float] = ..., name: str = ..., size: Queryable[float] = ..., steadyStroke: bool = ..., steadyStrokeDistance: Queryable[float] = ..., touchToSew: bool = ...) -> Union[float, bool, str]:
    """This command creates a context for cut uv tool.  This
    context only works in the UV editor.
    Args:
        adjustSize (bool?): If true, puts the tool into the mode where dragging the mouse will edit the brush size.  
                If false, puts the tool back into the previous mode.  
                Properties: edit
        displayShellBorders (bool?): Toggle the display of shell borders.  
                Properties: query, edit
        edgeSelectSensitive (Queryable[float]?): Set the value of the edge selection sensitivity.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        mode (Queryable[str]?): Specifies the type of effect the brush will perform, Cut or Sew.  
                Properties: query, edit
        moveRatio (Queryable[float]?): The cut open ratio relative to edge length.  
                Properties: query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        size (Queryable[float]?): Brush size value of the brush ring.  
                Properties: query, edit
        steadyStroke (bool?): Turn on steady stroke or not.  
                Properties: query, edit
        steadyStrokeDistance (Queryable[float]?): The distance for steady stroke.  
                Properties: query, edit
        touchToSew (bool?): Toggle the touch to sew mode.  
                Properties: query, edit

    Returns:
        float: Size of the brush rung, when querying brushSize
        float: The value of the edge selection sensitivity, when querying the edgeSelectSensitive flag.
        bool: Whether steady stroke is on or not, when querying the steadyStroke flag.
        float: The distance for a steady stroke, when querying the steadyStrokeDistance flag.
        float: The cut open ratio relative to edge length, when querying the moveRatio flag.
        str: The type of effect the brush will perform, when querying the mode flag.
        bool: Whether shell borders are displayed, when querying the displayShellBorders flag.
        bool: Current touch-to-sew mode, when querying the touchToSew flag.

    Example:
    """

def texLatticeDeformContext(*args: Any, edit: bool = ..., query: bool = ..., envelope: Queryable[float] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., latticeColumns: Queryable[int] = ..., latticeRows: Queryable[int] = ..., name: str = ..., showMoveManipulator: bool = ..., snapPixelMode: bool = ..., useBoundingRect: bool = ...) -> Union[int, float, bool, str]:
    """This command creates a context which may be used to
    deform UV maps with lattice manipulator.  This context
    only works in the texture UV editor.
    Args:
        envelope (Queryable[float]?): Specifies the influence of the lattice.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        latticeColumns (Queryable[int]?): Specifies the number column points the lattice contains.  The  
                maximum size lattice is restricted to 8 columns.  
                Properties: create, query, edit
        latticeRows (Queryable[int]?): Specifies the number of rows the lattice contains. The  
                maximum size lattice is restricted to 8 rows.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        showMoveManipulator (bool?): Specifies whether show move manipulator in UV Editor  
                Properties: create, query, edit
        snapPixelMode (bool?): Specifies the influenced uv points should be snapped to a pixel  
                center or corner.  
                Properties: create, query, edit
        useBoundingRect (bool?): When constructing the lattice use the bounding box of the  
                selected UVs for the extents of the lattice.  When this is  
                disabled the extents of the marquee selections are used as the  
                extents for the lattice.  
                Properties: create, query, edit

    Returns:
        int: Number of column divisions, when querying the latticeColumns flag.
        int: Number of row divisions, when querying the latticeRows flag.
        float: Value of the deform envelope, when querying the envelope flag.
        bool: Whether snapping to pixels is on, when querying the snapPixelMode flag.
        bool: Whether the bounding rectangle is to be used for deforemation, when querying the useBoundingRect flag.

    Example:
    """

def texManipContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """Command used to register the texSelectCtx tool.
    Command used to register the texManipCtx tool.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: : name of the context created
        str: : name of the context created

    Example:
    """

def texMoveContext(*args: Any, edit: bool = ..., query: bool = ..., editPivotMode: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., position: bool = ..., snap: bool = ..., snapComponentsRelative: bool = ..., snapPixelMode: Queryable[int] = ..., snapValue: Queryable[float] = ..., tweakMode: bool = ...) -> Union[str, bool, int, float]:
    """This command can be used to create, edit, or query a texture editor
    move manip context.
    Note that the above flags control the global behaviour of all texture
    editor move manip contexts.  Changing one context independently is not
    allowed.  Changing a context's behaviour using the above flags, will
    change all existing texture editor move manip contexts.
    Args:
        editPivotMode (bool?): Returns true when the manipulator is in edit pivot mode.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        position (bool?): Returns the current position of the manipulator  
                Properties: query
        snap (bool?): Sets or queries whether snapping is to be used.  
                Properties: query, edit
        snapComponentsRelative (bool?): Value can be : true or false.  
                If true, while snapping a group of UVs, the  
                relative spacing between them will be preserved.  
                If false, all the UVs will be snapped to the  
                target point  
                Properties: query, edit
        snapPixelMode (Queryable[int]?): Sets the snapping mode to be the pixel center or upper  
                left corner.  
                Properties: query, edit
        snapValue (Queryable[float]?): Sets or queries the size of the snapping increment.  
                Properties: query, edit
        tweakMode (bool?): When true, the manipulator is hidden and highlighted components can be selected  
                and moved in one step using a click-drag interaction.  
                Properties: query, edit

    Returns:
        str: (the name of the new context)

    Example:
    """

def texMoveUVShellContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., iterations: Queryable[int] = ..., mask: bool = ..., position: bool = ..., shellBorder: Queryable[float] = ...) -> Union[str, int, bool, float]:
    """This command can be used to create, edit, or query a texture editor
    move manip context.
    Note that the above flags control the global behaviour of all texture
    editor move manip contexts.  Changing one context independently is not
    allowed.  Changing a context's behaviour using the above flags, will
    change all existing texture editor move manip contexts.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        iterations (Queryable[int]?): Sets or queries the number of iterations to perform.  
                Properties: query, edit
        mask (bool?): Sets or queries masking on the shell.  
                Properties: query, edit
        position (bool?): Returns the current position of the manipulator  
                Properties: query
        shellBorder (Queryable[float]?): Sets or queries the size of the shell border.  
                Properties: query, edit

    Returns:
        str: (the name of the new context)

    Example:
    """

def texRotateContext(*args: Any, edit: bool = ..., query: bool = ..., editPivotMode: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., position: bool = ..., snap: bool = ..., snapRelative: bool = ..., snapValue: Queryable[float] = ..., tweakMode: bool = ...) -> Union[str, bool, float]:
    """This command can be used to create, edit, or query a
    rotate context for the UV Editor.
    Note that the above flag controls the global behaviour of all texture
    editor rotate contexts.  Changing one context independently is not
    allowed.  Changing a context's behaviour using the above flag, will
    change all existing texture editor rotate contexts.
    Args:
        editPivotMode (bool?): Returns true when the manipulator is in edit pivot mode.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        position (bool?): Returns the current position of the manipulator.  
                Properties: query
        snap (bool?): Sets or queries whether snapping is to be used.  
                Properties: query, edit
        snapRelative (bool?): Sets or queries whether snapping is relative.  
                Properties: query, edit
        snapValue (Queryable[float]?): Sets or queries the size of the snapping increment.  
                Properties: query, edit
        tweakMode (bool?): When true, the manipulator is hidden and highlighted components can be selected  
                and rotated in one step using a click-drag interaction.  
                Properties: query, edit

    Returns:
        str: : name of the context created

    Example:
    """

def texScaleContext(*args: Any, edit: bool = ..., query: bool = ..., editPivotMode: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., position: bool = ..., preventNegativeScale: bool = ..., snap: bool = ..., snapRelative: bool = ..., snapValue: Queryable[float] = ..., tweakMode: bool = ...) -> Union[str, bool, float]:
    """This command can be used to create, edit, or query a
    scale context for the UV Editor.
    Note that the above flag controls the global behaviour of all texture
    editor scale contexts.  Changing one context independently is not
    allowed.  Changing a context's behaviour using the above flag, will
    change all existing texture editor scale contexts.
    Args:
        editPivotMode (bool?): Returns true when manipulator is in edit pivot mode.  
                Properties: query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        position (bool?): Returns the current position of the manipulator.  
                Properties: query
        preventNegativeScale (bool?): Prevent negative scale for components.  
                Properties: query, edit
        snap (bool?): Sets or queries whether snapping is to be used.  
                Properties: query, edit
        snapRelative (bool?): Sets or queries whether snapping is relative.  
                Properties: query, edit
        snapValue (Queryable[float]?): Sets or queries the size of the snapping increment.  
                Properties: query, edit
        tweakMode (bool?): When true, the manipulator is hidden and highlighted components can be selected  
                and scaled in one step using a click-drag interaction.  
                Properties: query, edit

    Returns:
        str: : name of the context created

    Example:
    """

def texSculptCacheContext(*args: Any, edit: bool = ..., query: bool = ..., adjustSize: bool = ..., adjustStrength: bool = ..., direction: Queryable[int] = ..., falloffType: Queryable[int] = ..., floodPin: float = ..., grabTwist: bool = ..., inverted: bool = ..., mode: Queryable[str] = ..., sculptFalloffCurve: Queryable[str] = ..., showBrushRingDuringStroke: bool = ..., size: Queryable[float] = ..., strength: Queryable[float] = ...) -> Union[bool, int, str, float]:
    """This is a tool context command for uv cache sculpting tool.
    Args:
        adjustSize (bool?): If true, puts the tool into the mode where dragging the mouse will edit the brush size.  
                If false, puts the tool back into the previous sculpt mode.  
                Properties: edit
        adjustStrength (bool?): If true, puts the tool into the mode where dragging the mouse will edit the brush strength.  
                If false, puts the tool back into the previous sculpt mode.  
                Properties: edit
        direction (Queryable[int]?): Specifies how the brush determines where the uvs go.  
                Properties: query, edit
        falloffType (Queryable[int]?): Specifies how the brush determines which uvs to affect.  
                Properties: query, edit
        floodPin (float?): Sets the pin value for each UV to the given value  
                Properties: create, edit
        grabTwist (bool?): If true, the grab brush twists the UVs  
                Properties: create, query, edit
        inverted (bool?): If true, inverts the effect of the brush.  
                Properties: create, query, edit
        mode (Queryable[str]?): Specifies the type of sculpting effect the brush will perform.  
                Properties: query, edit
        sculptFalloffCurve (Queryable[str]?): Specifies the falloff curve that affects the brush.  
                Properties: query, edit
        showBrushRingDuringStroke (bool?): Specifies whether or not to show the brush ring during stroke.  
                Properties: query, edit
        size (Queryable[float]?): Specifies the world-space size of the current brush.  
                Properties: query, edit
        strength (Queryable[float]?): Specifies the world-space strength of the current brush.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def texSculptCacheSync(*args: Any, **kwargs: Any) -> None: ...
def texSelectContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> str:
    """Command used to register the texSelectCtx tool.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        str: : name of the context created

    Example:
    """

def texSelectShortestPathCtx(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ...) -> Union[bool, str]:
    """Creates a new context to select shortest edge path
    between two vertices or UVs in the texture editor window.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def texSmoothContext(*args: Any, **kwargs: Any) -> None: ...
def texSmudgeUVContext(*args: Any, edit: bool = ..., query: bool = ..., dragSlider: Queryable[str] = ..., effectType: Queryable[str] = ..., exists: bool = ..., functionType: Queryable[str] = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., pressure: Queryable[float] = ..., radius: Queryable[float] = ..., smudgeIsMiddle: bool = ...) -> Union[str, float, bool]:
    """This command creates a context for smudge UV tool.  This
    context only works in the texture UV editor.
    Args:
        dragSlider (Queryable[str]?): radius | none  
                Enables the drag slider mode. This is to support brush  
                resizing while holding the 'b' or 'B' button.  
                Properties: query, edit
        effectType (Queryable[str]?): fixed | smudge  
                Specifies the effect of the tool. In fixed mode, the UVs  
                move as if they are attached by a rubber band. In smudge mode the  
                UVs are moved as the cursor is dragged over the UVs.  
                Properties: query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        functionType (Queryable[str]?): exponential | linear | constant.  
                Specifies how UVs fall off from the center of influence.  
                Properties: query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        pressure (Queryable[float]?): Pressure value when effect type is set to smudge.  
                Properties: query, edit
        radius (Queryable[float]?): Radius of the smudge tool. All UVs within this radius are  
                affected by the tool  
                Properties: query, edit
        smudgeIsMiddle (bool?): By default, the left mouse button initiates the smudge.  
                However, this conflicts with selection. When smudgeIsMiddle is  
                on, smudge mode is activated by the middle mouse button  
                instead of the left mouse button.  
                Properties: query, edit

    Returns:
        str: Name of the effect type created.

    Example:
    """

def texTweakUVContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., position: bool = ..., tolerance: Queryable[float] = ...) -> Union[str, bool, float]:
    """This command can be used to create, edit, or query a texture editor
    move manip context.
    Note that the above flags control the global behaviour of all texture
    editor move manip contexts.  Changing one context independently is not
    allowed.  Changing a context's behaviour using the above flags, will
    change all existing texture editor move manip contexts.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        position (bool?): Returns the current position of the manipulator  
                Properties: query
        tolerance (Queryable[float]?): Controls the initial selection snapping tolerance.  
                Properties: create, query, edit

    Returns:
        str: (the name of the new context)

    Example:
    """

def texWinToolCtx(*args: Any, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., boxzoom: bool = ..., dolly: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., toolName: Queryable[str] = ..., track: bool = ...) -> Union[str, bool]:
    """This class creates a context for the View Tools "track", "dolly",
    and "box zoom" in the texture window.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        boxzoom (bool?): Perform Box Zoom  
                Properties: create, query, edit
        dolly (bool?): Dollies the view  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query
        track (bool?): Tracks the view  
                Properties: create, query, edit

    Returns:
        str: Context name

    Example:
    """

def text(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., align: Queryable[str] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., dropRectCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., hyperlink: bool = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., recomputeSize: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., wordWrap: bool = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a simple text label control.
    Args:
        align (Queryable[str]?): The label alignment.  Alignment values are "left",  
                "right", and "center".  Note that the alignment will  
                only be noticable if the control is wider than the label length.  
                By default, the label is aligned "center".  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        dropRectCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is hovering above the drop site.  It returns the shape of the  
                rectangle to be drawn to highlight the entry, if the control can receive  
                the dropped data. The MEL version of the callback is of the form:  
              
                global proc int[] callbackName(string $dropControl, int $x, int $y)  
              
                The return value is an array of size 4, with the parameters, in order, being  
                the left and top coordinates of the rectangle to be drawn, followed by the  
                width and height.  
                This functionality is currently only implemented in MEL.  
                Properties: edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        hyperlink (bool?): Sets the label text to be a hyperlink if the argument is true.  The label text  
                must be a proper HTML link.  
                In MEL, double quotes in the link will most likely have to be protected from  
                the MEL interpreter by preceding them with a backslash.  Clicking on  
                the link will open it in an external Web browser.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text.  The default label is the name of  
                the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        recomputeSize (bool?): If true then the control will recompute it's size to  
                just fit the size of the label.  If false then the control size  
                will remain fixed as you change the size of the label.  The  
                default value of this flag is true.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        wordWrap (bool?): If true then label text is wrapped where necessary at  
                word-breaks. If false, it is not wrapped at all. The  
                default value of this flag is false.  
                Properties: create, query

    Returns:
        str: Full path name to the control.

    Example:
    """

def textCurves(*args: str, edit: bool = ..., query: bool = ..., font: str = ..., name: str = ..., object: bool = ..., text: str = ...) -> List[str]:
    """The textCurves command creates NURBS curves from a text string
    using the specified font.A single letter can be made up of more than one NURBS curve.
    The number of curves per letter varies with the font.
    Args:
        font (str?): The font to use.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        text (str?): The string to create the curves for.  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def textField(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alwaysInvokeEnterCommandOnReturn: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., disableButtons: bool = ..., disableClearButton: bool = ..., disableHistoryButton: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., drawInactiveFrame: bool = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enterCommand: Callable[..., Any] = ..., exists: bool = ..., fileName: Queryable[str] = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., insertText: str = ..., insertionPosition: Queryable[int] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., placeholderText: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., receiveFocusCommand: Callable[..., Any] = ..., searchField: bool = ..., statusBarMessage: str = ..., text: Queryable[str] = ..., textChangedCommand: Callable[..., Any] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Callable[..., Any]]:
    """Create a text field control.
    Args:
        alwaysInvokeEnterCommandOnReturn (bool?): Sets whether to always invoke the enter command when the return key is  
                pressed by the user.  
                By default, this option is false.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the text changes.  This command is  
                not invoked when the value changes via the -tx/text flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        disableButtons (bool?): Sets the visibility state of search field buttons to true/false depending on the passed value.  
                In Query mode returns whether both buttons are visible or not.  
                Properties: create, query, edit
        disableClearButton (bool?): Sets the visibility state of search field clear button to true/false depending on the passed value.  
                In Query mode returns whether clear button of search field is visible or not.  
                Properties: create, query, edit
        disableHistoryButton (bool?): Sets the visibility state of search field history button to true/false depending on the passed value.  
                In Query mode returns whether history button of search field is visible or not.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        drawInactiveFrame (bool?): Sets whether the text field draws itself with a frame when it's inactive.  
                By default, this option is false.  
                Properties: create, query, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is  
                set to true and the field value may be changed by typing into it.  
                If false then the field is 'read only' and can not be typed into.  
                The text in the field can always be changed with the -tx/text flag  
                regardless of the state of the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enterCommand (Callable[..., Any]?): Command executed when the keypad 'Enter' key is pressed.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fileName (Queryable[str]?): Text in the field as a filename. This does conversions between  
                internal and external (UI) file representation.  
                Properties: create, query, edit
        font (Queryable[str]?): The font for the text.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        insertText (str?): Insert text into the field at the current insertion  
                position (specified by the -ip/insertionPosition flag).  
                Properties: create, edit
        insertionPosition (Queryable[int]?): The insertion position for inserted text.  This is a  
                1 based value where position 1 specifies the beginning of the  
                field.  Position 0 may be used to specify the end of the field.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        placeholderText (Queryable[str]?): Setting this property makes the line edit display a grayed-out placeholder text as long as the text field is empty and the widget doesn't have focus.  
                By default, this property contains an empty string.  
                Properties: create, query, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        receiveFocusCommand (Callable[..., Any]?): Command executed when the field receives focus.  
                Properties: create, edit
        searchField (bool?): Creates a search field instead of a text field.  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        text (Queryable[str]?): The field text.  
                Properties: create, query, edit
        textChangedCommand (Callable[..., Any]?): Command executed immediately when the field text changes.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def textFieldButtonGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., buttonCommand: Callable[..., Any] = ..., buttonLabel: Queryable[str] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableButton: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fileName: Queryable[str] = ..., forceChangeCommand: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., insertText: str = ..., insertionPosition: Queryable[int] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., placeholderText: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., text: Queryable[str] = ..., textChangedCommand: Callable[..., Any] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command adds a button to the textFieldGrp command.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        buttonCommand (Callable[..., Any]?): Command attached to the button.  
                Properties: create, edit
        buttonLabel (Queryable[str]?): Label text of the button.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the field text changes and user presses Enter or Return.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is  
                set to true and the field value may be changed by typing into it.  
                If false then the field is 'read only' and can not be typed into.  
                The text in the field can always be changed with  
                the -tx/text flag regardless of the state of  
                the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableButton (bool?): Enable state of the button.  By default, this flag is  
                set to true and the button is enabled.  Specify true, and the  
                button will appear dimmed or greyed-out indicating it is  
                disabled.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fileName (Queryable[str]?): Text in the field as a filename. This does conversions between  
                internal and external (UI) file representation.  
                Properties: create, query, edit
        forceChangeCommand (bool?): If used together with -text or -inserText flag, change command  
                will be executed after text modification.  
                Properties: create, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        insertText (str?): Insert text into the field at the current insertion  
                position (specified by the -ip/insertionPosition flag).  
                Properties: create, edit
        insertionPosition (Queryable[int]?): The insertion position for inserted text.  This is a  
                1 based value where position 1 specifies the beginning of the  
                field.  Position 0 may be used to specify the end of the field.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the group.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        placeholderText (Queryable[str]?): Setting this property makes the line edit display a grayed-out placeholder text as long as the text field is empty and the widget doesn't have focus.  
                By default, this property contains an empty string.  
                Properties: create, query, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        text (Queryable[str]?): Text in the field.  
                Properties: create, query, edit
        textChangedCommand (Callable[..., Any]?): Command executed immediately when the field text changes.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def textFieldGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fileName: Queryable[str] = ..., forceChangeCommand: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., insertText: str = ..., insertionPosition: Queryable[int] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., placeholderText: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., text: Queryable[str] = ..., textChangedCommand: Callable[..., Any] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text and
    editable text field.  The label text is optional.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the field text changes and user presses Enter or Return.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is  
                set to true and the field value may be changed by typing into it.  
                If false then the field is 'read only' and can not be typed into.  
                The text in the field can always be changed with  
                the -tx/text flag regardless of the state of  
                the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fileName (Queryable[str]?): Text in the field as a filename. This does conversions between  
                internal and external (UI) file representation.  
                Properties: create, query, edit
        forceChangeCommand (bool?): If used together with -text or -inserText flag, change command  
                will be executed after text modification.  
                Properties: create, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        insertText (str?): Insert text into the field at the current insertion  
                position (specified by the -ip/insertionPosition flag).  
                Properties: create, edit
        insertionPosition (Queryable[int]?): The insertion position for inserted text.  This is a  
                1 based value where position 1 specifies the beginning of the  
                field.  Position 0 may be used to specify the end of the field.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): Label text for the group.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        placeholderText (Queryable[str]?): Setting this property makes the line edit display a grayed-out placeholder text as long as the text field is empty and the widget doesn't have focus.  
                By default, this property contains an empty string.  
                Properties: create, query, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        text (Queryable[str]?): Text in the field.  
                Properties: create, query, edit
        textChangedCommand (Callable[..., Any]?): Command executed immediately when the field text changes.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def textManip(*args: Any, query: bool = ..., visible: bool = ...) -> bool:
    """Shows/hides the text manip.
    Args:
        visible (bool?): Shows/hides the text manip.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def textScrollList(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allItems: bool = ..., allItemsUniqueTags: bool = ..., allowAutomaticSelection: bool = ..., allowMultiSelection: bool = ..., annotation: Queryable[str] = ..., append: Multiuse[str] = ..., appendPosition: Multiuse[Tuple[int, str]] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., deleteKeyCommand: Callable[..., Any] = ..., deselectAll: bool = ..., deselectIndexedItem: Multiuse[int] = ..., deselectItem: Multiuse[str] = ..., docTag: Queryable[str] = ..., doubleClickCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., emptyLabel: Queryable[str] = ..., enable: bool = ..., enableAll: bool = ..., enableBackground: bool = ..., enableIndexedItem: Multiuse[Tuple[int, bool]] = ..., enableItem: Multiuse[Tuple[str, bool]] = ..., enableKeyboardFocus: bool = ..., enableUniqueTagItem: Multiuse[Tuple[str, bool]] = ..., exists: bool = ..., font: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., lineFont: Multiuse[Tuple[int, str]] = ..., manage: bool = ..., noBackground: bool = ..., numberOfItems: bool = ..., numberOfPopupMenus: bool = ..., numberOfRows: Queryable[int] = ..., numberOfSelectedItems: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., removeAll: bool = ..., removeIndexedItem: Multiuse[int] = ..., removeItem: Multiuse[str] = ..., selectCommand: Callable[..., Any] = ..., selectIndexedItem: Queryable[Multiuse[int]] = ..., selectItem: Queryable[Multiuse[str]] = ..., selectUniqueTagItem: Queryable[Multiuse[str]] = ..., showIndexedItem: int = ..., statusBarMessage: str = ..., uniqueTag: Multiuse[str] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Multiuse[int], Multiuse[str], Callable[..., Any]]:
    """This command creates/edits/queries a text scrolling list. The
    list can be in single select mode where only one item at time
    is selected, or in multi-select mode where many items may be
    selected.Note: The -dgc/dragCallback flag works only on Windows.
    Args:
        allItems (bool?): All the items.  
                Properties: query
        allItemsUniqueTags (bool?): Return all the items as unique tags.  
                Properties: query
        allowAutomaticSelection (bool?): Specify automatic selection mode.  When automaticSelection  
                is on each item that the mouse is over (during dragging once an  
                item has been selected) will be selected.  Thus,  
                if -sc/selectCommand someCommand is set, someCommand  
                will be called for each selected item.  
                If -aas/allowAutomaticSelection is off, then only the item  
                selected when the mouse button is up will be the selected item,  
                so -sc/selectCommand someCommand is only called once if  
                it is set.  
                Properties: create, query, edit
        allowMultiSelection (bool?): Specify multi or single selection mode.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        append (Multiuse[str]?): Add an item to the end of the list.  
                Properties: create, edit, multiuse
        appendPosition (Multiuse[Tuple[int, str]]?): Append an item at the specified position.  
                The position is a 1. based index.  
                Properties: create, edit, multiuse
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        deleteKeyCommand (Callable[..., Any]?): Specify the command to be executed when the delete or  
                backspace key is pressed.  
                Properties: create, edit
        deselectAll (bool?): Deselect all items.  
                Properties: create, edit
        deselectIndexedItem (Multiuse[int]?): Deselect the indexed item.  Indices are 1. based.  
                Properties: create, edit, multiuse
        deselectItem (Multiuse[str]?): Deselect the item that contains the specified text.  
                Properties: create, edit, multiuse
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Callable[..., Any]?): Specify the command to be executed when an item is double  
                clicked.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        emptyLabel (Queryable[str]?): String that is displayed when the list is empty.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableAll (bool?): Enable all items.  
                Properties: create, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableIndexedItem (Multiuse[Tuple[int, bool]]?): Enable/disable an item using on the item index. Indices are 1. based.  
                Properties: create, edit, multiuse
        enableItem (Multiuse[Tuple[str, bool]]?): Enable/disable an item using the item text.  
                Properties: create, edit, multiuse
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enableUniqueTagItem (Multiuse[Tuple[str, bool]]?): Enable/disable an item using on the unique item tag.  
                Properties: create, edit, multiuse
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        font (Queryable[str]?): The font for the list items.  Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        lineFont (Multiuse[Tuple[int, str]]?): Specify the font for a specific line of the list.  
                The indices are 1. based. Valid font values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, edit, multiuse
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfItems (bool?): Number of items.  
                Properties: query
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        numberOfRows (Queryable[int]?): Number of visible rows.  
                Properties: create, query, edit
        numberOfSelectedItems (bool?): Number of selected items.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        removeAll (bool?): Remove all items.  
                Properties: create, edit
        removeIndexedItem (Multiuse[int]?): Remove the indexed item. Indices are 1. based.  
                Properties: create, edit, multiuse
        removeItem (Multiuse[str]?): Remove the item with the specified text.  
                Properties: create, edit, multiuse
        selectCommand (Callable[..., Any]?): Specify the command to be executed when an item is selected.  
                Properties: create, edit
        selectIndexedItem (Queryable[Multiuse[int]]?): Select the indexed item. Indices are 1. based.  
                Properties: create, query, edit, multiuse
        selectItem (Queryable[Multiuse[str]]?): Select the item that contains the specified text.  
                Properties: create, query, edit, multiuse
        selectUniqueTagItem (Queryable[Multiuse[str]]?): Allow item selections based on the unique tag.  
                In query mode, it will return the unique tag of the selected items.  
                Properties: create, query, edit, multiuse
        showIndexedItem (int?): Show the indexed item.  Scroll the list as necessary so that  
                the indexed item is visible.  Indices are 1. based.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        uniqueTag (Multiuse[str]?): This flag can only be used in conjunction with the append or the appendPosition flag.  
                The string specifies a unique tag for the appended item; the tag can then be used to query an item.  
                This tag provides an alternate way to uniquely identify a list item using a string instead of by index.  
                Tags are case insensitive.  
                Properties: create, edit, multiuse
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def textureDeformer(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., deformerTools: bool = ..., direction: str = ..., envelope: float = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., name: str = ..., offset: float = ..., parallel: bool = ..., pointSpace: str = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., split: bool = ..., strength: float = ..., useComponentTags: bool = ..., vectorOffset: Tuple[float, float, float] = ..., vectorSpace: str = ..., vectorStrength: Tuple[float, float, float] = ...) -> Union[str, bool, Multiuse[str]]:
    """This command creates a texture deformer for the object.
    The selected objects are the input geometry objects.
    The deformer node name will be returned.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        direction (str?): Set the deformation direction of texture deformer  
                It can only handle three types: "Normal", "Handle" and "Vector".  
                "Normal"  each vertices use its own normal vector.  
                "Handle"  all vertices use Up vector of the handle.  
                "Vector"  each vertices use RGB color vector  
                strings.  
                Properties: create
        envelope (float?): Set the envelope of texture deformer.  
                Envelope determines the percent  
                of deformation. The final result is  
                (color * normal * strength + offset) * envelope  
                Properties: create
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        offset (float?): Set the offset of texture deformer.  
                Offset plus a translation on the final  
                deformed vertices.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        pointSpace (str?): Set the point space of texture deformer.  
                It can only handle three strings: "World", "Local" and "UV".  
                "World"   map world space to color space.  
                "Local"	  map local space to color space.  
                "UV"	  map UV space to color space.  
                strings.  
                Properties: create
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        strength (float?): Set the strength of texture deformer.  
                Strength determines how strong the  
                object is deformed.  
                Properties: create
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        vectorOffset (Tuple[float, float, float]?): Set the vector offset of texture deformer.  
                Vector offset indicates the offset of the  
                deformation on the vector mode.  
                Properties: create
        vectorSpace (str?): Set the vector space of texture deformer.  
                It can only handle three strings: "Object", "World" and "Tangent".  
                "Object"   	use color vector in object space  
                "World"	 	use color vector in world space  
                "Tangent"	use color vector in tangent space  
                strings.  
                Properties: create
        vectorStrength (Tuple[float, float, float]?): Set the vector strength of texture deformer.  
                Vector strength determines how strong the  
                object is deformed on the vector mode.  
                Properties: create

    Returns:
        str: Texture deformer node name

    Example:
    """

def textureLassoContext(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., history: bool = ..., drawClosed: bool = ..., exists: bool = ..., image1: str = ..., image2: str = ..., image3: str = ..., name: str = ...) -> None: ...
def texturePlacementContext(*args: Any, edit: bool = ..., query: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., labelMapping: bool = ..., name: str = ...) -> Union[str, bool]:
    """Create a command for creating new texture placement contexts. By
    default label mapping is on when the context is created.
    Args:
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        labelMapping (bool?): Set the context to label mapping.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: The name of the context created

    Example:
    """

def textureWindow(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., activeSelectionOnTop: bool = ..., axesColor: Queryable[Tuple[float, float, float]] = ..., backFacingColor: Queryable[Tuple[float, float, float, float]] = ..., capture: str = ..., captureSequenceNumber: int = ..., changeCommand: Queryable[Tuple[str, str, str, str]] = ..., checkerColor1: Queryable[Tuple[float, float, float]] = ..., checkerColor2: Queryable[Tuple[float, float, float]] = ..., checkerColorMode: Queryable[int] = ..., checkerDensity: Queryable[int] = ..., checkerDrawTileLabels: bool = ..., checkerGradient1: Queryable[Tuple[float, float, float]] = ..., checkerGradient2: Queryable[Tuple[float, float, float]] = ..., checkerGradientOverlay: bool = ..., checkerTileLabelColor: Queryable[Tuple[float, float, float]] = ..., clearImage: bool = ..., cmEnabled: bool = ..., control: bool = ..., defineTemplate: str = ..., displayAxes: bool = ..., displayCheckered: bool = ..., displayDistortion: bool = ..., displayDivisionLines: bool = ..., displayGridLines: bool = ..., displayImage: Queryable[int] = ..., displayIsolateSelectHUD: bool = ..., displayLabels: bool = ..., displayOverlappingUVCountHUD: bool = ..., displayPreselection: bool = ..., displayReversedUVCountHUD: bool = ..., displaySolidMap: bool = ..., displayStyle: Queryable[str] = ..., displayTextureBorder: bool = ..., displayUVPositionHUD: bool = ..., displayUVShellCountHUD: bool = ..., displayUVStatisticsHUD: bool = ..., displayUsedPercentageHUD: bool = ..., distortionAlpha: Queryable[float] = ..., distortionPerObject: bool = ..., divisions: Queryable[int] = ..., docTag: Queryable[str] = ..., doubleBuffer: bool = ..., drawAxis: bool = ..., drawSubregions: bool = ..., exists: bool = ..., exposure: Queryable[float] = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., forceRebake: bool = ..., frameAll: bool = ..., frameSelected: bool = ..., frontFacingColor: Queryable[Tuple[float, float, float, float]] = ..., gamma: Queryable[float] = ..., gridLinesColor: Queryable[Tuple[float, float, float]] = ..., gridNumbersColor: Queryable[Tuple[float, float, float]] = ..., highlightConnection: Queryable[str] = ..., imageBaseColor: Queryable[Tuple[float, float, float]] = ..., imageDim: bool = ..., imageDisplay: bool = ..., imageNames: bool = ..., imageNumber: Queryable[int] = ..., imagePixelSnap: bool = ..., imageRatio: bool = ..., imageRatioValue: Queryable[float] = ..., imageSize: bool = ..., imageTileRange: Queryable[Tuple[float, float, float, float]] = ..., imageUnfiltered: bool = ..., internalFaces: bool = ..., labelPosition: Queryable[str] = ..., loadImage: str = ..., lockMainConnection: bool = ..., mainListConnection: Queryable[str] = ..., maxResolution: Queryable[int] = ..., multiColorAlpha: Queryable[float] = ..., nbImages: bool = ..., nextView: bool = ..., numUvSets: bool = ..., numberOfImages: Queryable[int] = ..., numberOfTextures: Queryable[int] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., previousView: bool = ..., realSize: bool = ..., refresh: bool = ..., relatedFaces: bool = ..., removeAllImages: bool = ..., removeImage: bool = ..., rendererString: Queryable[str] = ..., reset: bool = ..., saveImage: bool = ..., scaleBlue: Queryable[float] = ..., scaleGreen: Queryable[float] = ..., scaleRed: Queryable[float] = ..., selectInternalFaces: bool = ..., selectRelatedFaces: bool = ..., selectionConnection: Queryable[str] = ..., setUvSet: int = ..., singleBuffer: bool = ..., size: Queryable[float] = ..., solidMap3dView: bool = ..., solidMapColorSeed: Queryable[int] = ..., solidMapPerShell: bool = ..., spacing: float = ..., stateString: bool = ..., style: Queryable[int] = ..., subdivisionLinesColor: Queryable[Tuple[float, float, float]] = ..., textureBorder3dView: bool = ..., textureBorderColor: Queryable[Tuple[float, float, float]] = ..., textureBorderWidth: Queryable[int] = ..., textureNames: bool = ..., textureNumber: Queryable[int] = ..., tileLabels: bool = ..., tileLinesColor: Queryable[Tuple[float, float, float]] = ..., toggle: bool = ..., toggleExposure: bool = ..., toggleGamma: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useFaceGroup: bool = ..., useTemplate: str = ..., usedPercentageHUDRange: Queryable[Tuple[float, float, float, float]] = ..., uvSets: bool = ..., viewPortImage: bool = ..., viewTransformName: Queryable[str] = ..., wireframeComponentColor: Queryable[Tuple[float, float, float, float]] = ..., wireframeObjectColor: Queryable[Tuple[float, float, float, float]] = ..., writeImage: str = ...) -> Union[str, bool, Tuple[float, float, float], Tuple[float, float, float, float], Tuple[str, str, str, str], int, float]:
    """This command is used to create a UV Editor and to query or edit
    the texture editor settings.The UV Editor displays texture mapped polygon objects in 2D
    texture space. Only active objects are visible in this window.The UV Editor has the ability to display two types of images. The
    Texture Image is a visualisation of the current texture and associated
    placement parameters. The Editor Image is a user specified image loaded
    from disk.A UV Editor can be invoked by selecting the "Window -> UV
    Texture Editor..." menu item from the main maya menu listing that
    appears at the top of the maya window. It can also be invoked by
    selecting the "Panel -> UV Editor" item under the "Panels"
    menu item that appears at the top right hand corner of the view.As a UV Editor typically exists at start-up time, and as only
    one of these can exist at any given time, this command is normally
    used to query and edit the editor settings.
    Args:
        activeSelectionOnTop (bool?): Display the solid map / distortion of active selection on top of others.  
                Properties: create, query, edit
        axesColor (Queryable[Tuple[float, float, float]]?): The color of axes, default is 0.0 0.0 1.0  
                Properties: create, query, edit
        backFacingColor (Queryable[Tuple[float, float, float, float]]?): Sets or queries the RGBA back facing color.  
                Properties: create, query, edit
        capture (str?): Perform an one-time capture of the viewport to the named image file on disk.  
                Properties: edit
        captureSequenceNumber (int?): When a number greater or equal to 0 is specified each  
                subsequent refresh will save an image file to disk if the  
                capture flag has been enabled.  
              
                The naming of the file is:  
              
                {root name}.#.{extension}  
              
                if the name {root name}.{extension} is used for the capture flag argument.  
                The value of # starts at the number specified to for this argument and  
                increments for each subsequent refresh.  
              
                Sequence capture can be disabled by specifying a number less  
                than 0 or an empty file name for the capture flag.  
                Properties: edit
        changeCommand (Queryable[Tuple[str, str, str, str]]?): Parameters:  
              
                First string: command  
                Second string: editorName  
                Third string: editorCmd  
                Fourth string: updateFunc  
              
              
                Call the command when something changes in the editor The command  
                should have this prototype :  
              
                command(string $editor, string $editorCmd, string $updateFunc, int $reason)  
              
                The possible reasons could be :  
              
                0. no particular reason  
                1. scale color  
                2. buffer (single/double)  
                3. axis   
                4. image displayed  
                5. image saved in memory  
                Properties: create, query, edit
        checkerColor1 (Queryable[Tuple[float, float, float]]?): Sets the first color of the checker and identification pattern, when color mode is 2. colors.  
                Properties: create, query, edit
        checkerColor2 (Queryable[Tuple[float, float, float]]?): Sets the second color of the checker and identification pattern, when color mode is 2. colors.  
                Properties: create, query, edit
        checkerColorMode (Queryable[int]?): Sets the color mode of the checker and identification pattern.  
                0. multi-colors;  
                1. 2. colors;  
                Properties: create, query, edit
        checkerDensity (Queryable[int]?): Sets the density of the checker and identification pattern.  
                Properties: create, query, edit
        checkerDrawTileLabels (bool?): Toggles the checker tile label display.  
                Properties: create, query, edit
        checkerGradient1 (Queryable[Tuple[float, float, float]]?): Sets the first gradient of the checker and identification pattern, when color mode is 2. colors.  
                Properties: create, query, edit
        checkerGradient2 (Queryable[Tuple[float, float, float]]?): Sets the second gradient of the checker and identification pattern, when color mode is 2. colors.  
                Properties: create, query, edit
        checkerGradientOverlay (bool?): Toggle application of the gradient.  
                Properties: create, query, edit
        checkerTileLabelColor (Queryable[Tuple[float, float, float]]?): Sets the checker tile label color.  
                Properties: create, query, edit
        clearImage (bool?): Clears the current Editor Image.  
                Properties: edit
        cmEnabled (bool?): Turn on or off applying color management in the editor.  If set, the color  
                management configuration set in the current editor is used.  
                Properties: query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayAxes (bool?): Specify true to display the grid axes.  
                Properties: query, edit
        displayCheckered (bool?): Display a unique checker and identification pattern for each UV tiles.  
                Properties: create, query, edit
        displayDistortion (bool?): Display the layout in shaded colors to indentify areas with stretched/squashed UVs  
                Properties: create, query, edit
        displayDivisionLines (bool?): Specify true to display the subdivision lines between  
                grid lines.  
                Properties: query, edit
        displayGridLines (bool?): Specify true to display the grid lines.  
                Properties: query, edit
        displayImage (Queryable[int]?): Set a particular image in the Editor Image Stack as the current Editor Image.  
                Images are added to the Editor Image Stack using the "si/saveImage" flag.  
                Properties: query, edit
        displayIsolateSelectHUD (bool?): Show heads-up display of isolate selection  
                Properties: create, query, edit
        displayLabels (bool?): Specify true to display the grid line numeric labels.  
                Properties: query, edit
        displayOverlappingUVCountHUD (bool?): Show heads-up display of overlapping UV count, as a part UV Statistics HUD  
                Properties: create, query, edit
        displayPreselection (bool?): Toggles the pre-selection display.  
                Properties: create, query, edit
        displayReversedUVCountHUD (bool?): Show heads-up display of UV Shells, as a part UV Statistics HUD  
                Properties: create, query, edit
        displaySolidMap (bool?): Display a solid overlay for the active texture map.  
                Properties: create, query, edit
        displayStyle (Queryable[str]?): Set the mode to display the image. Valid values are:  
              
                "color" to display the basic RGB image  
                "mask" to display the mask channel  
                "lum" to display the luminance of the image  
                Properties: create, query, edit
        displayTextureBorder (bool?): Toggles the texture borders display.  
                Properties: create, query, edit
        displayUVPositionHUD (bool?): Show heads-up display of UV positions  
                Properties: create, query, edit
        displayUVShellCountHUD (bool?): Show heads-up display of UV Shell count, as a part UV Statistics HUD  
                Properties: create, query, edit
        displayUVStatisticsHUD (bool?): Show heads-up display of UV Statistics  
                Properties: create, query, edit
        displayUsedPercentageHUD (bool?): Show heads-up display of used UV space percentage, as a part UV Statistics HUD  
                Properties: create, query, edit
        distortionAlpha (Queryable[float]?): Set or query the distortion display alpha.  
                Properties: create, query, edit
        distortionPerObject (bool?): Toggles the per-object distortion display.  
                Properties: create, query, edit
        divisions (Queryable[int]?): Sets the number of subdivisions between main grid lines.  
                Properties: create, query, edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        doubleBuffer (bool?): Set the display in double buffer mode  
                Properties: create, query, edit
        drawAxis (bool?): Set or query whether the axis will be drawn.  
                Properties: create, query, edit
        drawSubregions (bool?): Toggles the subregion display.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        exposure (Queryable[float]?): The exposure value used by the color management of the current editor.  
                Properties: query, edit
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        forceRebake (bool?): Forces the current cache texture to refresh.  
                Properties: create, edit
        frameAll (bool?): This will zoom on the whole scene.  
                Properties: create
        frameSelected (bool?): This will zoom on the currently selected objects.  
                Properties: create
        frontFacingColor (Queryable[Tuple[float, float, float, float]]?): Sets or queries the RGBA front facing color.  
                Properties: create, query, edit
        gamma (Queryable[float]?): The gamma value used by the color management of the current editor.  
                Properties: query, edit
        gridLinesColor (Queryable[Tuple[float, float, float]]?): The color of grid lines, default is 0.325 0.325 0.325  
                Properties: create, query, edit
        gridNumbersColor (Queryable[Tuple[float, float, float]]?): The color of grid numbers, default is 0.2 0.2 0.2  
                Properties: create, query, edit
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        imageBaseColor (Queryable[Tuple[float, float, float]]?): The base color of the image, default is white 1.0 1.0 1.0  
                Properties: create, query, edit
        imageDim (bool?): Toggles the image dimming.  
                Properties: create, query, edit
        imageDisplay (bool?): Toggles the Texture Image display.  
                Properties: query, edit
        imageNames (bool?): List image names for all Texture Images available for display,  
                if any.  
                Properties: query
        imageNumber (Queryable[int]?): Sets the number of Texture Images to display.  
                This depends on the number of textures corresponding to  
                the current selection. If there are N textures, then the  
                possible Texture Image numbers are 0 to N-1.  
                Properties: query, edit
        imagePixelSnap (bool?): Sets a mode so that UV transformations in  
                the UV Texture Editor will cause UV values to snap  
                to image pixel corners. Which pixels are used depends on whether  
                a Texture Image or an Editor Image is being displayed. If both  
                are displayed, the Texture Image pixels will be used.  
                Properties: query, edit
        imageRatio (bool?): Sets the window to draw using the Texture Image's height versus  
                width ratio. If the width is greater than the height,  
                then the width is set to be 1 "unit" in the window,  
                and the height is adjusted by width divided by height. This  
                only affects the display of a Texture Image, not an Editor Image.  
                Properties: query, edit
        imageRatioValue (Queryable[float]?): Query current image ratio value in UV Editor.  
                Properties: query
        imageSize (bool?): Returns the size of the Texture Image currently being displayed.  
                The values returned are width followed by height.  
                Image size can only be queried.  
                Properties: query
        imageTileRange (Queryable[Tuple[float, float, float, float]]?): Sets the UV range of the display. The 4 values specify the  
                minimum U, V and maximum U, V in that order. When viewing a texture  
                image, these values affect how many times the image is tiled based on  
                appropriate parameters (e.g. Repeat UV, Mirror, Wrap, etc...)  
                When viewing an Editor Image these values determine the visible size  
                of the image. For example, setting the range to ( 0, 0, 2, 1 ) will  
                cause the Editor Image to be loaded into a 2x1 rectangle, distorting  
                it as necessary to fill the available space.  
                Properties: query, edit
        imageUnfiltered (bool?): Sets the Texture Image to draw unfiltered. The image will  
                appear "pixelated" when the display resolution is higher than the  
                resolution of the image.  
                Properties: query, edit
        internalFaces (bool?): Display contained faces by the selected components.  
                Properties: create, query, edit
        labelPosition (Queryable[str]?): The position of the grid's numeric labels. Valid values are  
                "axis" and "edge".  
                Properties: query, edit
        loadImage (str?): load an image from disk and set it as the current Editor Image  
                Properties: edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        maxResolution (Queryable[int]?): This flag will set the current cached texture's maximum resolution.  
                Properties: create, query, edit
        multiColorAlpha (Queryable[float]?): Sets the multi-color alpha of shaded UVs.  
                Properties: create, query, edit
        nbImages (bool?): returns the number of images  
                Properties: query
        nextView (bool?): Switches to the next view.  
                Properties: edit
        numUvSets (bool?): This flag will return the number of UV sets for selected  
                objects in the texture window.  
                Properties: create, query, edit
        numberOfImages (Queryable[int]?): The number of Texture Images currently available.  
                for display.  
                Properties: query
        numberOfTextures (Queryable[int]?): The number of textures currently available.  
                for display.  
                Properties: query
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        previousView (bool?): Switches to the previous view.  
                Properties: edit
        realSize (bool?): This will display the image with the size of the  
                internal buffer. Note: This argument no long has  
                any affect on image display.  
                Properties: create
        refresh (bool?): requests a refresh of the current Editor Image.  
                Properties: edit
        relatedFaces (bool?): Display connected faces by the selected components.  
                Properties: create, query, edit
        removeAllImages (bool?): remove all the Editor Images from the Editor Image Stack  
                Properties: edit
        removeImage (bool?): remove the current Editor Image from the Editor Image Stack  
                Properties: edit
        rendererString (Queryable[str]?): Set or query the string describing the current renderer.  
                Properties: create, query, edit
        reset (bool?): Resets the ground plane to its default values.  
                Properties: create
        saveImage (bool?): save the current Editor Image to memory. Saved Editor Images are  
                stored in an Editor Image Stack. The most recently saved image is stored in  
                position 0, the second most recently saved image in position 1,  
                and so on... To set the current Editor Image to a previously saved  
                image use the "di/displayImage" flag.  
                Properties: edit
        scaleBlue (Queryable[float]?): Define the scaling factor for the blue component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        scaleGreen (Queryable[float]?): Define the scaling factor for the green component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        scaleRed (Queryable[float]?): Define the scaling factor for the red component  
                in the View. The default value is 1 and can be  
                between -1000 to +1000  
                Properties: create, query, edit
        selectInternalFaces (bool?): Add to selectionList the faces which are contained by  
                (internal to) selected components.  
                Properties: create, query, edit
        selectRelatedFaces (bool?): Add to selectionList the faces which are connected to  
                (non-internally related to) selected components.  
                Properties: create
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        setUvSet (int?): This flag will set the current UV set on one given  
                selected object within the texture window.  
                Properties: create, edit
        singleBuffer (bool?): Set the display in single buffer mode  
                Properties: create, query, edit
        size (Queryable[float]?): Sets the size of the grid.  
                Properties: create, query, edit
        solidMap3dView (bool?): Display a solid overlay for the active texture map in 3D viewport.  
                Properties: create, query, edit
        solidMapColorSeed (Queryable[int]?): Sets the multi-color seed of shaded UVs.  
                Properties: create, query, edit
        solidMapPerShell (bool?): Display a solid overlay with a random color per shell.  
                Properties: create, query, edit
        spacing (float?): Sets the spacing between main grid lines.  
                Properties: create
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        style (Queryable[int]?): This flag is obsolete and should not be used.  
                Properties: query, edit
        subdivisionLinesColor (Queryable[Tuple[float, float, float]]?): The color of subdivision lines, default is 0.25 0.25 0.25  
                Properties: create, query, edit
        textureBorder3dView (bool?): Toggles the texture borders display in 3d viewport.  
                Properties: create, query, edit
        textureBorderColor (Queryable[Tuple[float, float, float]]?): Sets the display color of texture border.  
                Properties: create, query, edit
        textureBorderWidth (Queryable[int]?): Set the display edge width of texture border.  
                Properties: create, query, edit
        textureNames (bool?): Texture names for all Texture Images available for display,  
                if any.  
                Properties: query
        textureNumber (Queryable[int]?): Sets the number of textures to display  
                This depends on the number of textures corresponding to  
                the current selection. If there are N textures, then the  
                possible Texture Image numbers are 0 to N-1.  
                Properties: query, edit
        tileLabels (bool?): Toggles the texture tile label display.  
                Properties: create, query, edit
        tileLinesColor (Queryable[Tuple[float, float, float]]?): The color of tile lines, default is 0.0 0.0 0.0  
                Properties: create, query, edit
        toggle (bool?): Toggles the ground plane display.  
                Properties: create, query, edit
        toggleExposure (bool?): Toggles between the current and the default exposure value of the editor.  
                Properties: edit
        toggleGamma (bool?): Toggles between the current and the default gamma value of the editor.  
                Properties: edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useFaceGroup (bool?): Display faces that are associated with the groupId  
                that is set on the mesh node that is drawn.  
                (The attribute "displayFacesWithGroupId")  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        usedPercentageHUDRange (Queryable[Tuple[float, float, float, float]]?): Sets the range when calculating used UV space percentage. The 4 values specify the minimum U, V and maximum U, V in that order., default is 0 0 1 1.  
                Properties: create, query, edit
        uvSets (bool?): This flag will return strings containing  
                UV set and object name pairs for selected  
                objects in the texture window. The syntax of  
                each pair is "objectName | uvSetName", where |  
                is a literal character.  
                Properties: create, query, edit
        viewPortImage (bool?): Toggles the view port/ caching Texture Images.  
                Properties: create, edit
        viewTransformName (Queryable[str]?): Sets the view pipeline to be applied if color management is enabled in the  
                current editor.  
                Properties: query, edit
        wireframeComponentColor (Queryable[Tuple[float, float, float, float]]?): Sets or queries the RGBA component wireframe color.  
                Properties: create, query, edit
        wireframeObjectColor (Queryable[Tuple[float, float, float, float]]?): Sets or queries the RGBA object wireframe color.  
                Properties: create, query, edit
        writeImage (str?): write the current Editor Image to disk  
                Properties: edit

    Returns:
        str: The name of the texture window

    Example:
    """

def threadCount(*, query: bool = ..., numberOfThreads: Queryable[int] = ...) -> Union[bool, int]:
    """This command sets the number of threads to be used by Maya in
    regions of code that are multithreaded. By default the number
    of threads is equal to the number of logical CPUs, not the
    number of physical CPUs. Logical CPUs are different from
    physical CPUs in the following ways:A physical CPU with hyperthreading counts as two logical CPUsA dual-core CPU counts as two logical CPUsWith some workloads, using one thread per logical CPU may
    not perform well. This is sometimes the case with
    hyperthreading. It is worth experimenting with different
    numbers of threads to see which gives the best performance.
    Note that having more threads can mean Maya uses more memory.Setting a value of zero means the number of threads used will
    equal the number of logical processors in the system.
    Args:
        numberOfThreads (Queryable[int]?): Sets the number of threads to use  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def threePointArcCtx(*args: Any, edit: bool = ..., query: bool = ..., degree: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., spans: Queryable[int] = ...) -> Union[str, int]:
    """The threePointArcCtx command creates a new context for creating 3 point arcs
    Args:
        degree (Queryable[int]?): VAlid values are 1 or 3. Default degree 3.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        spans (Queryable[int]?): Default is 8.  
                Properties: create, query, edit

    Returns:
        str: (name of the new context)

    Example:
    """

def thumbnailCaptureComponent(*, query: bool = ..., capture: bool = ..., capturedFrameCount: bool = ..., closeCurrentSession: bool = ..., delete: bool = ..., endFrame: Queryable[int] = ..., fileDialogCallback: str = ..., isSessionOpened: bool = ..., launchedFromOptionsBox: bool = ..., previewPath: bool = ..., removeProjectThumbnail: str = ..., save: str = ..., startFrame: Queryable[int] = ...) -> Union[bool, int]:
    """This command is used to generate a thumbnail/playblast sequence from the scene.
    Args:
        capture (bool?): Create a new component to capture a sequence of image for the current scene.  
                Properties: create
        capturedFrameCount (bool?): Query only. Return the number of frames that have been captured.  
                Properties: query
        closeCurrentSession (bool?): Delete the current thumbnail component (preview image will be destroyed).  
                Properties: create
        delete (bool?): Delete the generated image sequence and preview for the current capture session.  
                Properties: create
        endFrame (Queryable[int]?): Set the end captured frame. Only valid when the -c/capture flag is set.  
                If -sf/startFrame is set and not -ef/endFrame, or if endFrame is smaller than startFrame, endFrame will be automatically set to startFrame.  
                Properties: create, query
        fileDialogCallback (str?): MEL only. Set the callback file dialog which is called after the capture component window has been closed. Only valid when the -c/capture flag is set.  
                Properties: create
        isSessionOpened (bool?): Returns true if a thumbnail/playblast capture session is currently running (already opened and still not cancelled/saved).  
                Properties: query
        launchedFromOptionsBox (bool?): Returns true if the thumbnail capture component was launched through the options dialog box, else false.  
                Properties: query
        previewPath (bool?): Returns the generated preview path (the first frame of generated sequence resized to 100x100 px).  
                Properties: query
        removeProjectThumbnail (str?): Remove all captured thumbnail/playblast from the given project file path.  
                Properties: create
        save (str?): Save the generated image sequence for the given file to disk. The file path must be an absolute path.  
                Properties: create
        startFrame (Queryable[int]?): Set the start captured frame. Only valid when -c/capture flag is set.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def timeCode(*, edit: bool = ..., query: bool = ..., mayaStartFrame: Queryable[float] = ..., productionStartFrame: Queryable[float] = ..., productionStartHour: Queryable[float] = ..., productionStartMinute: Queryable[float] = ..., productionStartSecond: Queryable[float] = ...) -> Union[int, float]:
    """Use this command to query and set the time code information in the filetimecode, time
    Args:
        mayaStartFrame (Queryable[float]?): Sets the Maya start time of the time code, in frames.  
                In query mode, returns the Maya start frame of the time code.  
                Properties: create, query, edit
        productionStartFrame (Queryable[float]?): Sets the production start time of the time code, in terms of frames.  
                In query mode, returns the sub-second frame of production start time.  
                Properties: create, query, edit
        productionStartHour (Queryable[float]?): Sets the production start time of the time code, in terms of hours.  
                In query mode, returns the hour of production start time.  
                Properties: create, query, edit
        productionStartMinute (Queryable[float]?): Sets the production start time of the time code, in terms of minutes.  
                In query mode, returns the minute of production start time.  
                Properties: create, query, edit
        productionStartSecond (Queryable[float]?): Sets the production start time of the time code, in terms of seconds.  
                In query mode, returns the second of production start time.  
                Properties: create, query, edit

    Returns:
        int: values

    Example:
    """

def timeControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., animCurveNames: bool = ..., animLayerFilterOptions: Queryable[str] = ..., animLayerShowWeight: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., beginScrub: bool = ..., currentFrameColor: Tuple[float, float, float, float] = ..., defineTemplate: str = ..., displaySound: bool = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., endScrub: bool = ..., exists: bool = ..., forceRedraw: bool = ..., forceRefresh: bool = ..., foregroundColor: Tuple[float, float, float] = ..., fullPathName: bool = ..., globalTime: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., mainListConnection: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., pressCommand: Callable[..., Any] = ..., preventOverride: bool = ..., range: bool = ..., rangeArray: bool = ..., rangeVisible: bool = ..., releaseCommand: Callable[..., Any] = ..., repeatChunkSize: Queryable[float] = ..., repeatOnHold: bool = ..., resample: bool = ..., showKeys: Queryable[str] = ..., showKeysCombined: bool = ..., snap: bool = ..., sound: Queryable[str] = ..., statusBarMessage: str = ..., tickSize: Queryable[int] = ..., tickSpan: Queryable[int] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., waveform: Queryable[str] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, float, Callable[..., Any]]:
    """This command creates a control that can be used for
    changing current time, displaying/editing keys, and
    displaying/scrubbing sound.: only one timeControl may be created.  The one Maya creates
    on startup can be accessed from the global string variable $gPlayBackSlider.
    Also, it is not a good idea to delete it.
    Args:
        animCurveNames (bool?): When "showKeys" is not "none", querying this flag will  
                return the names of all the animCurves for which keyframe  
                ticks are being displayed.  Query returns string[].  
                Properties: create, query
        animLayerFilterOptions (Queryable[str]?): Specifies whether a filter is to be applied when displaying animation layers.  
                If so, the options can be "allAffecting" (no filter), "active" (only the active  
                layers on the object will be displayed) and "animLayerEditor" (the settings will  
                be taken from the animation layer editor).  
                Properties: create, query, edit
        animLayerShowWeight (bool?): Specifies or queries whether weights are to be shown when displaying animation layers.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        beginScrub (bool?): Set this widget up for sound scrubbing.  
                Subsequent changes to current time will result  
                in "sound scrubbing" behavior, until the  
                "-endScrub" command is issued for this widget.  
                Properties: edit
        currentFrameColor (Tuple[float, float, float, float]?): This flag is used to specify the rgba color of the  
                current frame overlay rectangle in the timeControl.  
                Properties: edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displaySound (bool?): Turn sound display off.  Query returns int.  
                Properties: query, edit
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        endScrub (bool?): End sound scubbing for this widget.  This stops  
                sound scrubbing behavior and should be issued  
                before any subsequent "-beginScrub" flags  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        forceRedraw (bool?): Force a redraw of the time control UI. Similiar to forceRefresh but  
                does not rebuild key information.  
                Properties: create, edit
        forceRefresh (bool?): Force a refresh of the time control UI.  
                Properties: create, edit
        foregroundColor (Tuple[float, float, float]?): This flag is used to specify the rgb color of the  
                vertical lines and numeric text in the timeControl.  
                Properties: edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        globalTime (bool?): "true" means this widget controls and displays the global,  
                dependency graph time.  "false" means time changes here  
                do NOT affect the dependency graph. Query returns int.  
                Properties: create, query, edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                time slider will use as its source of content.  The time slider will  
                only display keys for items contained in the selectionConnection object.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        pressCommand (Callable[..., Any]?): script to run on mouse-down in this control.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        range (bool?): Returns string representing the currently highlighted  
                range visible on the time slider.  A range from 10 to 20  
                would be returned as "10. 20".  When there's no range  
                visible on the time slider, the query returns a range  
                spanning the current time: for example, "10. 11".  These  
                values are in the current time unit.  
                Properties: create, query
        rangeArray (bool?): Returns a float array representing the currently highlighted  
                range visible on the time slider.  A range from 10 to 20  
                would be returned as { 10.0, 20.0 }.  When there's no range  
                visible on the time slider, the query returns values spanning  
                the current time: { 10.0, 11.0 }.  These values are in the current time unit.  
                Properties: create, query
        rangeVisible (bool?): Returns true if a currently highlighted range is visible  
                on the time slider, false if no.  
                Properties: create, query
        releaseCommand (Callable[..., Any]?): script to run on mouse-up in this control.  
                Properties: create, edit
        repeatChunkSize (Queryable[float]?): How much sound (in the current time unit) is repeated  
                when -repeatOnHold is true.  Default is 1.0.  
                Properties: query, edit
        repeatOnHold (bool?): Repeat sound during mouse-down events  
                Properties: query, edit
        resample (bool?): Resample the sound display to fit the widget  
                Properties: edit
        showKeys (Queryable[str]?): "active" will show tick marks for keyframes on all active  
                objects.  "none" shows no tick marks.  Any other name is  
                taken as the name of a channel box whose selected attributes  
                will display tick marks.  Default "active".  Query returns string.  
                Properties: create, query, edit
        showKeysCombined (bool?): This flag can be used in conjunction with the showKeys flag to  
                enable a combination of "active" + "channel box" behavior.  
                Specifically, if channel box attributes are selected, tick marks will  
                be shown for those attributes. If no channel box attributes are  
                selected, tick marks will be shown for keyframes on all active objects.  
                Properties: create, query, edit
        snap (bool?): "true" means this widget is constrained to having  
                values that are integers representing the current time unit..  
                "false" means the current time indicator is "free floating"  
                and not constrained.  
                Properties: create, query, edit
        sound (Queryable[str]?): Name of audio depend node whose data should display in the  
                sound-display widget. Query returns string.  
                Properties: query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        tickSize (Queryable[int]?): Specifies the width of keyframe ticks drawn in the time slider.  
                The value will be clamped to the range [1, 63].  
                Properties: create, query, edit
        tickSpan (Queryable[int]?): Specifies the interval between keyframe ticks in the timeControl. For example,  
                a value of 10, will place ticks at 0, 10, 20, etc.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        waveform (Queryable[str]?): Determines what part of the sound waveform to display,  
                when -displaySound is "true". Valid values are "top", "bottom",  
                and "both".  Default is "top". Query returns string.  
                Properties: query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Name of created or edited control

    Example:
    """

def timeEditor(*args: Any, query: bool = ..., allClips: str = ..., clipId: Multiuse[int] = ..., commonParentTrack: bool = ..., composition: str = ..., drivingClipsForAttr: str = ..., drivingClipsForObj: Tuple[str, int] = ..., includeParent: bool = ..., mute: bool = ..., selectedClips: str = ..., topLevelClips: str = ...) -> Union[str, bool]:
    """General Time Editor commandstimeEditor, nle
    Args:
        allClips (str?): Return an exhaustive (recursive) list of all clip IDs from the active composition.  
                Arguments may be used to filter the returning result. An empty string will return clip IDs for all clip types:  
              
                 roster   
                 container   
                 group  
                Properties: create
        clipId (Multiuse[int]?): ID of the clip to be edited.  
                Properties: create, multiuse
        commonParentTrack (bool?): Locate the common parent track node and track index of the given clip IDs.  
                Requires a list of clip IDs to be specified using the clipId flag.  
                The format of the returned string is "track_node:track_index". If the clips specified  
                are on the same track node but in different track indexes, only the track node  
                will be returned.  
                Properties: create
        composition (str?): A flag to use in conjunction with -dca/drivingClipsForObj to indicate the name of composition to use.  
                By default if this flag is not provided, current active composition will be used.  
                Properties: create
        drivingClipsForAttr (str?): Return a list of clips driving the specified attribute(s).  
                If the composition is not specified, current active composition will be used.  
                Properties: create
        drivingClipsForObj (Tuple[str, int]?): Return a list of clips driving the specified object(s) with an integer value indicating the matching mode.  
                If no object is specified explicitly, the selected object(s) will be used.  
                Objects that cannot be driven by clips are ignored.  
                If the composition is not specified, current active composition will be used.  
                Default match mode is 0.  
              
                0. Include only the clip that has an exact match  
                1. Include any clip that contains all of the specified objects  
                2. Include any clip that contains any of the specified objects  
                3. Include all clips that do not include any of the specified objects  
                Properties: create
        includeParent (bool?): A toggle flag to use in conjunction with -dca/drivingClipsForObj.  
                When toggled, parent clip is included in selection (the entire hierarchy will be selected).  
                Properties: create
        mute (bool?): Mute/unmute Time Editor.  
                Properties: create, query
        selectedClips (str?): Return a list of clip IDs of currently selected Time Editor clips.  
                Arguments may be used to filter the returning result. An empty string will return clip IDs for all clip types:  
              
                 roster   
                 container   
                 group  
                Properties: create
        topLevelClips (str?): Return a list of all top-level clip IDs from the active composition.  
                Arguments may be used to filter the returning result. An empty string will return clip IDs for all clip types:  
              
                 roster   
                 container   
                 group  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def timeEditorAnimSource(*args: Any, edit: bool = ..., query: bool = ..., addSource: str = ..., apply: bool = ..., bakeToAnimSource: str = ..., calculateTiming: bool = ..., copyAnimation: bool = ..., drivenClips: bool = ..., export: str = ..., isUnique: bool = ..., removeSource: str = ..., targetIndex: Queryable[str] = ..., targets: bool = ..., addObjects: Queryable[str] = ..., addRelatedKG: bool = ..., addSelectedObjects: bool = ..., attribute: Multiuse[str] = ..., exclusive: bool = ..., importAllFbxTakes: bool = ..., importFbx: str = ..., importFbxTakes: str = ..., importMayaFile: str = ..., importOption: str = ..., importPopulateOption: str = ..., importedContainerNames: str = ..., includeRoot: bool = ..., populateImportedAnimSources: str = ..., poseClip: bool = ..., recursively: bool = ..., removeSceneAnimation: bool = ..., showAnimSourceRemapping: bool = ..., takeList: str = ..., takesToImport: str = ..., type: Queryable[Multiuse[str]] = ...) -> Union[str, bool, Multiuse[str]]:
    """Commands for managing animation sources.timeEditor, nle
    Args:
        addSource (str?): Add single new target attribute with its animation.  
                Properties: edit
        apply (bool?): Connect anim source's animation directly to the target objects. If the Time Editor is not muted, connect to scene storage instead.  
                Properties: edit
        bakeToAnimSource (str?): Create a new anim source with the same animation as this anim source. All non-curve inputs will be baked down, whereas curve sources will be shared.  
                Properties: edit
        calculateTiming (bool?): Adjust start/duration when adding/removing sources. If query it returns the [start,duration] pair.  
                Properties: query, edit
        copyAnimation (bool?): Copy animation when adding source.  
                Properties: edit
        drivenClips (bool?): Return all clips driven by the given anim source.  
                Properties: query
        export (str?): Export given anim source and the animation curves to a specified Maya file.  
                Properties: edit
        isUnique (bool?): Return true if the anim source node is only driving a single clip.  
                Properties: query
        removeSource (str?): Remove single attribute.  
                Properties: edit
        targetIndex (Queryable[str]?): Get target index.  
                Properties: query
        targets (bool?): Get a list of all targets in this anim source.  
                Properties: query
        addObjects (Queryable[str]?): Populate the given object(s) and their attributes to anim source to Time Editor. For multiple object, pass each name separated by semicolon.  
                In query mode, return the number of attributes that will be populated given the flags, along with the animation's first and last frames for the given object(s).  
                Similar to -addSelectedObjects flag but acts on given object(s) instead.  
                This flag will override the flag -addSelectedObjects.  
                Properties: create, query, edit
        addRelatedKG (bool?): During population, determine if associated keying groups should be populated  
                or not. Normally used for populating HIK. By default the value is false.  
                Properties: create, query, edit
        addSelectedObjects (bool?): Populate the currently selected objects and their attributes to anim source or Time Editor.  
                In query mode, return the number of attributes that will be populated given the flags, along with the animation's first and last frames.  
                Properties: create, query, edit
        attribute (Multiuse[str]?): Populate a specific attribute on a object.  
                Properties: create, edit, multiuse
        exclusive (bool?): Populate all types of animation sources which are not listed by "type" Flag.  
                Properties: create, edit
        importAllFbxTakes (bool?): Import all FBX takes into the new anim sources (for timeEditorAnimSource command) or new containers (for timeEditorClip command).  
                Properties: create
        importFbx (str?): Import an animation from FBX file into the new anim source (for timeEditorAnimSource command) or new container (for timeEditorClip command).  
                Properties: create
        importFbxTakes (str?): Import multiple FBX takes (separated by semicolons) into the new anim sources (for timeEditorAnimSource command) or new containers (for timeEditorClip command).  
                Properties: create
        importMayaFile (str?): Import an animation from Maya file into the new anim sources (for timeEditorAnimSource command) or new containers (for timeEditorClip command).  
                Properties: create
        importOption (str?): Option for importing animation source. Specify either 'connect' or 'generate'.  
                connect:  Only connect with nodes already existing in the scene.  
                                  Importing an animation source that does not match with any element  
                                  of the current scene will not create any clip.  
                                  (connect is the default mode).  
                generate: Import everything and generate new nodes for items not existing in the scene.  
                Properties: edit
        importPopulateOption (str?): Option for population when importing.  
                Properties: edit
        importedContainerNames (str?): Internal use only. To be used along with populateImportedAnimSources to specify names for the created containers.  
                Properties: create
        includeRoot (bool?): Populate transform (Translate, Rotate, Scale) of hierarchy root nodes.  
                Properties: create, edit
        populateImportedAnimSources (str?): Internal use only. Populate the Time Editor with clips using the Animation Sources specified (use ; as a delimiter for multiple anim sources).  
                Properties: create
        poseClip (bool?): Populate as pose clip with current attribute values.  
                Properties: create
        recursively (bool?): Populate selection recursively, adding all the children.  
                Properties: create, edit
        removeSceneAnimation (bool?): If true, remove animation from scene when creating clips or anim sources. Only Time Editor will drive the removed scene animation.  
                Properties: create, edit
        showAnimSourceRemapping (bool?): Show a remapping dialog when the imported anim source attributes do not match the scene attributes.  
                Properties: create
        takeList (str?): Internal use only. To be used along with populateImportedAnimSources to specify the imported take names.  
                Properties: create
        takesToImport (str?): Internal use only. To be used along with populateImportedAnimSources to specify the imported take indices.  
                Properties: create
        type (Queryable[Multiuse[str]]?): Only populate the specified type of animation source.  
                Properties: create, query, edit, multiuse

    Returns:
        str: Command result

    Example:
    """

def timeEditorBakeClips(*args: Any, edit: bool = ..., query: bool = ..., bakeToAnimSource: str = ..., bakeToClip: str = ..., clipId: Multiuse[int] = ..., combineLayers: bool = ..., forceSampling: bool = ..., keepOriginalClip: bool = ..., path: Multiuse[str] = ..., sampleBy: int = ..., targetTrackIndex: int = ..., targetTracksNode: str = ...) -> int:
    """This command is used to bake Time Editor clips and to blend them into a single clip.
    Args:
        bakeToAnimSource (str?): Bake/merge the selected clips into the animation source.  
                Properties: create
        bakeToClip (str?): Bake/merge the selected clips into a clip.  
                Properties: create
        clipId (Multiuse[int]?): Clip IDs of the clips to bake.  
                Properties: create, multiuse
        combineLayers (bool?): Combine the layers of the input clip.  
                Properties: create
        forceSampling (bool?): Force sampling on the whole time range when baking.  
                Properties: create
        keepOriginalClip (bool?): Keep the source clips after baking.  
                Properties: create
        path (Multiuse[str]?): Full path of clips on which to operate. For example: composition1|track1|group; composition1|track1|group|track2|clip1.  
                Properties: create, multiuse
        sampleBy (int?): Sampling interval when baking crossfades and timewarps.  
                Properties: create
        targetTrackIndex (int?): Specify the target track when baking containers.  
                If targetTrackIndex is specified, the track index within the specified node is used.  
                If targetTrackIndex is not specified or is the default value (-1), the track index within the current node is used.  
                If targetTrackIndex is -2, a new track will be created.  
                Properties: create
        targetTracksNode (str?): Target tracks node when baking containers.  
                Properties: create

    Returns:
        int: Command result

    Example:
    """

def timeEditorClip(*args: Any, edit: bool = ..., query: bool = ..., absolute: bool = ..., addAttribute: Multiuse[str] = ..., allowShrinking: bool = ..., animSource: Queryable[str] = ..., audio: str = ..., blendMode: Queryable[int] = ..., children: Queryable[int] = ..., clipAfter: bool = ..., clipBefore: bool = ..., clipDataType: bool = ..., clipId: Multiuse[int] = ..., clipIdFromNodeName: Queryable[int] = ..., clipIdFromPath: bool = ..., clipNode: bool = ..., clipPath: bool = ..., copyClip: bool = ..., crossfadeMode: Queryable[int] = ..., crossfadePlug: bool = ..., curveTime: Queryable[int] = ..., defaultGhostRoot: bool = ..., drivenAttributes: bool = ..., drivenClipsBySource: Queryable[str] = ..., drivenObjects: bool = ..., drivenRootObjects: bool = ..., drivingSources: Queryable[str] = ..., duplicateClip: bool = ..., duration: Queryable[int] = ..., emptySource: bool = ..., endTime: Queryable[int] = ..., existingOnly: bool = ..., exists: bool = ..., explode: int = ..., exportAllClips: bool = ..., exportFbx: str = ..., extend: bool = ..., extendParent: bool = ..., ghost: bool = ..., ghostRootAdd: Multiuse[str] = ..., ghostRootRemove: Multiuse[str] = ..., group: bool = ..., holdEnd: Queryable[int] = ..., holdStart: Queryable[int] = ..., importTakeDestination: int = ..., isContainer: bool = ..., listUserGhostRoot: bool = ..., loopEnd: Queryable[int] = ..., loopStart: Queryable[int] = ..., minClipDuration: bool = ..., modifyAnimSource: bool = ..., moveClip: int = ..., mute: bool = ..., name: Queryable[str] = ..., parent: int = ..., parentClipId: Queryable[int] = ..., parentGroupId: bool = ..., pasteClip: int = ..., path: Multiuse[str] = ..., preserveAnimationTiming: bool = ..., razorClip: int = ..., remap: Tuple[str, str] = ..., remapNamespace: Multiuse[Tuple[str, str]] = ..., remapSource: Tuple[str, str] = ..., remappedSourceAttrs: bool = ..., remappedTargetAttrs: bool = ..., removeAttribute: Multiuse[str] = ..., removeClip: bool = ..., removeCrossfade: bool = ..., removeWeightCurve: bool = ..., resetTiming: bool = ..., resetTransition: bool = ..., ripple: bool = ..., rootClipId: int = ..., rootPath: str = ..., scaleEnd: int = ..., scalePivot: int = ..., scaleStart: int = ..., setKeyframe: Multiuse[str] = ..., speedRamping: Queryable[int] = ..., startTime: Queryable[int] = ..., timeWarp: bool = ..., timeWarpCurve: bool = ..., timeWarpType: Queryable[int] = ..., track: Queryable[str] = ..., tracksNode: bool = ..., transition: bool = ..., trimEnd: int = ..., trimStart: int = ..., truncated: bool = ..., uniqueAnimSource: bool = ..., userGhostRoot: bool = ..., weightCurve: bool = ..., zeroKeying: bool = ..., addObjects: Queryable[str] = ..., addRelatedKG: bool = ..., addSelectedObjects: bool = ..., attribute: Multiuse[str] = ..., exclusive: bool = ..., importAllFbxTakes: bool = ..., importFbx: str = ..., importFbxTakes: str = ..., importMayaFile: str = ..., importOption: str = ..., importPopulateOption: str = ..., importedContainerNames: str = ..., includeRoot: bool = ..., populateImportedAnimSources: str = ..., poseClip: bool = ..., recursively: bool = ..., removeSceneAnimation: bool = ..., showAnimSourceRemapping: bool = ..., takeList: str = ..., takesToImport: str = ..., type: Queryable[Multiuse[str]] = ...) -> Union[str, bool, int, Multiuse[str]]:
    """This command edits/queries Time Editor clips.timeEditor, nle
    Args:
        absolute (bool?): This flag is used in conjunction with other timing flags like -s/start, -d/duration, -ed/end, etc.  
                to query (global) absolute time.  
                Properties: query
        addAttribute (Multiuse[str]?): Add new attribute to the clip.  
                Properties: edit, multiuse
        allowShrinking (bool?): When extending clip, allow shrinking.  
                Properties: edit
        animSource (Queryable[str]?): Populate based on animation source.  
                Properties: create, query, edit
        audio (str?): Create a clip with audio inside.  
                Properties: create
        blendMode (Queryable[int]?): Set the blending mode for the clips specified with the -clipId flags:  
              
                0. normal          - absolute blend  
                1. additive        - relative blend  
                Properties: query, edit
        children (Queryable[int]?): Get children clip IDs.  
                Properties: query
        clipAfter (bool?): Get the clip ID of the next clip.  
                Properties: query
        clipBefore (bool?): Get the clip ID of the previous clip.  
                Properties: query
        clipDataType (bool?): Query the type of data being driven by the given clip ID.  
                Return values are:  
              
                0. Animation       - Clip drives animation curves  
                1. Audio           - Clip drives audio  
                3. Group           - Clip is a group  
                Properties: query
        clipId (Multiuse[int]?): ID of the clip to be edited.  
                Properties: create, edit, multiuse
        clipIdFromNodeName (Queryable[int]?): Get clip ID from clip node name.  
                Properties: query
        clipIdFromPath (bool?): Flag for querying the clip ID given the path. Clip path is a vertical-bar-delimited string to indicate  
                a hierarchical structure of a clip. Please refer to the hierarchical path in outliner to see how it is represented.  
                For example: composition1|track1|clip1  
                Note: To specify the path, this flag must appear before -query flag.  
                Properties: query
        clipNode (bool?): Flag for querying the name of the clip node.  
                Properties: query
        clipPath (bool?): Flag for querying the path given the clip ID. Clip path is a vertical bar delimited string to indicate  
                a hierarchical structure of a clip. Please refer to the hierarchical path in outliner to see how it is represented.  
                For example: composition1|track1|clip1.  
                Note: If the clip is not connected to any track, it will return empty string.  
                Properties: query
        copyClip (bool?): Get the selected clip IDs and store them in a list that could be used for pasting.  
                Properties: edit
        crossfadeMode (Queryable[int]?): Set the crossfading mode between two clips that lie on the same track, and that are specified with the -clipId flags:  
              
                0. linear          - Two clips are blended with a constant ratio  
                1. step            - Left clip keeps its value until the middle of the crossfading region and then right clip's value is used  
                2. hold left       - Use only left clip's value  
                3. hold right      - Use only right clip's value  
                4. custom          - User defined crossfade curve  
                5. custom (spline) - User defined crossfade curve with spline preset  
                Properties: query, edit
        crossfadePlug (bool?): Get plug path for a custom crossfade curve between 2 clips.  
                Properties: query
        curveTime (Queryable[int]?): Query the curve local time in relation to the given clip.  
                Properties: query
        defaultGhostRoot (bool?): Edit or query default ghost root variable.  
                Determine whether to use the default ghost root (object driven by clip).  
                Properties: query, edit
        drivenAttributes (bool?): Return a list of attributes driven by a clip.  
                Properties: query
        drivenClipsBySource (Queryable[str]?): Returns the clips driven by the given source. Can filter the return result by the specified type, like animCurve, expression, constraint, etc.  
                This flag must come before the -query flag.  
                Properties: query
        drivenObjects (bool?): Return an array of strings consisting of the names of all objects driven by the current clip and its children clips.  
                Properties: query
        drivenRootObjects (bool?): Return an array of strings consisting of the names of all root objects driven by this clip and its children clips.  
                Properties: query
        drivingSources (Queryable[str]?): Return all sources driving the given clip. Can filter the return result by the specified type, like animCurve, expression, constraint, etc.  
                If used after the -query flag (without an argument), the command returns all sources driving the given clip.  
                To specify the type, this flag must appear before the -query flag.  
                			In query mode, this flag can accept a value.  
                Properties: query
        duplicateClip (bool?): Duplicate clip into two clips with the same timing info.  
                Properties: edit
        duration (Queryable[int]?): Relative duration of the new clip.  
                Properties: create, query
        emptySource (bool?): Create a clip with an empty source.  
                Properties: create
        endTime (Queryable[int]?): Query the relative end time of the clip.  
                Properties: query
        existingOnly (bool?): This flag can only be used in edit mode, in conjunction with the animSource flag. Retain the animSource flag functionality but  
                only bind attributes that are already part of the clip. It does not attempt to populate unbound  
                source attributes to their default destination.  
                Properties: edit
        exists (bool?): Return true if the specified clip exists.  
                Properties: query
        explode (int?): Reparent all tracks and their clips within a group out to its parent track node and remove the group.  
                Properties: edit
        exportAllClips (bool?): When used with the ef/exportFbx flag, export all clips.  
                Properties: edit
        exportFbx (str?): Export currently selected clips to FBX files.  
                Properties: edit
        extend (bool?): Extend the clip to encompass all children.  
                Properties: edit
        extendParent (bool?): Extend parent to fit this clip.  
                Properties: edit
        ghost (bool?): Enable/disable ghosting for the specified clip.  
                Properties: query, edit
        ghostRootAdd (Multiuse[str]?): Add path to specified node as a custom ghost root.  
                Properties: edit, multiuse
        ghostRootRemove (Multiuse[str]?): Remove path to specified node as a custom ghost root.  
                Properties: edit, multiuse
        group (bool?): Specify if the new container should be created as a group, containing other specified clips.  
                Properties: create
        holdEnd (Queryable[int]?): Hold clip's end to time.  
                Properties: query, edit
        holdStart (Queryable[int]?): Hold clip's start to time.  
                Properties: query, edit
        importTakeDestination (int?): Specify how to organize imported FBX takes:  
                0. Import takes into a group (default)  
                1. Import takes into multiple compositions  
                2. Import takes as a sequence of clips  
                Properties: create
        isContainer (bool?): Indicate if given clip ID is a container.  
                Properties: query
        listUserGhostRoot (bool?): Get user defined ghost root object for indicated clips.  
                Properties: query
        loopEnd (Queryable[int]?): Loop clip's end to time.  
                Properties: query, edit
        loopStart (Queryable[int]?): Loop clip's start to time.  
                Properties: query, edit
        minClipDuration (bool?): Returns the minimum allowed clip duration.  
                Properties: query
        modifyAnimSource (bool?): When populating, automatically modify Anim Source without asking the user.  
                Properties: create, edit
        moveClip (int?): Move clip by adding delta to its start time.  
                Properties: edit
        mute (bool?): Mute/Unmute the clip given a clip ID. In query mode, return the muted state of the clip. Clips muted by soloing are not affected by this flag.  
                Properties: query, edit
        name (Queryable[str]?): Name of the clip. A clip will never have an empty name.  
                If an empty string is provided, it will be replaced with "_".  
                Properties: query, edit
        parent (int?): Specify group/object parent ID.  
                Properties: edit
        parentClipId (Queryable[int]?): Specify the parent clip ID of a clip to be created.  
                Properties: create, query
        parentGroupId (bool?): Return the parent group ID of the given clip.  
                Properties: query
        pasteClip (int?): Paste clip to the given time and track. Destination track is required to be specified through the track flag in the format "tracksNode:trackIndex".  
                A trackIndex of -1 indicates that a new track will be created.  
                Properties: edit
        path (Multiuse[str]?): Full path of the clip to be edited. For example: composition1|track1|clip1.  
                			In query mode, this flag can accept a value.  
                Properties: edit, multiuse
        preserveAnimationTiming (bool?): When used with the population command, it ensures the animation is offset within a clip in such way that it matches its original scene timing, regardless of the new clip's position.  
                Properties: create
        razorClip (int?): Razor clip into two clips at the specified time.  
                Properties: edit
        remap (Tuple[str, str]?): Change animation source for a given clip item to a new one, specified by the target path.  
                This removes all clips for the roster item and creates new clips from the Anim Source for the new target path.  
                Properties: edit
        remapNamespace (Multiuse[Tuple[str, str]]?): Remap namespace(s). Can only be used in create mode, in conjunction with the  
                -importFbx/fbx, -importMayaFile/mf, or -attribute/at flags.  
                This flag will replace any occurrences of a given namespace to  
                an alternate specified namespace.  It takes in two string arguments. The  
                first argument specifies the namespace to replace. The second argument  
                specifies the replacement namespace. This flag cannot be used in conjunction  
                with the -sar/showAnimSourceRemapping flag.  
                Note that a track must be specified, and  must exist prior to invoking the  
                timeEditorClip command with the -remapNamespace flag.  
                Properties: create, multiuse
        remapSource (Tuple[str, str]?): Set animation source to be remapped for a given clip item to new one, specified by the target path.  
                Properties: edit
        remappedSourceAttrs (bool?): Return an array of attribute indices and names of the source attributes of a remapped clip.  
                Properties: query
        remappedTargetAttrs (bool?): Return an array of attribute indices and names of the target attributes of a remapped clip.  
                Properties: query
        removeAttribute (Multiuse[str]?): Remove attribute from the clip.  
                Properties: edit, multiuse
        removeClip (bool?): Remove clip of specified ID.  
                Properties: edit
        removeCrossfade (bool?): Remove custom crossfade between two clips specified by -clipId flags.  
                Properties: edit
        removeWeightCurve (bool?): Remove the weight curve connected to the clip.  
                Properties: create, query, edit
        resetTiming (bool?): Reset start and duration of a clip with the given clip ID to the values stored in its Anim Source.  
                Properties: edit
        resetTransition (bool?): Reset transition intervals between specified clips.  
                Properties: edit
        ripple (bool?): Apply rippling to a clip operation.  
                Properties: edit
        rootClipId (int?): ID of the root clip. It is used together with various clip editing flags. When used, the effect of clip editing and its parameters will be affected by the given root clip.  
                For example, moving a clip under the group root (usually in group tab view) will be performed in the local time space of the group root.  
                Properties: edit
        rootPath (str?): Path of the root clip. It is used together with various clip editing flags. When used, the effect of clip editing and its parameters will be affected by the given root clip.  
                For example, moving a clip under the group root (usually in group tab view) will be performed in the local time space of the group root.  
                Properties: edit
        scaleEnd (int?): Scale the end time of the clip to the given time.  
                Properties: edit
        scalePivot (int?): Scale the time of the clip based on the pivot. This should be used together with -scs/scaleStart or -sce/scaleEnd.  
                Properties: edit
        scaleStart (int?): Scale the start time of the clip to the given time.  
                Properties: edit
        setKeyframe (Multiuse[str]?): Set keyframe on a specific clip for a specified attribute.  
                Properties: edit, multiuse
        speedRamping (Queryable[int]?): To control the playback speed of the clip by animation curve:  
              
                1. create - Attach a speed curve and a time warp curve to the clip to control the playback speed  
                2. edit - Open the Graph editor to edit the speed curve  
                3. enable - Create a time warp curve from current speed curve and attach to clip  
                4. disable - Remove the time warp curve from clip  
                5. delete - Delete the attached speed curve and time warp curve  
                6. reset - Reset the speed curve back to the default  
                7. convert to speed curve from time warp  
                8. convert to time warp from speed curve  
              
                In query mode, return true if a speed curve is attached to the clip.  
                Properties: query, edit
        startTime (Queryable[int]?): Relative start time of the new clip.  
                Properties: create, query
        timeWarp (bool?): Return true if the clip is being warped by the speed curve. If no speed curve is attached to the clip, it will always return false.  
                Properties: query
        timeWarpCurve (bool?): Returns the name of the time warp curve connected to the clip.  
                Properties: query
        timeWarpType (Queryable[int]?): Time warp mode:  
              
                0. remapping - Connected time warp curve performs frame by frame remapping  
                1. speed curve - Connected time warp curve acts as a speed curve  
              
                In query mode, return time warp mode of a clip.  
                Properties: query, edit
        track (Queryable[str]?): The new clip container will be created on the track in the format "trackNode:trackNumber", or on a track path, for example "composition1|track1".  
                In query mode, return a string containing the track number and tracks node of the given clip ID.  
                In create mode, if the track number is '-1' or not given at all, then a new track will be created. For example: "trackNode:-1"; "composition1|".  
                Properties: create, query, edit
        tracksNode (bool?): Get tracks node if specified clip is a group clip.  
                Properties: query
        transition (bool?): Create transition intervals between specified clips.  
                Properties: edit
        trimEnd (int?): Trim the end time of the clip to the given time.  
                Properties: edit
        trimStart (int?): Trim the start time of the clip to the given time.  
                Properties: edit
        truncated (bool?): This flag is used in conjunction with other timing flags like -s/start, -d/duration, -ed/end, etc.  
                to query (global) truncated time.  
                Properties: query
        uniqueAnimSource (bool?): If a given clip is sharing its Anim Source node with another clip, make the Anim Source of this clip unique.  
                Properties: edit
        userGhostRoot (bool?): Edit or query custom ghost root variable.  
                Determine whether to use user defined ghost root.  
                Properties: query, edit
        weightCurve (bool?): In edit mode, create a weight curve and connect it to the clip.  
                In query mode, return the name of the weight curve connected to the clip.  
                Properties: create, query, edit
        zeroKeying (bool?): A toggle flag to use in conjunction with k/setKeyframe, set the value of the key frame(s) to be keyed to zero.  
                Properties: edit
        addObjects (Queryable[str]?): Populate the given object(s) and their attributes to anim source to Time Editor. For multiple object, pass each name separated by semicolon.  
                In query mode, return the number of attributes that will be populated given the flags, along with the animation's first and last frames for the given object(s).  
                Similar to -addSelectedObjects flag but acts on given object(s) instead.  
                This flag will override the flag -addSelectedObjects.  
                Properties: create, query, edit
        addRelatedKG (bool?): During population, determine if associated keying groups should be populated  
                or not. Normally used for populating HIK. By default the value is false.  
                Properties: create, query, edit
        addSelectedObjects (bool?): Populate the currently selected objects and their attributes to anim source or Time Editor.  
                In query mode, return the number of attributes that will be populated given the flags, along with the animation's first and last frames.  
                Properties: create, query, edit
        attribute (Multiuse[str]?): Populate a specific attribute on a object.  
                Properties: create, edit, multiuse
        exclusive (bool?): Populate all types of animation sources which are not listed by "type" Flag.  
                Properties: create, edit
        importAllFbxTakes (bool?): Import all FBX takes into the new anim sources (for timeEditorAnimSource command) or new containers (for timeEditorClip command).  
                Properties: create
        importFbx (str?): Import an animation from FBX file into the new anim source (for timeEditorAnimSource command) or new container (for timeEditorClip command).  
                Properties: create
        importFbxTakes (str?): Import multiple FBX takes (separated by semicolons) into the new anim sources (for timeEditorAnimSource command) or new containers (for timeEditorClip command).  
                Properties: create
        importMayaFile (str?): Import an animation from Maya file into the new anim sources (for timeEditorAnimSource command) or new containers (for timeEditorClip command).  
                Properties: create
        importOption (str?): Option for importing animation source. Specify either 'connect' or 'generate'.  
                connect:  Only connect with nodes already existing in the scene.  
                                  Importing an animation source that does not match with any element  
                                  of the current scene will not create any clip.  
                                  (connect is the default mode).  
                generate: Import everything and generate new nodes for items not existing in the scene.  
                Properties: edit
        importPopulateOption (str?): Option for population when importing.  
                Properties: edit
        importedContainerNames (str?): Internal use only. To be used along with populateImportedAnimSources to specify names for the created containers.  
                Properties: create
        includeRoot (bool?): Populate transform (Translate, Rotate, Scale) of hierarchy root nodes.  
                Properties: create, edit
        populateImportedAnimSources (str?): Internal use only. Populate the Time Editor with clips using the Animation Sources specified (use ; as a delimiter for multiple anim sources).  
                Properties: create
        poseClip (bool?): Populate as pose clip with current attribute values.  
                Properties: create
        recursively (bool?): Populate selection recursively, adding all the children.  
                Properties: create, edit
        removeSceneAnimation (bool?): If true, remove animation from scene when creating clips or anim sources. Only Time Editor will drive the removed scene animation.  
                Properties: create, edit
        showAnimSourceRemapping (bool?): Show a remapping dialog when the imported anim source attributes do not match the scene attributes.  
                Properties: create
        takeList (str?): Internal use only. To be used along with populateImportedAnimSources to specify the imported take names.  
                Properties: create
        takesToImport (str?): Internal use only. To be used along with populateImportedAnimSources to specify the imported take indices.  
                Properties: create
        type (Queryable[Multiuse[str]]?): Only populate the specified type of animation source.  
                Properties: create, query, edit, multiuse

    Returns:
        str: Return created clip's name.

    Example:
    """

def timeEditorClipLayer(*args: Any, edit: bool = ..., query: bool = ..., addAttribute: str = ..., addLayer: str = ..., addObject: str = ..., allLayers: bool = ..., attribute: Multiuse[str] = ..., attributeKeyable: Queryable[str] = ..., clipId: int = ..., index: int = ..., keySiblings: bool = ..., layerId: int = ..., layerName: Queryable[str] = ..., mode: int = ..., mute: bool = ..., name: bool = ..., path: str = ..., removeAttribute: str = ..., removeLayer: bool = ..., removeObject: str = ..., resetSolo: bool = ..., setKeyframe: bool = ..., solo: bool = ..., zeroKeying: bool = ...) -> Union[str, bool]:
    """Time Editor clip layers commandstimeEditor, nle, layer
    Args:
        addAttribute (str?): Add given plug to a layer with a supplied layerId.  
                Properties: edit
        addLayer (str?): Add a new layer with a given name.  
                Properties: edit
        addObject (str?): Add given object with all its attributes in the clip to a layer with a supplied layerId.  
                Properties: edit
        allLayers (bool?): Return all layers given clip ID.  
                Properties: query
        attribute (Multiuse[str]?): The attribute path to key.  
                Properties: edit, multiuse
        attributeKeyable (Queryable[str]?): Return whether specified attribute is keyable.  
                Properties: query
        clipId (int?): ID of the clip this layer command operates on.  
                			In query mode, this flag can accept a value.  
                Properties: edit
        index (int?): Layer index, used when adding new layer at specific location in the stack.  
                Properties: edit
        keySiblings (bool?): If set to true, additional attributes might be keyed while keying to achieve desired result.  
                Properties: edit
        layerId (int?): Layer ID used in conjunction with other edit flags.  
                			In query mode, this flag can accept a value.  
                Properties: edit
        layerName (Queryable[str]?): Edit layer name.  
                In query mode, return the layer name given its layer ID and clip ID.  
                Properties: query, edit
        mode (int?): To control the playback speed of the clip by animation curve:  
              
                0. additive  
                1. additive override  
                2. override  
                3. override passthrough  
                Properties: edit
        mute (bool?): Mute/unmute a layer given its layer ID and clip ID.  
                Properties: edit
        name (bool?): Query the attribute name of a layer given its layer ID and clip ID.  
                Properties: query
        path (str?): Full path of a layer or a clip on which to operate. For example: composition1|track1|clip1|layer1; composition1|track1|group|track1|clip1.  
                			In query mode, this flag can accept a value.  
                Properties: edit
        removeAttribute (str?): Remove given plug from a layer with a supplied layerId.  
                Properties: edit
        removeLayer (bool?): Remove layer with an ID.  
                Properties: edit
        removeObject (str?): Remove given object with all its attributes in the clip to a layer with a supplied layerId.  
                Properties: edit
        resetSolo (bool?): Unsolo all soloed layers in a given clip ID.  
                Properties: edit
        setKeyframe (bool?): Set keyframe on specified attributes on specified layer of a clip.  
                Use -clipId to indicate the specified clip.  
                Use -layerId to indicate the specified layer of the clip.  
                Use -attribute to indicate the specified attributes (if no attribute flag is used, all attribute will be keyed).  
                Use -zeroKeying to indicate that zero offset from original animation should be keyed.  
                Properties: edit
        solo (bool?): Solo/unsolo a layer given its layers ID and clip ID.  
                Properties: edit
        zeroKeying (bool?): Indicate if the key to set should be zero offset from original animation.  
                Properties: edit

    Returns:
        str: Command result

    Example:
    """

def timeEditorClipOffset(*args: Any, edit: bool = ..., query: bool = ..., applyToAllRoots: bool = ..., clipId: Multiuse[int] = ..., matchClipId: int = ..., matchDstTime: int = ..., matchObj: str = ..., matchOffsetRot: bool = ..., matchOffsetTrans: bool = ..., matchPath: str = ..., matchRotOp: int = ..., matchSrcTime: int = ..., matchTransOp: int = ..., offsetTransform: bool = ..., path: Multiuse[str] = ..., resetMatch: int = ..., resetMatchPath: str = ..., rootObj: Queryable[Multiuse[str]] = ..., upVectorX: float = ..., upVectorY: float = ..., upVectorZ: float = ...) -> Union[bool, Multiuse[str]]:
    """This command is used to compute an offset to apply on a source clip in order to
    automatically align it to a destination clip at a specified match element.
    For this command to work, offset objects must be specified for the character.timeEditor, nle
    Args:
        applyToAllRoots (bool?): Apply root offsets to all roots in the population. However, if the root objects are specified by rootObj flag, this flag will be ignored.  
                Properties: create
        clipId (Multiuse[int]?): ID of the clip to be edited.  
                Properties: create, edit, multiuse
        matchClipId (int?): Specify the ID of a clip to match.  
                Properties: create
        matchDstTime (int?): Specify the time on target clip.  
                Properties: create
        matchObj (str?): Specify the object to match.  
                Properties: create
        matchOffsetRot (bool?): Get the rotation of the match offset matrix.  
                Properties: query
        matchOffsetTrans (bool?): Get the translation of the match offset matrix.  
                Properties: query
        matchPath (str?): Full path of the clip to match. For example: composition1|track1|Group|track2|clip1  
                Properties: create
        matchRotOp (int?): Specify the option for matching rotation.  
              
                0. full - All rotation components are matched  
                1. Y    - Y component is matched  
                2. none - No rotation matching  
                Properties: create
        matchSrcTime (int?): Specify the time on source clip.  
                Properties: create
        matchTransOp (int?): Specify the option for matching translation.  
              
                0. full - All translation components are matched  
                1. XZ   - X and Z components are matched  
                2. none - No translation matching  
                Properties: create
        offsetTransform (bool?): Create/get an offset for the specified clip.  
                Properties: create, query
        path (Multiuse[str]?): Full path of a clip to be edited. For example: composition1|track1|group; composition1|track1|group|track2|clip1.  
                			In query mode, this flag can accept a value.  
                Properties: create, edit, multiuse
        resetMatch (int?): Specify clip ID to remove offset.  
                Properties: create
        resetMatchPath (str?): Specify clip's full path to remove offset. For example: composition1|track1|Group|track2|clip1  
                Properties: create
        rootObj (Queryable[Multiuse[str]]?): Specify the root objects. If specified, this flag will take precedence over applyToAllRoots flag.  
                When used in query mode, returns list of roots defined for the relocator.  
                Properties: create, query, edit, multiuse
        upVectorX (float?): Specify the X coordinate of the up vector.  
                Properties: create
        upVectorY (float?): Specify the Y coordinate of the up vector.  
                Properties: create
        upVectorZ (float?): Specify the Z coordinate of the up vector.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def timeEditorComposition(*args: Any, edit: bool = ..., query: bool = ..., active: bool = ..., allCompositions: bool = ..., createTrack: bool = ..., delete: bool = ..., duplicateFrom: str = ..., rename: Tuple[str, str] = ..., tracksNode: bool = ...) -> Union[str, bool]:
    """Commands related to composition management inside Time Editor.timeEditor, nle
    Args:
        active (bool?): Query or edit the active composition.  
                Properties: query, edit
        allCompositions (bool?): Return all compositions inside Time Editor.  
                Properties: query
        createTrack (bool?): Create a default track when creating a new composition.  
                Properties: create
        delete (bool?): Delete the composition.  
                Properties: query, edit
        duplicateFrom (str?): Duplicate the composition.  
                Properties: create
        rename (Tuple[str, str]?): Rename the composition of the first name to the second name.  
                Properties: edit
        tracksNode (bool?): Query the tracks node of a composition.  
                Properties: query

    Returns:
        str: Return values currently not documented.

    Example:
    """

def timeEditorPanel(*args: Any, edit: bool = ..., query: bool = ..., activeClipEditMode: Queryable[int] = ..., activeTabRootClipId: bool = ..., activeTabTime: bool = ..., activeTabView: Queryable[int] = ..., autoFit: Queryable[str] = ..., autoFitTime: Queryable[str] = ..., control: bool = ..., defineTemplate: str = ..., displayActiveKeyTangents: str = ..., displayActiveKeys: str = ..., displayInfinities: str = ..., displayKeys: str = ..., displayTangents: str = ..., displayValues: str = ..., docTag: Queryable[str] = ..., exists: bool = ..., filter: Queryable[str] = ..., forceMainConnection: Queryable[str] = ..., groupIdForTabView: int = ..., highlightConnection: Queryable[str] = ..., keyingTarget: Queryable[int] = ..., layerId: int = ..., lockMainConnection: bool = ..., lookAt: str = ..., mainListConnection: Queryable[str] = ..., menu: Callable[..., Any] = ..., minClipWidth: Queryable[int] = ..., panel: Queryable[str] = ..., parent: Queryable[str] = ..., selectionConnection: Queryable[str] = ..., setToPrevClipEditMode: bool = ..., snapTime: Queryable[str] = ..., snapToClip: bool = ..., snapToFrame: bool = ..., snapTolerance: Queryable[int] = ..., snapValue: Queryable[str] = ..., stateString: bool = ..., tabView: int = ..., timeCursor: bool = ..., unParent: bool = ..., unlockMainConnection: bool = ..., updateMainConnection: bool = ..., useTemplate: str = ...) -> Union[str, int, bool]:
    """Time Editor - non-linear animation editor
    Args:
        activeClipEditMode (Queryable[int]?): Set the appropriate clip edit mode for the editor.  
              
                0. Default Mode  
                1. Trim Mode  
                2. Scale Mode  
                3. Loop Mode  
                4. Hold Mode  
                Properties: query, edit
        activeTabRootClipId (bool?): Get the clip id for which current active tab has been opened. In case of main tab, this will return -1  
                meaning there is no root clip.  
                Properties: query
        activeTabTime (bool?): Get current time displayed inside the active tab. This will be global time in case of the main tab and  
                local time for others.  
                Properties: query
        activeTabView (Queryable[int]?): Get/set the index of the tab widget's (active) visible tab. Note: the index is zero-based.  
                Properties: query, edit
        autoFit (Queryable[str]?): on | off | tgl  
                Auto fit-to-view.  
                Properties: query, edit
        autoFitTime (Queryable[str]?): on | off | tgl  
                Auto fit-to-view along the time axis, as well.  
                Properties: query, edit
        control (bool?): Query only. Returns the top level control for this editor.  
                Usually used for getting a parent to attach popup menus.  
                Caution: It is possible for an editor to exist without a  
                control. The query will return "NONE" if no control is present.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayActiveKeyTangents (str?): on | off | tgl  
                Display active key tangents in the editor.  
                Properties: edit
        displayActiveKeys (str?): on | off | tgl  
                Display active keys in the editor.  
                Properties: edit
        displayInfinities (str?): on | off | tgl  
                Display infinities in the editor.  
                Properties: edit
        displayKeys (str?): on | off | tgl  
                Display keyframes in the editor.  
                Properties: edit
        displayTangents (str?): on | off | tgl  
                Display tangents in the editor.  
                Properties: edit
        displayValues (str?): on | off | tgl  
                Display active keys and tangents values in the editor.  
                Properties: edit
        docTag (Queryable[str]?): Attaches a tag to the editor.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        filter (Queryable[str]?): Specifies the name of an itemFilter object to be used with this editor.  
                This filters the information coming onto the main list  
                of the editor.  
                Properties: create, query, edit
        forceMainConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will only  
                display items contained in the selectionConnection object. This is  
                a variant of the -mainListConnection flag in that it will force a  
                change even when the connection is locked. This flag is used to  
                reduce the overhead when using the -unlockMainConnection  
                , -mainListConnection, -lockMainConnection flags in immediate  
                succession.  
                Properties: create, query, edit
        groupIdForTabView (int?): Get the group clip id for the given tab view index.  
                To specify the tab index, this flag must appear before the -query flag.  
                      In query mode, this flag needs a value.  
                Properties: query
        highlightConnection (Queryable[str]?): Specifies the name of a selectionConnection object that  
                the editor will synchronize with its highlight list. Not all  
                editors have a highlight list. For those that do, it is a secondary  
                selection list.  
                Properties: create, query, edit
        keyingTarget (Queryable[int]?): Set keying target to specified clip ID.  
                If keying into layer, '-layer' flag must be used.  
                In query mode, the clip id is omitted, and the name of the keying target will be returned.  
                Properties: query, edit
        layerId (int?): Indicate layer ID of keying target.  
                Properties: edit
        lockMainConnection (bool?): Locks the current list of objects within the mainConnection,  
                so that only those objects are displayed within the editor.  
                Further changes to the original mainConnection are ignored.  
                Properties: create, edit
        lookAt (str?): all | selected | currentTime  
                FitView helpers.  
                Properties: edit
        mainListConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will use as its source of content. The editor will  
                only display items contained in the selectionConnection object.  
                Properties: create, query, edit
        menu (Callable[..., Any]?): Specify a script to be run when the editor  
                is created.  The function will be passed one string  
                argument which is the new editor's name.  
                Properties: create
        minClipWidth (Queryable[int]?): Set the minimum clip width.  
                Properties: query, edit
        panel (Queryable[str]?): Specifies the panel for this editor. By default if  
                an editor is created in the create callback of a scripted panel it  
                will belong to that panel. If an editor does not belong to a panel  
                it will be deleted when the window that it is in is deleted.  
                Properties: create, query
        parent (Queryable[str]?): Specifies the parent layout for this editor. This flag will only  
                have an effect if the editor is currently un-parented.  
                Properties: create, query, edit
        selectionConnection (Queryable[str]?): Specifies the name of a selectionConnection object that the  
                editor will synchronize with its own selection list. As the user  
                selects things in this editor, they will be selected in the  
                selectionConnection object. If the object undergoes changes, the  
                editor updates to show the changes.  
                Properties: create, query, edit
        setToPrevClipEditMode (bool?): Revert to previous clip edit mode.  
                Properties: edit
        snapTime (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in time.  
                Properties: query, edit
        snapToClip (bool?): Enable/Disable snap-to-clip option in Time Editor while manipulating and drag-and-drop clips.  
                When snapToClip is on all manipulated timing will land on a clip boundary if it is close to it.  
                Properties: query, edit
        snapToFrame (bool?): Enable/Disable snap-to-frame option in Time Editor while manipulating and drag-and-drop clips.  
                When snapToFrame is on all manipulated timing will land on an exact frame.  
                Properties: query, edit
        snapTolerance (Queryable[int]?): Set the tolerance value for snapping.  
                Properties: query, edit
        snapValue (Queryable[str]?): none | integer | keyframe  
                Keyframe move snap in values.  
                Properties: query, edit
        stateString (bool?): Query only flag. Returns the MEL command that will create an  
                editor to match the current editor state. The returned command string  
                uses the string variable $editorName in place of a specific name.  
                Properties: query
        tabView (int?): Create a tab view for the given group clip ID.  
                Properties: edit
        timeCursor (bool?): Activate the time cursor in Time Editor for scrubbing.  
                Properties: query, edit
        unParent (bool?): Specifies that the editor should be removed from its layout.  
                This cannot be used in query mode.  
                Properties: create, edit
        unlockMainConnection (bool?): Unlocks the mainConnection, effectively restoring the original  
                mainConnection (if it is still available), and dynamic updates.  
                Properties: create, edit
        updateMainConnection (bool?): Causes a locked mainConnection to be updated from the orginal  
                mainConnection, but preserves the lock state.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Command result

    Example:
    """

def timeEditorTracks(*args: Any, edit: bool = ..., query: bool = ..., activeClipWeight: Queryable[int] = ..., activeClipWeightId: Queryable[int] = ..., addTrack: int = ..., allClips: bool = ..., allTracks: bool = ..., allTracksRecursive: bool = ..., composition: bool = ..., path: str = ..., plugIndex: Queryable[int] = ..., removeTrack: Multiuse[int] = ..., removeTrackByPath: Multiuse[str] = ..., reorderTrack: Tuple[int, int] = ..., resetMute: bool = ..., resetSolo: bool = ..., selectedTracks: bool = ..., trackGhost: bool = ..., trackIndex: Queryable[int] = ..., trackMuted: bool = ..., trackName: Queryable[str] = ..., trackSolo: bool = ..., trackType: Queryable[int] = ...) -> Union[int, bool, str]:
    """Time Editor tracks commandstimeEditor, nle
    Args:
        activeClipWeight (Queryable[int]?): Get the clip weight at the specified time.  
                Properties: query
        activeClipWeightId (Queryable[int]?): Get the clip ID carrying the active clip weight at the specified time.  
                Properties: query
        addTrack (int?): Add new track at the track index specified. Indices are 0. based.  
                Specify -1 to add the track at the end.  
                Properties: edit
        allClips (bool?): Return a list of clip IDs under the specified track.  
                Properties: query
        allTracks (bool?): Return a list of strings for all the immediate tracks for the given tracks node in the format "tracksNode:trackIndex".  
                Properties: query
        allTracksRecursive (bool?): Return a list of strings for all the tracks for the given tracks node, or  
                return a list of strings for all tracks of all tracks nodes in the format "tracksNode:trackIndex".  
                If the given root tracks node is from a composition, this command returns the tracks under that composition, including the tracks within groups that is under the same composition.  
                Properties: query
        composition (bool?): Return the composition the specified track belongs to.  
                Properties: query
        path (str?): Full path of a track node or a track on which to operate. For example: composition1|track1|group; composition1|track1.  
                			In query mode, this flag can accept a value.  
                Properties: edit
        plugIndex (Queryable[int]?): Get the plug index of the specified track.  
                Properties: query, edit
        removeTrack (Multiuse[int]?): Remove track at given index. It is a multi-use flag.  
                Properties: edit, multiuse
        removeTrackByPath (Multiuse[str]?): Remove track at given path. It is a multi-use flag. For example: composition1|track1|group|track1;  
                Properties: edit, multiuse
        reorderTrack (Tuple[int, int]?): Move the track relative to other tracks. The first argument is the track index (0. based). The second argument can be a positive or negative number  
                to indicate the steps to move. Positive numbers move forward and negative numbers move backward.  
                Properties: edit
        resetMute (bool?): Reset all the muted tracks in the active composition.  
                Properties: create
        resetSolo (bool?): Reset the soloing of all tracks on the active composition.  
                Properties: create
        selectedTracks (bool?): Return a list of the indices for all the selected tracks for the given tracks node, or  
                return a list of strings for all selected tracks of all tracks nodes in the format "tracksNode:trackIndex".  
                Properties: query
        trackGhost (bool?): Ghost all clips under track.  
                Properties: query, edit
        trackIndex (Queryable[int]?): Specify the track index. This flag is used in conjunction with the other flags.  
                			In query mode, this flag can accept a value.  
                Properties: query, edit
        trackMuted (bool?): Return whether the track is muted.  
                Properties: query, edit
        trackName (Queryable[str]?): Display name of the track.  
                Properties: query, edit
        trackSolo (bool?): Return whether the track is soloed.  
                Properties: query, edit
        trackType (Queryable[int]?): Specify the track type. Can only be used together with -at/addTrack. Does not work by itself.  
                In query mode, return the integer corresponding to the track type.  
              
                 0. Animation Track (Default)  
                 1. Audio Track  
                Properties: query, edit

    Returns:
        int: In edit mode, return the newly created Track index.

    Example:
    """

def timeField(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., autoUnitWidth: Queryable[int] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editable: bool = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., enterCommand: Callable[..., Any] = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: Queryable[int] = ..., preventOverride: bool = ..., receiveFocusCommand: Callable[..., Any] = ..., statusBarMessage: str = ..., step: Queryable[int] = ..., useTemplate: str = ..., value: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, int, Tuple[float, float, float], bool, Callable[..., Any]]:
    """Create a field control that accepts only time values.
    An invisible slider is attached to the
    field and accessed by holding down the Ctrl modifier key while pressing
    one of the mouse buttons.  Dragging the invisible slider to the right
    with the middle mouse button increases the field value by the amount
    specified with theflag, while dragging to the left
    decreases the value by the same amount.  The left and right mouse
    buttons apply a factor of 0.1 and 10 to the step value.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        autoUnitWidth (Queryable[int]?): When this is non-zero the widget will automatically scale  
                based on the unit time settings (frame or timecode). The value  
                of autoUnitWidth specifies the number of digits that should be  
                able to be displayed as the frame number. So a value of 4 will  
                make sure frame number 8723 can be displayed.  
                When the value is zero the normal widget width will be used.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the field changes.  This command is  
                not invoked when the value changes via the -v/value flag.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command executed when dragging in the field.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editable (bool?): The edit state of the field.  By default, this flag is set  
                to true and the field value may be changed by typing into it.  If  
                false then the field cannot be changed interactively.  However,  
                the field text can be changed using the -v/value flag  
                regardless of the state of the -ed/editable flag.  
                Properties: create, query, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enterCommand (Callable[..., Any]?): Command executed when the keypad 'Enter' key is pressed.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (Queryable[int]?): Number of digits to the right of the decimal place.  
                Properties: create, query, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        receiveFocusCommand (Callable[..., Any]?): Command executed when the field receives focus.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[int]?): Increment for the invisible slider.   The field value  
                will change by this amount when the invisible slider is dragged.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[int]?): Value of the field.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def timeFieldGrp(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., adjustableColumn: int = ..., adjustableColumn2: int = ..., adjustableColumn3: int = ..., adjustableColumn4: int = ..., adjustableColumn5: int = ..., adjustableColumn6: int = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., columnAlign: Multiuse[Tuple[int, str]] = ..., columnAlign2: Tuple[str, str] = ..., columnAlign3: Tuple[str, str, str] = ..., columnAlign4: Tuple[str, str, str, str] = ..., columnAlign5: Tuple[str, str, str, str, str] = ..., columnAlign6: Tuple[str, str, str, str, str, str] = ..., columnAttach: Multiuse[Tuple[int, str, int]] = ..., columnAttach2: Tuple[str, str] = ..., columnAttach3: Tuple[str, str, str] = ..., columnAttach4: Tuple[str, str, str, str] = ..., columnAttach5: Tuple[str, str, str, str, str] = ..., columnAttach6: Tuple[str, str, str, str, str, str] = ..., columnOffset2: Tuple[int, int] = ..., columnOffset3: Tuple[int, int, int] = ..., columnOffset4: Tuple[int, int, int, int] = ..., columnOffset5: Tuple[int, int, int, int, int] = ..., columnOffset6: Tuple[int, int, int, int, int, int] = ..., columnWidth: Multiuse[Tuple[int, int]] = ..., columnWidth1: int = ..., columnWidth2: Tuple[int, int] = ..., columnWidth3: Tuple[int, int, int] = ..., columnWidth4: Tuple[int, int, int, int] = ..., columnWidth5: Tuple[int, int, int, int, int] = ..., columnWidth6: Tuple[int, int, int, int, int, int] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dragCommand: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enable1: bool = ..., enable2: bool = ..., enable3: bool = ..., enable4: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., extraLabel: Queryable[str] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfFields: int = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., precision: int = ..., preventOverride: bool = ..., rowAttach: Multiuse[Tuple[int, str, int]] = ..., statusBarMessage: str = ..., step: Queryable[int] = ..., useTemplate: str = ..., value: Queryable[Tuple[int, int, int, int]] = ..., value1: Queryable[int] = ..., value2: Queryable[int] = ..., value3: Queryable[int] = ..., value4: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Tuple[int, int, int, int], Callable[..., Any]]:
    """All of the group commands position their individual controls in columns
    starting at column 1.  The layout of each control (ie. column) can be
    customized using the, andflags.  By default, columns are left aligned
    with no offset and are 100 pixels wide.  Only one column in any group can
    be adjustable.This command creates a pre-packaged collection of label text and
    editable time fields.  The label text is optional and one to four
    time fields can be created.
    Args:
        adjustableColumn (int?): Specifies which column has an adjustable size that changes with the  
                sizing of the layout.  The column value is a 1. based index.  
                Passing 0 as argument turns off the previous adjustable column.  
                Properties: create, edit
        adjustableColumn2 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        adjustableColumn3 (int?): Specifies that the column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        adjustableColumn4 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        adjustableColumn5 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        adjustableColumn6 (int?): Specifies which column has an adjustable size that changes with  
                the size of the parent layout. Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command string executed when the value of any of the  
                fields changes.  
                Properties: create, edit
        columnAlign (Multiuse[Tuple[int, str]]?): Arguments are : column number, alignment type.  
                Possible alignments are: left | right | center.  
                Specifies alignment type for the specified column.  
                Properties: create, edit, multiuse
        columnAlign2 (Tuple[str, str]?): Sets the text alignment of both columns.  Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign3 (Tuple[str, str, str]?): Sets the text alignment for all three columns.  Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign4 (Tuple[str, str, str, str]?): Sets the text alignment for all four columns.  Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign5 (Tuple[str, str, str, str, str]?): Sets the text alignment for all five columns.  Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAlign6 (Tuple[str, str, str, str, str, str]?): Sets the text alignment for all six columns.  Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "center".  
                Properties: create, edit
        columnAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column number, attachment type, and offset.  
                Possible attachments are: left | right | both.  
                Specifies column attachment types and offets.  
                Properties: create, edit, multiuse
        columnAttach2 (Tuple[str, str]?): Sets the attachment type of both columns. Ignored if there are not  
                exactly two columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach3 (Tuple[str, str, str]?): Sets the attachment type for all three columns. Ignored if there are not  
                exactly three columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach4 (Tuple[str, str, str, str]?): Sets the attachment type for all four columns. Ignored if there are not  
                exactly four columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach5 (Tuple[str, str, str, str, str]?): Sets the attachment type for all five columns. Ignored if there are not  
                exactly five columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnAttach6 (Tuple[str, str, str, str, str, str]?): Sets the attachment type for all six columns. Ignored if there are not  
                exactly six columns. Valid values are "left", "right", and "both".  
                Properties: create, edit
        columnOffset2 (Tuple[int, int]?): This flag is used in conjunction with the -columnAttach2 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the two columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach2 flag.  Ignored if there are not exactly  
                two columns.  
                Properties: create, edit
        columnOffset3 (Tuple[int, int, int]?): This flag is used in conjunction with the -columnAttach3 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the three columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach3 flag.  Ignored if there are not exactly  
                three columns.  
                Properties: create, edit
        columnOffset4 (Tuple[int, int, int, int]?): This flag is used in conjunction with the -columnAttach4 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the four columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach4 flag.  Ignored if there are not exactly  
                four columns.  
                Properties: create, edit
        columnOffset5 (Tuple[int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach5 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the five columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach5 flag.  Ignored if there are not exactly  
                five columns.  
                Properties: create, edit
        columnOffset6 (Tuple[int, int, int, int, int, int]?): This flag is used in conjunction with the -columnAttach6 flag.  If that  
                flag is not used then this flag will be ignored.  It sets the offset for  
                the six columns.  The offsets applied are based on the attachments  
                specified with the -columnAttach6 flag.  Ignored if there are not exactly  
                six columns.  
                Properties: create, edit
        columnWidth (Multiuse[Tuple[int, int]]?): Arguments are : column number, column width.  
                Sets the width of the specified column where the first parameter specifies  
                the column (1 based index) and the second parameter specifies the width.  
                Properties: create, edit, multiuse
        columnWidth1 (int?): Sets the width of the first column. Ignored if there is not  
                exactly one column.  
                Properties: create, edit
        columnWidth2 (Tuple[int, int]?): Sets the column widths of both columns. Ignored if there are not  
                exactly two columns.  
                Properties: create, edit
        columnWidth3 (Tuple[int, int, int]?): Sets the column widths for all 3 columns. Ignored if there are not  
                exactly 3 columns.  
                Properties: create, edit
        columnWidth4 (Tuple[int, int, int, int]?): Sets the column widths for all 4 columns. Ignored if there are not  
                exactly 4 columns.  
                Properties: create, edit
        columnWidth5 (Tuple[int, int, int, int, int]?): Sets the column widths for all 5 columns. Ignored if there are not  
                exactly 5 columns.  
                Properties: create, edit
        columnWidth6 (Tuple[int, int, int, int, int, int]?): Sets the column widths for all 6 columns. Ignored if there are not  
                exactly 6 columns.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dragCommand (Callable[..., Any]?): Command string executed when dragging the invisible slider  
                in any of the fields.  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enable1 (bool?):   
                Properties: create, query, edit
        enable2 (bool?):   
                Properties: create, query, edit
        enable3 (bool?):   
                Properties: create, query, edit
        enable4 (bool?): Enable state for the respective field.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        extraLabel (Queryable[str]?): If present on creation this specifies that there will be  
                an extra label in the group.  Sets the string to be label text to  
                the right of fields.  
                Properties: create, query, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): If present on creation this specifies that there will be  
                a label to the left of the fields.  Sets the string to be the label  
                text.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfFields (int?): Set the number of fields on creation. One to four fields are  
                available.  The default is one field.  
                Properties: create
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        precision (int?): Set the number of digits to the right of the decimal.  
                Properties: create, edit
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        rowAttach (Multiuse[Tuple[int, str, int]]?): Arguments are : column, attachment type, offset.  
                Possible attachments are: top | bottom | both.  
                Specifies attachment types and offsets for the entire row.  
                Properties: create, edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        step (Queryable[int]?): Set the delta of invisioSlider delta , the invisioSlider  
                step is delta/10.0 in LMB , delta in MMB,delta*10.0 in RMB.  
                Default is 10.0  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        value (Queryable[Tuple[int, int, int, int]]?): Values for all fields.  
                Properties: create, query, edit
        value1 (Queryable[int]?):   
                Properties: create, query, edit
        value2 (Queryable[int]?):   
                Properties: create, query, edit
        value3 (Queryable[int]?):   
                Properties: create, query, edit
        value4 (Queryable[int]?): Value for the respective field.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def timePort(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., globalTime: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., snap: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates a simple time control widget.
    See also the "timeControl" command.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        globalTime (bool?): "true" means this widget controls and displays the global,  
                dependency graph time.  "false" means time changes here  
                do NOT affect the dependency graph. Query returns int.  
                Properties: create, query, edit
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        snap (bool?): "true" means this widget is constrained to having  
                values that are integers representing the current time unit..  
                "false" means the current time indicator is "free floating"  
                and not constrained.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Widget name

    Example:
    """

def timeRangeInfo(*, time: Multiuse[NullableRange[float]] = ...) -> None: ...
def timeSliderCustomDraw(arg0: int = ..., /, *, edit: bool = ..., query: bool = ..., color: Tuple[float, float, float, float] = ..., clearPrimitives: bool = ..., deregister: int = ..., height: int = ..., layer: int = ..., location: int = ..., priority: int = ..., registerAbove: str = ..., registerBelow: str = ..., registerOn: Tuple[str, int] = ..., setPrimitives: Tuple[str, float, float] = ..., visible: bool = ...) -> None: ...
def timeWarp(*args: str, edit: bool = ..., query: bool = ..., deleteFrame: int = ..., frame: Queryable[Multiuse[float]] = ..., g: bool = ..., interpType: Queryable[Tuple[int, str]] = ..., moveFrame: Queryable[Tuple[int, float]] = ...) -> Union[str, Multiuse[float], bool, Tuple[int, str], Tuple[int, float]]:
    """This command is used to create a time warp input to a set of animation curves.fcurve, animCurve, animation, timing
    Args:
        deleteFrame (int?): The flag value indicates the 0. based index of the warp frame to delete. This flag can only be used in edit mode.  
                Properties: edit
        frame (Queryable[Multiuse[float]]?): In create and edit mode, this flag can be used to specify warp frames added to the warp operation.  
                In query mode, this flag returns a list of the frame values where warping occurs. The moveFrame flag command can be used to query the associated warped values.  
                Properties: create, query, edit, multiuse
        g (bool?): In create mode, creates a global time warp node which impacts every animated object in the scene. In query mode, returns the global time warp node. Note: only one global time warp can exist in the scene.  
                Properties: create, query, edit
        interpType (Queryable[Tuple[int, str]]?): This flag can be used to set the interpolation type for a given span. Valid interpolation types are linear, easeIn and easeOut. When queried, it returns a string array of the interpolation types for the specified time warp.  
                Properties: create, query, edit
        moveFrame (Queryable[Tuple[int, float]]?): This flag can be used to move a singular warp frame. The first value specified indicates the 0. based index of the warp frame to move. The second value indicates the new warp frame value. This flag can only be used in edit and query mode. When queried, it returns an array of the warped frame values.  
                Properties: query, edit

    Returns:
        str: timeWarp name

    Example:
    """

def timer(*, endTimer: bool = ..., lapTime: bool = ..., name: str = ..., startTimer: bool = ...) -> bool:
    """Allow simple timing of scripts and commands. The resolution of this timer
    is at the level of your OS'sfunction.This command does not handle stacked calls. For
    example, this code below will give an incorrect answer on the
    secondcall.To do this use named timers:debug, timer
    Args:
        endTimer (bool?): Stop the timer and return the time elapsed since the timer was  
                started (in seconds). Once a timer is turned off it no longer exists,  
                though it can be recreated with a new start  
                Properties: create
        lapTime (bool?): Get the lap time of the timer (time elapsed since start in seconds).  
                Unlike the end flag this keeps the timer running.  
                Properties: create
        name (str?): Use a named timer for the operation. If this is omitted then the default  
                timer is assumed.  
                Properties: create
        startTimer (bool?): Start the timer.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def timerX(*, startTime: float = ...) -> float:
    """Used to calculate elapsed time. This command returns
    sub-second accurate time values. It is useful from scripts
    for timing the length of operations. Call this command
    before and after the operation you wish to time. On the
    first call, do not use any flags. It will return the start
    time. Save this value. After the operation, call this
    command a second time, and pass the saved start time using
    the -st flag. The elapsed time will be returned.
    Args:
        startTime (float?): When this flag is used, the command returns the elapsed time since the specified start time.  
                Properties: create

    Returns:
        float: This command returns a different value depending on
            the flag used. If no flag is used, then the start time
            is returned. If the "-st" flag is used, then it returns
            the elapsed time since the start time.

    Example:
    """

def toggle(*args: str, query: bool = ..., above: bool = ..., below: bool = ..., boundary: bool = ..., boundingBox: bool = ..., controlVertex: bool = ..., doNotWrite: bool = ..., editPoint: bool = ..., extent: bool = ..., facet: bool = ..., geometry: bool = ..., gl: bool = ..., highPrecisionNurbs: bool = ..., hull: bool = ..., latticePoint: bool = ..., latticeShape: bool = ..., localAxis: bool = ..., newCurve: bool = ..., newPolymesh: bool = ..., newSurface: bool = ..., normal: bool = ..., origin: bool = ..., point: bool = ..., pointDisplay: bool = ..., pointFacet: bool = ..., rotatePivot: bool = ..., scalePivot: bool = ..., selectHandle: bool = ..., state: bool = ..., surfaceFace: bool = ..., template: bool = ..., uvCoords: bool = ..., vertex: bool = ...) -> bool:
    """The toggle command is used to toggle the display of various
    object features for objects which have these components. For
    example, CV and edit point display may be toggled for those
    listed     NURB curves or surfaces.Note: This command is not undoable.
    Args:
        above (bool?): Toggle state for all objects above listed objects.  
                Properties: create
        below (bool?): Toggle state for all objects below listed objects.  
                Properties: create
        boundary (bool?): Toggle boundary display of listed mesh objects.  
                Properties: create, query
        boundingBox (bool?): Toggle or query the bounding box display of listed objects.  
                Properties: create, query
        controlVertex (bool?): Toggle CV display of listed curves and surfaces.  
                Properties: create, query
        doNotWrite (bool?): Toggle the "this should be written to the file" state.  
                Properties: create, query
        editPoint (bool?): Toggle edit point display of listed curves and surfaces.  
                Properties: create, query
        extent (bool?): Toggle display of extents of listed mesh objects.  
                Properties: create, query
        facet (bool?): For use with normal flag. Set the normal display style to facet display.  
                Properties: create, query
        geometry (bool?): Toggle geometry display of listed objects.  
                Properties: create, query
        gl (bool?): Toggle state for all objects  
                Properties: create
        highPrecisionNurbs (bool?): Toggle high precision display for Nurbs  
                Properties: create, query
        hull (bool?): Toggle hull display of listed curves and surfaces.  
                Properties: create, query
        latticePoint (bool?): Toggle point display of listed lattices  
                Properties: create, query
        latticeShape (bool?): Toggle display of listed lattices  
                Properties: create, query
        localAxis (bool?): Toggle local axis display of listed objects.  
                Properties: create, query
        newCurve (bool?): Set component display state of new curve objects  
                Properties: create, query
        newPolymesh (bool?): Set component display state of new polymesh objects  
                Properties: create, query
        newSurface (bool?): Set component display state of new surface objects  
                Properties: create, query
        normal (bool?): Toggle display of normals of listed surface and mesh objects.  
                Properties: create, query
        origin (bool?): Toggle origin display of listed surfaces.  
                Properties: create, query
        point (bool?): For use with normal flag. Set the normal display style to vertex display.  
                Properties: create, query
        pointDisplay (bool?): Toggle point display of listed surfaces.  
                Properties: create, query
        pointFacet (bool?): For use with normal flag. Set the normal display style to vertex and face display.  
                Properties: create, query
        rotatePivot (bool?): Toggle rotate pivot display of listed objects.  
                Properties: create, query
        scalePivot (bool?): Toggle scale pivot display of listed objects.  
                Properties: create, query
        selectHandle (bool?): Toggle select handle display of listed objects.  
                Properties: create, query
        state (bool?): Explicitly set the state to true or false instead of toggling the state.  
                Can not be queried.  
                Properties: create
        surfaceFace (bool?): Toggle surface face handle display of listed surfaces.  
                Properties: create, query
        template (bool?): Toggle template state of listed objects  
                Properties: create, query
        uvCoords (bool?): Toggle display uv coords of listed mesh objects.  
                Properties: create, query
        vertex (bool?): Toggle vertex display of listed mesh objects.  
                Properties: create, query

    Returns:
        bool: when in the query mode. none otherwise.

    Example:
    """

def toggleAxis(*, query: bool = ..., origin: bool = ..., view: bool = ...) -> bool:
    """Toggles the state of the display axis.Note: the display of the axis in the bottom left corner has
    been rendered obsolete by the headsUpDisplay command.
    Args:
        origin (bool?): Turns display of the axis at the origin of the ground plane  
                on or off.  
                Properties: create, query
        view (bool?): Turns display of the axis at the bottom left of each view  
                on or off. (Obsolete - refer to the headsUpDisplay command)  
                Properties: create, query

    Returns:
        bool: if in the query mode, otherwise none.

    Example:
    """

def toggleDisplacement(*args: str) -> bool:
    """This command toggles the displacement preview of the polygon.
    This command is NOT un-doable.
    Returns:
        bool:

    Example:
    """

def toggleWindowVisibility(arg0: str = ..., /) -> bool:
    """Toggle the visibility of a window. If no window is specified then
    the current window (most recently created) is used. See also
    thecommand'sflag.
    Returns:
        bool:

    Example:
    """

def tolerance(*, query: bool = ..., angular: Queryable[float] = ..., linear: Queryable[float] = ...) -> Union[bool, float]:
    """This command sets tolerances used by modelling operations
    that require a tolerance, such as surface fillet.
    Linear tolerance is also known as "positional" tolerance.
    Angular tolerance is also known as "tangential" tolerance.
    Args:
        angular (Queryable[float]?): Sets the angular, or "tangential" tolerance.  
                Properties: create, query
        linear (Queryable[float]?): Sets the linear, or "positonal" tolerance.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def toolBar(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowedArea: Queryable[Multiuse[str]] = ..., annotation: Queryable[str] = ..., area: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., content: Queryable[str] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., label: Queryable[str] = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, Multiuse[str], Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """Create a toolbar.
    Tool bars are movable panel that contains a set of controls.
    They are placed in the tool bar area around the central control in a main window.
    Tool bars can be moved inside their current area, moved into new areas and floated.
    Args:
        allowedArea (Queryable[Multiuse[str]]?): Areas where the dock control may be placed. Valid values are "top", "left", "bottom", "right" and "all".  The default is "all".  
                Properties: create, query, edit, multiuse
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        area (Queryable[str]?): The initial dock area for this dock control. Valid values are "top", "left", "bottom" and "right". This is a required flag.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        content (Queryable[str]?): The name of the control that is a content of this dock control. This is a required flag.  
                Properties: create, query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        label (Queryable[str]?): The label text.  The default label is the name of the control.  
                Properties: create, query, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def toolButton(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., allowMultipleTools: bool = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., changeCommand: Callable[..., Any] = ..., collection: str = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., doubleClickCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., imageOverlayLabel: Queryable[str] = ..., isObscured: bool = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., offCommand: Callable[..., Any] = ..., onCommand: Callable[..., Any] = ..., parent: Queryable[str] = ..., popupIndicatorVisible: bool = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., select: bool = ..., statusBarMessage: str = ..., style: str = ..., tool: Queryable[Multiuse[str]] = ..., toolArray: bool = ..., toolCount: bool = ..., toolImage1: Queryable[Multiuse[Tuple[str, str]]] = ..., toolImage2: Queryable[Multiuse[Tuple[str, str]]] = ..., toolImage3: Queryable[Multiuse[Tuple[str, str]]] = ..., useTemplate: str = ..., version: Queryable[str] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], int, Multiuse[str], Multiuse[Tuple[str, str]], Callable[..., Any]]:
    """This command creates a toolButton that is added to the most recently
    created tool button collection unless theflag is
    used. It also attaches the named tool, activating it when this control
    is selected.By default, this control only handles one tool at a time.  Using
    theflag to associate a new tool will simply override the
    previous attached tool.  If you use theflag then you will be able to attach more than one tool with this
    control.  Only one tool will be current within the control.  To access
    the other tools press the right mouse button to display a popup menu
    containing all the tools associated with this control.  If you set
    theflag then a small arrow will be
    drawn on the control to indicate that additional tools are attached to
    this control.
    Args:
        allowMultipleTools (bool?): Indicates whether this control will allow you to attach more  
                than one tool.  By default, this control accepts only one tool.  
                You can add multiple tools by setting this flag to true.  
                Only one tool will be current and displayed at any one time.  
                Use the pop up menu attached to the right mouse button to view  
                all the tools.  
                Properties: create, query
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        changeCommand (Callable[..., Any]?): Command executed when the control's state is changed.  
                Note that this flag should not be used in conjunction with  
                onCommand and offCommand. That is, one should either use  
                changeCommand and test the state of the control from inside  
                the callback, or use onCommand and offCommand as separate  
                callbacks.  
                Properties: create, edit
        collection (str?): To explicitly add a tool button to a tool collection.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        doubleClickCommand (Callable[..., Any]?): Command executed when the control is double clicked.  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        image1 (Queryable[str]?):   
                Properties: create, query, edit
        image2 (Queryable[str]?):   
                Properties: create, query, edit
        image3 (Queryable[str]?): This control supports three images.  The image that best fits the  
                current size of the control will be displayed.  This flag  
                applies the image to the current tool.  
                Properties: create, query, edit
        imageOverlayLabel (Queryable[str]?): A short string (5 characters) label that will be displayed  
                on top of the icon.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        offCommand (Callable[..., Any]?): Command executed when the control is turned off.  
                Properties: create, edit
        onCommand (Callable[..., Any]?): Command executed when the control is turned on.  
                Properties: create, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupIndicatorVisible (bool?): Edit this flag to set the visibility of the popup tool indicator.  
                The indicator is a simple image that appears in the top right corner  
                of the button when more that one tool is associated with this control.  
                This flag is queryable and true by default.  
                Properties: create, query, edit
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        select (bool?): Will set this button as the selected one.  This flag also  
                queries the select state of the control.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        style (str?): The draw style of the control.  Valid styles are "iconOnly",  
                "textOnly", "iconAndTextHorizontal" and "iconAndTextVertical".  
                Properties: create, edit
        tool (Queryable[Multiuse[str]]?): The name of the tool to be attached to the button.  If the  
                tool specified is already attached to this button then it will  
                be selected.  Query this flag to return the current tool.  This  
                flag may be specified more than once to attach more than one  
                tool.  
                Properties: create, query, edit, multiuse
        toolArray (bool?): This query only flag returns the names of all the tools attached  
                to the toolButton control.  
                Properties: query
        toolCount (bool?): This query only flag return the number of tools attached to the  
                toolButton control.  
                Properties: query
        toolImage1 (Queryable[Multiuse[Tuple[str, str]]]?):   
                Properties: create, query, edit, multiuse
        toolImage2 (Queryable[Multiuse[Tuple[str, str]]]?):   
                Properties: create, query, edit, multiuse
        toolImage3 (Queryable[Multiuse[Tuple[str, str]]]?): This control supports three images.  The image that best fits the  
                current size of the control will be displayed.  This flag  
                applies the image to the specified tool.  The first argument is the  
                name of the tool and the second is the name of the image.  When  
                queried an array of tool icon pairs is returned.  
                Properties: create, query, edit, multiuse
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        version (Queryable[str]?): Specify the version that this tool button feature was introduced.  
                The argument should be given as a string of the version number  
                (e.g. "2013", "2014"). Currently only accepts major version  
                numbers (e.g. 2013 Ext 1, or 2013.5 should be given as "2014").  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the toolButton created.

    Example:
    """

def toolCollection(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., collectionItemArray: bool = ..., defineTemplate: str = ..., exists: bool = ..., gl: bool = ..., numberOfCollectionItems: bool = ..., parent: str = ..., select: Queryable[str] = ..., useTemplate: str = ...) -> Union[str, bool]:
    """This command creates a tool button collection. Collections are parented
    to the current default layout if no parent is specified with
    the -p/parent flag.  As children of the layout they will be deleted when
    the layout is deleted. Collections may also span more than one window
    if the -gl/global flag is used. In this case the collection has no parent
    and must be explicitly deleted with the 'deleteUI' command when it is no
    longer wanted.
    Args:
        collectionItemArray (bool?): Returns a string list giving the long names of all the items  
                in this collection.  
                Properties: query
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        gl (bool?): Set the collection to have no parent layout.  This flag must be  
                specified when the collection is created and can not be queried  
                or edited.  Consequently, global collections must be explicitly  
                deleted.  
                Properties: create, query
        numberOfCollectionItems (bool?): Returns the number of items that are in this collection.  
                Properties: query
        parent (str?): Specify the parent to associate the collection with.  The collection  
                will be deleted along with the parent.  This flag must be specified  
                when the collection is created and can not be edited.  
                Properties: create
        select (Queryable[str]?): Select the specified collection item.  If queried will return  
                the name of the currently selected collection item.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the toolCollection created.

    Example:
    """

def toolDropped(arg0: str = ..., /) -> bool:
    """This command builds and executes the commands necessary to recreate the
    specified tool button.  It is invoked when a tool is dropped on the shelf.
    Returns:
        bool:

    Example:
    """

def toolHasOptions(arg0: str = ..., /) -> bool:
    """This command queries a tool to see if it has options. If it does,
    it returns true. Otherwise it returns false.
    Returns:
        bool: True if the queried tool has options, otherwise false.

    Example:
    """

def toolPropertyWindow(*, edit: bool = ..., query: bool = ..., field: Queryable[str] = ..., helpButton: Queryable[str] = ..., icon: Queryable[str] = ..., inMainWindow: bool = ..., location: Queryable[str] = ..., noviceMode: bool = ..., resetButton: Queryable[str] = ..., restore: bool = ..., selectCommand: Queryable[str] = ..., showCommand: Queryable[str] = ...) -> Union[bool, str]:
    """End users should only call this command as 1. a query (in the
    custom tool property sheet code) or 2. with no arguments
    to create the default tool property sheet.  The more complex
    uses of it are internal.
    Args:
        field (Queryable[str]?): Sets/returns the name of the text field used to store the  
                tool name in the property sheet.  
                Properties: query, edit
        helpButton (Queryable[str]?): Sets/returns the name of the button used to show help  
                on the tool in the property sheet.  
                Properties: query, edit
        icon (Queryable[str]?): Sets/returns the name of the static picture object (used to display the  
                tool icon in the property sheet).  
                Properties: query, edit
        inMainWindow (bool?): Specify true if you want the tool settings to appear in the main  
                window rather than a separate window.  
                Properties: create
        location (Queryable[str]?): Sets/returns the location of the current tool property sheet, or an empty  
                string if there is none.  
                Properties: query, edit
        noviceMode (bool?): Sets/returns the 'novice mode' flag.(unused at the moment)  
                Properties: query, edit
        resetButton (Queryable[str]?): Sets/returns the name of the button used to restore the  
                tool settings in the property sheet.  
                Properties: query, edit
        restore (bool?): Reopens the tool settings window.  
                This flag can be used with the flag inMainWindow for the fall back location if the tool settings can't be restored.  
                Properties: create
        selectCommand (Queryable[str]?): Sets/returns the property sheet's select command.  
                Properties: query, edit
        showCommand (Queryable[str]?): Sets/returns the property sheet's display command.  
                Properties: query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def torus(*args: str, edit: bool = ..., query: bool = ..., axis: Queryable[Tuple[float, float, float]] = ..., caching: bool = ..., degree: Queryable[int] = ..., endSweep: Queryable[float] = ..., heightRatio: Queryable[float] = ..., minorSweep: Queryable[float] = ..., nodeState: Queryable[int] = ..., pivot: Queryable[Tuple[float, float, float]] = ..., radius: Queryable[float] = ..., sections: Queryable[int] = ..., spans: Queryable[int] = ..., startSweep: Queryable[float] = ..., tolerance: Queryable[float] = ..., useTolerance: bool = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ..., polygon: int = ...) -> Union[List[str], Tuple[float, float, float], bool, int, float]:
    """The torus command creates a new torus and/or a
    dependency node that creates one, and returns their names.
    Args:
        axis (Queryable[Tuple[float, float, float]]?): The primitive's axis  
                Properties: create, query, edit
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        degree (Queryable[int]?): The degree of the resulting surface:  
                1. linear,  
                3. cubic  
                Default: 3  
                Properties: create, query, edit
        endSweep (Queryable[float]?): The angle at which to end the surface of revolution.  
                Default is 2Pi radians, or 360 degrees.  
                Default: 6.2831853  
                Properties: create, query, edit
        heightRatio (Queryable[float]?): Ratio of "height" to "width"  
                Default: 2.0  
                Properties: create, query, edit
        minorSweep (Queryable[float]?): The sweep angle for the minor circle in the torus  
                Default: 6.2831853  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        pivot (Queryable[Tuple[float, float, float]]?): The primitive's pivot point  
                Properties: create, query, edit
        radius (Queryable[float]?): The radius of the object  
                Default: 1.0  
                Properties: create, query, edit
        sections (Queryable[int]?): The number of sections determines the resolution of the surface in the sweep direction.  
                Used only if useTolerance is false.  
                Default: 8  
                Properties: create, query, edit
        spans (Queryable[int]?): The number of spans determines the resolution of the surface in the opposite direction.  
                Default: 1  
                Properties: create, query, edit
        startSweep (Queryable[float]?): The angle at which to start the surface of revolution  
                Default: 0  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to build the surface.  
                Used only if useTolerance is true  
                Default: 0.01  
                Properties: create, query, edit
        useTolerance (bool?): Use the specified tolerance to determine resolution.  
                Otherwise number of sections will be used.  
                Default: false  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        polygon (int?): The value of this argument controls the type of the object  
                created by this operation  
              
                 0. nurbs surface  
                 1. polygon (use nurbsToPolygonsPref to set the parameters for the conversion)  
                 2. subdivision surface (use nurbsToSubdivPref to set the parameters for the conversion)  
                 3. Bezier surface  
                 4. subdivision surface solid (use nurbsToSubdivPref to set the  
                parameters for the conversion)  
                Properties: create

    Returns:
        List[str]: Object name and node name

    Example:
    """

def track(arg0: str = ..., /, *, down: float = ..., left: float = ..., right: float = ..., upDistance01: float = ..., upDistance02: float = ...) -> bool:
    """The track command translates a camera horizontally or vertically
    in the world space. The viewing-direction and up-direction of the
    camera are not altered. There is no translation in the viewing
    direction.The track command can be applied to either a perspective or an
    orthographic camera.When no camera name is supplied, this command is applied to the
    camera in the active view.
    Args:
        down (float?): Set the amount of down translation in unit distance.  
                Properties: create
        left (float?): Set the amount of left translation in unit distance.  
                Properties: create
        right (float?): Set the amount of right translation in unit distance.  
                Properties: create
        upDistance01 (float?): Set the amount of up translation in unit distance. This is equivalent  
                to using up/upDistance02 flag.  
                Properties: create
        upDistance02 (float?): Set the amount of up translation in unit distance. This is equivalent  
                to using u/upDistance01 flag.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def trackCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., toolName: Queryable[str] = ..., trackGeometry: bool = ..., trackScale: Queryable[float] = ...) -> Union[str, bool, float]:
    """This command can be used to create a track context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query
        trackGeometry (bool?): Toggle whether the drag should try to track geometry. The  
                context will compute a track plane by intersecting the initial  
                press with geometry or the live object.  
                Properties: create, query, edit
        trackScale (Queryable[float]?): Specify the distance to the track plane from the camera. The  
                smaller the scale the slower the drag.  
                Properties: create, query, edit

    Returns:
        str: The name of the context

    Example:
    """

def transferAttributes(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., colorBorders: int = ..., components: bool = ..., deformerTools: bool = ..., exclusive: Queryable[str] = ..., flipUVs: int = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., matchChoice: int = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., sampleSpace: int = ..., searchMethod: int = ..., searchScaleX: float = ..., searchScaleY: float = ..., searchScaleZ: float = ..., selectedComponents: bool = ..., sourceColorSet: str = ..., sourceUvSet: str = ..., sourceUvSpace: str = ..., split: bool = ..., targetColorSet: str = ..., targetUvSet: str = ..., targetUvSpace: str = ..., transferColors: int = ..., transferNormals: int = ..., transferPositions: int = ..., transferUVs: int = ..., useComponentTags: bool = ...) -> Union[str, bool, Multiuse[str]]:
    """Samples the attributes of a source surface (first argument) and
    transfers them onto a target surface (second argument).
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        colorBorders (int?): Controls whether color borders are preserved when transferring color  
                data. If this is non-zero, any color borders will be mapped onto the nearest  
                edge on the target geometry. 0 means any color borders will be  
                smoothly blended onto the vertices of the target geometry.  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        flipUVs (int?): Controls how sampled UV data is flipped before being transferred  
                to the target. 0 means no flipping; 1 means UV data is flipped in the  
                U direction; 2 means UV data is flipped in the V direction; and 3 means  
                it is flipped in both directions. In conjunction with mirroring, this  
                allows the creation of symmetric UV mappings (e.g. the left hand side of the  
                character on one side of the UV map, the right hand side on the other).  
                Properties: create, edit
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        matchChoice (int?): When using topological component matching, selects between possible matches.  
                If the meshes involved in the transfer operation have symmetries in their  
                topologies, there may be more than one possible topological match.  
                Maya scores the possible matches (by comparing the shapes of the meshes)  
                and assigns them an index, starting at zero.  
                Match zero, the default, is considered the best, but in the event that Maya  
                chooses the wrong one, changing this value will allow the user to explore the  
                other matches.  
                Properties: create, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        sampleSpace (int?): Selects which space the attribute transfer is performed in.  
                0 is world space, 1 is model space, 4 is component-based, 5 is topology-based. The default is world space.  
                Properties: create, edit
        searchMethod (int?): Specifies which search method to use when correlating points.  
                0 is closest along normal, 3 is closest to point. The default is closest to point.  
                Properties: create, edit
        searchScaleX (float?): Specifies an optional scale that should be applied to the x-axis  
                of the target model before transferring data. A value of 1.0 (the  
                default) means no scaling; a value of -1.0 would indicate mirroring  
                along the x-axis.  
                Properties: create, edit
        searchScaleY (float?): Specifies an optional scale that should be applied to the y-axis  
                of the target model before transferring data. A value of 1.0 (the  
                default) means no scaling; a value of -1.0 would indicate mirroring  
                along the y-axis.  
                Properties: create, edit
        searchScaleZ (float?): Specifies an optional scale that should be applied to the z-axis  
                of the target model before transferring data. A value of 1.0 (the  
                default) means no scaling; a value of -1.0 would indicate mirroring  
                along the z-axis.  
                Properties: create, edit
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        sourceColorSet (str?): Specifies the name of a single color set on the source surface(s) that  
                should be transferred to the target. This value is only used when  
                the operation is configured to transfer a single color set (see the  
                transferColors flag).  
                Properties: create
        sourceUvSet (str?): Specifies the name of a single UV set on the source surface(s) that  
                should be transferred to the target. This value is only used when  
                the operation is configured to transfer a single UV set (see the  
                transferUVs flag).  
                Properties: create
        sourceUvSpace (str?): Specifies the name of the UV set on the source surface(s) that  
                should be used as the transfer space. This value is only used when  
                the operation is configured to transfer attributes in UV space.  
                Properties: create
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        targetColorSet (str?): Specifies the name of a single color set on the target surface that  
                should be receive the sampled color data. This value is only used when  
                the operation is configured to transfer a single color set (see the  
                transferColors flag).  
                Properties: create
        targetUvSet (str?): Specifies the name of a single UV set on the target surface that  
                should be receive the sampled UV data. This value is only used when  
                the operation is configured to transfer a single UV set (see the  
                transferUVs flag).  
                Properties: create
        targetUvSpace (str?): Specifies the name of the UV set on the target surface( that  
                should be used as the transfer space. This value is only used when  
                the operation is configured to transfer attributes in UV space.  
                Properties: create
        transferColors (int?): Controls color set transfer. 0 means no color sets are transferred,  
                1 means that a single color set (specified by sourceColorSet and targetColorSet)  
                is transferred, and 2 means that all color sets are transferred.  
                Properties: create, edit
        transferNormals (int?): A non-zero value indicates vertex normals should be sampled  
                and written into user normals on the target surface.  
                Properties: create, edit
        transferPositions (int?): A non-zero value indicates vertex position should be sampled,  
                causing the target surface to "wrap" to the source surface(s).  
                Properties: create, edit
        transferUVs (int?): Controls UV set transfer. 0 means no UV sets are transferred,  
                1 means that a single UV set (specified by sourceUVSet and targetUVSet)  
                is transferred, and 2 means that all UV sets are transferred.  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create

    Returns:
        str: The node name.

    Example:
    """

def transferShadingSets(*args: str, edit: bool = ..., query: bool = ..., sampleSpace: Queryable[int] = ..., searchMethod: Queryable[int] = ...) -> Union[bool, int]:
    """Command to transfer shading set assignments between meshes.
    The last mesh in the list receives the shading assignments from the other meshes.shading, sets
    Args:
        sampleSpace (Queryable[int]?): Selects which space the attribute transfer is performed in.  
                0 is world space, 1 is model space. The default is world space.  
                Properties: create, query, edit
        searchMethod (Queryable[int]?): Specifies which search method to use when correlating points.  
                0 is closest along normal, 3 is closest to point. The default is closest to point.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def transformCompare(*args: str, root: bool = ...) -> int:
    """Compares two transforms passed as arguments. If they are the same,
    returns 0. If they are different, returns 1. If no transforms are
    specified in the command line, then the transforms from the active
    list are used.
    Args:
        root (bool?): Compare the root only, rather than the entire hierarchy below the roots.  
                Properties: create

    Returns:
        int: 0 if successful, 1 if transform1 and transform2 are not determined to be equal.

    Example:
    """

def transformLimits(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., enableRotationX: Queryable[Tuple[bool, bool]] = ..., enableRotationY: Queryable[Tuple[bool, bool]] = ..., enableRotationZ: Queryable[Tuple[bool, bool]] = ..., enableScaleX: Queryable[Tuple[bool, bool]] = ..., enableScaleY: Queryable[Tuple[bool, bool]] = ..., enableScaleZ: Queryable[Tuple[bool, bool]] = ..., enableTranslationX: Queryable[Tuple[bool, bool]] = ..., enableTranslationY: Queryable[Tuple[bool, bool]] = ..., enableTranslationZ: Queryable[Tuple[bool, bool]] = ..., remove: bool = ..., rotationX: Queryable[Tuple[float, float]] = ..., rotationY: Queryable[Tuple[float, float]] = ..., rotationZ: Queryable[Tuple[float, float]] = ..., scaleX: Queryable[Tuple[float, float]] = ..., scaleY: Queryable[Tuple[float, float]] = ..., scaleZ: Queryable[Tuple[float, float]] = ..., translationX: Queryable[Tuple[float, float]] = ..., translationY: Queryable[Tuple[float, float]] = ..., translationZ: Queryable[Tuple[float, float]] = ...) -> Union[bool, Tuple[bool, bool], Tuple[float, float]]:
    """The transformLimits command allows us to set, edit, or query
    the limits of the transformation that can be applied to objects.We can also turn any limits off which may have been previously set.
    When an object is first created, all the transformation limits are off
    by default.Transformation limits allow us to control how much an object can
    be transformed. This is most useful for joints, although it can be
    used any place we would like to limit the movement of an object.Default values are:( -1, 1) for translation,
    ( -1, 1) for scaling, and
    (-45,45) for rotation.
    Args:
        enableRotationX (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper x-rotation limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableRotationY (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper y-rotation limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableRotationZ (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper z-rotation limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableScaleX (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper x-scale limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableScaleY (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper y-scale limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableScaleZ (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper z-scale limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableTranslationX (Queryable[Tuple[bool, bool]]?): enable/disable the  ower and upper x-translation limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableTranslationY (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper y-translation limits  
                When queried, it returns boolean boolean  
                Properties: query
        enableTranslationZ (Queryable[Tuple[bool, bool]]?): enable/disable the lower and upper z-translation limits  
                When queried, it returns boolean boolean  
                Properties: query
        remove (bool?): turn all the limits off and reset them to their default values  
                Properties: create
        rotationX (Queryable[Tuple[float, float]]?): set the lower and upper x-rotation limits  
                When queried, it returns angle angle  
                Properties: query
        rotationY (Queryable[Tuple[float, float]]?): set the lower and upper y-rotation limits  
                When queried, it returns angle angle  
                Properties: query
        rotationZ (Queryable[Tuple[float, float]]?): set the lower and upper z-rotation limits  
                When queried, it returns angle angle  
                Properties: query
        scaleX (Queryable[Tuple[float, float]]?): set the lower and upper x-scale limits  
                When queried, it returns float float  
                Properties: query
        scaleY (Queryable[Tuple[float, float]]?): set the lower and upper y-scale limits  
                When queried, it returns float float  
                Properties: query
        scaleZ (Queryable[Tuple[float, float]]?): set the lower and upper z-scale limits  
                When queried, it returns float float  
                Properties: query
        translationX (Queryable[Tuple[float, float]]?): set the lower and upper x-translation limits  
                When queried, it returns linear linear  
                Properties: query
        translationY (Queryable[Tuple[float, float]]?): set the lower and upper y-translation limits  
                When queried, it returns linear linear  
                Properties: query
        translationZ (Queryable[Tuple[float, float]]?): set the lower and upper z-translation limits  
                When queried, it returns linear linear  
                Properties: query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def translator(arg0: str = ..., /, *, query: bool = ..., defaultFileRule: bool = ..., defaultOptions: Queryable[str] = ..., extension: bool = ..., fileCompression: Queryable[str] = ..., filter: bool = ..., list: bool = ..., loaded: bool = ..., objectType: bool = ..., optionsScript: bool = ..., readSupport: bool = ..., writeSupport: bool = ...) -> Union[bool, str]:
    """Set or query parameters associated with the file translators specified
    in as the argument.
    Args:
        defaultFileRule (bool?): Returns the default file rule value, can return "" as well  
                Properties: query
        defaultOptions (Queryable[str]?): Return/set a string of default options used by this translator.  
                Properties: query
        extension (bool?): Returns the default file extension for this translator.  
                Properties: query
        fileCompression (Queryable[str]?): Specifies the compression action to take when a file is saved.  
                Possible values are "compressed", "uncompressed" "asCompressed".  
                Properties: query
        filter (bool?): Returns the filter string used for this translator.  
                Properties: query
        list (bool?): Return a string array of all the translators that are loaded.  
                Properties: query
        loaded (bool?): Returns true if the given translator is currently loaded.  
                Properties: query
        objectType (bool?): This flag is obsolete. This will now return the same results as  
                defaultFileRule going forward.  
                Properties: query
        optionsScript (bool?): Query the name of the options script to use to post the user  
                options UI. When this script is invoked it will expect the name of the  
                parent layout in which the options will be displayed as well as the name  
                of the callback to be invoked once the apply button has been depressed  
                in the options area.  
                Properties: query
        readSupport (bool?): Returns true if this translator supports read operations.  
                Properties: query
        writeSupport (bool?): Returns true if this translator supports write operations.  
                Properties: query

    Returns:
        bool: or string array depending upon which flags are specified.

    Example:
    """

def treeLister(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addFavorite: Multiuse[str] = ..., addItem: Multiuse[Tuple[str, str, Callable[..., Any]]] = ..., addVnnItem: Multiuse[Tuple[str, str, str, str]] = ..., annotation: Queryable[str] = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., clearContents: bool = ..., collapsePath: Multiuse[str] = ..., defineTemplate: str = ..., displayName: Queryable[str] = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., executeItem: str = ..., exists: bool = ..., expandPath: Multiuse[str] = ..., expandToDepth: int = ..., favoritesCallback: Callable[..., Any] = ..., favoritesList: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., isObscured: bool = ..., itemScript: str = ..., manage: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., refreshCommand: Queryable[Callable[..., Any]] = ..., removeFavorite: Multiuse[str] = ..., removeItem: Multiuse[str] = ..., resultsPathUnderCursor: bool = ..., selectPath: Multiuse[str] = ..., setDisplayName: Multiuse[Tuple[str, str]] = ..., statusBarMessage: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., vnnString: bool = ..., width: Queryable[int] = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command creates/edits/queries the tree lister control.
    The optional argument is the name of the control.
    Args:
        addFavorite (Multiuse[str]?): Add an item path to the favorites folder.  The item path does not have to actually be in the tree.  
                Properties: create, edit, multiuse
        addItem (Multiuse[Tuple[str, str, Callable[..., Any]]]?): Add an item to the control.  The arguments are item-path,icon path,command  
                where item-path is the path from the root of the tree to the item's name  
                icon path is the icon displayed in the results list  
                command is the script which is executed when the item is LMB clicked  
                Properties: create, edit, multiuse
        addVnnItem (Multiuse[Tuple[str, str, str, str]]?): Add a VNN (Virtual Node Network) item to the control.  The arguments are:  
                item-path, icon-path, vnn-string, vnn-action.  
                Where item-path is the path from the root of the tree to the item's name,  
                icon-path is the icon displayed in the results list,  
                vnn-string is used for drag data when MMB dragging the item  
                and vnn-action is the script which is executed when the item is LMB clicked.  
                The vnn-string should be comprised of: 'VNN runtime,VNN library,VNN node',  
                where the VNN library can contain sub-libraries, using / to separate.  
                Properties: create, edit, multiuse
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        clearContents (bool?): Clears the contents of the control.  
                Properties: edit
        collapsePath (Multiuse[str]?): Collapse a path in the tree.  
                Properties: edit, multiuse
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayName (Queryable[str]?): Query the display name of a given item.  
                Properties: query
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        executeItem (str?): Execute the command associated with an item.  
                Properties: edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        expandPath (Multiuse[str]?): Expand a path in the tree.  
                Properties: edit, multiuse
        expandToDepth (int?): Expand the tree to the given depth.  
                Properties: edit
        favoritesCallback (Callable[..., Any]?): This script is called whenever a favorite is added or removed.  
                It is passed two arguments: The item's path and a boolean indicating if it  
                is being added to favorites (True) or removed (False).  
                Properties: create, edit
        favoritesList (bool?): Returns the list of favorite items.  
                Properties: query
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        itemScript (str?): Returns the language and script command of the passed item path as a  
                two-element list, the first element is the string "MEL" or "Python" and  
                the second is the command script. Note that items with Python callable  
                commands will be returned as strings.  
                      In query mode, this flag needs a value.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        refreshCommand (Queryable[Callable[..., Any]]?): Command executed when the refresh button is pressed.  Note: by default the  
                refresh button is hidden and will be shown automatically when this command  
                script is attached.  
                Properties: create, query, edit
        removeFavorite (Multiuse[str]?): Remove an item from favorites.  Accepts the full favorite path or the tail of the full path.  
                Properties: edit, multiuse
        removeItem (Multiuse[str]?): Remove an item path.  
                Properties: edit, multiuse
        resultsPathUnderCursor (bool?): Returns the path to the result (right-pane) item under the mouse cursor.  
                Returns an empty string if there is no such item.  
                Properties: query
        selectPath (Multiuse[str]?): Select a path in the tree.  
                Properties: edit, multiuse
        setDisplayName (Multiuse[Tuple[str, str]]?): Edit the displayed name of a given item.  
                Properties: edit, multiuse
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        vnnString (bool?): Returns the VNN (Virtual Node Network) string of the passed item path.  
                Properties: query
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The name of the created control.

    Example:
    """

def treeView(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., addItem: Multiuse[Tuple[str, str]] = ..., allowDragAndDrop: bool = ..., allowHiddenParents: bool = ..., allowMultiSelection: bool = ..., allowReparenting: bool = ..., annotation: Queryable[str] = ..., attachButtonRight: int = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., borderHighlite: Tuple[str, bool] = ..., borderHighliteColor: Tuple[str, float, float, float] = ..., buttonErase: Queryable[Multiuse[Tuple[str, bool]]] = ..., buttonState: Multiuse[Tuple[str, int, str]] = ..., buttonStyle: Multiuse[Tuple[str, int, str]] = ..., buttonTextIcon: Multiuse[Tuple[str, int, str]] = ..., buttonTooltip: Multiuse[Tuple[str, int, str]] = ..., buttonTransparencyColor: Multiuse[Tuple[str, int, float, float, float]] = ..., buttonTransparencyOverride: Multiuse[Tuple[str, int, bool]] = ..., buttonVisible: Multiuse[Tuple[str, int, bool]] = ..., children: str = ..., clearSelection: bool = ..., contextMenuCommand: Callable[..., Any] = ..., defineTemplate: str = ..., displayLabel: Multiuse[Tuple[str, str]] = ..., displayLabelSuffix: Multiuse[Tuple[str, str]] = ..., docTag: Queryable[str] = ..., dragAndDropCommand: Callable[..., Any] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., editLabelCommand: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableButton: Multiuse[Tuple[str, int, int]] = ..., enableKeyboardFocus: bool = ..., enableKeys: bool = ..., enableLabel: Tuple[str, int] = ..., exists: bool = ..., expandCollapseCommand: Callable[..., Any] = ..., expandItem: Tuple[str, bool] = ..., flatButton: Queryable[int] = ..., font: Queryable[Tuple[str, str]] = ..., fontFace: Tuple[str, int] = ..., fullPathName: bool = ..., height: Queryable[int] = ..., hideButtons: bool = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlite: Tuple[str, bool] = ..., highliteColor: Tuple[str, float, float, float] = ..., ignoreButtonClick: Multiuse[Tuple[str, int, int]] = ..., image: Multiuse[Tuple[str, int, str]] = ..., insertItem: Multiuse[Tuple[str, str, int]] = ..., isItemExpanded: str = ..., isLeaf: str = ..., isObscured: bool = ..., item: str = ..., itemAnnotation: Queryable[Tuple[str, str]] = ..., itemDblClickCommand: Callable[..., Any] = ..., itemDblClickCommand2: Callable[..., Any] = ..., itemExists: str = ..., itemIndex: str = ..., itemParent: str = ..., itemRenamedCommand: Callable[..., Any] = ..., itemSelected: str = ..., itemVisible: Queryable[Tuple[str, bool]] = ..., labelBackgroundColor: Tuple[str, float, float, float] = ..., manage: bool = ..., noBackground: bool = ..., numberOfButtons: int = ..., numberOfPopupMenus: bool = ..., ornament: Tuple[str, int, int, int] = ..., ornamentColor: Tuple[str, float, float, float] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., pressCommand: Multiuse[Tuple[int, Callable[..., Any]]] = ..., preventOverride: bool = ..., removeAll: bool = ..., removeItem: str = ..., reverseTreeOrder: bool = ..., rightPressCommand: Multiuse[Tuple[int, Callable[..., Any]]] = ..., select: Tuple[str, int] = ..., selectCommand: Callable[..., Any] = ..., selectItem: Queryable[Tuple[str, bool]] = ..., selectionChangedCommand: Callable[..., Any] = ..., selectionColor: Queryable[Tuple[str, float, float, float]] = ..., showItem: str = ..., statusBarMessage: str = ..., textColor: Tuple[str, float, float, float] = ..., useTemplate: str = ..., verticalScrollPosition: Queryable[int] = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ...) -> Union[str, bool, Tuple[float, float, float], Multiuse[Tuple[str, bool]], int, Tuple[str, str], Tuple[str, bool], Tuple[str, float, float, float], Callable[..., Any]]:
    """This command creates a custom control.
    Args:
        addItem (Multiuse[Tuple[str, str]]?): Adds a tree view item to the tree view.  
                First argument specifies the item's name, second argument specifies the item's parent (use an empty string to have it at the top level of the tree)  
                Properties: create, edit, multiuse
        allowDragAndDrop (bool?): Allow the user to perform drag and drop of treeView items.  If enabled,  
                re-ordering / re-parenting operations can be perfomed with the middle mouse button.  
                This flag takes precendence over other drag and drop related flags.  
                Defaults to true.  
                Properties: create, query, edit
        allowHiddenParents (bool?): If not cleared(default), the treeView will make parent nodes of visible nodes automatically visible  
                Properties: create, query, edit
        allowMultiSelection (bool?): Specify multi or single selection mode.  
                Allow the user to perform multiple selection by holding  
                ctrl or shift key while selecting items of treeView items.  
                Defaults to true.  
                Properties: create, query, edit
        allowReparenting (bool?): Allow the user to reparent items in the tree view using the middle  
                mouse button. Defaults to true. If false, user can still reorder items  
                within a group using the middle mouse button.  
                Properties: create, query, edit
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        attachButtonRight (int?): Sets tree view item's buttons to appear on the right or left.  
                Argument specifies if they are to be attached to the right, if it is set to false they will attach on the left.  
                Properties: create, edit
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        borderHighlite (Tuple[str, bool]?): Sets an item's border as highlit or not.  
                First Argument specifies item, second argument specifies on or off.  
                Properties: create, edit
        borderHighliteColor (Tuple[str, float, float, float]?): Sets the color an item's border highlite will turn when highlite is enabled.  
                first parameter specifies layer  
                three float values specify RGB values, between 0 and 1.  
                Properties: create, edit
        buttonErase (Queryable[Multiuse[Tuple[str, bool]]]?): If buttonErase was set true , then even if the button of the treeView item  is set invisible , the treeView will still erase the buttonRect of this treeView item with background .  
                First argument is the item name, second argument is whether buttonErase was set true or false  
                Properties: create, query, edit, multiuse
        buttonState (Multiuse[Tuple[str, int, str]]?): Sets the state of a button.  
                First argument specifies the layer, second argument specifies which button, third argument specifies the state  
                Possible states:  
                "buttonUp" - button is up  
                "buttonDown" - button is down  
                "buttonThirdState" - button is in state three (used by the "3StateButton" button style)  
                Properties: create, edit, multiuse
        buttonStyle (Multiuse[Tuple[str, int, str]]?): Sets the type of button, used to indicate possible states and if the button is reset upon release.  
                First argument specifies the layer, second argument specifies which button, third argument specifies the type of button  
                Possible button types:  
                "pushButton" - two possible states, button is reset to up upon release  
                "2StateButton" - two possible states, button changes state on click  
                "3StateButton" - three button states, button changes state on click  
                Properties: create, edit, multiuse
        buttonTextIcon (Multiuse[Tuple[str, int, str]]?): Sets a one letter text to use as the icon to use for a specific button on a specific item.  
                First argument specifies the item, second argument specifies the button, third argument specifies the icon text.  
                Properties: create, edit, multiuse
        buttonTooltip (Multiuse[Tuple[str, int, str]]?): Sets a tooltip for specific button on a specific item.  
                First argument specifies the item, second argument specifies the button, third argument specifies the tooltip.  
                Properties: create, edit, multiuse
        buttonTransparencyColor (Multiuse[Tuple[str, int, float, float, float]]?): Sets the background color of a button that will be used if buttonTransparencyOverride is enabled.  
                First argument specifies item, second argument specifies button,  
                three floats specify RGB values, between 0 and 1.  
                Properties: create, edit, multiuse
        buttonTransparencyOverride (Multiuse[Tuple[str, int, bool]]?): Sets a button's background as being overridden or not.  
                First argument specifies item, second argument specifies button, third argument specifies overridden or not.  
                Properties: create, edit, multiuse
        buttonVisible (Multiuse[Tuple[str, int, bool]]?): Sets a button as visible or not.  
                First Argument specifies item.  
                Second Argument specifies a button.  
                Third Argument specifies visible or not.  
                Properties: create, multiuse
        children (str?): Query the children of an item. If the argument is null, all items will be returned.  
                      In query mode, this flag needs a value.  
                Properties: query
        clearSelection (bool?): Clears all selected items.  
                Properties: create, edit
        contextMenuCommand (Callable[..., Any]?): Set the callback function to be invoked just before any attached context  
                menu is shown. This can be used as a replacement to, or in addition to the  
                postMenuCommand flag on the popupMenu command. The function should accept  
                a string which will be the item that was clicked on (empty if no item was hit).  
                The function should return true if the menu should be shown, false otherwise.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        displayLabel (Multiuse[Tuple[str, str]]?): Set a label for the item that is different than the  
                string that identifies the item. This label will be used in the  
                display of the item. The first parameter specifies  
                the item, the second specifies the display label.  
                Properties: create, edit, multiuse
        displayLabelSuffix (Multiuse[Tuple[str, str]]?): Set a suffix for the display label for the item. This suffix will  
                not be shown when renaming the item in the tree view.  
                Properties: create, edit, multiuse
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragAndDropCommand (Callable[..., Any]?): Sets the callback function to be invoked upon drag and drop of layers.  
                the callback function should take as parameters:  
                - a string array of the dropped items  
                - a string array of the items previous parents  
                - an integer array of the items previous indexes  
                - a string for the item(s) new parent  
                - an integer array for the item's new indexes  
                - a string for the item that now comes before the dropped items  
                - a string for the item that now comes after the dropped items  
                Properties: create, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        editLabelCommand (Callable[..., Any]?): Set the callback function to be invoked when the user changes  
                the name of an item by double clicking it in the UI. The callback should  
                accept two string arguments: the item name and the new name. The item  
                name refers to the name of the item and not the display label. The callback  
                function should return a string. An empty string indicates that the rename  
                operation was invalid and the control should revert to the original name.  
                If the rename operation is valid the callback should return a string that  
                identifies the item, possibly different from the new display name entered  
                by the user.  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableButton (Multiuse[Tuple[str, int, int]]?): Sets a specific button on a specific item to being usable or not.  
                First argument specifies the item, second argument specifies the button, third argument specifies on or off.  
                Properties: create, edit, multiuse
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        enableKeys (bool?): By default the treeview does not accept input from the keyboard.  By enabling keyboard support  
                The treeview will support up/down navigation using the up/down arrow keys.  
                Properties: edit
        enableLabel (Tuple[str, int]?): enables or disables the label of a tree view item from being displayed. The first parameter specifies  
                the item, the second specifies on or off.  
                Properties: create, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        expandCollapseCommand (Callable[..., Any]?): Set the callback function to be invoked upon hitting the expand/collapse button.  
                The function should take as parameters:  
                - a string for the item for which the expand/collapse button was hit  
                - an integer for the state of expansion  
                Properties: create, edit
        expandItem (Tuple[str, bool]?): Expands or collapses an item's children.  
                First argument specifies the item, second argument specifies expanded or collapsed.  
                Properties: create, edit
        flatButton (Queryable[int]?): Type of flat button to use.  
                Properties: create, query, edit
        font (Queryable[Tuple[str, str]]?): The first parameter specifies the item string for  
                the TtreeViewNode in the TtreeNodeMap.  
                The second string specifies the font for the text.  
                Valid values are  
                "boldLabelFont", "smallBoldLabelFont", "tinyBoldLabelFont",  
                "plainLabelFont", "smallPlainLabelFont", "obliqueLabelFont",  
                "smallObliqueLabelFont", "fixedWidthFont" and "smallFixedWidthFont".  
                Properties: create, query, edit
        fontFace (Tuple[str, int]?): Sets the font face used for the specified item's text:  
                0 for normal,  
                1 for bold,  
                2 for italic.  
                Properties: create, edit
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        hideButtons (bool?): Hides the buttons for an item in the tree view. Can only be used when  
                adding the item to the tree with the "addItem" flag. Space for the buttons  
                is left to make sure items still line up correctly under their parent.  
                Properties: create, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        highlite (Tuple[str, bool]?): Sets an item as highlit. Highliting is shown by outlining the item.  
                First parameter specifies the item, the second specifies the highliting  
                or not.  
                Properties: create, edit
        highliteColor (Tuple[str, float, float, float]?): Sets the color an item's highlite will turn when highlite is enabled.  
                first parameter specifies layer  
                three float values specify RGB values, between 0 and 1.  
                Properties: create, edit
        ignoreButtonClick (Multiuse[Tuple[str, int, int]]?): Sets a specific button on a specific item to ignore the button clicks  
                First argument specifies the item ,second argument specifies the button, third argument specifies on or off  
                Properties: create, edit, multiuse
        image (Multiuse[Tuple[str, int, str]]?): Sets an image to use as the icon for the button.  
                First argument specifies the item, second argument specifies the button, third argument specifies the image.  
                Properties: create, edit, multiuse
        insertItem (Multiuse[Tuple[str, str, int]]?): Create and insert a tree view item to the tree view.  
                First argument specifies the item's name, second argument specifies the item's parent (use an empty string to have it at the top level of the tree), third argument is the child's index position in the children list.  An index less than or equal to 0 inserts as the first child, greater than or equal to the number of children inserts as last child.  
                Properties: create, edit, multiuse
        isItemExpanded (str?): Is the item in the tree view expanded.  
                      In query mode, this flag needs a value.  
                Properties: query
        isLeaf (str?): Query whether an item is a leaf.  
                      In query mode, this flag needs a value.  
                Properties: query
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        item (str?): Specify the item to query. Used with the flag "selectionColor" and "itemAnnotation".  
                      In query mode, this flag needs a value.  
                Properties: query
        itemAnnotation (Queryable[Tuple[str, str]]?): Annotate the specified item with an extra string value.  
                When used for query, this flag has no argument and needs to be used with the  
                flag "item".  
                Properties: create, query, edit
        itemDblClickCommand (Callable[..., Any]?): Set the callback function to be invoked when an item in the tree has been  
                double clicked. The callback should accept one string, the display label of the  
                item that was double clicked. If this callback is defined, it supersedes  
                the normal item renaming behavior.  
                Properties: create, edit
        itemDblClickCommand2 (Callable[..., Any]?): Set the callback function to be invoked when an item in the tree has been  
                double clicked. This callback is similar to itemDblClickCommand(idc), but it accepts two strings:  
                the name and the display label of the item that was double clicked. If this callback is defined,  
                it supersedes the normal item renaming behavior  
                Properties: create, edit
        itemExists (str?): Queries the existence of the specified Tree View item.  
                      In query mode, this flag needs a value.  
                Properties: create, query
        itemIndex (str?): Get the index for the specified item in the list of children of the item's  
                parent. Index is 0. based.  
                      In query mode, this flag needs a value.  
                Properties: create, query
        itemParent (str?): If the specified item is a child, it returns the parent item. If the specified item is not a child it returns nothing.  
                      In query mode, this flag needs a value.  
                Properties: create, query
        itemRenamedCommand (Callable[..., Any]?): Set the callback function to be invoked when an item in the tree has been  
                renamed. This occurs if there is a successful return of the command attached  
                by "editLabelCommand" or unconditionally if there is no editLabelCommand.  
                The callback should accept two strings, the old name and the new name of the  
                item that was renamed.  
                Properties: create, edit
        itemSelected (str?): Queries the item is currently selected or not.  
                      In query mode, this flag needs a value.  
                Properties: query
        itemVisible (Queryable[Tuple[str, bool]]?): Control the given item's visibility.  
                Properties: create, query, edit
        labelBackgroundColor (Tuple[str, float, float, float]?): Set the background color for text label for a particular item  
                in the tree. The first parameter specifies layer.  
                Set (-1.0, -1.0, -1.0) to restore the background  
                to the default of "transparent"  
                Properties: create, edit
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfButtons (int?): Specifies the number of buttons for items in the tree.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        ornament (Tuple[str, int, int, int]?): Sets an item as having an ornament (a small colored circle), its on/off state, if it should have a dot, and its size.  
                First Argument specifies item,  
                second argument specifies on or off,  
                third argument specifies dotted or not,  
                fourth argument specifies radius (in pixels).  
                Properties: create, edit
        ornamentColor (Tuple[str, float, float, float]?): Sets the color an ornament will be draw with for the specified layer.  
                Properties: create, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        pressCommand (Multiuse[Tuple[int, Callable[..., Any]]]?): Sets the callback function to be invoked upon clicking a treeView button.  
                First argument specifies which treeView button.  
                Second argument specifies the callback function to be executed  
                the callback function should take as parameters:  
                - a string for the clicked button's item  
                - an int for the clicked button's state  
                Properties: create, edit, multiuse
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        removeAll (bool?): Removes all items from the tree view.  
                Properties: create, edit
        removeItem (str?): Removes a tree view item from the tree view. If this item has children items, all children items are removed.  
                First argument specifies the item's name.  
                Properties: create, edit
        reverseTreeOrder (bool?): Controls the order the tree will be drawn in (reversed if true).  
                Properties: create, edit
        rightPressCommand (Multiuse[Tuple[int, Callable[..., Any]]]?): Sets the callback function to be invoked upon right clicking a treeView button.  
                First argument specifies which treeView button.  
                Second argument specifies the callback function to be executed  
                the callback function should take as parameters:  
                - a string for the clicked button's item  
                - an int for the clicked button's state  
                Properties: create, edit, multiuse
        select (Tuple[str, int]?): Set selection on an element. The first parameter specifies the item, the second specifies on or off.  
                Properties: create, edit
        selectCommand (Callable[..., Any]?): Set the callback function to be invoked when an item is selected or deselected  
                in the tree. The function should accept one string argument and  
                one integer argument: the item name and the select state respectively. If the  
                function returns true, the select/deselect is considered valid and will  
                occur normally, otherwise it will be disallowed.  
                name and  
                Properties: create, edit
        selectItem (Queryable[Tuple[str, bool]]?): Sets an item's selected state.  
                first argument specifies the item, second argument specifies selection status.  
                When used for query without arguments, return all selected items in the treeview.  
                Properties: create, query, edit
        selectionChangedCommand (Callable[..., Any]?): Set the callback function to be invoked when a complete selection operation  
                triggered by the user has occurred successfully. The callback is invoked if  
                the "selectCommand" callback has returned a non-empty value (or always there  
                is no "selectCommand" callback). This differs from selectCommand in that a  
                simple selection replacement will generate two callbacks with "selectCommand"  
                (one for deselect of the old item and one for select of the new), whereas  
                "selectionChangedCommand" will only be invoked once, after the selection is  
                complete. The callback is not passed any parameters and does not need to  
                return any value (i.e. It is simply a notification mechanism).  
                Properties: create, edit
        selectionColor (Queryable[Tuple[str, float, float, float]]?): Sets the color an item will turn to indicate that it is selected.  
                first parameter specifies the item  
                three float values specify RGB values, between 0 and 1.  
                When used for query, this flag has no argument and needs to be used with the  
                flag "item". It returns the color an item will become if it is selected.  
                Properties: create, query, edit
        showItem (str?): Show the  item. Scroll the list as necessary so that item is visible.  
                Properties: create, edit
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        textColor (Tuple[str, float, float, float]?): Sets the label's text color for the specified layer.  
                first argument specifies layer.  
                three float values specify RGB values, between 0 and 1.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        verticalScrollPosition (Queryable[int]?): The position of the vertical scrollbar.  
                Properties: create, query, edit
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit

    Returns:
        str: The full name of the control.

    Example:
    """

def trim(*args: str, edit: bool = ..., query: bool = ..., caching: bool = ..., locatorU: Queryable[Multiuse[float]] = ..., locatorV: Queryable[Multiuse[float]] = ..., nodeState: Queryable[int] = ..., selected: Queryable[int] = ..., shrink: bool = ..., tolerance: Queryable[float] = ..., constructionHistory: bool = ..., name: str = ..., object: bool = ...) -> Union[List[str], bool, Multiuse[float], int, float]:
    """This command trims a surface to its curves on surface by first
    splitting the surface and then selecting which regions to keep
    or discard.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        locatorU (Queryable[Multiuse[float]]?): u parameter value to position a locator on the surface.  
                Default: 0.5  
                Properties: create, query, edit, multiuse
        locatorV (Queryable[Multiuse[float]]?): v parameter value to position a locator on the surface.  
                Default: 0.5  
                Properties: create, query, edit, multiuse
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        selected (Queryable[int]?): Specify whether to keep or discard selected regions.  
                Default: 0  
                Properties: create, query, edit
        shrink (bool?): If true, shrink underlying surface to outer boundaries of trimmed surface.  
                Default: false  
                Properties: create, query, edit
        tolerance (Queryable[float]?): The tolerance with which to trim.  
                Default: 0.001  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        object (bool?): Create the result, or just the dependency node.  
                Properties: create

    Returns:
        List[str]: Object name and node name.

    Example:
    """

def trimCtx(*args: Any, **kwargs: Any) -> None: ...
def truncateFluidCache(*args: str) -> bool:
    """This command sets the end time of a fluid cache to the current time.
    If the current time is less than the end time of the cache,
    the cache is truncated so that only the portion of the cache up
    to and including the current time is preserved.fluid
    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def truncateHairCache(*args: str) -> bool:
    """This command sets the end time of a hair cache to the current time.
    If the current time is less than the end time of the cache,
    the cache is truncated so that only the portion of the cache up
    to and including the current time is preserved.truncate, hair, cache
    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def tumble(arg0: str = ..., /, *, azimuthAngle: float = ..., elevationAngle: float = ..., localTumble: int = ..., pivotPoint: Tuple[float, float, float] = ..., rotationAngles: Tuple[float, float] = ...) -> bool:
    """The tumble command revolves the camera(s) by varying the azimuth
    and elevation angles in the perspective window. When both the
    azimuth and the elevation angles are supplied on the command line,
    the camera is firstly tumbled for the azimuth angle, then tumbled
    for the elevation angle.When no camera name is supplied, this command is applied to the
    camera in the active view.The camera's rotate pivot will override a specified pivot point if
    the rotate pivot is not at the camera's eye point.
    Args:
        azimuthAngle (float?): Degrees to change the azimuth angle.  
                Properties: create
        elevationAngle (float?): Degrees to change the elevation angle.  
                Properties: create
        localTumble (int?): Describes what point the camera will tumble around:  
                0 for the camera's tumble pivot,  
                1 for the camera's center of interest, and  
                2 for the camera's local axis, offset by its tumble pivot.  
                Properties: create
        pivotPoint (Tuple[float, float, float]?): Three dimensional point used as the pivot point in the world  
                space.  
                Properties: create
        rotationAngles (Tuple[float, float]?): Two values in degrees to change the azimuth and elevation  
                angles.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def tumbleCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., autoOrthoConstrain: bool = ..., autoSetPivot: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., localTumble: Queryable[int] = ..., name: str = ..., objectTumble: bool = ..., orthoLock: bool = ..., orthoStep: Queryable[float] = ..., toolName: Queryable[str] = ..., tumbleScale: Queryable[float] = ...) -> Union[str, bool, int, float]:
    """This command can be used to create, edit, or query a tumble
    context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        autoOrthoConstrain (bool?): Automatically constrain horizontal and vertical rotations when  
                the camera is orthographic. The shift key can be used to  
                unconstrain the rotation.  
                Properties: create, query, edit
        autoSetPivot (bool?): Automatically set the camera pivot to the selection or tool effect region  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        localTumble (Queryable[int]?): Describes what point the camera will tumble around:  
              
                0 for the camera's tumble pivot  
                1 for the camera's center of interest  
                2 for the camera's local axis, offset by its tumble pivot  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        objectTumble (bool?): Make the camera tumble around the selected object, if true.  
                Properties: create, query, edit
        orthoLock (bool?): Orthographic cameras cannot be tumbled while orthoLock is on.  
                Properties: create, query, edit
        orthoStep (Queryable[float]?): Specify the angular step in degrees for orthographic  
                rotation. If camera is orthographic and autoOrthoConstrain is  
                toggled on the rotation will be stepped by this amount.  
                Properties: create, query, edit
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query
        tumbleScale (Queryable[float]?): Set the rotation speed. A tumble scale of 1.0 will result in  
                in 40 degrees of rotation per 100 pixels of cursor drag.  
                Properties: create, query, edit

    Returns:
        str: The name of the context

    Example:
    """

def turbulence(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., frequency: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., noiseLevel: Queryable[int] = ..., noiseRatio: Queryable[float] = ..., perVertex: bool = ..., phase: Queryable[float] = ..., phaseX: Queryable[float] = ..., phaseY: Queryable[float] = ..., phaseZ: Queryable[float] = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, int, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A turbulence field causes irregularities (also called 'noise' or
    'jitter') in the motion of affected objects.Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        frequency (Queryable[float]?): Frequency of turbulence field. This determines how often  
                motion is disrupted.  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        noiseLevel (Queryable[int]?): If the noiseLevel parameter is greater than zero, the field  
                will do multiple lookups in the table.  Each additional lookup is  
                weighted using noiseRatio (which see).  The noiseLevel is the  
                number of additional lookups, so if noiseLevel is 0, there is just  
                one lookup.  A value of 0 (the default) corresponds to the way  
                the field behaved prior to Maya 3.0.  
                Properties: query, edit
        noiseRatio (Queryable[float]?): If noiseLevel is greater than zero, then noiseRatio is  
                the relative magnitude for each consecutive noise evaluation.  
                These are cumulative: for example, if noiseRatio is 0.5, then  
                the first evaluation is weighted 0.5, the second 0.25, and so on.  
                Has no effect if noiseLevel is zero.  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        phase (Queryable[float]?): Phase shift of turbulence field. This influences the direction  
                of the disruption.  This flag is obsolete and is retained only  
                for backward compatibility.  It is replaced by -phaseX, -phaseY, and  
                -phaseZ.  Setting -phase is identical to setting -phaseZ (the  
                phase shift was always in the Z dimension).  
                Properties: query, edit
        phaseX (Queryable[float]?): X component of phase shift of turbulence field. This influences  
                the direction of the disruption.  
                Properties: query, edit
        phaseY (Queryable[float]?): Y component of phase shift of turbulence field. This influences  
                the direction of the disruption.  
                Properties: query, edit
        phaseZ (Queryable[float]?): Z component of phase shift of turbulence field. This influences  
                the direction of the disruption.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def twoPointArcCtx(*args: Any, edit: bool = ..., query: bool = ..., degree: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., spans: Queryable[int] = ...) -> Union[str, int]:
    """The twoPointArcCtx command creates a new context for creating two point circular arcs
    Args:
        degree (Queryable[int]?): Valid values are 1 or 3. Default degree 3.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        spans (Queryable[int]?): Default is 4.  
                Properties: create, query, edit

    Returns:
        str: Name of the new context

    Example:
    """

def ubercam(arg0: str = ..., /) -> str:
    """Use this command to create a "ubercam" with equivalent behavior
    to all cameras used by shots in the sequencer.sequencer, shot, camera
    Returns:
        str: Ubercam name

    Example:
    """

def uiTemplate(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., defineTemplate: str = ..., exists: bool = ..., useTemplate: str = ...) -> str:
    """This command creates a new command template object. Template objects can
    hold default flag arguments for multiple UI commands. The command arguments
    are specified with the individual commands using the -defineTemplate
    flag and the desired flags and arguments.  See also
    Args:
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: The name of the uiTemplate created.

    Example:
    """

def unapplyOverride() -> None: ...
def unassignInputDevice(*args: Any, query: bool = ..., clutch: str = ..., device: str = ...) -> bool:
    """This command deletes all command strings associated with this
    device.
    Args:
        clutch (str?): Only delete command attachments with this clutch.  
                Properties: create
        device (str?): Specifies the device to work on.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def undo() -> bool:
    """Takes the most recent command from the undo list and undoes it.
    Returns:
        bool:

    Example:
    """

def undoInfo(*, query: bool = ..., chunkName: Queryable[str] = ..., closeChunk: bool = ..., infinity: bool = ..., length: Queryable[int] = ..., openChunk: bool = ..., printQueue: bool = ..., printRedoQueue: bool = ..., redoName: Queryable[str] = ..., redoQueueEmpty: bool = ..., state: bool = ..., stateWithoutFlush: bool = ..., undoName: Queryable[str] = ..., undoQueueEmpty: bool = ...) -> Union[str, int, bool]:
    """This command controls the undo/redo parameters.In query mode, if invoked without flags (other than the query flag), this
    command will return the number of items currently on the undo queue.
    Args:
        chunkName (Queryable[str]?): Sets the name used to identify a chunk for undo/redo  
                purposes when opening a chunk.  
                Properties: create, query
        closeChunk (bool?): Closes the chunk that was opened earlier by openChunk.  
                Once close chunk is called, all undoable operations in the chunk  
                will undo as a single undo operation.  
                Use with CAUTION!! Improper use of this command can leave the  
                undo queue in a bad state.  
                Properties: create
        infinity (bool?): Set the queue length to infinity.  
                Properties: create, query
        length (Queryable[int]?): Specifies the maximum number of items in the undo queue.  
                The infinity flag overrides this one.  
                Properties: create, query
        openChunk (bool?): Opens a chunk so that all undoable operations after this call  
                will fall into the newly opened chunk, until close chunk is called.  
                Once close chunk is called, all undoable operations in the chunk  
                will undo as a single undo operation.  
                Use with CAUTION!! Improper use of this command can leave the  
                undo queue in a bad state.  
                Properties: create
        printQueue (bool?): Prints to the Script Editor the contents of the undo queue.  
                Properties: query
        printRedoQueue (bool?): Prints to the Script Editor the contents of the redo queue.  
                Properties: query
        redoName (Queryable[str]?): Returns what will be redone (if anything)  
                Properties: query
        redoQueueEmpty (bool?): Return true if the redo queue is empty. Return false if  
                there is at least one command in the queue to be redone.  
                Properties: query
        state (bool?): Turns undo/redo on or off.  
                Properties: create, query
        stateWithoutFlush (bool?): Turns undo/redo on or off without flushing the queue. Use with CAUTION!!  
                Note that if you  perform destructive operations while stateWithoutFlush is  
                disabled, and you then enable it again, subsequent undo operations that try  
                to go past the  destructive operations may be unstable since undo will  
                not be able to properly reconstruct the former state of the scene.  
                Properties: create, query
        undoName (Queryable[str]?): Returns what will be undone (if anything)  
                Properties: query
        undoQueueEmpty (bool?): Return true if the undo queue is empty. Return false if  
                there is at least one command in the queue to be undone.  
                Properties: query

    Returns:
        str: If querying undoName or redoName
        int: If querying state, infinity, or length

    Example:
    """

def unfold(*args: str, applyToShell: bool = ..., areaWeight: float = ..., globalBlend: float = ..., globalMethodBlend: float = ..., iterations: int = ..., optimizeAxis: int = ..., pinSelected: bool = ..., pinUvBorder: bool = ..., scale: float = ..., stoppingThreshold: float = ..., useScale: bool = ...) -> int:
    """Nonepoly, uv, map, border, relax
    Args:
        applyToShell (bool?): Specifies that the selected components should be only work on shells that  
                have something have been selected or pinned.  
                Properties: create
        areaWeight (float?): Surface driven importance. 0 treat all faces equal. 1 gives more importance to large ones.  
                Properties: create
        globalBlend (float?): This allows the user to blend between a local optimization method  
                (globalBlend = 0.0) and a global optimization method  
                (globalBlend = 1.0). The local optimization method looks at the  
                ratio between the triangles on the object and the triangles in UV  
                space.  It has a side affect that it can sometimes introduce tapering  
                problems.  The global optimization is much slower, but takes into  
                consideration the entire object when optimizing uv placement.  
                Properties: create
        globalMethodBlend (float?): The global optimization method uses two functions to compute  
                a minimization.  The first function controls edge  
                stretch by using edges lengths between xyz and uv.  The second  
                function penalizes the first function by preventing  
                configurations where triangles would overlap.  For every surface  
                there is a mix between these two functions that will give the  
                appropriate response. Values closer to 1.0 give more weight to  
                the edge length function. Values closer to 0.0 give more weight to  
                surface area.  The default value of '0.5' is a even mix  
                between these two values.  
                Properties: create
        iterations (int?): Maximum number of iterations for each connected UV piece.  
                Properties: create
        optimizeAxis (int?): Degree of freedom for optimization  
                0=Optimize freely, 1=Move vertically only, 2=Move horzontally only  
                Properties: create
        pinSelected (bool?): Specifies that the selected components should be pinned instead  
                the unselected components.  
                Properties: create
        pinUvBorder (bool?): Specifies that the UV border should be pinned when doing the solve.  
                By default only unselected components are pinned.  
                Properties: create
        scale (float?): Ratio between 2d and 3d space.  
                Properties: create
        stoppingThreshold (float?): Minimum distorsion improvement between two steps in %.  
                Properties: create
        useScale (bool?): Adjust the scale or not.  
                Properties: create

    Returns:
        int: the number of relaxation iterations carried out

    Example:
    """

def ungroup(*args: str, absolute: bool = ..., parent: str = ..., relative: bool = ..., world: bool = ...) -> bool:
    """This command ungroups the specified objects.The objects will be placed at the same level in the hierarchy the
    group node occupied unless the -w flag is specified, in which case
    they will be placed under the world.If an object is ungrouped and there is an object in the new group
    with the same name then this command will rename the ungrouped
    object.group, parent, instance, duplicate
    Args:
        absolute (bool?): preserve existing world object transformations  
                (overall object transformation is preserved  
                by modifying the objects local transformation)  
                [default]  
                Properties: create
        parent (str?): put the ungrouped objects under the given parent  
                Properties: create
        relative (bool?): preserve existing local object transformations  
                (don't modify local transformation)  
                Properties: create
        world (bool?): put the ungrouped objects under the world  
                Properties: create

    Returns:
        bool:

    Example:
    """

def uniform(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A uniform field pushes objects in a fixed direction.  The field
    strength, but not the field direction, depends on the distance
    from the object to the field location.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        directionX (Queryable[float]?): X-component of direction.  
                Properties: query, edit
        directionY (Queryable[float]?): Y-component of direction.  
                Properties: query, edit
        directionZ (Queryable[float]?): Z-component of direction  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def unknownNode(arg0: str = ..., /, *, query: bool = ..., plugin: bool = ..., realClassName: bool = ..., realClassTag: bool = ...) -> Union[List[str], bool]:
    """Allows querying of the data stored for unknown nodes
    (nodes that are defined by a plug-in that Maya could not
    load when loading a scene file).
    Args:
        plugin (bool?): In query mode return the name of the plug-in from which the unknown node originated.  
                If no plug-in then the empty string is returned.  
                Properties: query
        realClassName (bool?): Return the real class name of the node.  
                Properties: query
        realClassTag (bool?): Return the real class IFF tag of the node.  
                Properties: query

    Returns:
        List[str]: in query mode

    Example:
    """

def unknownPlugin(arg0: str = ..., /, *, query: bool = ..., dataTypes: bool = ..., list: bool = ..., nodeTypes: bool = ..., remove: bool = ..., version: bool = ...) -> Union[List[str], bool]:
    """Allows querying of the unknown plug-ins used by the scene,
    and provides a means to remove them.
    Args:
        dataTypes (bool?): Returns the data types associated with the given unknown plug-in.  
                This will always be empty for pre-Maya 2014 files.  
                Properties: query
        list (bool?): Lists the unknown plug-ins in the scene.  
                Properties: query
        nodeTypes (bool?): Returns the node types associated with the given unknown plug-in.  
                This will always be empty for pre-Maya 2014 files.  
                Properties: query
        remove (bool?): Removes the given unknown plug-in from the scene.  
                For Maya 2014 files and onwards, this will fail if node  
                or data types defined by the plug-in are still in use.  
                Properties: create
        version (bool?): Returns the version string of the given unknown plug-in.  
                Properties: query

    Returns:
        List[str]: in query mode

    Example:
    """

def unloadPlugin(*args: str, addCallback: Callable[..., Any] = ..., force: bool = ..., removeCallback: Callable[..., Any] = ...) -> List[str]:
    """Unload plug-ins from Maya. After the successful execution of
    this command, plug-in services will no longer be available.
    Args:
        addCallback (Callable[..., Any]?): Add a procedure to be called just before a plugin is  
                unloaded. The procedure should have one string argument, which  
                will be the plugin's name.  
                Properties: create
        force (bool?): Unload the plugin even if it is providing services.  This  
                is not recommended.  If you unload a plug-in that implements  
                a node or data type in the scene, those instances will be  
                converted to unknown nodes or data and the scene will no  
                longer behave properly. Maya may become unstable or even  
                crash. If you use this flag you are advised to save your scene  
                in MayaAscii format and restart Maya as soon as possible.  
                Properties: create
        removeCallback (Callable[..., Any]?): Remove a procedure which was previously added  
                with -addCallback.  
                Properties: create

    Returns:
        List[str]: the internal names of the successfully unloaded plug-ins

    Example:
    """

def untangleUV(*args: str, mapBorder: str = ..., maxRelaxIterations: int = ..., pinBorder: bool = ..., pinSelected: bool = ..., pinUnselected: bool = ..., relax: str = ..., relaxTolerance: float = ..., shapeDetail: float = ...) -> int:
    """This command will aid in the creation of non-overlapping regions (i.e. polygons)
    in texture space by untangling texture UVs. This is done in two stages:1) Use this command to map the UV border determined by the current selection
    or passed component into a shape that is more suitable for subsequent relaxation.2) Relax all the internal texture UVs by performing a length minimization
    algorithm on all edges in texture space.poly, uv, map, border, relax, untangle
    Args:
        mapBorder (str?): Map the border containing the selected UV into a variety of shapes that may  
                be more amenable to UV relaxation operations. There are various types of  
                mapping available. All the resulting mappings are fit inside the unit square.  
              
                Valid values for the STRING are:  
                circular - a circular mapping with picked UV closest to (0,0)  
                square - map to unit square with picked UV at (0,0)  
                shape - a mapping which attempts to reflect the actual shape of the object  
                        where the picked UV is placed on the line from (0,0) -> (0.5,0.5)  
                shape_circular - shape mapping which will interpolate to a circular mapping  
                                 just enough to prevent self-intersections of the mapped border   
                shape_square - shape mapping which will interpolate to a square mapping just  
                               enough to prevent self-intersections of the mapped border  
                Properties: create
        maxRelaxIterations (int?): The relaxation process is an iterative algorithm. Using this flag  
                will put an upper limit on the number of iterations that will be  
                performed.  
                Properties: create
        pinBorder (bool?): If this is true, then the relevant texture borders are pinned in  
                place during any relaxation  
                Properties: create
        pinSelected (bool?): If this is true, then then any selected UVs are pinned in  
                place during any relaxation  
                Properties: create
        pinUnselected (bool?): If this is true, then all unselected UVs in each mesh are pinned in  
                place during any relaxation  
                Properties: create
        relax (str?): Relax all UVs in the shell of the selected UV's. The relaxation is done by  
                simulating a spring system where each UV edge is treated as a spring.  
                There are a number of different methods characterized by the way the UV  
                edges are weighted in the spring system. These weightings are determined by  
                STRING. Valid values for STRING are:  
                uniform - every edge is weighted the same. This is the fastest method.  
                inverse_length - every edge weight is inversely proportional to it's world space length.  
                inverse_sqrt_length - every edge weight is inversely proportional the the square root of it's world space length.  
                harmonic - this weighting can yield near optimal results in matching the UV's with  
                the geometry, but can also take a long time.  
                Properties: create
        relaxTolerance (float?): This sets the tolerance which is used to determine when the  
                relaxation process can stop. Smaller tolerances yield better  
                results but can take much longer.  
                Properties: create
        shapeDetail (float?): If the mapBorder flag is set to circular or square, then this flag  
                will control how much of the border's corresponding surface shape  
                should be retained in the final mapped border.  
                Properties: create

    Returns:
        int: the number of relaxation iterations carried out

    Example:
    """

def untrim(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., caching: bool = ..., nodeState: Queryable[int] = ..., constructionHistory: bool = ..., curveOnSurface: bool = ..., name: str = ..., noChanges: bool = ..., object: bool = ..., replaceOriginal: bool = ..., untrimAll: bool = ...) -> Union[List[str], bool, int]:
    """Untrim the surface.
    Args:
        caching (bool?): Toggle caching for all attributes so that no recomputation is needed  
                Properties: create, query, edit
        nodeState (Queryable[int]?): Maya dependency nodes have 6 possible states.  
                The Normal (0), HasNoEffect (1), and Blocking (2) states can be  
                used to alter how the graph is evaluated.  
              
              
              
                The Waiting-Normal (3), Waiting-HasNoEffect (4), Waiting-Blocking (5)  
                are for internal use only. They temporarily shut off parts of the graph during interaction  
                (e.g., manipulation). The understanding is that once the operation is done,  
                the state will be reset appropriately, e.g. Waiting-Blocking will reset  
                back to Blocking.  
              
              
              
                The Normal and Blocking cases apply to all nodes, while  
                HasNoEffect is node specific; many nodes do not support this option.  
                Plug-ins store state in the MPxNode::state attribute. Anyone can set  
                it or check this attribute.  Additional details about each of these 3 states follow.  
              
              
              
              
                State  
                Description  
              
              
                Normal  
                The normal node state. This is the default.  
              
              
                HasNoEffect  
              
              
                The HasNoEffect option (a.k.a. pass-through), is used in cases where  
                there is an operation on an input producing an output of the same data type.  
                Nearly all deformers support this state, as do a few other nodes.  
                As stated earlier, it is not supported by all nodes.  
              
              
                Itâ€™s typical to implement support for the HasNoEffect state in  
                the nodeâ€™s compute method and to perform appropriate operations.  
                Plug-ins can also support HasNoEffect.  
              
              
                The usual implementation of this state is to copy the input directly to the  
                matching output without applying the algorithm in the node. For deformers,  
                applying this state leaves the input geometry undeformed on the output.  
              
              
              
              
                Blocking  
              
              
                This is implemented in the depend node base class and applies to all nodes.  
                Blocking is applied during the evaluation phase to connections.  
                An evaluation request to a blocked connection will return as failures,  
                causing the destination plug to retain its current value. Dirty propagation  
                is indirectly affected by this state since blocked connections are never cleaned.  
              
              
                When a node is set to Blocking the behavior is supposed to be the same as  
                if all outgoing connections were broken. As long as nobody requests evaluation  
                of the blocked node directly it wonâ€™t evaluate after that. Note that a blocked  
                node will still respond to getAttr requests but a getAttr on a  
                downstream node will not reevaluate the blocked node.  
              
              
                Setting the root transform of a hierarchy to Blocking wonâ€™t automatically  
                influence child transforms in the hierarchy. To do this, youâ€™d need to  
                explicitly set all child nodes to the Blocking state.  
              
              
                For example, to set all child transforms to Blocking, you could use the  
                following script.  
              
              
              
                import maya.cmds as cmds  
                def blockTree(root):  
                nodesToBlock = []  
                for node in {child:1 for child in cmds.listRelatives( root, path=True, allDescendents=True )}.keys():  
                nodesToBlock += cmds.listConnections(node, source=True, destination=True )  
                for node in {source:1 for source in nodesToBlock}.keys():  
                cmds.setAttr( '%s.nodeState' % node, 2 )  
              
              
              
                Applying this script would continue to draw objects but things would not be animated.  
              
              
              
              
                Default: kdnNormal  
                Properties: create, query, edit
        constructionHistory (bool?): Turn the construction history on or off.  
                Properties: create
        curveOnSurface (bool?): If possible, create 2D curve as a result.  
                Properties: create
        name (str?): Sets the name of the newly-created node. If it contains  
                namespace path, the new node will be created under the  
                specified namespace; if the namespace does not exist, it  
                will be created.  
                Properties: create
        noChanges (bool?): If set then the operation node will be automatically put into pass-through mode.  
                Properties: create, query, edit
        object (bool?): Create the result, or just the dependency node.  
                Properties: create
        replaceOriginal (bool?): Create "in place" (i.e., replace).  
                Properties: create
        untrimAll (bool?): if true, untrim all the trims for the surface else untrim  
                only the last trim  
                Properties: query, edit

    Returns:
        List[str]: Object name and node name

    Example:
    """

def upAxis(*args: str, query: bool = ..., axis: Queryable[str] = ..., rotateView: bool = ...) -> Union[bool, str]:
    """The upAxis command changes the world up direction.
    Current implementation provides only two choices of axis (the Y-axis
    or the Z-axis) as the world up direction.By default, the ground plane in Maya is on the XY plane.
    Hence, the default up-direction is the direction of the positive Z-axis.The -ax flag is mandatory. In conjunction with the -ax flag,
    when the -rv flag is specified, the camera of currently active view is
    revolved about the X-axis such that the position of the groundplane in
    the view will remain the same as before the the up direction is changed.The screen update is applied to all cameras of all views.
    Args:
        axis (Queryable[str]?): This flag specifies the axis as the world up direction.  
                The valid axis are either "y" or "z".  
                When queried, it returns a string.  
                Properties: query
        rotateView (bool?): This flag specifies to rotate the view as well.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def userCtx(arg0: str = ..., /) -> None:
    """This command has beed replaced with scriptCtx."""

def uvLink(*, query: bool = ..., b: bool = ..., isValid: bool = ..., make: bool = ..., queryObject: str = ..., texture: str = ..., uvSet: str = ...) -> str:
    """This command is used to make, break and query UV linking
    relationships between UV sets on objects and textures that use those
    UV sets.If no make, break or query flag is specified and both uvSet and
    texture flags are present, the make flag is assumed to be specified.If no make, break or query flag is specified and only one of the
    uvSet and texture flags is present, the query flag is assumed to be
    specified.The term "texture" in the context of UV linking is a bit of an
    oversimplification. In fact, UV sets can be linked to any node which
    takes UV coordinates as input. However in most cases it will be a
    texture to which you wish to link a UV set.
    Args:
        b (bool?): The presence of this flag on the command indicates that the  
                command is being invoked to break links between UV sets and  
                textures.  
                Properties: create
        isValid (bool?): This flag is used to verify whether or not a texture or UV set is  
                valid for the purposes of UV linking. It should be used in  
                conjunction with either the -texture flag or the -uvSet flag, but  
                not both at the same time.  
                Properties: create
        make (bool?): The presence of this flag on the command indicates that the  
                command is being invoked to make links between UV sets and  
                textures.  
                Properties: create
        queryObject (str?): This flag should only be used in conjunction with a query of a  
                texture. This flag is used to indicate that the results of the  
                query should be limited to UV sets of the object specified by this  
                flag.  
                Properties: create
        texture (str?): The argument to the texture flag specifies the texture to be used by  
                the command in performing the action.  
                Properties: create
        uvSet (str?): The argument to the uvSet flag specifies the UV set to be used by  
                the command in performing the action.  
                Properties: create

    Returns:
        str: or array of strings for query
            boolean for isValid

    Example:
    """

def uvSnapshot(*args: str, antiAliased: bool = ..., blueColor: int = ..., entireUVRange: bool = ..., fileFormat: str = ..., greenColor: int = ..., name: str = ..., overwrite: bool = ..., redColor: int = ..., uMax: float = ..., uMin: float = ..., uvSetName: str = ..., vMax: float = ..., vMin: float = ..., xResolution: int = ..., yResolution: int = ...) -> bool:
    """Builds an image containg the UVs of the selected objects.texture, uv, image
    Args:
        antiAliased (bool?): When this flag is set, lines are antialiased.  
                Properties: create
        blueColor (int?): Blue component of line drawing. Default is 255.  
                Properties: create
        entireUVRange (bool?): When this flag is set, the generated image will contain the entire uv range. Default is UV in 0. 1 range.  
                Properties: create
        fileFormat (str?): Output file format. Any of those keyword:  
                                                "iff", "sgi", "pic", "tif", "als", "gif", "rla", "jpg"  
                        Default is iff.  
                Properties: create
        greenColor (int?): Green component of line drawing. Default is 255.  
                Properties: create
        name (str?): Name of the file to be created.  
                Properties: create
        overwrite (bool?): When this flag is set, existing file can be ovewritten.  
                Properties: create
        redColor (int?): Red component of line drawing. Default is 255.  
                Properties: create
        uMax (float?): Optional User Specified Max value for U. Default value is 1. This will take precedence over the "entire range" -euv flag.  
                Properties: create
        uMin (float?): Optional User Specified Min value for U. Default value is 0. This will take precedence over the "entire range" -euv flag.  
                Properties: create
        uvSetName (str?): Name of the uv set to use. Default is the current one.  
                Properties: create
        vMax (float?): Optional User Specified Max value for V. Default value is 1. This will take precedence over the "entire range" -euv flag.  
                Properties: create
        vMin (float?): Optional User Specified Min value for V. Default value is 0. This will take precedence over the "entire range" -euv flag.  
                Properties: create
        xResolution (int?): Horizontal size of the image. Default is 512.  
                Properties: create
        yResolution (int?): Vertical size of the image. Default is 512.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def view2dToolCtx(*args: Any, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., boxzoom: bool = ..., dolly: bool = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., toolName: Queryable[str] = ..., track: bool = ...) -> Union[str, bool]:
    """This class creates a context for the View Tools "track", "dolly",
    and "box zoom" in the Hypergraph.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        boxzoom (bool?): Perform Box Zoom  
                Properties: create, query
        dolly (bool?): Dollies the view  
                Properties: create, query
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query
        track (bool?): Tracks the view  
                Properties: create, query

    Returns:
        str: The context name

    Example:
    """

def viewCamera(arg0: str = ..., /, *, move: str = ..., sideView: bool = ..., topView: bool = ...) -> bool:
    """The viewCamera command is used to position a camera to look
    directly at the side or top of another camera. This is primarily
    useful for the user when he or she is setting depth-of-field and
    clipping planes, if they are being used.The default behaviour: If no other flags are specified, the camera
    in the active panel is moved and the -t is presumed. If there is a
    camera selected, it is used as the target camera.
    Args:
        move (str?): Specifies which camera needs to move.  
                Properties: create
        sideView (bool?): Position camera to look at the side of the target camera.  
                Properties: create
        topView (bool?): Position camera to look at the top of the target camera  
                (default).  
                Properties: create

    Returns:
        bool:

    Example:
    """

def viewClipPlane(arg0: str = ..., /, *, query: bool = ..., autoClipPlane: bool = ..., farClipPlane: Queryable[float] = ..., nearClipPlane: Queryable[float] = ..., surfacesOnly: bool = ...) -> Union[bool, float]:
    """The viewClipPlane command can be used to query or set a camera's
    clip planes. If a camera is not specified, the camera in the
    active view will be used. The near and far clip plane flags may be
    used in conjunction with the auto clip plane flag.
    Args:
        autoClipPlane (bool?): Compute the clip planes such that all object's in the camera's  
                viewing frustum will be visible.  
                Properties: create, query
        farClipPlane (Queryable[float]?): Set or query the far clip plane.  
                Properties: create, query
        nearClipPlane (Queryable[float]?): Set or query the near clip plane.  
                Properties: create, query
        surfacesOnly (bool?): This flag is to be used in conjunction with the auto clip  
                plane flag. Only the bounding boxes of surfaces will be used  
                to compute the camera's clipping planes.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def viewFit(*args: str, allObjects: bool = ..., animate: bool = ..., center: bool = ..., fitClipPlanes: bool = ..., fitFactor: float = ..., namespace: str = ..., noChildren: bool = ...) -> bool:
    """The viewFit command positions the specified camera so its
    point-of-view contains all selected objects other than itself. If
    no objects are selected, everything is fit to the view (excepting
    cameras, lights, and sketching plannes). The fit-factor, if
    specified, determines how much of the view should be filled. If a
    camera is not specified, the camera in the active view will be
    used. After the camera is moved, its center of interest is set to
    the center of the bounding box of the objects.Additionally, a list of objects can be passed as arguments.
    If a camera is specified it must be the first argument. Objects
    passed as arguments to the command will be used instead of the
    selected objects.
    Args:
        allObjects (bool?): Specifies that all objects are to be fit regardless of the  
                active list.  
                Properties: create
        animate (bool?): Specifies that the transition between camera positions  
                should be animated.  
                Properties: create
        center (bool?): Specifies that the camera moves to the center of the  
                selected object, but does not move the camera closer.  
                Properties: create
        fitClipPlanes (bool?): Fit orthographic clipping planes in order to contain selection bounding box in the view frustum  
                Properties: create
        fitFactor (float?): Specifies how much of the view should be filled with the  
                "fitted" items.  
                Properties: create
        namespace (str?): Specifies a namespace that should be excluded. All objects  
                in the specified namespace will be excluded from the fit  
                process.  
                Properties: create
        noChildren (bool?): Specifies that the children of fitted objects should be ignored when determining  
                the fit.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def viewHeadOn(arg0: str = ..., /) -> bool:
    """The viewHeadOn command positions the specified camera so it is
    looking "down" the normal of the live object, and fitted to the
    live object. If the live object is a surface, an arbitrary normal
    is chosen.
    Returns:
        bool:

    Example:
    """

def viewLookAt(arg0: str = ..., /, *, position: Tuple[float, float, float] = ...) -> bool:
    """The viewLookAt command positions the specified camera so it is
    looking at the centroid of all selected objects. If no objects are
    specified the camera will look at the ground plane.
    Args:
        position (Tuple[float, float, float]?): Position in world space to make the camera look at.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def viewManip(*args: Any, query: bool = ..., bottomLeft: bool = ..., bottomRight: bool = ..., compassAngle: Queryable[float] = ..., dragSnap: bool = ..., drawCompass: bool = ..., fitToView: bool = ..., frontParameters: Queryable[str] = ..., goDefault: bool = ..., goHome: bool = ..., homeParameters: Queryable[str] = ..., levelCamera: bool = ..., minOpacity: Queryable[float] = ..., namespace: Queryable[str] = ..., postCommand: Queryable[str] = ..., preCommand: Queryable[str] = ..., preserveSceneUp: bool = ..., resetFront: bool = ..., resetHome: bool = ..., restoreCenter: bool = ..., selectionLockParameters: Queryable[str] = ..., setFront: bool = ..., setHome: bool = ..., size: Queryable[str] = ..., toggleSelectionLock: bool = ..., topLeft: bool = ..., topRight: bool = ..., visible: bool = ..., zoomToFitScene: bool = ...) -> Union[bool, float, str]:
    """Mel access to the view cube manipulator.
    Args:
        bottomLeft (bool?): Positions the cube in the bottom left of the screen.  
                Properties: create, query
        bottomRight (bool?): Positions the cube in the bottom right of the screen.  
                Properties: create, query
        compassAngle (Queryable[float]?): Angle (in degrees) to rotate the compass.  
                Properties: create, query
        dragSnap (bool?): Enable snapping of orbit direction to view cube part directions during drag operation.  
                Properties: create, query
        drawCompass (bool?): Show compass below the view cube.  
                Properties: create, query
        fitToView (bool?): Fits the scene bounding box to the active view.  
                Properties: create
        frontParameters (Queryable[str]?): Parameter string for the front position  
                Properties: create, query
        goDefault (bool?): Go to the default position  
                Properties: create, query
        goHome (bool?): Go to the home position  
                Properties: create, query
        homeParameters (Queryable[str]?): Parameter string for the home position  
                Properties: create, query
        levelCamera (bool?): Flattens the camera view rotation relative to the ground plane.  
                Properties: create
        minOpacity (Queryable[float]?): Opacity level (in range [0,1]) on view cube when the cursor is away from it (it is fully opaque when the cursor is in the view cube area).  
                Properties: create, query
        namespace (Queryable[str]?): Namespace to use for the object  
                Properties: create, query
        postCommand (Queryable[str]?): Command to run after moving  
                Properties: create, query
        preCommand (Queryable[str]?): Command to run before moving  
                Properties: create, query
        preserveSceneUp (bool?): Specify whether the scene "up" direction should be preserved  
                Properties: create, query
        resetFront (bool?): Reset the front position  
                Properties: create, query
        resetHome (bool?): Reset the home position  
                Properties: create, query
        restoreCenter (bool?): Repositions the pivot point for orbiting/tumbling the scene to the center  
                of the scene's bounding box.  
                Properties: create
        selectionLockParameters (Queryable[str]?): String containing the selection lock parameters  
                Properties: create, query
        setFront (bool?): Set the front view to the current one  
                Properties: create
        setHome (bool?): Set the home view to the current one  
                Properties: create
        size (Queryable[str]?): Set or query the size of the View Cube, which can be one of "tiny",  
                "small", "normal", "large" or "auto". When set to "auto" the View Cube  
                will be automatically set to the size most appropriate for the view.  
                Properties: create, query
        toggleSelectionLock (bool?): Toggle the selection lock  
                Properties: create
        topLeft (bool?): Positions the cube in the top left of the screen.  
                Properties: create, query
        topRight (bool?): Positions the cube in the top right of the screen.  
                Properties: create, query
        visible (bool?): Shows/hides the view manip.  
                Properties: create, query
        zoomToFitScene (bool?): Zoom the camera during animated transitions to fit the scene object in the viewport.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def viewPlace(arg0: str = ..., /, *, animate: bool = ..., eyePoint: Tuple[float, float, float] = ..., fieldOfView: float = ..., lookAt: Tuple[float, float, float] = ..., ortho: bool = ..., perspective: bool = ..., upDirection: Tuple[float, float, float] = ..., viewDirection: Tuple[float, float, float] = ...) -> bool:
    """This command positions the camera as specified. The lookAt and
    viewDirection flags are mutually exclusive, as are the ortho and
    perspective flags. If this command switches a camera from ortho to
    perspective or the other way around without specifying a new field
    of view, then one is calculated based on a heuristic involving the
    selected objects.If the camera is not specified on the command line, the command
    will check to see if there is a camera on the active list.The user should be aware that some positions will be
    unattainable. For example, using a new camera located at the
    origin and specifying a lookAt of [0 0 -5] and an up of [1 1
    1]. In these cases, the camera will always aim at the lookAt, and
    the new up direction will be determined by transforming the
    specified up into camera space and then projecting this vector
    onto a plane defined by the camera's up and right vectors. Using
    the example above, the new up vector will be [1 1 0].
    Args:
        animate (bool?): If set to true then animate the camera transition from current  
                position to the final one.  
                Properties: create
        eyePoint (Tuple[float, float, float]?): The new eye point in world coordinates.  
                Properties: create
        fieldOfView (float?): The new field of view (in degrees, for perspective cameras,  
                and in world distance for ortho cameras)  
                Properties: create
        lookAt (Tuple[float, float, float]?): The new look-at point in world coordinates.  
                Properties: create
        ortho (bool?): Sets the camera to be orthgraphic.  
                Properties: create
        perspective (bool?): Sets the camera to be perspective.  
                Properties: create
        upDirection (Tuple[float, float, float]?): The new up direction vector.  
                Properties: create
        viewDirection (Tuple[float, float, float]?): The new view direction vector.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def viewSet(arg0: str = ..., /, *, query: bool = ..., animate: bool = ..., back: bool = ..., bottom: bool = ..., fit: bool = ..., fitFactor: float = ..., front: bool = ..., home: bool = ..., keepRenderSettings: bool = ..., leftSide: bool = ..., namespace: str = ..., nextView: bool = ..., persp: bool = ..., previousView: bool = ..., rightSide: bool = ..., side: bool = ..., top: bool = ..., viewNegativeX: bool = ..., viewNegativeY: bool = ..., viewNegativeZ: bool = ..., viewX: bool = ..., viewY: bool = ..., viewZ: bool = ...) -> bool:
    """This command positions the camera to one of the pre-defined
    positions. If the fit flag is set in conjunction with persp, top,
    side, or front, the view is "fit" based on the list of selected
    objects (if there are any) or on all the objects if nothing is
    selected. Notice that the fit flag cannot be set in conjunction with
    view along axis commands like viewX. If a camera is not specified,
    the camera in the active view will be used. If no flag is specified,
    the camera is set to the home position.
    Args:
        animate (bool?): Specifies that the transition between camera positions  
                should be animated.  
                Properties: create
        back (bool?): Moves the camera to the back position.  
                Properties: create
        bottom (bool?): Moves the camera to the bottom position.  
                Properties: create
        fit (bool?): Apply a viewFit after positioning camera to persp, top, side,  
                or front.  
                Properties: create, query
        fitFactor (float?): Specifies how much of the view should be filled with the "fitted" items  
                Properties: create
        front (bool?): Moves the camera to the front position.  
                Properties: create
        home (bool?): Executes the camera's home attribute command. Before the  
                string is executed, all occurances of "%camera" will be  
                replaced by the camera's name. Use the camera command to set a  
                camera's home command.  
                Properties: create
        keepRenderSettings (bool?): Retain the 'renderable' flag vaue on the view. Especially important if it switches from  
                perspective to orthographic and then back again.  
                Properties: create, query
        leftSide (bool?): Moves the camera to the left side position.  
                Properties: create
        namespace (str?): Specifies a namespace that should be excluded. All objects  
                in the specified namespace will be excluded from the fit  
                process.  
                Properties: create
        nextView (bool?): Moves the camera to the next position.  
                Properties: create, query
        persp (bool?): Moves the camera to the persp position.  
                Properties: create
        previousView (bool?): Moves the camera to the previous position.  
                Properties: create, query
        rightSide (bool?): Moves the camera to the right side position.  
                Properties: create
        side (bool?): Moves the camera to the (right) side position (deprecated).  
                Properties: create
        top (bool?): Moves the camera to the top position.  
                Properties: create
        viewNegativeX (bool?): Moves the camera to view along negative X axis.  
                Properties: create
        viewNegativeY (bool?): Moves the camera to view along negative Y axis.  
                Properties: create
        viewNegativeZ (bool?): Moves the camera to view along negative Z axis.  
                Properties: create
        viewX (bool?): Moves the camera to view along X axis.  
                Properties: create
        viewY (bool?): Moves the camera to view along Y axis.  
                Properties: create
        viewZ (bool?): Moves the camera to view along Z axis.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def visor(*args: Any, query: bool = ..., addFolder: bool = ..., addNodes: Queryable[str] = ..., allowPanningInX: bool = ..., allowPanningInY: bool = ..., allowZooming: bool = ..., command: Queryable[str] = ..., deleteFolder: Queryable[str] = ..., editFolder: Queryable[str] = ..., folderList: Queryable[str] = ..., menu: Queryable[str] = ..., name: Queryable[str] = ..., nodeType: Queryable[str] = ..., openDirectories: bool = ..., openFolder: bool = ..., parent: Queryable[str] = ..., path: Queryable[str] = ..., popupMenuScript: Queryable[str] = ..., rebuild: bool = ..., refreshAllSwatches: bool = ..., refreshSelectedSwatches: bool = ..., refreshSwatch: Queryable[str] = ..., reset: bool = ..., restrictPanAndZoom: bool = ..., saveSwatches: bool = ..., scrollBar: Queryable[str] = ..., scrollPercent: Queryable[float] = ..., selectedGadgets: Queryable[str] = ..., showDividers: bool = ..., showFiles: bool = ..., showFolders: bool = ..., showNodes: bool = ..., stateString: bool = ..., style: Queryable[str] = ..., transform: Queryable[str] = ..., type: Queryable[str] = ...) -> Union[str, bool, float]:
    """Command for the creation and manipulation of a Visor UI element. The Visor is
    used to display the contents of a scene (rendering related nodes in
    particular), as well as files on disk which the user may wish to bring into
    the scene (shader and texture libraries for example).render, hypergraph, shader, hypershade
    Args:
        addFolder (bool?): Add a new folder to the current visual browser  
                Properties: create, query
        addNodes (Queryable[str]?): Add dependency graph nodes by name to a user defined custom folder.  The  
                argument is a string encolsed in quotes with 1 one more node names  
                seperated by blanks  
                Properties: create, query
        allowPanningInX (bool?): Specifies whether or not the user should be able to pan the contents of the  
                visor horizontally. Default is true.  
                Properties: create, query
        allowPanningInY (bool?): Specifies whether or not the user should be able to pan the contents of the  
                visor vertically. Default is true.  
                Properties: create, query
        allowZooming (bool?): Specifies whether or not the user should be able to zoom the contents of the  
                visor. Default is true.  
                Properties: create, query
        command (Queryable[str]?): Mel command which will return a list of nodes to add to a folder  
                Properties: create, query
        deleteFolder (Queryable[str]?): Delete the specified folder and all of its children  
                Properties: create, query
        editFolder (Queryable[str]?): Edit the name and MEL command for an existing folder  
                Properties: create, query
        folderList (Queryable[str]?): Return a string array of the folders in the visor.  
                Properties: query
        menu (Queryable[str]?): Set the name of the script to run to get a popup menu  
                Properties: create, query
        name (Queryable[str]?): Name of the new folder  
                Properties: create, query
        nodeType (Queryable[str]?): A node type used by folders of type nodeTypeInDAG  
                Properties: create, query
        openDirectories (bool?): When adding a new folder indicate if it sub directories will be show.  
                The default is to not show sub directories.  
                Properties: create, query
        openFolder (bool?): When adding a new folder indicate if it will be open or closed by default.  
                The default is closed.  
                Properties: create, query
        parent (Queryable[str]?): Parent folder of this folder  
                Properties: create, query
        path (Queryable[str]?): Path to a file system directory to be displayed in the folder  
                Properties: create, query
        popupMenuScript (Queryable[str]?): Specifies the script to be called when the right mouse button is pressed in  
                the visor. The name of the editor in which the right mouse button was pressed  
                will be appended to the script at the time the script is called.  
                Properties: create, query
        rebuild (bool?): Rebuild the visor after interactively adding a folder  
                Properties: create, query
        refreshAllSwatches (bool?): Refresh the swatches of all files currently displayed in this visor.  
                Properties: create, query
        refreshSelectedSwatches (bool?): Refresh the swatches of all files currently selected in any visor.  
                Properties: create, query
        refreshSwatch (Queryable[str]?): Refresh the swatch of the file with the specified path.  
                Properties: create, query
        reset (bool?): Clear all previously loaded folder descriptions in preperation for  
                building a new visual browser  
                Properties: create, query
        restrictPanAndZoom (bool?): Specifies whether the panning and zooming of the visor should be  
                restricted to keep the contents in the top left corner of the  
                visor when they are smaller than the visible area within the visor.  
                Default is true.  
                Properties: create, query
        saveSwatches (bool?): Save swatches to disk for currently displayed image files.  
                Properties: create, query
        scrollBar (Queryable[str]?): Set the name of the scroll bar associated with visor  
                Properties: create, query
        scrollPercent (Queryable[float]?): Set the percentage value for the scroll bar.  Typically called from a  
                a scroll bars callback.  
                Properties: create, query
        selectedGadgets (Queryable[str]?): Return a string array of the currently selected gadgets (files, folders, nodes)  
                in the visor.  
                Properties: query
        showDividers (bool?): Specifies whether or not the visor should show dividers. The default is true.  
                If -showDividers is set to false, dividers will be drawn as folders instead.  
                Properties: create, query
        showFiles (bool?): Specifies whether or not the visor should show files. The default is true.  
                Properties: create, query
        showFolders (bool?): Specifies whether or not the visor should show folders. The default is true.  
                Properties: create, query
        showNodes (bool?): Specifies whether or not the visor should show nodes. The default is true.  
                Properties: create, query
        stateString (bool?): Return the MEL command string to save the folder setup in visor  
                Properties: create, query
        style (Queryable[str]?): Set display style for the browser.  Options are:  
                    outliner  
                         A single column with an outliner style icon and a text label  
                    singleColumn  
                         A single column with an image style icon and a text label  
                    multiColumn  
                         A multiple column grid of swatches with the text label below the swatch  
                Properties: create, query
        transform (Queryable[str]?): Name of a transform node used by folders of type nodeTypeInDAG  
                Properties: create, query
        type (Queryable[str]?): Type of the new folder.  Options are:   
              
                command   
                         A mel command that will return a list of depend nodes that will  
                         be displayed in the folder  
                connectedNodes   
                         The nodes connected to the specified node name will be displayed  
                         in the folder  
                defaultNodes   
                         A mel command that will generate default node types.  These nodes  
                         will not be part of the scene and are used for drag and drop  
                         creation of new nodes that are in the scene.  The mel command  
                         use with this type is usually "listNodetypes".  
                directory   
                        A directory name in the file system  
                directoryCommand   
                        A mel command that will return a directory name in the file system  
                folder   
                        An empty folder(the default value).  Empty folders can be used  
                        as user defined folders by dropping dependency graph nodes in to them  
                nodeTypeInDAG   
                                List all nodes of a given type under a specified transforms in the  
                                DAG.  For example list all the shaders for a character by specifying  
                        the top transform of the character  
                shelfItems   
                        A directory containing mel files to use as shelf items  
                Properties: create, query

    Returns:
        str: Command result

    Example:
    """

def volumeAxis(*args: str, edit: bool = ..., query: bool = ..., alongAxis: Queryable[float] = ..., aroundAxis: Queryable[float] = ..., attenuation: Queryable[float] = ..., awayFromAxis: Queryable[float] = ..., awayFromCenter: Queryable[float] = ..., detailTurbulence: Queryable[float] = ..., directionX: Queryable[float] = ..., directionY: Queryable[float] = ..., directionZ: Queryable[float] = ..., directionalSpeed: Queryable[float] = ..., invertAttenuation: bool = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., turbulence: Queryable[float] = ..., turbulenceFrequencyX: Queryable[float] = ..., turbulenceFrequencyY: Queryable[float] = ..., turbulenceFrequencyZ: Queryable[float] = ..., turbulenceOffsetX: Queryable[float] = ..., turbulenceOffsetY: Queryable[float] = ..., turbulenceOffsetZ: Queryable[float] = ..., turbulenceSpeed: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A volume axis field can push particles in four directions, defined with
    respect to a volume: along the axis, away from the axis or center,
    around the axis, and in a user-specified direction.  These are analogous
    to the emission speed controls of volume emitters. The volume axis field
    also contains a wind turbulence model (different from the
    turbulence field) that simulates an evolving flow of liquid or
    gas. The turbulence has a build in animation that is driven
    by a connection to a time node.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        alongAxis (Queryable[float]?): Initial velocity multiplier in the direction along  
                the central axis of the volume.  See the diagrams in  
                the documentation.  
                Properties: query, edit
        aroundAxis (Queryable[float]?): Initial velocity multiplier in the direction around  
                the central axis of the volume.  See the diagrams  
                in the documentation.  
                Properties: query, edit
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        awayFromAxis (Queryable[float]?): Initial velocity multiplier in the direction away  
                from the central axis of the volume.  See the diagrams  
                in the documentation.  Used only with the cylinder, cone,  
                and torus volumes.  
                Properties: query, edit
        awayFromCenter (Queryable[float]?): Initial velocity multiplier in the direction away from  
                the center point of a cube or sphere volume. Used only with  
                the cube and sphere volumes.  
                Properties: query, edit
        detailTurbulence (Queryable[float]?): The relative intensity of a second higher frequency turbulence.  
                This can be used to create fine features in large scale flows.  
                Both the speed and the frequency on this second turbulence are  
                higher than the primary turbulence. When the detailTurbulence  
                is non-zero the simulation may run a bit slower, due to the  
                computation of a second turbulence.  
                Properties: query, edit
        directionX (Queryable[float]?): x-component of force direction.  Used with directional speed.  
                Properties: query, edit
        directionY (Queryable[float]?): y-component of force direction.  Used with directional speed.  
                Properties: query, edit
        directionZ (Queryable[float]?): z-component of force direction.  Used with directional speed.  
                Properties: query, edit
        directionalSpeed (Queryable[float]?): Adds a component of speed in the  
                direction specified by the directionX, Y, and Z attributes.  
                Properties: query, edit
        invertAttenuation (bool?): If this attribute is FALSE, the default, then the  
                attenuation makes the field's effect decrease as the  
                affected point is further from the volume's axis and  
                closer to its edge.  If the is set to TRUE, then the  
                effect of the field increases in this case, making the  
                full effect of the field felt at the volume's edge.  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        turbulence (Queryable[float]?): Adds a force simulating a turbulent  
                wind that evolves over time.  
                Properties: query, edit
        turbulenceFrequencyX (Queryable[float]?): The repeats of the turbulence function in X.  
                Properties: query, edit
        turbulenceFrequencyY (Queryable[float]?): The repeats of the turbulence function in Y.  
                Properties: query, edit
        turbulenceFrequencyZ (Queryable[float]?): The repeats of the turbulence function in Z.  
                Properties: query, edit
        turbulenceOffsetX (Queryable[float]?): The translation of the turbulence function in X.  
                Properties: query, edit
        turbulenceOffsetY (Queryable[float]?): The translation of the turbulence function in Y.  
                Properties: query, edit
        turbulenceOffsetZ (Queryable[float]?): The translation of the turbulence function in Z.  
                Properties: query, edit
        turbulenceSpeed (Queryable[float]?): The rate of change of the turbulence over time.  
                The turbulence loops seamlessly every 1.0/turbulenceSpeed seconds.  
                To animate this rate attach a new time node to the time input  
                on the volumeAxisNode then animate the time value on the time node.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def volumeBind(*, edit: bool = ..., query: bool = ..., influence: Queryable[str] = ..., name: str = ...) -> Union[List[str], str]:
    """Command for creating and editing volume binding nodes.
    The node is use for storing volume data to define skin weighting data.
    Args:
        influence (Queryable[str]?): Edit or Query the list of influences connected to the skin cluster.  
                Properties: query, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create

    Returns:
        List[str]: List of queried influences

    Example:
    """

def vortex(*args: str, edit: bool = ..., query: bool = ..., attenuation: Queryable[float] = ..., axisX: Queryable[float] = ..., axisY: Queryable[float] = ..., axisZ: Queryable[float] = ..., magnitude: Queryable[float] = ..., maxDistance: Queryable[float] = ..., name: Queryable[str] = ..., perVertex: bool = ..., position: Queryable[Multiuse[Tuple[float, float, float]]] = ..., torusSectionRadius: Queryable[float] = ..., volumeExclusion: bool = ..., volumeOffset: Queryable[Tuple[float, float, float]] = ..., volumeShape: Queryable[str] = ..., volumeSweep: Queryable[float] = ...) -> Union[str, float, bool, Multiuse[Tuple[float, float, float]], Tuple[float, float, float]]:
    """For each listed object, the command creates a new field.
    The field has a shape which lives in the DAG and it has an associated
    dependency node. The field is added to the list of fields owned
    by the object. Use connectDynamic to cause the field to affect a dynamic
    object. Note that if more than one object is listed, a separate field is
    created for each object.If fields are created, this command returns the names of each
    owning shape and of the field shapes themselves. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If no object names are provided but the active selection list is non-empty,
    the command creates a field for every object in the list. If the
    list is empty, the command defaults to -pos 0 0 0.
    A vortex field pulls objects in a circular direction, like a whirlpool
    or tornado.   Objects affected by the vortex field tend to rotate around
    the axis specified by -ax, -ay, and -az.The transform is the associated dependency node.
    Use connectDynamic to cause the field to affect a dynamic object.If fields are created, this command returns the names of each
    of the fields. If a field was queried,
    the results of the query are returned. If a field was edited, the field
    name is returned.If object names are provided or the active selection list is non-empty,
    the command creates a field for every object in the list and calls
    addDynamic to add it to the object. If the
    list is empty, the command defaults to -pos 0 0 0.Setting the -pos flag with objects named on the command line is an error.
    Args:
        attenuation (Queryable[float]?): Attentuation rate of field  
                Properties: query, edit
        axisX (Queryable[float]?): X-component of vortex axis  
                Properties: query, edit
        axisY (Queryable[float]?): Y-component of vortex axis  
                Properties: query, edit
        axisZ (Queryable[float]?): Z-component of vortex axis  
                Properties: query, edit
        magnitude (Queryable[float]?): Strength of field.  
                Properties: query, edit
        maxDistance (Queryable[float]?): Maximum distance at which field is exerted.  
                -1 indicates that the field has no maximum distance.  
                Properties: query, edit
        name (Queryable[str]?): name of field  
                Properties: query, edit
        perVertex (bool?): Per-vertex application. If this flag is set true, then each  
                individual point (CV, particle, vertex,etc.) of the chosen object  
                exerts an identical copy of the force field. If this flag is set to  
                false, then the froce is exerted only from the geometric center of  
                the set of points.  
                Properties: query, edit
        position (Queryable[Multiuse[Tuple[float, float, float]]]?): Position in space (x,y,z) where you want to place a gravity field.  
                The gravity then emanates from this position in space rather  
                than from an object. Note that you can both use -pos  
                (creating a field at a position) and also provide object names.  
                Properties: query, edit, multiuse
        torusSectionRadius (Queryable[float]?): Section radius for a torus volume.  Applies only to torus.  
                Similar to the section radius in the torus modelling primitive.  
                Properties: query, edit
        volumeExclusion (bool?): Volume exclusion of the field.  If true, points outside the  
                volume (defined by the volume shape attribute) are affected,  If false,  
                points inside the volume are affected.  Has no effect if volumeShape  
                is set to "none."  
                Properties: query, edit
        volumeOffset (Queryable[Tuple[float, float, float]]?): Volume offset of the field.  Volume offset translates  
                the field's volume by the specified amount from the actual  
                field location. This is in the field's local space.  
                Properties: query, edit
        volumeShape (Queryable[str]?): Volume shape of the field.  Sets/edits/queries the  
                field's volume shape attribute.  If set to any value other  
                than "none", determines a 3. D volume within which the field has effect.  
                Values are: "none," "cube," "sphere," "cylinder," "cone," "torus."  
                Properties: query, edit
        volumeSweep (Queryable[float]?): Volume sweep of the field.  Applies only to sphere, cone,  
                cylinder, and torus.  Similar effect to the sweep attribute  
                in modelling.  
                Properties: query, edit

    Returns:
        str: Command result

    Example:
    """

def waitCursor(*, query: bool = ..., state: bool = ...) -> bool:
    """This command sets/resets a wait cursor for the
    entire Maya application.
    This works as a stack, such that for eachcommand executed there should be a matchingcommand pending.If a script fails that has turned
    the wait cursor on, the wait cursor may be left on.
    You need to turn it off manually from the command line by entering
    and executing the command 'waitCursor -state off'.
    Args:
        state (bool?): Set or reset the wait cursor for the entire Maya application.  
                Properties: create, query

    Returns:
        bool: True if the wait cursor is on.

    Example:
    """

def walkCtx(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., alternateContext: bool = ..., crouchCount: Queryable[float] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., toolName: Queryable[str] = ..., walkHeight: Queryable[float] = ..., walkSensitivity: Queryable[float] = ..., walkSpeed: Queryable[float] = ..., walkToolHud: bool = ...) -> Union[str, bool, float]:
    """This command can be used to create, edit, or query a walk
    context.
    Args:
        alternateContext (bool?): Set the ALT+MMB and ALT+SHIFT+MMB to refer to this context.  
                Properties: create, query
        crouchCount (Queryable[float]?): The camera crouch count.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        toolName (Queryable[str]?): Name of the specific tool to which this command refers.  
                Properties: create, query
        walkHeight (Queryable[float]?): The camera initial height.  
                Properties: create, query, edit
        walkSensitivity (Queryable[float]?): The camera rotate sensitivity.  
                Properties: create, query, edit
        walkSpeed (Queryable[float]?): The camera move speed.  
                Properties: create, query, edit
        walkToolHud (bool?): Control whether show walk tool HUD.  
                Properties: create, query, edit

    Returns:
        str: The name of the context

    Example:
    """

def warnUserDialog(*, addInfo: Tuple[str, str] = ..., message: str = ..., title: str = ...) -> None: ...
def warning(*args: str, noContext: bool = ..., showLineNumber: bool = ...) -> bool:
    """The warning command is provided so that the user can issue warning
    messages from his/her scripts.
    The string argument is displayed in the command window (or stdout if
    running in batch mode) after being prefixed with a warning message heading
    and surrounded by the appropriate language separators
    (# for Python, // for Mel).debug, information, echo
    Args:
        noContext (bool?): Do not include the context information with the warning message.  
                Properties: create
        showLineNumber (bool?): Obsolete. Will be deleted in the next version of Maya. Use the checkbox in the  
                script editor that enables line number display instead.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def webBrowser(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., annotation: Queryable[str] = ..., back: bool = ..., backgroundColor: Queryable[Tuple[float, float, float]] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dragCallback: Callable[..., Any] = ..., dropCallback: Callable[..., Any] = ..., enable: bool = ..., enableBackground: bool = ..., enableKeyboardFocus: bool = ..., exists: bool = ..., find: str = ..., forward: bool = ..., fullPathName: bool = ..., height: Queryable[int] = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., home: bool = ..., isObscured: bool = ..., manage: bool = ..., matchCase: bool = ..., matchWholeWorld: bool = ..., noBackground: bool = ..., numberOfPopupMenus: bool = ..., openURL: Queryable[str] = ..., parent: Queryable[str] = ..., popupMenuArray: bool = ..., preventOverride: bool = ..., reload: bool = ..., searchForward: bool = ..., statusBarMessage: str = ..., stop: bool = ..., urlChangedCb: str = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Queryable[Callable[..., Any]] = ..., width: Queryable[int] = ..., wrap: bool = ...) -> Union[str, Tuple[float, float, float], bool, int, Callable[..., Any]]:
    """This command is obsolete and will be removed in next version of Maya.
    The internal web browser of Maya has been replaced by a plug-in which allows your own browser to connect with Maya.
    Please refer help for information on how to setup communication of Maya with external web browser application.
    Args:
        annotation (Queryable[str]?): Annotate the control with an extra string value.  
                Properties: create, query, edit
        back (bool?): Go back a page  
                Properties: create
        backgroundColor (Queryable[Tuple[float, float, float]]?): The background color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                When setting backgroundColor, the background is automatically  
                enabled, unless enableBackground is also specified with a false  
                value.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Add a documentation flag to the control.  The documentation flag  
                has a directory structure.  
                (e.g., -dt render/multiLister/createNode/material)  
                Properties: create, query, edit
        dragCallback (Callable[..., Any]?): Adds a callback that is called when the middle mouse button  
                is pressed.  The MEL version of the callback is of the form:  
              
                global proc string[] callbackName(string $dragControl, int $x, int $y, int $mods)  
              
                The proc returns a string array that is transferred to the drop site.  
                By convention the first string in the array describes the user settable  
                message type.  Controls that are application defined drag sources may  
                ignore the callback. $mods allows testing for the key modifiers CTRL and  
                SHIFT. Possible values are 0 == No modifiers, 1 == SHIFT, 2 == CTRL,  
                3 == CTRL + SHIFT.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def callbackName( dragControl, x, y, modifiers ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "x", "y", "modifiers".  The  
                "dragControl" value is a string and the other values are integers (eg the  
                callback string could be "print '%(dragControl)s %(x)d %(y)d %(modifiers)d'")  
                Properties: create, edit
        dropCallback (Callable[..., Any]?): Adds a callback that is called when a drag and drop  
                operation is released above the drop site.  The MEL version of the callback is  
                of the form:  
              
                global proc callbackName(string $dragControl, string $dropControl, string $msgs[], int $x, int $y, int $type)  
              
                The proc receives a string array that is transferred from the drag source.  
                The first string in the msgs array describes the user defined message type.  
                Controls that are application defined drop sites may ignore the  
                callback. $type can have values of 1 == Move, 2 == Copy, 3 == Link.  
              
                In Python, it is similar, but there are two ways to specify the callback.  The  
                recommended way is to pass a Python function object as the argument.  In that  
                case, the Python callback should have the form:  
              
                def pythonDropTest( dragControl, dropControl, messages, x, y, dragType ):  
              
                The values of these arguments are the same as those for the MEL version above.  
              
                The other way to specify the callback in Python is to specify a string to be  
                executed.  In that case, the string will have the values substituted into it  
                via the standard Python format operator.  The format values are passed in a  
                dictionary with the keys "dragControl", "dropControl", "messages", "x", "y",  
                "type".  The "dragControl" value is a string and the other values are integers  
                (eg the callback string could be  
                "print '%(dragControl)s %(dropControl)s %(messages)r %(x)d %(y)d %(type)d'")  
                Properties: create, edit
        enable (bool?): The enable state of the control.  By default, this flag is  
                set to true and the control is enabled.  Specify false and the control  
                will appear dimmed or greyed-out indicating it is disabled.  
                Properties: create, query, edit
        enableBackground (bool?): Enables the background color of the control.  
                Properties: create, query, edit
        enableKeyboardFocus (bool?): If enabled, the user can navigate to the control with the tab key and select values with the keyboard or mouse.  
                This flag would typically be used to turn off focus support from controls that get it by default, like Edit and List controls.  
                If disabled, text in text fields can still be selected with the mouse but cannot be copied (except on Linux when "Middle Click Paste" is enabled).  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        find (str?): Find text in a page  
                Properties: create
        forward (bool?): Go forward a page  
                Properties: create
        fullPathName (bool?): Return the full path name of the widget, which includes all the parents.  
                Properties: query
        height (Queryable[int]?): The height of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        highlightColor (Queryable[Tuple[float, float, float]]?): The highlight color of the control. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query, edit
        home (bool?): Go to the home page  
                Properties: create
        isObscured (bool?): Return whether the control can actually be seen by the user.  
                The control will be obscured if its state is invisible, if it is  
                blocked (entirely or partially) by some other control, if it or a  
                parent layout is unmanaged, or if the control's window is  
                invisible or iconified.  
                Properties: query
        manage (bool?): Manage state of the control.  An unmanaged control is  
                not visible, nor does it take up any screen real estate.  All  
                controls are created managed by default.  
                Properties: create, query, edit
        matchCase (bool?): True if the match should respect the case  
                Properties: create
        matchWholeWorld (bool?): True if the match should check the whole world  
                Properties: create
        noBackground (bool?): Clear/reset the control's background.  
                Passing true means the background should not be drawn at all, false means the background should be drawn.  The state of this flag is inherited by children of this control.  
                Properties: create, edit
        numberOfPopupMenus (bool?): Return the number of popup menus attached to this control.  
                Properties: query
        openURL (Queryable[str]?): Open the named URL  
                Properties: create, query, edit
        parent (Queryable[str]?): The parent layout for this control.  
                Properties: create, query
        popupMenuArray (bool?): Return the names of all the popup menus attached to this  
                control.  
                Properties: query
        preventOverride (bool?): If true, this flag prevents overriding the control's  
                attribute via the control's right mouse button menu.  
                Properties: create, query, edit
        reload (bool?): Reload the current page  
                Properties: create
        searchForward (bool?): True if search should be going forward from the current location  
                Properties: create
        statusBarMessage (str?): Extra string to display in the status bar when the mouse is over the control.  
                Properties: create, edit
        stop (bool?): Stop loading a page  
                Properties: create
        urlChangedCb (str?): Command to call when the URL changes  
                Properties: create
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the control.  A control is created  
                visible by default.  Note that a control's actual appearance is  
                also dependent on the visible state of its parent layout(s).  
                Properties: create, query, edit
        visibleChangeCommand (Queryable[Callable[..., Any]]?): Command that gets executed when visible state of the control changes.  
                Properties: create, query, edit
        width (Queryable[int]?): The width of the control.  The control will attempt to  
                be this size if it is not overruled by parent layout conditions.  
                Properties: create, query, edit
        wrap (bool?): Set to true if the page should wrap  
                Properties: create

    Returns:
        str: Full path name to the control

    Example:
    """

def webBrowserPrefs(arg0: str = ..., /) -> None:
    """This command is obsolete and will be removed in a future version of Maya.
    The internal web browser of Maya has been replaced by a plug-in which allows your own browser to connect with Maya.
    Please refer help for information on how to setup communication of Maya with external web browser application.
    """

def weightsColor(*args: Any, query: bool = ..., colorRamp: Queryable[str] = ..., deformer: Queryable[str] = ..., falseColor: bool = ..., outOfRangeColor: Queryable[Tuple[float, float, float]] = ..., rampMaxColor: Queryable[Tuple[float, float, float]] = ..., rampMinColor: Queryable[Tuple[float, float, float]] = ..., useColorRamp: bool = ..., useMaxMinColor: bool = ...) -> Union[List[str], str, bool, Tuple[float, float, float]]:
    """Controls the coloring of deformer weights.
    Args:
        colorRamp (Queryable[str]?): Allows a user defined color ramp to be used to map values to colors.  
                Properties: query
        deformer (Queryable[str]?): Specify the deformer that needs to be visualized.  
                Properties: query
        falseColor (bool?): Enable or disable false color display on the geometry.  
                Properties: query
        outOfRangeColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used for the areas outside the deformers subset.  
                Properties: query
        rampMaxColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is greater than or equal to  
                the maximum value.  
                Properties: query
        rampMinColor (Queryable[Tuple[float, float, float]]?): Defines a special color to be used when the value is less than or equal to the  
                minimum value.  
                Properties: query
        useColorRamp (bool?): Specifies whether the user defined color ramp should be used to map values  
                from to colors. If this is turned off, the default greyscale feedback  
                will be used.  
                Properties: query
        useMaxMinColor (bool?): Specifies whether the out of range colors should be used.  See rampMinColor  
                and rampMaxColor flags for further details.  
                Properties: query

    Returns:
        List[str]: For query operation

    Example:
    """

def whatsNewHighlight(*, query: bool = ..., highlightColor: Queryable[Tuple[float, float, float]] = ..., highlightOn: bool = ..., showStartupDialog: bool = ...) -> Union[bool, Tuple[float, float, float]]:
    """This command is used to toggle the What's New highlighting feature,
    and the display of the settings dialog for the feature that appears
    on startup.
    Args:
        highlightColor (Queryable[Tuple[float, float, float]]?): Set the color of the What's New highlight. The arguments correspond to  
                the red, green, and blue color components. Each color component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, query
        highlightOn (bool?): Toggle the What's New highlighting feature. When turned on, menu items  
                and buttons introduced in the latest version will be highlighted.  
                Properties: create, query
        showStartupDialog (bool?): Set whether the settings dialog for this feature appears on startup.  
                Properties: create, query

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def window(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., backgroundColor: Tuple[float, float, float] = ..., closeCommand: Callable[..., Any] = ..., defineTemplate: str = ..., docTag: Queryable[str] = ..., dockCorner: Multiuse[Tuple[str, str]] = ..., dockStation: bool = ..., dockingLayout: Queryable[str] = ..., exists: bool = ..., frontWindow: bool = ..., height: Queryable[int] = ..., iconName: Queryable[str] = ..., iconify: bool = ..., interactivePlacement: bool = ..., leftEdge: Queryable[int] = ..., mainMenuBar: bool = ..., mainWindow: bool = ..., maximizeButton: bool = ..., menuArray: bool = ..., menuBar: bool = ..., menuBarCornerWidget: Queryable[Tuple[str, str]] = ..., menuBarResize: bool = ..., menuBarVisible: bool = ..., menuIndex: Tuple[str, int] = ..., minimizeButton: bool = ..., minimizeCommand: Callable[..., Any] = ..., nestedDockingEnabled: bool = ..., numberOfMenus: bool = ..., parent: str = ..., resizeToFitChildren: bool = ..., restoreCommand: Callable[..., Any] = ..., retain: bool = ..., sizeable: bool = ..., state: Queryable[str] = ..., title: Queryable[str] = ..., titleBar: bool = ..., titleBarMenu: bool = ..., toolbox: bool = ..., topEdge: Queryable[int] = ..., topLeftCorner: Queryable[Tuple[int, int]] = ..., useTemplate: str = ..., visible: bool = ..., width: Queryable[int] = ..., widthHeight: Queryable[Tuple[int, int]] = ...) -> Union[str, bool, int, Tuple[str, str], Tuple[int, int]]:
    """This command creates a new window but leaves it invisible. It is most
    efficient to add the window's elements and then make it visible with
    the showWindow command. The window can have an optional menu bar. Also,
    the title bar and minimize/maximize buttons can be turned on or off. If the
    title bar is off, then you cannot have minimize or maximize buttons.Note: The window will require a control layout of some kind
    to arrange the controls (buttons, sliders, fields, etc.).  Examples of
    control layouts are columnLayout, formLayout, rowLayout, etc.Note: This command will clear the uiTemplate stack.  Templates for
    a window need to be set after the window cmd.
    Args:
        backgroundColor (Tuple[float, float, float]?): The background color of the window. The arguments correspond  
                to the red, green, and blue color components. Each component ranges  
                in value from 0.0 to 1.0.  
                Properties: create, edit
        closeCommand (Callable[..., Any]?): Script executed after the window is closed.  
                Properties: create, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        docTag (Queryable[str]?): Attach a tag to the window.  
                Properties: create, query, edit
        dockCorner (Multiuse[Tuple[str, str]]?): Specifies which docking areas occupied the four different corners of the window.  
                By default docking windows on the bottom or top will span the whole window.  
                Use multiple instances of this flag to allow the left and right docking areas to occupy the corners.  
                This method has two arguments: docking corner and docking area.  
                Possible values for docking corner are "topLeft", "topRight", bottomLeft", and "bottomRight".  
                Possible values for docking area are "left", "right", "top", and "bottom".  
                Properties: create, multiuse
        dockStation (bool?): When set this flag specifies that this window can contain other docked sub-windows.  
                Properties: create
        dockingLayout (Queryable[str]?): When queried this flag will return a string holding the docking layout information.  
                This string can be set when creating or editing a docking station to restore the previous docking layout.  
                This string is a hexadecimal representation of a binary string and is not meant to be humanly readable,  
                but can be saved and loaded using the optionVar command to restore layouts across sessions of Maya.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        frontWindow (bool?): Return the name of the front window.  Note: you must supply  
                the name of any window (the window does not need to exist).  
                Returns "unknown" if the front window cannot be determined.  
                Properties: query
        height (Queryable[int]?): Height of the window excluding any window frame in pixels.  
                Properties: create, query, edit
        iconName (Queryable[str]?): The window's icon title.  By default it is the same as the  
                window's title.  
                Properties: create, query, edit
        iconify (bool?): Icon state of the window.  
                Properties: create, query, edit
        interactivePlacement (bool?): Deprecated flag. Recognized but not implemented.  
                This flag will be removed in a future version of Maya.  
                Properties: create
        leftEdge (Queryable[int]?): Position of the left edge of the window.  
                Properties: create, query, edit
        mainMenuBar (bool?): If this flag is used then the main menu bar will be enabled.  
                Properties: create, query, edit
        mainWindow (bool?): Main window for the application.  The main window  
                has an 'Exit' item in the Window Manager menu.  By default, the  
                first created window becomes the main window.  
                Properties: create, query, edit
        maximizeButton (bool?): Turns the window's maximize button on or off.  
                Properties: create, query, edit
        menuArray (bool?): Return a string array containing the names of the menus in  
                the window's menu bar.  
                Properties: query
        menuBar (bool?): Adds an empty menu bar to the window.  
                The Qt name of the object will be m_menubar_nameOfTheWindow.  
                Properties: create, query
        menuBarCornerWidget (Queryable[Tuple[str, str]]?): This flag specifies a widget to add to a corner of the parent window.  
                The first argument corresponds to the widget name and the second to the position of the widget.  
                Possible values for widget position are "topLeft", "topRight", "bottomLeft", "bottomRight".  
                In query mode this flag returns all the corner widget names in the following order: topLeft, topRight, bottomLeft, bottomRight.  
                Add the -mbr/-menuBarResize flag to the changeCommand of widget passed (first argument) so that it will always have an  
                appropriate size.  
                Properties: query, edit
        menuBarResize (bool?): This flag should be used with the -mcw/-menuBarCornerWidget flag. This is used to resize the  
                menu bar so that the corner widgets are updated.  
                Properties: edit
        menuBarVisible (bool?): Visibility of the menu bar (if there is one).  
                Properties: create, query, edit
        menuIndex (Tuple[str, int]?): Sets the index of a specified menu.  
                Properties: edit
        minimizeButton (bool?): Turns the window's minimize button on or off.  
                Properties: create, query, edit
        minimizeCommand (Callable[..., Any]?): Script executed after the window is minimized (iconified).  
                Properties: create, edit
        nestedDockingEnabled (bool?): Controls whether nested docking is enabled or not.  Nested docking allows  
                for docking windows next to other docked windows for more possible arrangement styles.  
                Properties: create
        numberOfMenus (bool?): Return the number of menus attached to the window's menu bar.  
                Properties: query
        parent (str?): Specifies a parent window or layout which the created window is  
                always on top of. Note: If the parent is a window the created window  
                is not modal, so events are still propagated to the parent window.  
                Properties: create
        resizeToFitChildren (bool?): The window will always grow/shrink to just fit  
                the controls it contains.  
                Properties: create, query, edit
        restoreCommand (Callable[..., Any]?): Script executed after the window is restored from  
                it's minimized (iconified) state.  
                Properties: create, edit
        retain (bool?): Retains the window after it has been closed.  The default is  
                to delete the window when it is closed.  
                Properties: create
        sizeable (bool?): Whether or not the window may be interactively resized.  
                Properties: create, query, edit
        state (Queryable[str]?): When queried this flag will return a string holding the window state information.  
                This string is a hexadecimal representation of a binary string and is not meant to be humanly readable,  
                but can be saved and loaded using the optionVar command to restore window state across sessions of Maya.  
                Properties: create, query, edit
        title (Queryable[str]?): The window's title.  
                Properties: create, query, edit
        titleBar (bool?): Turns the window's title bar on or off.  
                Properties: create, query, edit
        titleBarMenu (bool?): Controls whether the title bar menu exists in the window  
                title bar. Only valid if -tb/titleBar is true. This Windows  
                only flag is true by default.  
                Properties: create, query, edit
        toolbox (bool?): Makes this a toolbox style window.  A Windows only  
                flag that makes the title bar smaller and uses a slightly  
                different display style.  
                Properties: create, query, edit
        topEdge (Queryable[int]?): Position of the top edge of the window.  
                Properties: create, query, edit
        topLeftCorner (Queryable[Tuple[int, int]]?): Position of the window's top left corner.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The window's visibility.  
                Properties: create, query, edit
        width (Queryable[int]?): Width of the window excluding any window frame in pixels.  
                Properties: create, query, edit
        widthHeight (Queryable[Tuple[int, int]]?): Window's width and height excluding any window frame in pixels.  
                Properties: create, query, edit

    Returns:
        str: Name to the window.

    Example:
    """

def windowPref(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., enableAll: bool = ..., exists: bool = ..., height: Queryable[int] = ..., leftEdge: Queryable[int] = ..., loadAll: bool = ..., maximized: bool = ..., parentMain: bool = ..., remove: bool = ..., removeAll: bool = ..., restoreMainWindowState: str = ..., saveAll: bool = ..., saveMainWindowState: str = ..., topEdge: Queryable[int] = ..., topLeftCorner: Queryable[Tuple[int, int]] = ..., width: Queryable[int] = ..., widthHeight: Queryable[Tuple[int, int]] = ...) -> Union[bool, int, Tuple[int, int]]:
    """Create or modify preferred window attributes.  The size and position
    of a window is retained during and between application sessions.  A
    default window preference is created when a window is closed.  Window
    preferences must be named and, consequently, only affect the window
    with a matching name.Note that window preferences are not applied to the main Maya window
    nor the Command window.
    Args:
        enableAll (bool?): Enable/disable all window preferences.  Preferences are enabled  
                by default.  Set this flag to false and window's will ignore all  
                preference values.  
                Properties: create, query
        exists (bool?): Returns true|false depending upon whether the specified object  
                exists. Other flags are ignored.  
                Properties: create
        height (Queryable[int]?): Height of the window.  
                Properties: create, query, edit
        leftEdge (Queryable[int]?): Left edge position of the window.  
                Properties: create, query, edit
        loadAll (bool?): Reads in file with window attributes from disk.  
                Properties: create
        maximized (bool?): Maximize the window.  
                Properties: create, query, edit
        parentMain (bool?): Set whether window is parented to main application window. Windows only.  
                Properties: create, query
        remove (bool?): Remove a window preference.  
                Properties: create
        removeAll (bool?): Remove all window preferences.  
                Properties: create
        restoreMainWindowState (str?): Reads in file with main window state (positions of toolbars and dock controls).  
                Properties: create
        saveAll (bool?): Writes out file with window attributes.  
                Properties: create
        saveMainWindowState (str?): Writes out file with main window state (positions of toolbars and dock controls).  
                Properties: create
        topEdge (Queryable[int]?): Top edge position of the window.  
                Properties: create, query, edit
        topLeftCorner (Queryable[Tuple[int, int]]?): Top and left edge position of the window.  
                Properties: create, query, edit
        width (Queryable[int]?): Width of the window.  
                Properties: create, query, edit
        widthHeight (Queryable[Tuple[int, int]]?): Width and height of the window.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def wire(*args: str, edit: bool = ..., query: bool = ..., after: bool = ..., afterReference: bool = ..., before: bool = ..., components: bool = ..., crossingEffect: Queryable[float] = ..., deformerTools: bool = ..., dropoffDistance: Queryable[Multiuse[Tuple[int, float]]] = ..., envelope: Queryable[float] = ..., exclusive: Queryable[str] = ..., frontOfChain: bool = ..., geometry: Queryable[Multiuse[str]] = ..., geometryIndices: bool = ..., groupWithBase: bool = ..., holder: Queryable[Multiuse[Tuple[int, str]]] = ..., ignoreSelected: bool = ..., includeHiddenSelections: bool = ..., localInfluence: Queryable[float] = ..., name: str = ..., parallel: bool = ..., prune: bool = ..., remove: Multiuse[bool] = ..., selectedComponents: bool = ..., split: bool = ..., useComponentTags: bool = ..., wire: Queryable[Multiuse[str]] = ..., wireCount: Queryable[int] = ...) -> Union[List[str], bool, float, Multiuse[Tuple[int, float]], str, Multiuse[str], Multiuse[Tuple[int, str]], int]:
    """This command creates a wire deformer.In the create mode the selection list is treated as the
    object(s) to be deformed, Wires are specified with the -w flag.
    Each wire can optionally have a holder which helps define the
    the regon of the object that is affected by the deformer.
    Args:
        after (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node after the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        afterReference (bool?): The -afterReference flag is used to specify deformer ordering in a hybrid way that  
                choses between -before and -after automatically. If the geometry being  
                deformed is referenced then the -after mode is used when adding the new deformer,  
                otherwise the -before mode is used. The net effect when using -afterReference to build  
                deformer chains is that internal shape nodes in the deformer chain will only  
                appear at reference file boundaries, leading to lightweight deformer networks that  
                may be more amicable to reference swapping.  
                Properties: create, edit
        before (bool?): If the default behavior for insertion/appending into/onto  
                the existing chain is not the desired behavior then this flag  
                can be used to force the command to place the deformer  
                node before the selected node in the chain even if  
                a new geometry shape has to be created in order to do so.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        components (bool?): Returns the components used by the deformer  
                Properties: query
        crossingEffect (Queryable[float]?): Set the amount of convolution effect. Varies from fully  
                convolved at 0 to a simple additive effect at 1 (which  
                is what you get with the filter off).  
                Default is 0.  
                 This filter should make its way into all  
                blend nodes that deal with combining effects from  
                multiple sources.  
                Properties: create, query, edit
        deformerTools (bool?): Returns the name of the deformer tool objects (if any)  
                as string string ...  
                Properties: query
        dropoffDistance (Queryable[Multiuse[Tuple[int, float]]]?): Set the dropoff distance (second parameter) for the wire at index (first parameter).  
                Properties: create, query, edit, multiuse
        envelope (Queryable[float]?): Set the envelope value for the deformer. Default is 1.0  
                Properties: create, query, edit
        exclusive (Queryable[str]?): Puts the deformation set in a deform partition.  
                Properties: create, query
        frontOfChain (bool?): This command is used to specify that the new deformer  
                node should be placed ahead (upstream) of existing deformer  
                and skin nodes in the shape's history (but not ahead of  
                existing tweak nodes). The input to the  
                deformer will be the upstream shape rather than the visible  
                downstream shape, so the behavior of this flag is the most  
                intuitive if the downstream deformers are in their reset  
                (hasNoEffect) position when the new deformer is added.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        geometry (Queryable[Multiuse[str]]?): The specified object will be added to the list of  
                objects being deformed by this deformer object, unless  
                the -rm flag is also specified. When queried, this flag  
                returns string string string ...  
                Properties: query, edit, multiuse
        geometryIndices (bool?): Complements the -geometry flag in query mode. Returns  
                the multi index of each geometry.  
                Properties: query
        groupWithBase (bool?): Groups the wire with the base wire so that they can easily be moved  
                together to create a ripple effect.  
                Default is false.  
                Properties: create
        holder (Queryable[Multiuse[Tuple[int, str]]]?): Set the specified curve or surface (second parameter  as a holder for the wire at index (first parameter).  
                Properties: create, query, edit, multiuse
        ignoreSelected (bool?): Tells the command to not deform objects on the  
                current selection list  
                Properties: create
        includeHiddenSelections (bool?): Apply the deformer to any visible and hidden objects in the selection list.  
                Default is false.  
                Properties: create
        localInfluence (Queryable[float]?): Set the local control a wire has with respect to other  
                wires irrespective of whether it is deforming the surface.  
                Varies from no local effect at 0 to full local control  
                at 1.  
                Default is 0.  
                Properties: create, query, edit
        name (str?): Used to specify the name of the node being created.  
                Properties: create
        parallel (bool?): Inserts the new deformer in a parallel chain to any existing deformers in  
                the history of the object. A blendShape is inserted to blend the parallel  
                results together.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        prune (bool?): Removes any points not being deformed by the deformer in  
                its current configuration from the deformer set.  
                Properties: edit
        remove (Multiuse[bool]?): Specifies that objects listed after the -g flag should  
                be removed from this deformer.  
                Properties: edit, multiuse
        selectedComponents (bool?): Returns the components used by the deformer that are currently selected.  
                This intersects the current selection with the components affected by the deformer.  
                Properties: query
        split (bool?): Branches off a new chain in the dependency graph instead  
                of inserting/appending the deformer into/onto an  
                existing chain.  
                Works in create mode (and edit mode if the deformer has  
                no geometry added yet).  
                Properties: create, edit
        useComponentTags (bool?): When this flag is specified a setup using componentTags will be created.  
                This means no groupId, groupParts, tweak or objectSet nodes will be  
                created and connected to the new deformer.  
                Properties: create
        wire (Queryable[Multiuse[str]]?): Specify or query the wire curve name.  
                Properties: create, query, edit, multiuse
        wireCount (Queryable[int]?): Set the number of wires.  
                Properties: create, query, edit

    Returns:
        List[str]: The wire node name and the wire curve name

    Example:
    """

def wireContext(*args: Any, edit: bool = ..., query: bool = ..., crossingEffect: Queryable[float] = ..., deformationOrder: Queryable[str] = ..., dropoffDistance: Queryable[float] = ..., envelope: Queryable[float] = ..., exclusive: bool = ..., exclusivePartition: Queryable[str] = ..., exists: bool = ..., groupWithBase: bool = ..., history: bool = ..., holder: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., localInfluence: Queryable[float] = ..., name: str = ...) -> Union[str, float, bool]:
    """This command creates a tool that can be used to
    create a wire deformer.
    Args:
        crossingEffect (Queryable[float]?): Set the amount of convolution filter effect. Varies from fully  
                convolved at 0 to a simple additive effect at 1.  
                Default is 0.  
                Properties: create, query, edit
        deformationOrder (Queryable[str]?): Set the appropriate flag that determines the position in  
                in the deformation hierarchy.  
                Properties: create, query, edit
        dropoffDistance (Queryable[float]?): Set the dropoff Distance for the wires.  
                Properties: create, query, edit
        envelope (Queryable[float]?): Set the envelope value for the deformer. Default is 1.0  
                Properties: create, query, edit
        exclusive (bool?): Set exclusive mode on or off.  
                Properties: create, query, edit
        exclusivePartition (Queryable[str]?): Set the name of an exclusive partition.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        groupWithBase (bool?): Groups the wire with the base wire so that they can easily be moved  
                together to create a ripple effect.  
                Default is false.  
                Properties: create, query, edit
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        holder (bool?): Controls whether the user can specify holders for the wires  
                from the wire context. A holder is a curve that you can use to limit  
                the wire's deformation region. Default is false.  
                Properties: create, edit
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        localInfluence (Queryable[float]?): Set the amount of local influence a wire has with respect  
                to other wires.  
                Default is 0.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create

    Returns:
        str: The name of the context created

    Example:
    """

def workspace(arg0: str = ..., /, *, query: bool = ..., active: bool = ..., baseWorkspace: Queryable[str] = ..., create: str = ..., directory: Queryable[str] = ..., expandName: Queryable[str] = ..., fileRule: Queryable[Tuple[str, str]] = ..., fileRuleEntry: Queryable[str] = ..., fileRuleList: bool = ..., filter: bool = ..., fullName: bool = ..., list: bool = ..., listFullWorkspaces: bool = ..., listWorkspaces: bool = ..., newWorkspace: bool = ..., objectType: Queryable[Tuple[str, str]] = ..., objectTypeEntry: Queryable[str] = ..., objectTypeList: bool = ..., openWorkspace: bool = ..., projectPath: Queryable[str] = ..., removeFileRuleEntry: str = ..., removeVariableEntry: str = ..., renderType: Queryable[Tuple[str, str]] = ..., renderTypeEntry: Queryable[str] = ..., renderTypeList: bool = ..., rootDirectory: bool = ..., saveWorkspace: bool = ..., shortName: bool = ..., update: bool = ..., updateAll: bool = ..., variable: Queryable[Tuple[str, str]] = ..., variableEntry: Queryable[str] = ..., variableList: bool = ...) -> Union[None, str, List[str], bool, Tuple[str, str]]:
    """Create, open, or edit a workspace associated with a given workspace
    file.The string argument represents the workspace. If no workspace is
    specified then the current workspace is assumed.A workspace provides the underlying definition of a Maya Project.
    Each project has an associated workspace file, named workspace.mel, which is stored in the project root directory.
    The workspace file defines a set of rules that map file types to their storage, either relative to the
    project root or as an absolute location.  These rules are used when resolving file paths at runtime.The workspace command operates directly on the low-level definition of the workspace to read, change and store
    the definition to the underlying file.  Use of this command is not generally required, for most purposes
    it is recommended that project definition changes be done via the Project Window in the User Interface. Multiple
    actions go under the assumption that given paths exist.
    Args:
        active (bool?): This flag is a synonym for -o/openWorkspace.  
                Properties: create, query
        baseWorkspace (Queryable[str]?): A workspace may be based on another workspace.  This means  
                that all the file rules and variables in the base workspace  
                apply to this workspace unless they are explicitly overridden.  
                By default, a new workspace has the workspace "default" as  
                it's base workspace. Note that "duplicated" file rules  
                containing relative paths are not verified nor created when  
                creating a new workspace or when changing the base workspace.  
                Properties: query
        create (str?): Create a new directory.  If the directory name is not  
                a full path name, it will be created as a subdirectory of  
                the "current" directory set with the -dir flag. Note that this  
                flag does not create a workspace.  
                Properties: create
        directory (Queryable[str]?): This option will set the current workspace directory to the  
                path specified. When queried it will return the current workspace  
                directory. This directory is used as an initial directory for the  
                fileBrowser and is part of the search path used for locating  
                files. It should not be confused with the current working  
                directory as used by the pwd and chdir commands.  
                When the file browser is used, it will set this value to the last  
                location navigated to.  
                Properties: create, query
        expandName (Queryable[str]?): Query for the full path location of a filename using the current workspace definition.  
                The path may be a project relative file name, a full path name or a variable name.  
                The return value is always a full path name.  
                If the path is an empty string, the return value will be the project root directory.  
                Variable expansion is supported, and will consider both variables defined in the workspace  
                as well as environment variables.  
                There are three formats supported for expanding variable names:  
                %variableName%, $variableName, ${variableName}.  
                Maya will first attempt to find matching variables defined in the current workspace,  
                then search for a matching environment variable.  
                The tilde character ('~') is also supported.  
                If a tilde is located at the beginning of a variable, Maya  
                will only consider and expand environment variables, and will leave the tilde in the  
                expanded result.  
                On linux and mac platforms, a tilde can be used to expand a user's home directory,  
                using the form ~username, ~, or ~/.  When specified as ~username, it will be replaced  
                with the corresponding user's home directory.  When specified as ~ or ~/, it will  
                be replaced with the value of the HOME environment variable.  
                Properties: create, query
        fileRule (Queryable[Tuple[str, str]]?): Set the default location for a file. The first parameter is  
                the fileRule name(scenes, images, etc) and the second is the location. When  
                queried, it returns a list of strings.  The elements of the  
                returned list alternate between fileRule names and the corresponding  
                location.  There is typically one file rule for each available  
                translator. Environment variables are supported.  
                You can set multiple path for the file rule by separating them with  
                semicolons (;) on Windows and colons(:) on MacOSX and Linux.  
                Note that whitespace at the beginning and end of each item in the  
                separated sequence is significant and will be included as part of the  
                path name (which is not usually desired unless the pathname does  
                actually start or end with spaces).  
                A valid filerule name cannot contain multiple byte characters. Note that  
                creating a filerule does not create any directories. It is the user's  
                responsibility to ensure that all paths are valid.  
                Properties: create, query
        fileRuleEntry (Queryable[str]?): Return the location for the given fileRule.  
                Properties: create, query
        fileRuleList (bool?): Returns a list of the currently defined file rules.  
                Properties: create, query
        filter (bool?): This flag is obsolete.
        fullName (bool?): Return the full name of the workspace.  
                Properties: create, query
        list (bool?): This option will list the current workspace directory. If a  
                path is specified for the "workspaceFile" then the contents of that  
                directory will be listed.  Otherwise, the contents of the directory  
                set with the -dir flag will be listed.  
                Properties: create, query
        listFullWorkspaces (bool?): Returns a list of the full path names of all the currently  
                defined workspaces.  
                Properties: create, query
        listWorkspaces (bool?): Returns a list of all the currently defined workspace  
                names.  
                Properties: create, query
        newWorkspace (bool?): This specifies that a new workspace is being created with a given  
                path (full path or relative to "current" directory). If a  
                workspace with this path already exists, the command will fail.  
                Note that the application is creating a virtual workspace without creating  
                any new directories. If given a relative path, it will map the  
                new workspace to the "current" directory set with the -dir flag  
                concatenated with the given path. If the path does not exist, it  
                will default the workspace root directory -rd to the system's root  
                path (e.g. C:\\ or '/'). It is the user's responsibility to ensure  
                that all paths exist.  
                Properties: create
        objectType (Queryable[Tuple[str, str]]?): This flag is obsolete. All default locations will be added to the  
                fileRules going forward.  
                Properties: create, query
        objectTypeEntry (Queryable[str]?): This flag is obsolete. This will now return the same as fileRuleEntry.  
                Properties: create, query
        objectTypeList (bool?): This flag is obsolete. This will now return the same results as  
                fileRuleList going forward.  
                Properties: create, query
        openWorkspace (bool?): Open the workspace.  The workspace becomes the current  
                workspace.  
                Properties: create, query
        projectPath (Queryable[str]?): Convert filePath passed as argument to a filename that is relative to the  
                project root directory (if possible) and return it.  If the  
                filePath is not under the project root directory, a full path  
                name will be returned.  
                Properties: create, query
        removeFileRuleEntry (str?): Remove the given file rule from the specified workspace. If the  
                workspace name is not specified, the given file rule will be removed from  
                the current workspace.  
                Properties: create
        removeVariableEntry (str?): Remove the given variable from the specified workspace. If the  
                workspace name is not specified, the given variable will be removed from  
                the current workspace.  
                Properties: create
        renderType (Queryable[Tuple[str, str]]?): This flag is obsolete. All default render types will be added to  
                fileRules going forward.  
                Properties: create, query
        renderTypeEntry (Queryable[str]?): This flag is obsolete, use fileRuleEntry going forward  
                Properties: create, query
        renderTypeList (bool?): This flag is obsolete, use fileRuleList going forward.  
                Properties: create, query
        rootDirectory (bool?): Returns the root directory of the workspace.  
                Properties: query
        saveWorkspace (bool?): Save the workspace.  Workspaces are normally saved when  
                Maya exits but this flag will make sure that the data is  
                flushed to disk.  
                Properties: create
        shortName (bool?): Query the short name of the workspace.  
                Properties: create, query
        update (bool?): This flag reads all the workspace definitions from the project  
                directory.  It is used by Maya at startup time to find the available  
                workspaces.  
                Properties: create
        updateAll (bool?): This flag is a synonym for -u/update.  
                Properties: create
        variable (Queryable[Tuple[str, str]]?): Set or query the value of a project variable. Project variables  
                are used when expanding names. See the -en/expandName flag below.  
                Properties: create, query
        variableEntry (Queryable[str]?): Given a variable name, will return its value.  
                Properties: create, query
        variableList (bool?): Return a list of all variables in the workspace.  
                Properties: create, query

    Returns:
        None: Depending upon the requested action.
        str: Project short name when querying the 'shortName' flag.
        str: Project full name when querying the 'fullName' flag.
        str: Current workspace name when querying the 'openWorkspace' flag and there is a current one.
        str: Working space directory when querying the 'directory' flag.
        str: File rule on the current workspace when querying one of the 'renderTypeEntry', 'fileRuleEntry', or 'objectTypeEntry' flags.
        str: File rule on the current workspace when querying the 'variableEntry' flag.
        str: Resolved full name of the given file name, or the current root directory if no name given when querying the 'expandName' flag.
        str: Path to the current project workspace when querying the 'projectPath' flag.
        str: Current workspace's base workspace name when querying the 'baseWorkspace' flag.
        str: Current workspace's root directory when querying the 'rootDirectory' flag.
        List[str]: List of file rules when querying the 'fileRule' flag.
        List[str]: List of variables when querying the 'variableList' flag.
        List[str]: List of all workspaces when querying the 'listWorkspaces' flag.
        List[str]: List of full names of all workspaces when querying the 'listFullWorkspaces' flag.
        List[str]: List of path names for all workspace in the directory named when querying the 'list' flag or the current workspace if no directory is named.
        List[str]: List of alternating (file rule, rule location) strings corresponding to the current workspace's file rules.
        List[str]: List of alternating (variable, value) strings corresponding to the current workspace's variables.

    Example:
    """

def workspaceControl(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., actLikeMayaUIElement: bool = ..., checksPlugins: bool = ..., close: bool = ..., closeCommand: Callable[..., Any] = ..., collapse: bool = ..., defineTemplate: str = ..., dockToControl: Tuple[str, str] = ..., dockToMainWindow: Tuple[str, bool] = ..., dockToPanel: Tuple[str, str, bool] = ..., duplicatable: bool = ..., exists: bool = ..., floating: bool = ..., height: bool = ..., heightProperty: Queryable[str] = ..., horizontal: bool = ..., initCallback: Queryable[str] = ..., initialHeight: int = ..., initialWidth: int = ..., label: Queryable[str] = ..., layoutDirectionCallback: Queryable[str] = ..., loadImmediately: bool = ..., minimumHeight: Queryable[int] = ..., minimumWidth: Queryable[int] = ..., r: bool = ..., requiredControl: Multiuse[str] = ..., requiredPlugin: Multiuse[str] = ..., resizeHeight: int = ..., resizeWidth: int = ..., restore: bool = ..., retain: bool = ..., stateString: Queryable[str] = ..., tabPosition: Queryable[Tuple[str, bool]] = ..., tabToControl: Tuple[str, int] = ..., uiScript: Callable[..., Any] = ..., useTemplate: str = ..., visible: bool = ..., visibleChangeCommand: Callable[..., Any] = ..., width: bool = ..., widthProperty: Queryable[str] = ...) -> Union[str, bool, int, Tuple[str, bool]]:
    """Creates and manages the widget used to host windows in a layout that enables docking and stacking windows together.
    Args:
        actLikeMayaUIElement (bool?): Controls whether or not this workspace control acts like Maya UI Elements such as the Shelf  
                and the Tool Box.  
              
                For example, this hides the tab bar and shows a toolbar grip on the end of the control to  
                allow undocking.  
                Properties: create, query, edit
        checksPlugins (bool?): Sets whether the UI (as defined by the uiScript) checks the loaded state of one or more plug-ins in its code.  
                The UI will not be loaded until the auto-loading of plug-ins is complete. Default value is false.  
                Properties: create, edit
        close (bool?): Closes the workspace control.  
                Properties: edit
        closeCommand (Callable[..., Any]?): Command that gets executed when the workspace control is closed.  
                Properties: create, edit
        collapse (bool?): Collapse or expand the tab widget parent of the workspace control.  
                Properties: create, query, edit
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        dockToControl (Tuple[str, str]?): Dock this workspace control next to the given control. The first argument is the control name,  
                the second is dock position relative to the control (valid values are: "left", "right", "top", "bottom").  
                Properties: create, edit
        dockToMainWindow (Tuple[str, bool]?): Dock this workspace control into the main window. The first argument is the dock position along the sides of  
                the main window (valid values are: "left", "right", "top", "bottom"), the second specifies whether the  
                control should be tabbed into the first control found at the dock position.  
                Properties: create, edit
        dockToPanel (Tuple[str, str, bool]?): Dock this workspace control into the workspace docking panel that the given workspace control is in. The first argument  
                is the control name, the second is dock position along the sides of the panel (valid values are: "left", "right", "top",  
                "bottom"), the third specifies whether the control should be tabbed into the first control found at the dock position.  
                Properties: create, edit
        duplicatable (bool?): Controls whether or not this workspace control can be duplicated.  
              
                The default duplicate state is controlled by whether or not the panel is unique. Unique panels cannot be  
                duplicated or copied. Workspace controls without a panel also cannot be duplicated, unless specifically  
                set as such using this flag.  
                Properties: create, query, edit
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        floating (bool?): Whether the workspace control is floating.  
                Properties: create, query, edit
        height (bool?): Query only flag returning the current height of the control.  
                Properties: query
        heightProperty (Queryable[str]?): Set height property of the workspace control.  
                Valid values are:  
              
                fixed	  - Cannot be resized manually and will not be given any extra space while maximizing/dynamically resizing  
                preferred - Can be resized manually but will not be given any extra space while maximizing/dynamically resizing  
                free	  - Can be resized manually and will be given extra space while maximizing/dynamically resizing  
              
                Default: free   
                In query mode returns the current height property of the workspace control.  
                Properties: create, query, edit
        horizontal (bool?): Orientation of the control. This flag is true by default, which corresponds to a horizontally oriented widget.  
              
                Note: currently only "Toolbox" and "Shelf" support a vertical orientation.  
                Properties: create, query, edit
        initCallback (Queryable[str]?): Adds a mel command to be executed when the control is added to the layout.  
                The command should be a mel proc and it will be called with the workspaceControl name as parameter.  
                The mel command should take the form:  
              
                global proc callbackName(string $workspaceControlName)  
              
                If "save" is appended to the command name, it will be called during the layout save.  
              
                global proc callbackNameSave(string $workspaceControlName)  
                Properties: create, query, edit
        initialHeight (int?): The initial height of the workspace control when first shown.  
                Properties: create, edit
        initialWidth (int?): The initial width of the workspace control when first shown.  
                Properties: create, edit
        label (Queryable[str]?): The label text. The default label is the name of the workspace control.  
                Properties: create, query, edit
        layoutDirectionCallback (Queryable[str]?): Set a mel procedure to be called when the control changes orientation. The procedure is  
                called with argument 1 for horizontal and 0 for vertical.  
                Properties: create, query, edit
        loadImmediately (bool?): Sets whether the UI (as defined by the uiScript) will be built immediately on workspace control  
                creation (true) or delayed until the control is actually shown (false). Default value is false.  
                Properties: create, edit
        minimumHeight (Queryable[int]?): Sets the minimum height of control to the given value.  
              
                If given value is 0 (False), minimum height is set to 0.  
                If given value is 1 (True), minimum height is set to initial height.  
                If given value is greater than 1, minimum height is set to the given value.  
              
                In query mode returns current minimum height of the control.  
                Properties: create, query, edit
        minimumWidth (Queryable[int]?): Sets the minimum width of control to the given value.  
                This flag parameter was changed from bool to int in 2018 and old settings are still respected according to the following.  
              
                If given value is 0 (False), minimum width is set to 0.  
                If given value is 1 (True), minimum width is set to initial width.  
                If given value is greater than 1, minimum width is set to the given value.  
              
                In query mode returns current minimum width of the control.  
                Properties: create, query, edit
        r (bool?): Raises a workspace control to the top and makes it active.  
                In Query mode, this flag will return whether the workspace control is active or not.  
                Note that this flag won't raise a control if is minimized or collapsed. Use the flag -rs/restore instead.  
                Properties: query, edit
        requiredControl (Multiuse[str]?): The name of a workspace control that needs to be open in order for this workspace control to properly function.  
                This workspace control will not be created if the required control is not open, and will be closed when the  
                required control is closed.  
                Properties: create, edit, multiuse
        requiredPlugin (Multiuse[str]?): The name of a plug-in that needs to be loaded in order to build the workspace control UI.  
                Properties: create, edit, multiuse
        resizeHeight (int?): Resizes a floating workspace control's height to the given value.  
                Properties: edit
        resizeWidth (int?): Resizes a floating workspace control's width to the given value.  
                Properties: edit
        restore (bool?): Restores the control according to the following rules:  
              
                If collapsed then the control will be expanded  
                If hidden then the control will be shown  
                If minimized then the control will be restored  
                If the control is an inactive tab into a tab group then it will become the active tab  
                Properties: create, edit
        retain (bool?): Sets whether the workspace control is retained (i.e. only hidden) or deleted when closed. Default value is true.  
                Properties: create
        stateString (Queryable[str]?): String containing the state of the control.  
                Can be used with the initCallback flag.  
                Properties: create, query, edit
        tabPosition (Queryable[Tuple[str, bool]]?): Changes the tab position. The possible values are: "north", "east" and "west".  
                The boolean value, if set to true, changes the tab positions of all the controls in the parent widget.  
                If it is not set, only the current control will get its position changed.  
                A control can have a different orientation than the tab widget.  
                If the control tab position is different from the tab widget's one, the tab position will be changed when the control becomes the only control in the tab widget.  
                On query, only the control's tab position will be returned, not the tab widget's position. They may differ.  
                Properties: create, query, edit
        tabToControl (Tuple[str, int]?): Tab this workspace control into the given control. The first argument is the control name,  
                the second is the index position within the containing tab widget (invalid values mean append).  
                Properties: create, edit
        uiScript (Callable[..., Any]?): The specified script will be invoked to build the UI of the workspaceControl.  This is a required flag.  
                Properties: create, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create
        visible (bool?): The visible state of the workspace control. A control is created visible by default.  
                If the control is created as not visible, the control will be created in a closed state.  
                To make it appear, edit the control to set the flags floating or the flag visible to true.  
                Use -r/raise flag to get the active status of a control as this flag will return true when the control  
                is minimized or collapsed.  
                Properties: create, query, edit
        visibleChangeCommand (Callable[..., Any]?): Command that gets executed when visible state of the workspace control changes.  
                Properties: create, edit
        width (bool?): Query only flag returning the current width of the control.  
                Properties: query
        widthProperty (Queryable[str]?): Set width property of the workspace control.  
                Valid values are:  
              
                fixed	  - Cannot be resized manually and will not be given any extra space while maximizing/dynamically resizing  
                preferred - Can be resized manually but will not be given any extra space while maximizing/dynamically resizing  
                free	  - Can be resized manually and will be given extra space while maximizing/dynamically resizing  
              
                Default: free   
                In query mode returns the current width property of the workspace control.  
                Properties: create, query, edit

    Returns:
        str: Full path name to the control.

    Example:
    """

def workspaceControlState(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., defaultTopLeftCorner: Queryable[Tuple[int, int]] = ..., defaultWidthHeight: Queryable[Tuple[int, int]] = ..., exists: bool = ..., height: Queryable[int] = ..., leftEdge: Queryable[int] = ..., maximized: bool = ..., remove: bool = ..., topEdge: Queryable[int] = ..., topLeftCorner: Queryable[Tuple[int, int]] = ..., width: Queryable[int] = ..., widthHeight: Queryable[Tuple[int, int]] = ...) -> Union[bool, Tuple[int, int], int]:
    """Create or modify preferred window attributes for workspace controls.
    The size and position of a workspace control is retained during application
    sessions (although position only applies to workspace controls that are
    alone in a floating workspace docking panel). A default workspace control
    state is created when a workspace control is closed. Workspace control
    states must be named and, consequently, only affect the workspace control
    with a matching name.
    Args:
        defaultTopLeftCorner (Queryable[Tuple[int, int]]?): Top and left edge position that the window will have when "Remember size and position" is off and when the panel is first opened.  
                The values will be DPI scaled on edit and the value in query is returned unscaled.  
                This value will only be used if the default width and height are also valid.  
                Properties: create, query, edit
        defaultWidthHeight (Queryable[Tuple[int, int]]?): Width and height that the window will have when "Remember size and position" is off and when the panel is first opened.  
                The values will be DPI scaled on edit and the value in query is returned unscaled.  
                The position used in that case is defaultTopLeftCorner.  
                Properties: create, query, edit
        exists (bool?): Returns true|false depending upon whether the specified object  
                exists. Other flags are ignored.  
                Properties: create
        height (Queryable[int]?): Height of the window.  
                Properties: create, query, edit
        leftEdge (Queryable[int]?): Left edge position of the window.  
                Properties: create, query, edit
        maximized (bool?): Maximize the window.  
                Properties: create, query, edit
        remove (bool?): Remove a window preference.  
                Properties: create
        topEdge (Queryable[int]?): Top edge position of the window.  
                Properties: create, query, edit
        topLeftCorner (Queryable[Tuple[int, int]]?): Top and left edge position of the window.  
                Properties: create, query, edit
        width (Queryable[int]?): Width of the window.  
                Properties: create, query, edit
        widthHeight (Queryable[Tuple[int, int]]?): Width and height of the window.  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def workspaceLayoutManager(*, edit: bool = ..., query: bool = ..., collapseMainWindowControls: Tuple[str, bool] = ..., current: bool = ..., delete: str = ..., i: str = ..., listLayouts: bool = ..., listModuleLayouts: bool = ..., listUserLayouts: bool = ..., modified: str = ..., parentWorkspaceControl: str = ..., reset: bool = ..., restoreMainWindowControls: bool = ..., save: bool = ..., saveAs: str = ..., setCurrent: str = ..., setCurrentCallback: str = ..., setModifiedCallback: str = ..., type: str = ...) -> Union[List[str], bool]:
    """The Workspace Layout Manager loads and saves the layout of the various toolbars and windows in the user interface.
    This command allows listing and managing their properties.
    Args:
        collapseMainWindowControls (Tuple[str, bool]?): Saves main window layout and collapses all other controls in main window except the given one (first parameter)  
                if it does not have any size constraint. Second parameter specifies if main window UI elements should be hidden or not.  
                Properties: create
        current (bool?): Get the name of the current layout.  
                Properties: create, query
        delete (str?): Delete the given workspace. The string is the name of the layout, not the file name.  
                Properties: create
        i (str?): Import the given workspace file to the workspaces directory. The string is an absolute path.  
                Properties: create
        listLayouts (bool?): List the names of all registered layouts.  
                Properties: create
        listModuleLayouts (bool?): List the names of module layouts.  
                Properties: create
        listUserLayouts (bool?): List the names of user layouts.  
                Properties: create
        modified (str?): Check whether or not the specified layout has been modified.  
                Properties: create
        parentWorkspaceControl (str?): Returns the parent workspace control of the given UI (panel) or an empty string if it does not exist.  
                Properties: create
        reset (bool?): Reset the current workspace to its original layout. Factory layouts will be reverted to default while user layouts will be reloaded from disk.  
                Properties: create
        restoreMainWindowControls (bool?): Restores the main window layout to the one saved with the -cmw/-collapseMainWindowControls flag.  
                The loaded workspace file will be deleted once it is restored.  
                Properties: create
        save (bool?): Save the current layout.  
                Properties: create
        saveAs (str?): Save the current layout under the specified name.  
                Properties: create
        setCurrent (str?): Load the given workspace.  The string is the name of the layout, not the file name.  
                Properties: create
        setCurrentCallback (str?): MEL only.  The string is interpreted as a MEL callback, which is called  
                each time a layout is set as current (with -setCurrent flag).  
                The callback is of the form:  
              
                global proc MySetCurrentCallback(string $layoutName)  
                Properties: create
        setModifiedCallback (str?): MEL only.  The string is interpreted as a MEL callback, which is called  
                each time a layout is modified or restored, that is, each time the -modified flag value changes.  
                The callback is of the form:  
              
                global proc MySetModifiedCallback()  
                Properties: create
        type (str?): Get the type of the specified layout: FACTORY, FACTORY_OVERRIDE, MODULE, MODULE_OVERRIDE or USER.  
                Properties: create

    Returns:
        List[str]: depending on arguments

    Example:
    """

def workspacePanel(arg0: str = ..., /, *, edit: bool = ..., query: bool = ..., defineTemplate: str = ..., exists: bool = ..., mainWindow: bool = ..., useTemplate: str = ...) -> Union[str, bool]:
    """Workspace panel.
    Args:
        defineTemplate (str?): Puts the command in a mode where any other flags and arguments are  
                parsed and added to the command template specified in the argument.  
                They will be used as default arguments in any subsequent  
                invocations of the command when templateName is set as the  
                current template.  
                Properties: create
        exists (bool?): Returns whether the  
                specified object exists or not. Other flags are ignored.  
                Properties: create
        mainWindow (bool?): Main window for the application.  The main window  
                has an 'Exit' item in the Window Manager menu.  By default, the  
                first created window becomes the main window.  
                Properties: create, query, edit
        useTemplate (str?): Forces the command to use a command template other than  
                the current one.  
                Properties: create

    Returns:
        str: Full path name to the workspace panel.

    Example:
    """

def wrinkle(*args: str, axis: Tuple[float, float, float] = ..., branchCount: int = ..., branchDepth: int = ..., center: Tuple[float, float, float] = ..., crease: Multiuse[str] = ..., dropoffDistance: float = ..., envelope: float = ..., randomness: float = ..., style: str = ..., thickness: float = ..., uvSpace: Tuple[float, float, float, float, float] = ..., wrinkleCount: int = ..., wrinkleIntensity: float = ...) -> List[str]:
    """The wrinkle command is used to create a network of wrinkles on a surface.
    It automatically creates a network of wrinkle curves that control a wire
    deformer. The wrinkle curves are attached to a cluster deformer.
    Args:
        axis (Tuple[float, float, float]?): Specifies the plane of the wrinkle.  
                Properties: create
        branchCount (int?): Specifies the number of branches per wrinkle. Default is 2.  
                Properties: create
        branchDepth (int?): Specifies the depth of the branching. Default is 0.  
                Properties: create
        center (Tuple[float, float, float]?): Specifies the center of the wrinkle.  
                Properties: create
        crease (Multiuse[str]?): Specifies an existing curve to serve as the wrinkle.  
                Properties: create, multiuse
        dropoffDistance (float?): Specifies the dropoff distance around the center.  
                Properties: create
        envelope (float?): The envelope globally attenuates the amount of deformation. Default is 1.0.  
                Properties: create
        randomness (float?): Amount of randomness. Default is 0.2.  
                Properties: create
        style (str?): Specifies the wrinkle style. Valid values are "radial" or "tangential"  
                Properties: create
        thickness (float?): Wrinkle thickness. Default is 1.0.  
                Properties: create
        uvSpace (Tuple[float, float, float, float, float]?): 1/2 length, 1/2 breadth, rotation angle, center u, v  
                definition of a patch in uv space where the wrinkle is  
                to be constructed.  
                Properties: create
        wrinkleCount (int?): Specifies the number of wrinkle lines to be generated.  
                Default is 3.  
                Properties: create
        wrinkleIntensity (float?): Increasing the intensity makes it more wrinkly. Default is 0.5.  
                Properties: create

    Returns:
        List[str]: List of clusters created followed by list of wire deformers created.

    Example:
    """

def wrinkleContext(*args: Any, edit: bool = ..., query: bool = ..., branchCount: Queryable[int] = ..., branchDepth: Queryable[int] = ..., exists: bool = ..., history: bool = ..., image1: Queryable[str] = ..., image2: Queryable[str] = ..., image3: Queryable[str] = ..., name: str = ..., randomness: Queryable[float] = ..., style: Queryable[str] = ..., thickness: Queryable[float] = ..., wrinkleCount: Queryable[int] = ..., wrinkleIntensity: Queryable[float] = ...) -> Union[str, int, float]:
    """This command creates a context that creates wrinkles.
    Args:
        branchCount (Queryable[int]?): Set the number of branches spawned from a crease for radial wrinkles.  
                Default is 2.  
                Properties: create, query, edit
        branchDepth (Queryable[int]?): Set the depth of branching for radial wrinkles.  
                Defaults to 0.  
                Properties: create, query, edit
        exists (bool?): Returns true or false depending upon whether the  
                specified object exists. Other flags are ignored.  
                Properties: create
        history (bool?): If this is a tool command, turn the construction history on  
                for the tool in question.  
                Properties: create
        image1 (Queryable[str]?): First of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image2 (Queryable[str]?): Second of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        image3 (Queryable[str]?): Third of three possible icons representing the tool  
                associated with the context.  
                Properties: create, query, edit
        name (str?): If this is a tool command, name the tool appropriately.  
                Properties: create
        randomness (Queryable[float]?): Set the deviation of the wrinkle creases from straight lines and  
                other elements of the wrinkle structure.  
                Defaults to 0.2.  
                Properties: create, query, edit
        style (Queryable[str]?): Set the wrinkle characteristic shape."lines"|"radial"|"custom.  
                Default is "radial".  
                Properties: create, query, edit
        thickness (Queryable[float]?): Set the thickness of wrinkle creases by setting the dropoff  
                distance on the underlying wires.  
                Properties: create, query, edit
        wrinkleCount (Queryable[int]?): Set the number of wrinkle creases.  
                Default is 3.  
                Properties: create, query, edit
        wrinkleIntensity (Queryable[float]?): Set the depth intensity of the wrinkle furrows.  
                Defaults to 0.5.  
                Properties: create, query, edit

    Returns:
        str: The name of the context created

    Example:
    """

def writeTake(*args: Any, angle: str = ..., device: str = ..., linear: str = ..., noTime: bool = ..., precision: int = ..., take: str = ..., virtualDevice: str = ...) -> bool:
    """This action writes a take from a device with recorded data to a
    take (.mov) file. The writeTake action can also write the virtual
    definition of a device.See also: recordDevice, readTake, defineVirtualDevice
    Args:
        angle (str?): Sets the angular unit used in the take.  
                Valid strings are [deg|degree|rad|radian].   
                C: The default is the current user angular unit.  
                Properties: create
        device (str?): Specifies the device that contains the take. This is a required  
                argument. If the device does not contain a take, the action will  
                fail.  
                Properties: create
        linear (str?): Sets the linear unit used in the take. Valid strings are  
                [mm|millimeter|cm|centimeter|m|meter|km|kilometer|in|inch|ft|foot|yd|yard|mi|mile]   
                C: The default is the current user linear unit.  
                Properties: create
        noTime (bool?): The take (.mov) file will not contain time stamps.   
                C: The default is to put time stamps in the take file.  
                Properties: create
        precision (int?): Sets the number of digits to the right of the decimal place in  
                the take file.  
                C: The default is 6.  
                Properties: create
        take (str?): Write out the take to a file with the specified name.  
                Properties: create
        virtualDevice (str?): Writes out the virtual device definition to a mel script with the  
                specified file name.  
                Properties: create

    Returns:
        bool:

    Example:
    """

def xform(*args: str, query: bool = ..., absolute: bool = ..., boundingBox: bool = ..., boundingBoxInvisible: bool = ..., centerPivots: bool = ..., centerPivotsOnComponents: bool = ..., deletePriorHistory: bool = ..., euler: bool = ..., matrix: Queryable[Tuple[float, float, float, float, float, float, float, float, float, float, float, float, float, float, float, float]] = ..., objectSpace: bool = ..., pivots: Queryable[Tuple[float, float, float]] = ..., preserve: bool = ..., preserveUV: bool = ..., reflection: bool = ..., reflectionAboutBBox: bool = ..., reflectionAboutOrigin: bool = ..., reflectionAboutX: bool = ..., reflectionAboutY: bool = ..., reflectionAboutZ: bool = ..., reflectionTolerance: float = ..., relative: bool = ..., rotateAxis: Queryable[Tuple[float, float, float]] = ..., rotateOrder: Queryable[str] = ..., rotatePivot: Queryable[Tuple[float, float, float]] = ..., rotateTranslation: Queryable[Tuple[float, float, float]] = ..., rotation: Queryable[Tuple[float, float, float]] = ..., scale: Queryable[Tuple[float, float, float]] = ..., scalePivot: Queryable[Tuple[float, float, float]] = ..., scaleTranslation: Queryable[Tuple[float, float, float]] = ..., shear: Queryable[Tuple[float, float, float]] = ..., translation: Queryable[Tuple[float, float, float]] = ..., worldSpace: bool = ..., worldSpaceDistance: bool = ..., zeroTransformPivots: bool = ...) -> Union[bool, Tuple[float, float, float, float, float, float, float, float, float, float, float, float, float, float, float, float], Tuple[float, float, float], str]:
    """This command can be used query/set any element in a
    transformation node. It can also be used to query some values
    that cannot be set directly such as the transformation matrix
    or the bounding box. It can also set both pivot points to
    convenient values.All values are specified in transformation coordinates.
    (attribute-space)In addition, the attributes are applied/returned in the order in
    which they appear in the flags section. (which corresponds to the
    order they appear in the transformation matrix as given below)move, rotate, scaleThe transformation matrix for a node is built by post-multiplying
    the following matrices in the given order (Note: rotations are
    applied according to the rotation order parameter and the 6
    different rotation possibilities are not shown below)
    Args:
        absolute (bool?): perform absolute transformation (default)  
                Properties: create
        boundingBox (bool?): Returns the bounding box of an object. The values  
                returned are in the following order:  
                xmin ymin zmin xmax ymax zmax.  
                Properties: query
        boundingBoxInvisible (bool?): Returns the bounding box of an object.  
                This includes the bounding boxes of all invisible  
                children which are not included using the  
                boundingBox flag. The values returned are in  
                following order: xmin ymin zmin xmax ymax zmax.  
                Properties: query
        centerPivots (bool?): Set pivot points to the center of the object's  
                bounding box. (see -p flag)  
                Properties: create
        centerPivotsOnComponents (bool?): Set pivot points to the center of the component's  
                bounding box. (see -p flag)  
                Properties: create
        deletePriorHistory (bool?): If true then delete the construction history before the operation is performed.  
                Properties: create
        euler (bool?): modifer for -relative flag that specifies rotation  
                values should be added to current XYZ rotation values.  
                Properties: create
        matrix (Queryable[Tuple[float, float, float, float, float, float, float, float, float, float, float, float, float, float, float, float]]?): Sets/returns the composite transformation matrix.  
                *Note* the matrix is represented by 16 double  
                arguments that are specified in row order.  
                Properties: create, query
        objectSpace (bool?): treat values as object-space transformation values  
                (only works for pivots, translations, rotation, rotation  
                axis, matrix, and bounding box flags)  
                Properties: create, query
        pivots (Queryable[Tuple[float, float, float]]?): convenience method that changes both the rotate and  
                scale pivots simultaneously. (see -rp -sp flags for  
                more info)  
                Properties: create, query
        preserve (bool?): preserve overall transformation. used to prevent object  
                from "jumping" when changing pivots or rotation order. the  
                default value is true. (used with -sp, -rp, -roo, -cp, -ra)  
                Properties: create
        preserveUV (bool?): When true, UV values on rotated components are projected across the rotation  
                in 3d space. For small edits, this will freeze the world space texture mapping  
                on the object.  
                When false, the UV values will not change for a selected vertices.  
                Default is false.  
                Properties: create
        reflection (bool?): To move the corresponding symmetric components also.  
                Properties: create
        reflectionAboutBBox (bool?): Sets the position of the reflection axis  at the geometry bounding box  
                Properties: create
        reflectionAboutOrigin (bool?): Sets the position of the reflection axis  at the origin  
                Properties: create
        reflectionAboutX (bool?): Specifies the X=0 as reflection plane  
                Properties: create
        reflectionAboutY (bool?): Specifies the Y=0 as reflection plane  
                Properties: create
        reflectionAboutZ (bool?): Specifies the Z=0 as reflection plane  
                Properties: create
        reflectionTolerance (float?): Specifies the tolerance to findout the corresponding reflected components  
                Properties: create
        relative (bool?): perform relative transformation  
                Properties: create
        rotateAxis (Queryable[Tuple[float, float, float]]?): rotation axis orientation (when used with  
                the -p flag the overall rotation is preserved  
                by modifying the rotation to compensate for  
                the axis rotation)  
                Properties: create, query
        rotateOrder (Queryable[str]?): rotation order (when used with the -p flag the  
                overall rotation is preserved by modifying the  
                local rotation to be quivalent to the old one)  
                Valid values for this flag are  
                <xyz | yzx | zxy | xzy | yxz | zyx>  
                Properties: create, query
        rotatePivot (Queryable[Tuple[float, float, float]]?): rotate pivot point transformation (when used with  
                the -p flag the overall transformation is preserved  
                by modifying the rotation translation)  
                Properties: create, query
        rotateTranslation (Queryable[Tuple[float, float, float]]?): rotation translation  
                Properties: create, query
        rotation (Queryable[Tuple[float, float, float]]?): rotation transformation  
                Properties: create, query
        scale (Queryable[Tuple[float, float, float]]?): scale transformation  
                Properties: create, query
        scalePivot (Queryable[Tuple[float, float, float]]?): scale pivot point transformation (when used with  
                the -p flag the overall transformation is preserved  
                by modifying the scale translation)  
                Properties: create, query
        scaleTranslation (Queryable[Tuple[float, float, float]]?): scale translation  
                Properties: create, query
        shear (Queryable[Tuple[float, float, float]]?): shear transformation.  
                The values represent the shear <xy,xz,yz>  
                Properties: create, query
        translation (Queryable[Tuple[float, float, float]]?): translation  
                Properties: create, query
        worldSpace (bool?): (works for pivots, translations, rotation, rotation  
                axis, matrix, and bounding box flags). Note that, when  
                querying the scale, that this calculation is cumulative  
                and is only valid if there are all uniform scales and  
                no rotation. In a hierarchy with non-uniform scale  
                and rotation, this value may not correspond entirely with  
                the perceived global scale.  
                Properties: create, query
        worldSpaceDistance (bool?): Values for -sp, -rp, -st, -rt, -t, -piv flags  
                are treated as world space distances to move along the  
                local axis. (where the local axis depends on whether  
                the command is operating in local-space or object-space.  
                This flag has no effect for world space.  
                Properties: create, query
        zeroTransformPivots (bool?): reset pivot points and pivot translations without  
                changing the overall matrix by applying these values  
                into the translation channel.  
                Properties: create

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def xformConstraint(*, edit: bool = ..., query: bool = ..., alongNormal: Queryable[int] = ..., live: bool = ..., type: Queryable[str] = ...) -> Union[bool, int, str]:
    """This command allows you to change the transform constraint used by the
    transform tools during component transforms.
    Args:
        alongNormal (Queryable[int]?): When set the transform constraint will first be applied along the  
                vertex normals of the components being transformed. When queried,  
                returns the current state of this option.  
                Properties: query, edit
        live (bool?): Query-only flag that can be used to check whether the current  
                live surface will be used as a transform constraint.  
                Properties: query
        type (Queryable[str]?): Set the type of transform constraint to use. When queried,  
                returns the current transform constraint as a string.  
              
                none - no constraint  
                surface - constrain components to their surface  
                edge - constrain components to surface edges  
                Properties: create, query, edit

    Returns:
        bool: In query mode, return type is based on queried flag.

    Example:
    """

def xpmPicker(*args: Any, fileName: str = ..., parent: str = ...) -> str:
    """Open a dialog and ask you to choose a xpm file
    Args:
        fileName (str?): default filename to display in dialog  
                Properties: create
        parent (str?): parent window for modal dialog  
                Properties: create

    Returns:
        str: The full name of the xpm file

    Example:
    """

